
//
// @(#)btyaccpar, based on byacc 1.8 (Berkeley)
// Parser skeleton modified for use in the Firebird project by Nickolay Samofatov
//
#define YYBTYACC 1

#include "firebird.h"

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "../dsql/Nodes.h"
#include "../dsql/AggNodes.h"
#include "../dsql/DdlNodes.h"
#include "../dsql/BoolNodes.h"
#include "../dsql/ExprNodes.h"
#include "../dsql/PackageNodes.h"
#include "../dsql/StmtNodes.h"
#include "../dsql/WinNodes.h"
#include "../jrd/RecordSourceNodes.h"
#include "../common/classes/Nullable.h"
#include "gen/parse.h"
#include "../dsql/Parser.h"

/*
*	PROGRAM:	Dynamic SQL runtime support
*	MODULE:		parse.y
*	DESCRIPTION:	Dynamic SQL parser
*
* The contents of this file are subject to the Interbase Public
* License Version 1.0 (the "License"); you may not use this file
* except in compliance with the License. You may obtain a copy
* of the License at http://www.Inprise.com/IPL.html
*
* Software distributed under the License is distributed on an
* "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
* or implied. See the License for the specific language governing
* rights and limitations under the License.
*
* The Original Code was created by Inprise Corporation
* and its predecessors. Portions created by Inprise Corporation are
* Copyright (C) Inprise Corporation.
*
* All Rights Reserved.
* Contributor(s): ______________________________________.
*
* 2002-02-24 Sean Leyne - Code Cleanup of old Win 3.1 port (WINDOWS_ONLY)
* 2001.05.20 Neil McCalden: Allow a udf to be used in a 'group by' clause.
* 2001.05.30 Claudio Valderrama: DROP TABLE and DROP VIEW lead now to two
*   different node types so DDL can tell which is which.
* 2001.06.13 Claudio Valderrama: SUBSTRING is being surfaced.
* 2001.06.30 Claudio valderrama: Feed (line,column) for each node. See node.h.
* 2001.07.10 Claudio Valderrama: Better (line,column) report and "--" for comments.
* 2001.07.28 John Bellardo: Changes to support parsing LIMIT and FIRST
* 2001.08.03 John Bellardo: Finalized syntax for LIMIT, change LIMIT to SKIP
* 2001.08.05 Claudio Valderrama: closed Bug #448062 and other spaces that appear
*   in rdb$*_source fields when altering domains plus one unexpected null pointer.
* 2001.08.12 Claudio Valderrama: adjust SUBSTRING's starting pos argument here
*   and not in gen.c; this closes Bug #450301.
* 2001.10.01 Claudio Valderrama: enable explicit GRANT...to ROLE role_name.
* 2001.10.06 Claudio Valderrama: Honor explicit USER keyword in GRANTs and REVOKEs.
* 2002.07.05 Mark O'Donohue: change keyword DEBUG to KW_DEBUG to avoid
*			clashes with normal DEBUG macro.
* 2002.07.30 Arno Brinkman:
* 2002.07.30 	Let IN predicate handle value_expressions
* 2002.07.30 	tokens CASE, NULLIF, COALESCE added
* 2002.07.30 	See block < CASE expression > what is added to value as case_expression
* 2002.07.30 	function is split up into aggregate_function, numeric_value_function, string_value_function, generate_value_function
* 2002.07.30 	new group_by_function and added to grp_column_elem
* 2002.07.30 	cast removed from function and added as cast_specification to value
* 2002.08.04 Claudio Valderrama: allow declaring and defining variables at the same time
* 2002.08.04 Dmitry Yemanov: ALTER VIEW
* 2002.08.06 Arno Brinkman: ordinal added to grp_column_elem for using positions in group by
* 2002.08.07 Dmitry Yemanov: INT64/LARGEINT are replaced with BIGINT and available in dialect 3 only
* 2002.08.31 Dmitry Yemanov: allowed user-defined index names for PK/FK/UK constraints
* 2002.09.01 Dmitry Yemanov: RECREATE VIEW
* 2002.09.28 Dmitry Yemanov: Reworked internal_info stuff, enhanced
*							exception handling in SPs/triggers,
*							implemented ROWS_AFFECTED system variable
* 2002.10.21 Nickolay Samofatov: Added support for explicit pessimistic locks
* 2002.10.29 Nickolay Samofatov: Added support for savepoints
* 2002.12.03 Dmitry Yemanov: Implemented ORDER BY clause in subqueries.
* 2002.12.18 Dmitry Yemanov: Added support for SQL-compliant labels and LEAVE statement
* 2002.12.28 Dmitry Yemanov: Added support for parametrized events.
* 2003.01.14 Dmitry Yemanov: Fixed bug with cursors in triggers.
* 2003.01.15 Dmitry Yemanov: Added support for runtime trigger action checks.
* 2003.02.10 Mike Nordell  : Undefined Microsoft introduced macros to get a clean compile.
* 2003.05.24 Nickolay Samofatov: Make SKIP and FIRST non-reserved keywords
* 2003.06.13 Nickolay Samofatov: Make INSERTING/UPDATING/DELETING non-reserved keywords
* 2003.07.01 Blas Rodriguez Somoza: Change DEBUG and IN to avoid conflicts in win32 build/bison
* 2003.08.11 Arno Brinkman: Changed GROUP BY to support all expressions and added "AS" support
*						   with table alias. Also removed group_by_function and ordinal.
* 2003.08.14 Arno Brinkman: Added support for derived tables.
* 2003.10.05 Dmitry Yemanov: Added support for explicit cursors in PSQL.
* 2004.01.16 Vlad Horsun: added support for default parameters and
*   EXECUTE BLOCK statement
* Adriano dos Santos Fernandes
*/

#include "firebird.h"
#include "dyn_consts.h"
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <stdarg.h>

#include "gen/iberror.h"
#include "../dsql/dsql.h"
#include "ibase.h"
#include "../jrd/flags.h"
#include "../jrd/jrd.h"
#include "../jrd/DataTypeUtil.h"
#include "../dsql/errd_proto.h"
#include "../dsql/make_proto.h"
#include "../yvalve/gds_proto.h"
#include "../jrd/err_proto.h"
#include "../common/intlobj_new.h"
#include "../jrd/Attachment.h"
#include "../common/StatusArg.h"

/* This is needed here to provide backward compatibility when working with SSPI plugin*/
#include "../auth/trusted/AuthSspi.h"

/* since UNIX isn't standard, we have to define*/
/* stuff which is in <limits.h> (which isn't available on all UNIXes...*/

const long SHRT_POS_MAX			= 32767;
const long SHRT_UNSIGNED_MAX	= 65535;
const long SHRT_NEG_MAX			= 32768;
const int POSITIVE	= 0;
const int NEGATIVE	= 1;
const int UNSIGNED	= 2;

/*const int MIN_CACHE_BUFFERS	= 250;*/
/*const int DEF_CACHE_BUFFERS	= 1000;*/

#define YYSTYPE YYSTYPE
#if defined(DEBUG) || defined(DEV_BUILD)
#define YYDEBUG		1
#endif

#define YYREDUCEPOSNFUNC yyReducePosn
#define YYREDUCEPOSNFUNCARG NULL


/* ASF: Inherited attributes (aka rule parameters) are executed even when in trial mode, but action*/
/* rules ({}) are executed only when in full parse mode. NOTRIAL should be used to avoid segfaults*/
/* due to accessing invalid pointers in parameters (not yet returned from action rules).*/
#define NOTRIAL(x) (yytrial ? NULL : (x))


inline unsigned trigger_type_suffix(const unsigned slot1, const unsigned slot2, const unsigned slot3)
{
	return ((slot1 << 1) | (slot2 << 3) | (slot3 << 5));
}


#include "../dsql/chars.h"

using namespace Jrd;
using namespace Firebird;

static int yylhs[] = {                                        -1,
    0,    0,    1,    1,    1,    1,    2,    2,    2,    2,
    2,    2,    2,    2,    2,    3,    3,    3,    3,    3,
    3,    3,    3,    3,    3,    4,    4,    4,    5,    5,
    5,    5,    5,    5,    5,    5,  650,  651,    6,  652,
  654,    7,    7,    7,    7,    7,    7,    7,  655,    7,
    7,  656,  657,    7,    8,    8,    8,    8,    8,    8,
    8,    8,    8,    8,    8,    8,    8,  653,  653,    9,
    9,  658,    9,   10,  659,   10,   11,   12,   13,   13,
   13,   13,   13,   14,   14,  660,  660,   15,   15,   16,
   16,   16,   17,   17,   18,   18,   19,   19,   19,   20,
   20,   21,   21,   22,   22,  661,  661,   23,   23,  662,
   24,  663,  664,   25,   25,   25,   25,   25,   25,   25,
  665,   25,   25,  666,   25,   25,   26,   26,   27,   27,
  667,   28,   28,  668,   28,   28,   29,   29,   29,   29,
   29,   29,   29,   30,   30,   30,   31,  669,   31,   32,
   32,   33,   33,   34,   34,   34,   35,   36,   36,  670,
  671,  672,   37,   38,   38,   38,   39,  673,   39,  674,
   39,   40,  675,   40,   41,   42,   42,   42,   42,  676,
   43,  677,   43,   44,   44,   45,   45,   45,   45,   45,
   46,   47,   47,   48,   49,  678,  679,   49,   49,   49,
   49,   49,   49,   49,   49,   49,   49,   49,   49,   49,
   49,   49,   49,   49,  680,   49,  681,   49,   50,   51,
   51,   51,   51,   51,   51,   51,   51,   51,   51,   51,
   51,   52,   53,   53,   53,   53,   53,   53,   53,   53,
   53,   53,   53,   54,   55,   56,   57,   57,   58,   58,
   58,  683,  684,   59,   60,   60,   60,   61,   61,   62,
   62,   63,  687,   63,   64,   64,  689,  690,   65,   66,
   66,   67,  691,   67,   68,   68,  688,  688,   69,   70,
   70,  692,   71,  693,  694,   72,   73,  695,   73,   74,
   74,   75,   76,  696,  696,  697,   77,   78,   78,   79,
   79,   79,  698,   80,   81,   81,   82,   82,   83,   84,
   84,   85,   86,   86,   86,   86,  699,  700,   87,   88,
   88,   88,  701,   89,   90,   91,  702,   91,   92,  703,
  704,  705,  706,   93,   94,   94,   94,   95,   95,   96,
  707,   96,   97,   97,   97,   98,   98,   99,   99,  100,
  100,  101,  101,  102,  103,  103,  103,  103,  103,  104,
  104,  104,  708,  709,  710,  105,  685,  685,  106,  107,
  107,  108,  711,  108,  109,  109,  109,  109,  109,  109,
  109,  109,  110,  110,  111,  111,  112,  112,  112,  112,
  712,  713,  113,  114,  114,  115,  714,  115,  116,  116,
  715,  715,  715,  686,  686,  686,  716,  717,  718,  117,
  118,  719,  720,  118,  119,  119,  120,  120,  121,  121,
  122,  122,  721,  722,  123,  723,  124,  724,  124,  125,
  125,  125,  125,  126,  126,  126,  127,  127,  725,  128,
  128,  726,  727,  129,  728,  129,  129,  129,  729,  730,
  130,  131,  131,  132,  731,  132,  133,  133,  134,  134,
  135,  732,  732,  733,  682,  682,  136,  136,  137,  137,
  138,  138,  138,  138,  139,  139,  139,  139,  139,  139,
  140,  734,  140,  141,  735,  141,  142,  143,  143,  143,
  143,  143,  736,  144,  145,  145,  146,  146,  146,  146,
  147,  147,  148,  148,  148,  148,  148,  149,  150,  151,
  151,  151,  151,  152,  152,  153,  154,  737,  738,  739,
  155,  156,  157,  158,  158,  158,  159,  159,  160,  160,
  161,  162,  162,  163,  164,  165,  165,  165,  166,  166,
  167,  168,  740,  169,  170,  170,  170,  171,  171,  172,
  172,  173,  174,  175,  176,  176,  177,  177,  178,  178,
  179,  180,  181,  181,  182,  182,  183,  183,  184,  184,
  184,  184,  185,  186,  186,  187,  187,  188,  188,  189,
  189,  190,  190,  191,  191,  191,  742,  743,  744,  192,
  745,  746,  193,  194,  194,  195,  741,  741,  196,  197,
  197,  197,  198,  198,  199,  200,  200,  200,  201,  201,
  202,  202,  203,  203,  203,  203,  203,  203,  203,  203,
  203,  203,  203,  203,  203,  203,  203,  203,  203,  203,
  203,  203,  203,  204,  204,  205,  205,  205,  205,  205,
  206,  207,  207,  207,  208,  747,  748,  209,  210,  210,
  211,  211,  212,  749,  750,  751,  213,  214,  215,  216,
  752,  216,  216,  217,  217,  218,  218,  219,  219,  220,
  221,  221,  753,  222,  222,  223,  223,  223,  223,  223,
  223,  223,  223,  224,  224,  225,  226,  227,  228,  229,
  229,  229,  229,  230,  231,  231,  232,  232,  233,  234,
  234,  235,  235,  236,  237,  237,  754,  755,  238,  756,
  239,  757,  239,  240,  240,  240,  240,  240,  241,  241,
  241,  242,  243,  758,  759,  244,  244,  245,  245,  245,
  245,  245,  245,  246,  246,  247,  247,  247,  248,  248,
  248,  760,  761,  762,  249,  250,  250,  251,  251,  252,
  253,  254,  255,  256,  256,  257,  257,  763,  764,  258,
  765,  259,  259,  260,  261,  261,  261,  262,  262,  262,
  263,  264,  264,  264,  264,  264,  265,  265,  266,  266,
  266,  266,  266,  266,  266,  266,  266,  266,  266,  266,
  266,  266,  266,  266,  266,  266,  266,  266,  266,  266,
  266,  266,  266,  266,  266,  266,  266,  266,  266,  266,
  266,  266,  266,  266,  266,  266,  266,  266,  266,  266,
  266,  266,  266,  267,  267,  268,  268,  268,  268,  268,
  268,  268,  268,  268,  268,  268,  268,  268,  268,  268,
  269,  269,  270,  270,  271,  766,  271,  271,  271,  271,
  271,  767,  271,  271,  271,  271,  271,  271,  271,  271,
  271,  271,  271,  271,  271,  271,  768,  769,  272,  273,
  770,  273,  274,  274,  274,  274,  274,  274,  274,  274,
  274,  275,  275,  276,  276,  276,  276,  276,  276,  276,
  276,  276,  276,  276,  276,  276,  772,  276,  276,  276,
  276,  276,  276,  276,  277,  278,  278,  278,  278,  278,
  278,  278,  278,  278,  278,  278,  278,  278,  278,  278,
  278,  278,  278,  278,  278,  278,  278,  278,  278,  278,
  278,  278,  278,  278,  278,  278,  278,  278,  278,  278,
  278,  278,  278,  278,  278,  278,  278,  278,  278,  278,
  278,  278,  278,  278,  278,  278,  278,  278,  278,  278,
  278,  278,  278,  278,  278,  278,  278,  278,  278,  278,
  278,  278,  278,  278,  278,  278,  278,  278,  278,  278,
  278,  278,  278,  278,  278,  278,  278,  278,  278,  278,
  278,  278,  278,  278,  278,  278,  278,  278,  278,  771,
  771,  279,  279,  773,  280,  280,  281,  281,  282,  282,
  283,  283,  284,  284,  285,  285,  285,  286,  286,  287,
  288,  288,  289,  289,  290,  291,  291,  292,  292,  293,
  293,  774,  294,  294,  294,  294,  294,  294,  775,  294,
  294,  294,  294,  294,  294,  294,  294,  294,  295,  295,
  296,  296,  297,  297,  298,  299,  299,  299,  300,  300,
  301,  301,  301,  301,  302,  303,  303,  303,  303,  303,
  303,  303,  303,  303,  303,  303,  303,  303,  303,  303,
  303,  303,  303,  303,  303,  303,  304,  304,  304,  305,
  305,  306,  306,  307,  307,  308,  308,  308,  309,  309,
  310,  310,  311,  311,  312,  312,  313,  313,  314,  314,
  314,  314,  314,  314,  314,  314,  314,  314,  314,  314,
  314,  314,  314,  776,  776,  777,  777,  778,  779,  315,
  315,  315,  315,  316,  316,  317,  317,  317,  318,  318,
  319,  319,  319,  320,  320,  320,  321,  321,  321,  784,
  784,  784,  783,  783,  780,  780,  780,  781,  782,  782,
  322,  323,  323,  324,  324,  324,  785,  785,  325,  325,
  325,  325,  326,  326,  327,  327,  327,  328,  329,  330,
  330,  331,  787,  787,  332,  333,  786,  786,  334,  334,
  788,  788,  789,  790,  335,  336,  337,  337,  338,  339,
  791,  792,  340,  341,  342,  342,  343,  343,  344,  344,
  344,  344,  344,  344,  345,  345,  346,  793,  346,  347,
  348,  348,  349,  349,  349,  349,  350,  350,  350,  350,
  350,  351,  352,  352,  353,  353,  354,  794,  354,  355,
  355,  355,  355,  355,  355,  355,  355,  355,  355,  795,
  796,  355,  356,  356,  357,  357,  357,  358,  358,  358,
  358,  359,  359,  360,  360,  360,  360,  361,  361,  361,
  362,  362,  363,  363,  364,  365,  365,  366,  366,  367,
  368,  368,  368,  368,  368,  368,  797,  798,  369,  370,
  370,  371,  372,  372,  372,  372,  372,  372,  372,  372,
  372,  372,  372,  372,  372,  373,  374,  374,  374,  375,
  375,  375,  376,  377,  377,  378,  378,  379,  380,  380,
  381,  381,  382,  382,  383,  383,  384,  384,  384,  385,
  385,  386,  387,  388,  389,  389,  389,  390,  391,  392,
  392,  392,  392,  393,  393,  393,  394,  394,  394,  395,
  395,  396,  396,  397,  397,  398,  398,  399,  399,  801,
  801,  400,  401,  401,  402,  402,  403,  403,  403,  403,
  404,  405,  406,  406,  407,  407,  408,  408,  409,  409,
  409,  410,  411,  412,  412,  413,  414,  415,  415,  415,
  415,  416,  416,  417,  417,  418,  419,  419,  419,  419,
  419,  802,  802,  420,  420,  421,  421,  422,  423,  423,
  424,  424,  425,  425,  426,  426,  427,  428,  428,  429,
  429,  804,  805,  430,  803,  803,  803,  803,  803,  803,
  431,  431,  432,  432,  433,  433,  434,  806,  807,  434,
  808,  434,  435,  435,  436,  809,  436,  437,  437,  438,
  439,  439,  440,  441,  441,  441,  442,  442,  443,  443,
  444,  444,  445,  445,  810,  810,  446,  446,  811,  811,
  447,  447,  447,  812,  448,  448,  448,  449,  450,  450,
  450,  451,  451,  452,  452,  813,  814,  453,  454,  454,
  815,  454,  454,  816,  817,  818,  455,  819,  820,  456,
  821,  457,  822,  457,  457,  457,  823,  458,  824,  458,
  459,  459,  460,  461,  462,  462,  825,  463,  464,  826,
  827,  828,  465,  466,  829,  466,  467,  467,  467,  468,
  469,  830,  470,  831,  470,  471,  471,  472,  472,  473,
  473,  474,  475,  475,  476,  832,  476,  477,  478,  478,
  479,  479,  479,  480,  481,  481,  482,  483,  483,  483,
  483,  483,  483,  483,  484,  484,  484,  484,  484,  484,
  484,  484,  484,  484,  484,  484,  485,  486,  486,  486,
  486,  486,  486,  486,  486,  487,  488,  488,  488,  489,
  489,  490,  490,  491,  491,  492,  492,  492,  493,  493,
  493,  493,  493,  493,  493,  493,  494,  494,  495,  496,
  497,  497,  497,  498,  499,  499,  499,  499,  500,  500,
  501,  833,  502,  835,  503,  836,  504,  837,  505,  834,
  834,  506,  506,  507,  838,  507,  508,  508,  508,  508,
  508,  508,  508,  508,  508,  839,  508,  509,  510,  510,
  511,  511,  840,  841,  842,  512,  843,  844,  513,  845,
  846,  514,  515,  847,  848,  849,  516,  517,  518,  518,
  519,  519,  519,  520,  520,  521,  521,  521,  521,  521,
  522,  522,  523,  523,  524,  524,  525,  525,  526,  526,
  527,  527,  528,  528,  528,  529,  529,  529,  529,  529,
  529,  529,  529,  529,  529,  529,  529,  529,  529,  529,
  529,  529,  529,  529,  529,  529,  529,  529,  529,  529,
  529,  529,  529,  529,  529,  530,  530,  531,  531,  531,
  531,  531,  532,  532,  533,  533,  534,  535,  535,  536,
  536,  537,  537,  537,  537,  537,  537,  538,  538,  538,
  538,  539,  540,  540,  540,  540,  540,  541,  541,  541,
  541,  541,  542,  542,  543,  544,  544,  545,  546,  546,
  546,  546,  546,  546,  546,  547,  547,  547,  547,  547,
  548,  548,  549,  550,  550,  551,  552,  553,  554,  555,
  555,  556,  557,  557,  557,  558,  558,  558,  559,  559,
  560,  560,  560,  560,  560,  560,  560,  560,  560,  560,
  560,  560,  560,  560,  560,  560,  560,  560,  560,  560,
  560,  560,  560,  560,  560,  560,  560,  560,  560,  561,
  561,  561,  561,  561,  561,  561,  561,  561,  561,  561,
  561,  561,  561,  561,  562,  562,  562,  563,  563,  563,
  564,  564,  565,  565,  566,  567,  567,  568,  850,  851,
  568,  852,  568,  569,  569,  570,  570,  570,  571,  571,
  571,  571,  572,  572,  572,  572,  573,  573,  573,  573,
  573,  574,  574,  575,  575,  576,  577,  577,  577,  578,
  579,  579,  580,  581,  581,  582,  582,  582,  582,  582,
  582,  582,  582,  582,  582,  582,  582,  582,  582,  582,
  582,  582,  582,  582,  582,  582,  582,  582,  582,  582,
  582,  582,  582,  582,  582,  582,  582,  582,  582,  582,
  582,  582,  582,  582,  582,  582,  582,  582,  582,  582,
  582,  582,  582,  582,  582,  582,  582,  582,  582,  582,
  582,  582,  582,  582,  582,  582,  582,  582,  582,  583,
  583,  583,  583,  583,  583,  583,  583,  583,  583,  583,
  583,  583,  583,  583,  583,  583,  584,  584,  585,  585,
  586,  586,  587,  587,  588,  588,  589,  589,  590,  590,
  591,  591,  592,  592,  593,  593,  594,  594,  595,  595,
  596,  596,  597,  597,  597,  598,  598,  598,  598,  599,
  599,  600,  600,  601,  601,  601,  601,  602,  602,  602,
  603,  603,  603,  603,  604,  605,  605,  606,  606,  606,
  606,  606,  607,  607,  853,  854,  855,  608,  609,  609,
  610,  610,  611,  611,  612,  612,  613,  614,  615,  616,
  616,  617,  617,  618,  618,  618,  618,  618,  618,  618,
  618,  618,  618,  618,  618,  800,  800,  799,  799,  619,
  619,  620,  621,  622,  622,  623,  623,  624,  625,  626,
  627,  628,  629,  630,  631,  632,  633,  634,  635,  636,
  637,  638,  639,  640,  641,  642,  643,  644,  645,  646,
  647,  648,  648,  649,  649,  649,  649,  649,  649,  649,
  649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
  649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
  649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
  649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
  649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
  649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
  649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
  649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
  649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
  649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
  649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
  649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
  649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
  649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
  649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
  649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
  649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
  649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
  649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
  649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
  649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
  649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
  649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
  649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
  649,  649,  649,  649,  649,  649,  649,  649,  649,  649,
  649,  649,  649,  649,  649,  649,  649,  649,
};
static int yylen[] = {                                         2,
    1,    2,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    0,    0,    4,    0,
    0,   10,   10,   10,   10,   10,   10,   10,    0,    8,
    8,    0,    0,    7,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    2,    1,    1,    0,    1,    1,
    2,    0,    2,    2,    0,    4,    1,    1,    1,    1,
    1,    2,    2,    2,    2,    0,    1,    2,    4,    1,
    2,    2,    2,    2,    2,    4,    1,    1,    1,    0,
    3,    0,    3,    0,    2,    2,    1,    1,    2,    0,
    4,    0,    0,   10,   10,   10,   10,   10,   10,   10,
    0,    8,    8,    0,    7,    6,    0,    3,    0,    3,
    0,    2,    2,    0,    4,    4,    2,    2,    2,    2,
    2,    2,    3,    1,    2,    2,    2,    0,    4,    1,
    2,    2,    4,    1,    2,    2,    2,    2,    3,    0,
    0,    0,   11,    1,    1,    5,    0,    0,    2,    0,
    4,    2,    0,    4,    2,    0,    2,    2,    1,    0,
    2,    0,    4,    2,    2,    0,    2,    2,    1,    3,
    9,    1,    1,    2,    2,    0,    0,    9,    2,    2,
    2,    4,    2,    2,    2,    2,    2,    2,    2,    2,
    2,    2,    2,    3,    0,    3,    0,    4,    2,    2,
    2,    2,    4,    2,    2,    2,    3,    2,    2,    2,
    2,    4,    2,    2,    2,    2,    2,    2,    2,    2,
    2,    3,    4,    2,    2,    2,    0,    1,    1,    1,
    4,    0,    0,    8,    0,    1,    1,    0,    1,    0,
    4,    0,    0,    2,    1,    2,    0,    0,    8,    0,
    2,    2,    0,    3,    1,    1,    0,    1,    2,    0,
    1,    2,    4,    0,    0,    4,    0,    0,    4,    2,
    2,    3,    3,    0,    1,    0,    4,    0,    4,    1,
    2,    2,    0,    4,    0,    4,    2,    2,    2,    0,
    2,    5,    1,    1,    2,    2,    0,    0,    4,    0,
    2,    2,    0,    6,    3,    2,    0,    4,    1,    0,
    0,    0,    0,   10,    0,    2,    5,    0,    2,    2,
    0,    3,    2,    2,    2,    2,    2,    2,    2,    2,
    2,    0,    1,    5,    3,    4,    2,    2,    2,    1,
    1,    1,    0,    0,    0,    6,    0,    1,    1,    0,
    2,    2,    0,    3,    3,    2,    2,    2,    2,    2,
    3,    4,    0,    2,    2,    3,    1,    4,    6,    3,
    0,    0,    5,    0,    2,    2,    0,    3,    3,    4,
    0,    1,    2,    0,    1,    1,    0,    0,    0,    9,
    0,    0,    0,    4,    1,    1,    3,    3,    0,    1,
    2,    2,    0,    0,    8,    0,    2,    0,    4,    0,
    1,    4,    4,    0,    3,    2,    2,    4,    0,    2,
    2,    0,    0,    7,    0,    7,    3,    2,    0,    0,
    7,    2,    1,    0,    0,    4,    3,    2,    3,    3,
    4,    1,    1,    3,    2,    1,    1,    1,    0,    2,
    1,    3,    6,    1,    1,    1,    1,    1,    1,    1,
    0,    0,    2,    2,    0,    3,    3,    1,    1,    5,
    2,    3,    0,    3,    0,    2,    3,    4,    8,    1,
    0,    4,    0,    1,    1,    2,    2,    3,    3,    1,
    2,    2,    2,    1,    1,    5,    3,    0,    0,    0,
    6,    1,    1,    0,    2,    4,    0,    5,    2,    4,
    3,    1,    4,    2,    2,    0,    2,    2,    1,    1,
    5,    3,    0,    8,    0,    2,    1,    5,    3,    0,
    2,    1,    1,    6,    1,    0,    1,    2,    3,    3,
    1,    1,    6,    5,    0,    1,    1,    2,    2,    3,
    2,    3,    2,    0,    1,    1,    2,    2,    2,    0,
    1,    1,    2,    4,    4,    4,    0,    0,    0,    8,
    0,    0,   10,    1,    1,    3,    0,    1,    7,    0,
    2,    1,    1,    1,    3,    0,    1,    2,    1,    2,
    2,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    2,    1,    1,    2,    1,    1,    1,    1,    1,
    5,    2,    3,    6,    1,    0,    0,    8,    2,    2,
    0,    1,    2,    0,    0,    0,    7,    3,    5,    1,
    0,    7,    7,    2,    4,    3,    4,    2,    4,    1,
    0,    2,    0,    3,    2,    5,    3,    3,    2,    2,
    3,    3,    3,    8,    6,    3,    0,    3,    2,    1,
    1,    3,    3,    7,    0,    2,    1,    2,    2,    0,
    1,    0,    1,    3,    1,    2,    0,    0,    6,    0,
    2,    0,    4,    2,    2,    2,    2,    1,    1,    1,
    1,    2,    2,    0,    0,    7,    3,    1,    1,    1,
    1,    2,    2,    5,    7,    0,    1,    3,    0,    2,
    4,    0,    0,    0,   10,    0,    4,    2,    4,    4,
    5,    1,    1,    0,    3,    5,    3,    0,    0,    4,
    0,    4,    5,    1,    1,    1,    0,    4,    2,    2,
    2,    1,    1,    2,    2,    2,    1,    3,    2,    2,
    2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
    2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
    2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
    2,    2,    2,    3,    2,    2,    2,    3,    3,    2,
    2,    2,    3,    1,    1,    1,    1,    1,    3,    3,
    3,    3,    3,    3,    5,    5,    5,    5,    5,    5,
    0,    2,    2,    1,    2,    0,    5,    2,    2,    2,
    2,    0,    4,    2,    2,    3,    2,    2,    2,    3,
    3,    2,    2,    3,    4,    4,    0,    0,    4,    2,
    0,    3,    2,    3,    2,    2,    2,    3,    3,    2,
    2,    2,    4,    3,    3,    3,    3,    4,    4,    5,
    5,    4,    5,    3,    4,    4,    0,    5,    4,    4,
    4,    3,    2,    2,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    2,    1,    1,    0,    4,    2,    3,    4,    0,    2,
    3,    2,    2,    4,    0,    1,    1,    2,    2,    3,
    0,    2,    0,    2,    5,    1,    1,    1,    1,    2,
    3,    0,    3,    4,    3,    2,    2,    5,    0,    5,
    1,    4,    2,    3,    2,    2,    5,    5,    0,    2,
    1,    3,    2,    4,    1,    8,    6,    5,    2,    0,
    0,    3,    3,    3,    2,    2,    2,    2,    2,    2,
    2,    2,    2,    3,    2,    3,    2,    2,    2,    2,
    5,    2,    2,    3,    3,    4,    0,    2,    2,    1,
    1,    1,    3,    1,    1,    3,    6,    1,    1,    1,
    4,    5,    1,    3,    1,    3,    1,    2,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    2,    4,
    2,    4,    1,    1,    1,    0,    3,    0,    0,    6,
    4,    6,    5,    0,    3,    0,    2,    2,    0,    3,
    4,    1,    5,    4,    1,    4,    4,    1,    4,    1,
    2,    2,    1,    1,    1,    2,    2,    1,    1,    2,
    2,    2,    2,    0,    3,    5,    1,    1,    2,    3,
    1,    2,    0,    3,    1,    1,    1,    2,    4,    0,
    1,    5,    0,    1,    3,    3,    0,    1,    0,    2,
    0,    1,    0,    0,    5,    3,    3,    3,    6,    4,
    0,    0,    7,    6,    1,    2,    1,    1,    1,    1,
    1,    1,    5,    5,    0,    2,    2,    0,    4,    1,
    6,    5,    0,    1,    1,    1,    0,    1,    1,    1,
    1,    4,    1,    1,    0,    2,    2,    0,    3,    2,
    2,    1,    2,    2,    3,    2,    2,    2,    3,    0,
    0,    4,    4,    1,    2,    3,    3,    1,    4,    2,
    3,    1,    1,    0,    1,    2,    2,    0,    1,    1,
    1,    1,    1,    3,    2,    0,    3,    1,    3,    4,
    5,    6,    7,    7,    6,    1,    0,    0,    9,    0,
    2,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    2,    1,    1,    1,    1,    2,    2,    1,
    2,    1,    2,    1,    3,    1,    1,    3,    0,    3,
    0,    2,    0,    2,    4,    5,    0,    3,    2,    1,
    3,    6,    1,    1,    1,    4,    4,    1,   10,    0,
    2,    1,    1,    2,    4,    2,    2,    4,    2,    1,
    1,    1,    1,    1,    3,    1,    3,    1,    3,    0,
    1,    2,    1,    3,    1,    1,    1,    1,    1,    3,
    6,    2,    0,    1,    0,    3,    1,    3,    1,    1,
    1,    4,    5,    5,    5,    2,    4,    4,    2,    6,
    4,    0,    3,    1,    3,    1,    0,    1,    2,    2,
    2,    0,    1,    0,    3,    1,    3,    1,    0,    2,
    0,    2,    0,    2,    1,    3,    5,    0,    1,    0,
    2,    0,    0,    6,    0,    1,    2,    1,    1,    1,
    1,    3,    2,    1,    1,    2,    1,    0,    0,    6,
    0,    5,    1,    3,    0,    0,    5,    0,    1,    3,
    1,    3,    3,    0,    1,    1,    0,    2,    1,    1,
    2,    4,    0,    1,    1,    1,    0,    3,    1,    1,
    0,    5,    4,    0,    9,    6,    4,    3,    0,    3,
    3,    1,    3,    1,    1,    0,    0,   11,    2,    2,
    0,    3,    3,    0,    0,    0,    6,    0,    0,    6,
    0,    5,    0,    7,    2,    4,    0,    9,    0,   11,
    1,    1,    8,    5,    1,    1,    0,   10,    7,    0,
    0,    0,   16,    0,    0,    3,    0,    2,    4,    4,
    3,    0,    2,    0,    4,    3,    3,    1,    1,    0,
    1,    3,    1,    3,    0,    0,    2,    4,    1,    3,
    1,    3,    4,    1,    1,    3,    1,    1,    3,    3,
    2,    3,    3,    4,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    3,    1,    1,    1,
    1,    1,    1,    1,    1,    6,    1,    1,    1,    5,
    6,    5,    6,    3,    4,    1,    1,    2,    3,    5,
    4,    6,    4,    6,    5,    7,    3,    4,    4,    4,
    1,    1,    1,    1,    3,    3,    4,    4,    1,    3,
    3,    0,    4,    0,    5,    0,    4,    0,    5,    0,
    1,    0,    2,    2,    0,    3,    2,    2,    2,    2,
    3,    3,    1,    1,    2,    0,    5,    3,    2,    4,
    3,    2,    0,    0,    0,    5,    0,    0,    5,    0,
    0,    5,    1,    0,    0,    0,    8,    1,    2,    2,
    1,    1,    1,    1,    1,    3,    3,    3,    2,    2,
    0,    2,    3,    2,    1,    1,    1,    1,    1,    3,
    1,    3,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    2,    2,    3,    3,
    3,    3,    5,    3,    3,    3,    3,    1,    1,    1,
    1,    3,    1,    1,    1,    1,    1,    1,    2,    2,
    2,    2,    0,    3,    0,    3,    4,    0,    1,    1,
    3,    1,    2,    2,    2,    2,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    2,
    2,    2,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    4,    1,    1,    1,    1,    1,
    1,    2,    1,    1,    2,    1,    1,    1,    1,    1,
    2,    1,    1,    1,    1,    1,    1,    1,    1,    6,
    4,    5,    5,    5,    5,    5,    5,    5,    5,    5,
    5,    6,    6,    4,    4,    4,    4,    6,    6,    6,
    6,    6,    6,    6,    6,    6,    6,    6,    6,    3,
    3,    3,    3,    3,    4,    4,    7,    8,    6,    4,
    8,    6,    4,    4,    0,    2,    2,    1,    1,    1,
    1,    1,    3,    5,    5,    0,    3,    0,    0,    0,
    4,    0,    4,    1,    4,    2,    2,    2,    2,    2,
    2,    2,    2,    2,    2,    2,    0,    3,    3,    2,
    2,    0,    2,    1,    1,    6,    1,    1,    1,    4,
    4,    4,    4,    4,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    7,
    8,    8,    8,   12,    6,    4,    6,    6,   10,    8,
    6,    4,    9,    9,   11,    4,    1,    1,    1,    1,
    0,    2,    0,    1,    0,    2,    0,    2,    0,    2,
    0,    2,    0,    1,    1,    1,    0,    2,    1,    1,
    1,    1,    2,    2,    2,    1,    1,    4,    4,    7,
    8,    0,    2,    7,    6,    6,    4,    1,    1,    1,
    4,    3,    6,    5,    6,    1,    1,    6,    8,    6,
    6,    8,    1,    1,    0,    0,    0,    8,    4,    5,
    0,    2,    3,    5,    4,    5,    1,    1,    1,    3,
    5,    4,    6,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    0,    1,    0,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,
};
static int yydefred[] = {                                      0,
    0,    0,    0,    0,    0,    0,    0,   37,    0,    0,
  110,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    3,    4,    5,    6,   22,   24,   20,   18,   23,
   19,  844,   10,   11,   16,   21,   12, 1175, 1176, 1177,
   27,   28,   26,   34,   33,   29,   30,   31,   36,   32,
   35,   25,   17, 1286,   13,    0,    0,    8,    0,    9,
    7, 1511, 1512,   14, 1515, 1516,   15,    0,    0,  852,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  215,    0,    0,  843, 1188,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  248,    0,    0,    0,    0,    0,    0,  215,    0,  194,
    0,    0,    0,  157,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  215,    0, 1065,    0,  742,   38,    0,    0,
   38,    0,    0,    0, 1193,    0,    0,    0,    0,    0,
    0,    0,    0, 2211, 2212, 2213, 2214, 2215, 2216, 2217,
 2218, 2219, 2220, 2221, 2222, 2223, 2224, 2225, 2226, 2227,
 2229, 2230, 2231, 2232, 2233, 2234, 2235, 2228, 2236, 2237,
 2238, 2239, 2240, 2241,    0, 2242, 2243, 2244, 2245, 2246,
 2247, 2248, 2249, 2250, 2251, 2252, 2253, 2254, 2255, 2256,
 2257, 2258, 2259, 2260, 2261, 2262, 2263, 2264, 2265, 2266,
 2267, 2269, 2270, 2102, 2104, 2105, 2106, 2107, 2108, 2109,
 2127, 2128, 2110, 2112, 2111, 2120, 2121, 2117, 2113, 2118,
 2114, 2116, 2119, 2115, 2123, 2124, 2122, 2125, 2126, 2130,
 2129, 2131, 2132, 2133, 2134, 2135, 2136, 2137, 2138, 2139,
 2140, 2141, 2142, 2143, 2144, 2145, 2146, 2147, 2148, 2149,
 2150, 2151, 2152, 2153, 2154, 2155, 2156, 2157, 2158, 2159,
 2160, 2161, 2162, 2163, 2164, 2165, 2166, 2167, 2168, 2169,
 2170, 2171, 2172, 2173, 2174, 2175, 2176, 2177, 2178, 2179,
 2180, 2181, 2182, 2183, 2184, 2185, 2186, 2187, 2188, 2189,
 2190, 2191, 2192, 2193, 2194, 2195, 2268, 2196, 2197, 2198,
 2204, 2200, 2199, 2201, 2202, 2203, 2205, 2206, 2207, 2208,
 2209, 2210, 2275, 2276, 2277, 2278, 2279, 2280, 2282, 2283,
 2284, 2285, 2271, 2286, 2272, 2273, 2274, 2281, 2287, 2288,
 2289, 2290, 2291, 2292, 2293, 2294, 2295, 2296, 2297, 2298,
 2299, 2300, 2301, 2302, 2303, 2304, 2307, 2309, 2306, 2310,
 2311, 2312, 2313, 2314, 2315, 2316, 2317, 2318, 2319, 2320,
 2321, 2322, 2323, 2324, 2325, 2326, 2327, 2328, 2329, 2330,
 2332, 2333, 2334, 2335, 2336, 2337, 2338, 2339, 2341, 2342,
 2343, 2345, 2346, 2347, 2348, 2349, 2350, 2351, 2352, 2353,
 2354, 2355, 2356, 2357, 2358, 2359, 2360, 2361, 2362, 2363,
 2364, 2365, 2308, 2344, 2331, 2305, 2340, 2366, 2367, 2368,
    0, 1394,    0, 2094, 2103,    0,    0, 1330,    0, 2093,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  219, 1178, 2099,    0,    0,    2,    0,    0,    0,
    0, 1335, 1338,    0,    0,    0,    0,  364,  907,  908,
  909,  910,  911,  912,  913,  914,  915,  916,  917,  918,
  919,  920,  921,  922,  923,  924,  925,  926,  927,  935,
  929,  930,  928,  962,  982,  959,  931,  932,  933,  934,
  936,  938,  941,  937,  939,  940,  942,  943,  944,  945,
  946,  947,  948,  949,  950,  951,  952,  953,  954,  964,
  976,  974,  960,  977,  955,  961,  980,  981,  975,  963,
  978,  979,  983,  984,  958,  957,  956,  965,  966,  967,
  968,  969,  970,  971,  972,  973,  985,  986,  987,  988,
  989,  990,  991,  992,  993,  994,  995,  996,  997,  998,
  999,  854,  867,  906,  845,    0, 2083,    0,    0,  552,
  539,  540,    0,  857,  543, 2073,  862,  303, 2086,  855,
    0, 2087,  522,  514,  515,    0,  850,  518, 2091,  846,
 1396,  849,    0, 2095,  859,    0, 2096,  753,  848,    0,
 1026, 1027,  858,    0, 2092,  863,  217, 1657,  561,  851,
    0, 2100, 1196,    0, 1185, 1781,    0,  207,  363, 1783,
  369,  208,    0, 2079,  195,    0,  199,  205,  284,    0,
  200, 1786,  209, 1788,    0,  201,    0,  203,    0,  758,
  212, 1622,  204,  210,  317,  206,  211,    0, 2078,    0,
  217, 1653,    0,  213, 1455, 1456,    0,    0,  158,    0,
 2084,    0, 1073, 2082, 1066,    0, 1072, 1075, 1078, 1067,
 1068,    0, 1069, 1070,    0, 1071, 2098, 1077, 1079, 1080,
  217,    0,    0, 1083,    0,    0,    0,  743,    0, 1478,
    0,    0,    0, 1186,    0,    0, 1194, 1197,    0,    0,
 1198,    0,    0,    0,    0,    0,    0, 1517, 1361,    0,
    0,    0,    0,    0,  228,  221,  229,  220,  222,  225,
  231,  224,  230,    0,    0,  226,    0,    0, 1292, 1293,
 1298,    0, 1297,    0, 1299, 1301, 1307,    0, 1294, 1296,
    0, 1295, 1302, 1306, 1300, 1304, 1305,    0,    0,    0,
    0,    0,    0,    0, 1318,    0,    0,    0,    0, 1343,
    0,    0,    0, 1449,    0,    0,    0, 2077,  861,    0,
 2076, 1631,  860, 1626,  364,  868,  246,  856,    0,    0,
    0,    0,  420,    0,    0,  161,  285, 1018, 1019,    0,
    0,  519,  412,  765,  766,    0, 1624,    0,    0, 1541,
 1029, 1028,    0,  318, 1657,  864,    0,    0, 1192, 1190,
 1782,  364,  278,    0,  244,  285,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  215,    0,  232,  257,  256,
    0,    0,  407,    0,    0,    0,    0,  759, 1288,    0,
    0, 1653,  216,    0,  214,    0,    0,  159,  160,    0,
    0,    0,    0, 1074,    0,    0, 1076,    0,    0, 1085,
 1663, 1668, 1084,    0,    0,    0,    0, 1726,    0, 1771,
    0, 2070,    0, 1723, 1925,    0,    0,    0,    0, 1943,
    0, 1772,    0, 1766, 1754, 1755, 1749, 1750, 1752,    0,
 1753,    0,    0,    0, 1728,    0,    0, 1756, 1757, 1767,
 1768,    0, 1769, 1770,    0,    0,    0, 1774, 1611, 1612,
 1613,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1937, 1940,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1773, 1763, 1764, 2071, 1727,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1614,    0, 1938, 1939,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1765, 1702,    0,
    0, 1551, 1688, 1558, 1565, 1572, 1566, 1567, 1568, 1569,
 1570, 1573, 1574, 1575, 1576, 1571,    0,    0,    0, 1691,
 1721, 1724, 1697,    0, 1758, 1751, 1748, 1699, 1700, 1701,
 1718, 1719, 1720, 1759, 1698, 1794,    0,    0, 1852,    0,
 1795, 1796, 1884, 1885, 1887, 1888, 1889, 1798,    0, 1895,
    0,    0,    0, 1797, 2006, 2007, 1706, 1703, 1704, 2026,
 2027, 2033, 2034, 1705, 1725,    0, 1554,    0,    0,    0,
    0,    0,   39,    0,   38,    0,    0,    0,    0,  111,
  112,  124, 1184,    0,    0, 1280,    0, 1234, 1232, 1233,
 1792,    0,    0,    0, 1118, 1167, 1124,    0, 1168,    0,
    0, 1125,    0,    0,    0, 1155, 1171, 1117, 1150,    0,
    0, 1114, 1123,    0,    0, 1115, 1159, 1207, 1099, 1107,
 1100, 1109, 1110,    0, 1113, 1111, 1112,    0, 1205, 1116,
    0,    0,    0,    0,    0,    0, 1200, 1201,    0,    0,
    0, 1532, 1395, 1331,    0, 1377, 2088,    0,    0,  227,
 1181, 1179, 1303, 1311, 1309, 1308, 1287,    0,    0, 2090,
    0,    0,    0,    0,    0, 1320, 1324,    0, 1346, 1344,
    0, 1349, 1347, 2067, 1350,    0, 1351, 1341,    0,    0,
 2069,    0,    0,    0, 1325,    0,    0, 1477,    0,    0,
 1525, 1547,    0, 1288,    0,    0,  868,    0,    0,    0,
    0,  866,    0,    0,    0,    0,    0,  542,    0,    0,
    0,  517,    0,  412,  825,  824,    0,    0, 1288,    0,
 1543,    0,    0,    0,  865, 1658, 1664,    0,    0,    0,
    0, 1090, 1091,    0,    0,    0,    0,  238,    0,  553,
  234,  239,  296,  523,  233,  764,  235,  241,    0,  752,
  237,  240,  217, 1660,  562,  236,  259,    0,    0,  436,
    0,    0,    0,  757,    0,    0,    0,  330,  202,  423,
  218, 1654,    0,    0,  161, 2075,    0,    0,  193, 1784,
  192, 2074,    0,    0, 1412,    0,    0,    0, 1514, 1089,
 1088,    0, 1086,    0,    0,    0, 1760,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1761, 1762,    0,
 1730,    0, 1732,    0,    0,    0,    0, 2035,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1729, 1731,    0,    0,    0,    0,    0,    0,    0,
    0, 1689,    0, 1333, 1334,    0,    0,    0,    0,    0,
  689,    0,    0,  734,    0,    0,    0, 1596, 1581,    0,
    0, 1582,    0, 1585,    0, 1583, 1584,    0,    0,    0,
 1578, 1579, 1580,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  170,  744,    0,   77,   78,    0,    0,
    0,    0,    0,   72,    0,    0,    0,    0,    0, 1366,
 1368, 1369, 1365, 1379, 1380, 1381, 1367,    0,    0,    0,
    0,    0,    0,   38, 1182,  314,    0,  312,  313, 1790,
 1195, 1194, 1228, 1229, 1230, 1231, 1222,    0, 1129, 1151,
 1152, 1172,    0, 1169,    0,    0, 1162, 1156, 1157,    0,
    0, 1206, 1119,    0, 1121, 1160, 1161,    0, 1108,    0,
    0,    0,    0,    0,    0,    0, 1163, 1202,    0,    0,
 1520,    0,    0,    0, 1376,    0,  223, 1288, 1317, 1281,
 1316,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1353,    0,    0, 1354, 1356,    0,    0,    0, 1451,    0,
 1337, 1336,    0,    0,    0, 1694,    0, 1693, 1742, 1747,
 1695,    0, 1326,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1041,    0,    0,
    0,  373,  373, 1030,    0,    0, 1022,    0, 1020,    0,
    0,  358,  359,  357,  549,    0,  417,  418,    0,    0,
    0,    0,  576,    0,    0,  551,    0,    0,  304,  285,
    0,  520,    0,    0,    0,    0,    0, 1059,    0,    0,
    0,    0, 1542,    0,    0,  319,    0, 1655,    0,    0,
  365,  364,    0,  281,  267,    0,    0,  286,  285,  245,
  285, 1628, 1660,  242,    0,    0,  435,  408, 1064, 1062,
 1063,    0,    0,  760,  761, 1623, 1288,  331,    0, 1655,
    0,    0,    0, 1787, 1785,    0,    0,    0, 1426, 1428,
    0, 1429, 1421, 1422,    0, 1081,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2054, 2055, 2056, 2057, 2058,
 2059, 2064, 2065, 2060, 2063, 2061, 2062,    0,    0,    0,
    0,    0,    0, 2043,    0, 2036,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2018, 2020, 2019,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1830,    0,    0,    0,    0,    0, 1831, 1834,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1833,    0,    0,    0,
 1849, 1848, 1850,    0, 1832, 1779, 1776, 1777, 1778, 1780,
    0,    0,    0,    0,    0, 1717,    0, 1692,  738,    0,
    0,  690,    0,  691,    0,    0,    0,    0,    0,    0,
 1607, 1619,    0, 1615,    0, 1616, 1563,    0,    0,    0,
    0,    0,    0,    0, 1598,    0, 1587, 1589, 1588,    0,
    0,    0,    0, 1712, 1711,    0,    0,    0,    0,    0,
    0,    0,    0, 1853, 2101,    0,    0,    0,    0, 2022,
    0, 1722, 1552,    0,    0,  168,    0,    0,    0,    0,
    0,    0,    0,   62,   63,   67,   58,   60,   57,   55,
   56,   64,   61,   66,   59,    0,    0,    0,    0,    0,
    0,   53,  148,    0,  147,  150,    0, 1372,    0,    0,
    0,    0, 1398,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  128,  130,    0,    0,    0,    0,    0,
    0,  316,  315, 1791,    0,    0, 1789,    0,    0,    0,
    0, 1170,    0,    0,    0,    0,    0,    0,    0, 1210,
 1211, 1209, 1204,    0,    0,    0,    0,    0,    0,    0,
 1224, 1225, 1226, 1221, 1199, 1521, 1534,    0,    0, 1533,
 1555,    0,    0, 1378,    0,    0, 1282, 1313,    0,    0,
 1315, 1285, 1345, 1348,    0,    0,    0,    0,    0,    0,
    0,    0, 1745, 1744, 1746, 1743, 2097, 1466, 1465, 1468,
 1469, 1470,    0,    0, 1480, 1481,    0, 1476,    0, 1549,
    0, 1627, 1031,    0,    0, 1036,    0, 1043, 1037,    0,
    0,    0, 1046, 1045,    0,    0,    0,    0,    0,    0,
    0,    0,  870, 1024,  355,    0,    0,    0,    0,    0,
  541,    0,  573,    0,  582,    0,    0,  577,  578,  579,
  525,  168,    0,  288,    0,  516,    0,  413,  493,    0,
    0,    0,    0,  882,    0,    0,    0,    0,  842,    0,
    0, 1625, 1544,    0,  751, 1025,    0,    0,  321,  322,
    0, 1665,    0,    0,    0,    0,  557,    0,    0,    0,
  279,  480,  475,  476,  477,  478,  479,  268,    0, 1103,
    0,    0,  288,    0,    0, 1288,  243, 1661,    0,  252,
  426,  756,    0,    0,    0,    0,    0,  408,    0,    0,
    0,    0,    0,    0,  567,  196,  170,    0,  168,    0,
 1530, 2081, 1427,    0, 1464,    0,    0,    0,    0,    0,
 1801,    0, 1609,    0, 2008,    0,    0,    0,    0,    0,
 1972, 1610,    0,    0,    0, 1734, 1736,    0,    0,    0,
    0,    0,    0, 2037,    0,    0,    0, 2052, 1890, 1891,
 1892, 2009, 1893,    0, 2017,    0,    0,    0,    0,    0,
    0,    0, 1966,    0,    0,    0, 1835,    0, 1836,    0,
 1840,    0, 1843, 1814, 1815, 1816, 1817,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2003,
 2004, 2005,    0,    0, 1844, 1775, 1976,    0,    0, 1690,
 1553,    0,    0,    0, 1737,    0,    0,    0,    0,    0,
 1617, 1618, 1564,    0,    0, 1608,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1419, 1894,    0,    0,    0,
 2021,    0,  735,    0,    0,    0,    0,   69,    0,    0,
    0,    0,    0,    0,    0,   65,   49,   49,   75,   75,
   75,    0,    0,   81,    0,   80,    0,   79,    0,   74,
   88,   95,  131,    0,  151,    0, 1370, 1403, 1401, 1399,
    0, 1486, 1400,    0,    0,    0,    0,    0,   49,    0,
    0,    0,    0,    0,   49,    0,    0,    0,    0, 1250,
 1242,    0,    0,    0, 1237,    0,    0,    0, 1131,    0,
    0, 1174,    0, 1165, 1120, 1127, 1122, 1140,    0,    0,
    0, 1141, 1144, 1146, 1147, 1149, 1203, 1202,    0,    0,
    0, 1519,    0,    0, 1332,    0,    0, 1283, 1284,    0,
    0,    0,    0, 1355, 1359, 1357, 1452,    0, 1453,    0,
    0,    0,    0, 1485,    0, 1482,    0,    0, 1548,  354,
    0,    0,    0,  265, 1035,    0, 1044,    0, 1039, 1051,
  373,    0,    0,  872,    0,    0,  875,  877,  876,    0,
    0,  873,  880,  881,  360,  361,  362,  356,  548,  591,
  587,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  633,  609,
  604,    0,    0,  603,    0,  613,  612,  636,  624,  625,
  639,    0,  622,  640,  637,  626,  619,  638,    0,  628,
  629,  627,  719,  721,  720,  620,    0,  614,  615,  618,
  616,  617,  634,  623,    0, 1539, 1538,    0,    0,  598,
    0,  583,    0,    0,    0,    0,    0,    0,    0, 1095,
 1094, 1098,    0,    0,    0,  308,  307,  521,    0,    0,
 1001,    0,    0,    0,    0,  904,  903,    0,  905,    0,
    0,    0,    0,    0,    0,    0,    0, 1057,    0,    0,
    0,    0,    0, 1659,    0,    0,    0,  554,  558,  366,
  364,    0,    0,    0,    0,    0,    0,    0,  372,    0,
    0, 1101,    0,    0,    0,    0,  290,  291,  297,    0,
    0, 1655,  368,    0,  253,    0,  439,    0,    0,    0,
    0,    0,    0, 1643,    0, 1644,    0,    0,    0,    0,
    0,    0, 1634,    0,    0,  332,  426, 1656,  569,    0,
    0,  571,    0,    0,    0,  564,    0,    0,  568,  197,
  168,  162,    0,    0,    0, 1423, 1513, 1807, 1806,    0,
    0,  471,  474, 1803, 1802,    0, 1811, 1810, 1809, 1808,
    0,    0, 1805, 1804,    0,    0,    0, 2045, 2044,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  741,  693,  692,    0,
 1621, 1620, 1590,    0,    0,    0,    0,    0,    0,    0,
 1713,    0,    0,    0, 1854,    0,    0,    0, 2024,    0,
  173,  747,    0,  748,    0,  173,    0,    0,    0,    0,
    0,    0,    0,    0,  131,  131,    0,    0,    0,   91,
   92,   83,   82,    0,    0,  149,    0,    0, 1487, 1382,
    0, 1393, 1388,    0,  131,    0,    0,    0,    0,    0,
    0,    0,  121,  121,  131, 1239, 1248,    0, 1243, 1240,
 1241, 1251,    0, 1247, 1246,    0,    0, 1244, 1254,    0,
 1133,    0, 1137, 1138,    0,    0,    0,    0,    0, 1143,
    0,    0,    0, 1535,    0, 1537,    0, 1556,    0,    0,
 1291,    0,    0,    0, 1459, 1460, 1458,    0, 1473,    0,
    0, 1550, 1034,  391,  266,    0, 1042,    0,  364,    0,
    0,    0,  874,  878,  879,  592,  588,    0,  654,    0,
    0,    0,  698,  701, 2089,  722,  723,    0,  725,  699,
    0,  635,  605,  707,  610,    0,  705,  611,    0,    0,
    0,    0,    0,  696,    0,    0,  594,  595,    0,    0,
    0,    0,  173,  526,  529,    0,    0,    0,    0,    0,
  306,    0,  309,  295,    0,  883,    0,  886,  887,  493,
    0,    0,  885, 2080,  902, 1017, 1016,  884,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  894,  462,    0,
  463,  450,    0,    0,    0,    0,    0,    0,    0,  755,
  325,    0, 1686, 1685,    0,    0,    0,    0,    0,    0,
  559,  560,    0,    0,  374,    0,    0,  380,    0,  377,
  376,  379,  378,    0,  268, 1104, 1106, 1102,  289,    0,
  300,  288,    0, 1629,    0,    0,    0,  428,  409,  437,
    0,    0,    0,    0,  772,  773,  769,  762,    0,    0,
    0,    0,    0,    0,  777,  771, 1636,    0, 1640,    0,
 1637, 1639, 1638, 1646, 1645,    0,  336,    0,    0,  570,
  572,  563,    0,    0,    0,  173,  165,    0,    0,  172,
  164,    0,    0,    0, 2025, 2053,    0, 1971, 1886,    0,
    0,    0, 2046,    0,    0, 2028, 2030,    0, 2015, 2016,
    0,    0,    0,    0,    0,    0,    0, 2031,    0, 1813,
 1812,    0,    0,    0, 1839,    0, 1842, 1818, 1819, 1820,
 1821, 1822, 1823, 1824, 1825, 1826, 1827, 1828, 1829, 1965,
 1968,    0,    0,    0, 1591,    0,    0,    0,    0, 1586,
 1800,    0,    0, 1967,    0,    0,    0,    0, 2023,    0,
    0,  535,    0,    0,   41,   41,   41,   41,   41,   41,
   41,    0,    0,    0,   76,    0,   90,    0,   89,   98,
   97,   99,   96,    0,  134,    0,    0,    0,  152,  154,
    0, 1374, 1383, 1487,    0,    0, 1384, 1385,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  131,  131,    0,
 1245,    0, 1249, 1251,    0,    0,    0, 1255, 1132,    0,
 1130, 1166,    0,    0, 1218, 1217, 1220,    0,    0, 1289,
    0,    0,    0,    0,    0, 1472, 1483, 1475,  392, 1038,
    0, 1040,    0,    0, 1048, 1047,    0,    0,    0,    0,
    0,  655,    0,    0,  686,    0,  727,  652,    0,  708,
  706,    0,    0,    0,    0,  646,    0,    0,    0,    0,
  584,    0,  602,    0,  585,  586,    0,    0,    0, 1096,
  470,    0,  547,  544, 1093,  311,  293,  496,    0,    0,
    0,  448,    0,  467,    0,  468,  900,  901,    0,  888,
    0,  889,  465,  896,  899,  895,  892,    0, 1003,    0,
    0,  450,  839,  840,  836,  835,  838,  837, 1056,  323,
 1683,    0,    0, 1679,    0, 1680, 1666,    0,    0,    0,
  385,  387,    0,  375,  381,  269,    0,    0,  292,    0,
  301,  302, 1662,  405,  406,  261,  254,    0,  439,    0,
  440,  441,  763,  775,  776,  774,    0,    0,  798,  792,
  786,  810,  783,  780,  789,  807,  795,  801,  804,  821,
  816,    0,  797,  791,  785,  809,  782,  779,  788,  806,
  794,  800,  803,  812,  820,    0,  799,  793,  787,  811,
  784,  781,  790,  808,  796,  802,  805,  813,  822,    0,
    0, 1641, 1642, 1288,    0,  333,  331,  424,  198,  250,
    0,    0,  171,  182,    0,    0,    0,    0,    0,  179,
  175,    0,    0,    0, 1434,    0, 1431,    0, 1435,    0,
  472,    0, 2010,    0,    0,    0,    0,    0,    0,    0,
 2014, 1960,    0,    0,    0,    0,    0,    0,    0, 1837,
    0,    0, 1986,    0,    0,    0,    0,    0, 1862, 1859,
    0,    0,    0, 1990,    0,  749,    0,    0,  532,    0,
  745,  131,  131,  131,  131,  131,  131,  131,    0,  134,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  132,  133,  144,    0,    0,    0,  107,    0,   54,    0,
  155,  156, 1371,    0,    0, 1386,    0, 1390,  113,  113,
  113,  113,  113,  113,  113,    0,    0,  125,    0, 1273,
    0, 1278,    0,    0,    0, 1265, 1257, 1256,    0,    0,
 1135, 1213, 1214,    0,    0, 1518, 1648,    0, 1406,    0,
 1410,    0,    0,    0, 1050,  365, 1053, 1055,  283,    0,
  589,    0,    0,    0,    0,    0,  728,  729,  731,  730,
    0,    0,    0,  710,    0,  647,    0,    0,    0,  596,
  601,    0,  530,  531,    0,  546,    0,    0,    0,  500,
  494,    0,  442,  445,  447,  890,  891,  893,  464,    0,
  898,    0,  318, 1678, 1677, 1682, 1676,    0,  386,    0,
    0,  382,    0,    0,  272,  276,  275,  299,    0,  438,
  410,    0,  768,  814,  778,  818,  819,  823,    0,    0,
    0,    0,    0,  331,  426,    0,    0,    0,    0,    0,
  181,  174,    0,  177,  178,  191,    0, 1424, 1438, 1437,
 1441, 1433, 1436,    0, 2011,    0, 2042,    0, 2038, 2029,
 1961, 1962, 1963,    0, 2032,    0, 1970, 1846, 1847, 1838,
 1841,    0, 1984,    0,    0, 1860, 1860,    0, 1855,    0,
    0,  750,  173,  528,  534,    0,    0,    0,    0,    0,
    0,    0,    0,    0,   50,  138,  146,  137,  140,  145,
  141,  142,  139,    0,   51,  103,  153,  106,    0,  105,
  108, 1488,    0,    0, 1489, 1490,    0,  131,  131,  131,
  131,  131,  131,  131,  122,  123,    0,    0,    0, 1275,
 1253, 1266, 1267,    0, 1261, 1219,    0,    0,    0, 1415,
    0, 1339,  393,  392,    0,    0,    0,    0,    0,  656,
    0,    0,  641,    0,    0,    0,    0,    0,  659,    0,
    0,  537,  538,    0,    0,    0,    0,    0,    0,  453,
    0,  443,  443,  461,    0, 1004,    0,    0,    0,    0,
    0, 1673, 1672, 1667,    0, 1671,    0,  390,  274,  282,
    0,    0,  413,  415,  416, 1646, 1647,    0, 1649,    0,
  337,  334,  353,  331,  340,    0,    0,    0,    0,    0,
    0,  185,    0,  189,  184,    0, 1432,    0,    0,    0,
 2039,    0,    0,    0, 1974,    0,    0,    0,    0, 1880,
    0, 1881, 1973,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  101,  135,  136,  143,  109, 1492, 1493,
    0, 1494, 1387,    0,    0,    0,    0,    0,    0,    0,
 1274, 1270, 1269,    0, 1279, 1262, 1263, 1259,    0, 1407,
    0,    0,    0,    0, 1054,    0,  590,  644,    0,    0,
    0,    0,    0,  712,  718,    0,    0,    0,    0,  711,
    0,    0,    0,    0,    0, 1097,    0,    0,    0,  497,
  452,    0,    0,    0,    0,    0,    0,    0,    0, 1012,
  327,  326,  329, 1670, 1669, 1674, 1675,    0,  422,  421,
    0,    0, 1652,    0,  342,    0,    0,    0,    0,  343,
  344,  345,  428,    0,  431,  427,  251,  183,    0,  187,
    0,  166, 1439, 1439,  473, 2040, 1969,    0,    0,    0,
    0,    0, 1863, 1864, 1861, 1879, 1878,    0, 1995, 1996,
    0, 1994,  533,   42,   44,   43,   45,   46,   47,   48,
 1498, 1495,  114,  116,  115,  117,  118,  119,  120, 1271,
 1272, 1277, 1522, 1416,    0,    0,    0,    0,  396,    0,
    0,  657,  655,    0,  726,  709,    0,  717,  716, 2085,
  714,  715,    0,    0,  650,  649,  703,  694,    0,    0,
  498,    0,  449,    0,  482,    0,    0, 1007, 1005,  450,
 1011,    0, 1013,    0,    0,  414, 1650, 1651,  346,  349,
  348,  351,  350,  347,    0,    0,  163,  190,    0,    0,
 1975,    0,    0,    0,    0, 1867, 1866, 1868, 1999, 2000,
    0,    0, 1499, 1496,    0,    0,  398,    0,    0,    0,
  593,  661,    0,    0,  684,  713,  648,    0,  599,    0,
    0,  450,  444,    0,    0,  446, 1008,    0,    0,  328,
  389,  429,    0,    0,    0, 1443,    0, 1442, 1870, 1869,
 1872, 1871,    0, 1964,    0,    0,    0, 1525,    0, 1417,
    0,  403,  399,  655,    0,    0,    0,    0,    0,    0,
  675,  704,    0,  502,    0,    0,  484,  485, 1014,  432,
  433,    0, 1440, 1446,    0,    0,    0, 1865,    0,    0,
 1500,    0,    0, 1497,    0, 1523,  400,    0,    0,    0,
  674,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  455,  451,  486,    0, 1444,    0, 1874, 1873,
 1876, 1875,    0, 1507,    0, 1505,    0, 1526,  656,  662,
  656,  663,    0,  664,  668,    0,    0,    0,    0,    0,
    0,  681,  683,  682,    0,    0,  499,    0,  507,    0,
  506,  450,    0,    0,    0,  489,  487,  488,    0,    0,
    0,    0, 1501,    0,    0,    0,    0,    0,    0,    0,
  510,  509,  508,    0,    0,    0,    0,  491, 1447, 1509,
    0, 1506,    0, 1532,  665,  669,    0,    0,    0,  513,
  511,  512,  456,    0,    0,    0,  458,  492,    0,    0,
    0, 1503,    0,    0,  457,    0,    0,    0,    0,    0,
 1532,  459,  460,  490,    0,    0,    0,    0,    0,    0,
 1508,    0, 1510,
};
static int yydgoto[] = {                                      20,
   21,   22,   23,   24, 2399,   26, 1103, 1876, 1459, 1878,
 1460, 1461, 2260, 1462, 1879, 2261, 1463, 1880, 2262, 3301,
 3006, 3319, 3520,   27, 1110, 1111, 1112, 2992, 3311, 3312,
 1465, 1885, 2664, 3009,   28,  114,  838, 2909, 2108, 2553,
 2910, 3241, 3235, 3451, 3625,  649, 1308,   29,  110,   30,
  442,   31,  818,  615, 1268,  555,  111, 3229,  623,  821,
 1288, 2090, 3167, 2353,  612, 2854, 3157, 3425, 1644, 1645,
 3426,  618, 1648, 2083, 2507, 2456, 1272, 2509, 2862,  567,
 1619, 2034, 2457, 2793,   32, 1488,  591, 1636, 2059, 2060,
 3589, 3722,  637, 2536, 3226, 3443, 3615, 3740, 3741, 3742,
 3612,  759, 1232, 2378,  608,  609, 1641, 2069, 2499, 2490,
 2843, 3151, 2354, 3553, 3683, 3799,  626, 3431, 3603,  773,
  774, 3605, 1299, 3617, 3746,  823, 2516, 2870, 2798, 3404,
 3581, 3964, 4024, 4047, 2818, 3113, 2789, 2561, 2071, 3824,
 3884, 3927, 4007, 2799, 2800, 3401, 3710, 3960, 3961, 3962,
 4022,  573,  574,  575,  576,  577, 1275, 1618, 2237, 2445,
 2785, 3288, 3289, 2643, 3390,  560,  561,  562,  563, 3104,
  775, 1238,  564, 1271,  599, 2065, 2066, 2067,  600, 1286,
  835, 2103, 2104, 2105, 1610, 1611, 1612, 1613, 2023, 2024,
 2025, 1614, 1615, 2776, 2777, 2778, 3094, 2400, 2401, 2402,
 2403, 2404, 2405, 2406, 2407, 2408, 2409, 2410, 2411, 3701,
 3077, 3078, 2412, 2413, 2414, 3560, 3948, 3984, 3949, 3985,
 3802, 3873, 3921, 2415, 2416, 3075, 2417, 1029, 1803, 2418,
 2419, 2420, 2421, 2753, 3816, 3815, 2766, 2767, 3567, 3700,
 2422, 2423, 2424, 2425, 3383, 2426, 1030, 1414,   34, 1455,
 2234, 2644,  588, 1281,  589, 2055,  628,  629, 1664, 1277,
  786, 2520, 2521, 2877, 2884, 2885, 1247, 2886, 1630,   35,
   88,  552, 1595, 2013, 1623, 2044, 2468,  553, 3127, 3411,
 3586, 3829, 3587, 3720, 2808,  570,  768, 1229, 1599,  592,
  593,  793, 1225, 1594, 3062, 2362, 3063, 3367,  582, 1248,
  827,   36,  135,  847, 1261, 2448, 2449, 2450, 2451, 1263,
 2079, 2080, 1149, 1150, 1151, 2706, 2301, 1519, 1152, 1153,
 1154, 1155, 1156, 1507, 1157, 1504,   37,   38,   39, 1182,
   40,   41,   42,  605,   43,   44,   45,   46,   47,   48,
   49, 1158, 1159, 1933, 2317, 2711, 3046,   50, 1944, 1497,
   51, 1119, 1491, 1915, 2295, 2698, 2699, 3038, 3678, 3347,
 3674, 3792, 3339, 3340, 3540, 3341,   52,   53,   54, 2326,
  738,  739,  740,  741,  742, 1544, 1192, 1540, 2427,  449,
 1196,  745,   56,   57,  427,  428, 1405, 1406,  451,  452,
  453,  748,  749,  750, 1206, 1552, 1553, 1554, 1555, 1966,
 2330, 1469, 1470, 1471, 1472, 3011,  704, 1175, 1473, 1474,
 1475, 1476, 3017, 3018, 1477, 1901,  421,  590, 1899, 2724,
 3358, 3359, 3055,  842, 3363, 3549, 3550, 2224, 1318, 3245,
 3246, 3247, 3248, 3462, 3895, 3898,  753,  754, 1558, 1559,
  647, 2339, 2727, 2115, 2116, 1216, 1573, 2428,   59, 1220,
 2345, 2346, 2429, 3324, 3525, 3526, 3944, 3941, 2430,   62,
   63, 2431,   65,   66, 2432, 3909, 1218,  843, 2433, 1532,
 1950, 2434,  789,  790, 1250,  756, 1222, 1989, 1031, 1032,
 2435, 1315, 1033, 1034, 1035, 1434, 1036, 1830, 1037, 1038,
 1039, 1435, 1040, 1041, 1042, 1043, 1044, 1045, 1046, 1811,
 1812,  631,  585,  763, 1278, 1666, 2095, 2533, 2721, 3439,
 3609,  833,  796, 1654,  850, 1256, 1257, 3594, 3595, 3725,
 2840, 3144, 2484, 2835, 1316, 1048, 1049, 1567, 1050, 1051,
 1052, 1341, 1343, 1053, 1701, 1054, 2073, 1055, 1056, 1057,
 1058, 1059, 1060, 1061, 1062, 1063, 1791, 1064, 1541, 1309,
  624, 1675,  625, 1919, 1489, 1490, 1065, 1066, 1067, 1068,
 1069, 3270, 1784, 1070, 1071, 2225, 2634, 3281, 3763, 3764,
 3855, 3938, 3489, 2595, 1072, 1073, 1074, 1075, 1076, 1077,
 1078, 1079, 1080, 1081, 1082, 2976, 3484, 2963, 3275, 2978,
 3645, 3771, 3772, 3861, 3862, 1083, 1779, 1084, 1085, 2921,
 1086, 1740, 1087, 1088, 1089, 1090, 1091, 1092, 2925, 3259,
 1093, 1347, 3256, 1348, 2142, 2593, 1094, 1718, 1095, 1096,
  565, 1311,  760,  638, 1097, 2803, 2111,  653,  616,  650,
 3809,  619, 3896, 1176, 2438, 1193,  578, 1886, 1098,  581,
  630,  632, 1411,  666,  443, 1099, 2226, 1100,  425,  138,
 1466, 1104, 2239, 3292, 2655, 1105, 2263, 1464, 2657, 1859,
 3320,  141, 1483, 3528, 3028, 1484, 2993, 3316, 2264, 1305,
 1239, 2905, 2554, 1856, 2980, 3236, 3447, 2550, 2903,  598,
  795, 2819, 2515, 2867, 2514, 3166, 3168,  804, 2078, 2500,
 3423, 3427,  806, 1620, 2453, 2795, 1651,  777,  794, 1254,
 3413, 3834, 1668, 3616, 2898, 3442, 3614,  802,  765, 2068,
 1582, 3059, 3364, 3796, 3870, 1291, 2091, 3170, 3432, 2459,
 1669, 3445, 2517, 3169, 2871, 3582, 3713, 3583, 3882, 3588,
 3717, 2820, 2821, 3825, 3926, 2460,  782, 1243, 2037,  776,
 2441, 2747, 3069, 3557, 2746, 3068, 3386, 3570, 3072, 3373,
 3690, 3914, 3915, 3080, 3384, 3568, 3807, 2759, 3079,  678,
 1102, 1857,  828, 1296, 2094,  783,  458,  766, 1227, 2007,
 2045, 2822, 3716, 1995, 2738, 1160, 1513, 1499, 1920, 1161,
 1162, 1163, 1164, 1266, 1166,   90, 1114,  800,  687, 2296,
 1528, 1940, 3354, 2286, 2692, 3032, 1538, 1667, 1212, 1207,
  700, 2269, 1684, 2114, 2913, 3628, 3849, 3629, 3968, 1980,
 1983,  455, 2669, 3014, 3523, 3782, 3864, 3907, 3863, 3906,
 4034, 4061, 4011, 4050, 1172, 1946, 2319, 3865, 1579, 1533,
 2320,  757,  829,  764, 1249, 1224, 2086, 2523, 3224,  834,
 1670, 2061,  797, 1638, 1655, 2512, 1639, 2485, 3418, 3487,
 3637, 3486, 1726, 2144, 2581,
};
static int yysindex[] = {                                   8210,
 5899,   -9,54184, 1868,  155,54919,   -4,    0,  813,  878,
    0,   -9, 2567,135979,136480, 3439,141991,  648,  948,    0,
 1339,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1143, 1060,    0, 1240,    0,
    0,    0,    0,    0,    0,    0,    0, 1098, 1092,    0,
127963,141991,  -76,141991,141991,141991,141991,141991,141991,141991,
141991,141991,141991,  988,    0,141991,  881,    0,    0, 1260,
 2181,141991,141991,141991,141991, 1387,141991, 1275,141991,141991,
    0,141991,141991,141991,141991,141991, 1622,    0,142492,    0,
 1453, 1510,141991,    0,141991,141991,141991, 1532,141991,141991,
141991,141991,141991, 1275,141991,141991,141991,141991,141991,141991,
141991, 1135,    0,142993,    0,141991,    0,    0,141991,141991,
    0, 1617,141991, 1621,    0,141991, 1245, 1473, 1669, 1762,
  561, 1525, 1885,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1939,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1910,    0, 2058,    0,    0,141991, 2312,    0, 2328,    0,
141991,141991,141991,141991,141991,141991,141991,141991,141991, 1781,
143494,    0,    0,    0,141991, 6713,    0, 1963, 1973,    0,
 1479,    0,    0, 1987,    0,136981, 2035,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2181,    0,141991, 1713,    0,
    0,    0,  -34,    0,    0,    0,    0,    0,    0,    0,
  129,    0,    0,    0,    0,  -34,    0,    0,    0,    0,
    0,    0, 1257,    0,    0, 2035,    0,    0,    0, 2428,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1790,    0,    0, 2129,    0,    0, 2101,    0,    0,    0,
    0,    0, 2289,    0,    0, 2181,    0,    0,    0, 3163,
    0,    0,    0,    0, 1312,    0, 2306,    0,   18,    0,
    0,    0,    0,    0,    0,    0,    0, 2337,    0, 2239,
    0,    0,147502,    0,    0,    0, 2331,141991,    0, 2349,
    0, 2254,    0,    0,    0,141991,    0,    0,    0,    0,
    0,   39,    0,    0, 2210,    0,    0,    0,    0,    0,
    0,141991,141991,    0,114308, 2668,    0,    0,    0,    0,
 2243, 1227, 2228,    0, 2315,141991,    0,    0,  594, 2298,
    0,150597,141991, 2344, 2242,141991, 2450,    0,    0,141991,
 2312,141991,141991, 2520,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2390,147502,    0, 2434, 2411,    0,    0,
    0, 2501,    0, 2443,    0,    0,    0, 2461,    0,    0,
141991,    0,    0,    0,    0,    0,    0, 2512,141991,141991,
141991,141991, 2489, 2367,    0,  342,  388, 1645,    0,    0,
 2596, 1768,  885,    0, 2358, 2168, 2852,    0,    0, 2495,
    0,    0,    0,    0,    0,    0,    0,    0, 2594, -113,
 2019, 2188,    0, 2639, 2679,    0,    0,    0,    0, 2681,
 2679,    0,    0,    0,    0, 2148,    0,141991, 2687,    0,
    0,    0, 2662,    0,    0,    0,141991, 2693,    0,    0,
    0,    0,    0,150676,    0,    0,141991,141991,141991,141991,
141991,141991,141991,141991, 2355,    0,141991,    0,    0,    0,
 2677,  728,    0, 2246, 2237, 2679, 2728,    0,    0,136981,
141991,    0,    0,141991,    0, 2734,141991,    0,    0,124539,
105102, 2643, 2358,    0, 2680, 2682,    0, 2381,141991,    0,
    0,    0,    0, 2995, 2996, 3001, 2595,    0, 3018,    0,
 3028,    0, 3029,    0,    0, 3039, 3046,115010, 3048,    0,
 3050,    0, 3056,    0,    0,    0,    0,    0,    0,    0,
    0, 3063, 2616, 2627,    0, 3068, 3083,    0,    0,    0,
    0, 3084,    0,    0,105804, 3088, 3101,    0,    0,    0,
    0, 3105, 2802, 3127, 3133, 3135, 3137, 3141, 3149,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 3151, 3154, 3159,    0,    0,
    0,    0, 3162,    0,    0,    0,    0,    0,    0,    0,
 3164,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 3165, 3166, 3168, 3169, 3171,
 3175, 3176, 3177,    0,    0,    0,    0,    0, 3178, 3182,
 3183, 3184, 3186, 3187, 3189, 3197, 3201, 3203, 3206, 3208,
 3212, 3213, 3214, 3215,    0,    0,    0,    0, 3217, 3223,
    0,    0, 3224, 3068, 3083,    0,    0, 3225, 3227,    0,
    0, 3229,    0,    0, 3232,    0,    0,    0,    0, 3233,
 3238,    0,    0,119924,119924,106506,141991,    0,    0, 2700,
 3104,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,80128, 2320,    0,    0,
    0,    0,    0, 3121,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2892,    0, 2661,
    0,    0,    0,    0,    0,    0,    0,    0, 3240,    0,
 3241, 3242, 3247,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 3256,    0, 3254, 3258,    0,
141991, 3261,    0,  740,    0,121940, 2937, 2938, 2939,    0,
    0,    0,    0,141991,  267,    0,    0,    0,    0,    0,
    0, 1374, 3267, 2880,    0,    0,    0, 2882,    0, 2930,
 3278,    0, 2979, 3281,  119,    0,    0,    0,    0,  446,
  163,    0,    0, 2905, 3278,    0,    0,    0,    0,    0,
    0,    0,    0, 3061,    0,    0,    0, 2920,    0,    0,
  442, 3303, 3305, 3307, 3309, 3281,    0,    0, 2298, 3291,
141991,    0,    0,    0, 1085,    0,    0, 3313,141991,    0,
    0,    0,    0,    0,    0,    0,    0, 1478, 3021,    0,
 3310, 3310,    0, 3022,141991,    0,    0,115010,    0,    0,
115010,    0,    0,    0,    0,107224,    0,    0,115010, 1060,
    0, 1060,115010, 2395,    0, 2856,107224,    0,  541, 2072,
    0,    0, 3065,    0,    0, 1496,    0, 2181, 3006, -103,
   -1,    0,141991, 2181, 1466,    0, 2181,    0, 3324,    0,
    0,    0, 3324,    0,    0,    0, 1305, 2983,    0, 2378,
    0, 2932, 2922,    0,    0,    0,    0, 3106,    0,  543,
 3079,    0,    0, 3284,  989, 3309,    0,    0, 2181,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2035,    0,
    0,    0,    0,    0,    0,    0,    0, 2181, 2181,    0,
 3339, 2645, 1718,    0,    0, 1800,    0,    0,    0,    0,
    0,    0, 3112, 3017,    0,    0, 2941, 3009,    0,    0,
    0,    0, 3025,106506,    0,80128, 1311, 3031,    0,    0,
    0,141991,    0, 1843,115010,  280,    0, 2932,141991,115010,
 1871, 1946, 3727,115010, 2932, 1964, 3711,    0,    0, 1275,
    0, 1275,    0,115010,115010,80128, 1179,    0,115010,115010,
115010, 3077,115010,115010,115010,115010,115010,100842,100124, 3711,
115010,115010, 2007,115010, 3349,115010,115010,115010,115010,115010,
 3354, 3360,115010,115010,115010,115010,115010,115010,115010,115010,
115010,115010,115010,115010,115010,115010,115010,115010, 3364, 3040,
 3040,    0,    0, 2348, 3381,  779,141991,115010,115010,106506,
 2414,    0, 2414,    0,    0, 3383,    0,    0, 2398, 3385,
    0,    0,122523,    0,115010,115010,119924,    0,    0, 3389,
 1036,    0,115010,    0,  908,    0,    0,115010, 3000, 3013,
    0,    0,    0,101544,115010, -101,141991,119924,119924,119924,
119924,119924,115010, 3401,123027,115010,115010,115010,115010,107942,
133975,141991,114308,    0,    0, 3059,    0,    0, 3078, 3085,
 3086, 5872, 3152,    0,  264,137482, 3407,121436, 2833,    0,
    0,    0,    0,    0,    0,    0,    0, 3411, 3409, 3199,
 3148, 3150,  740,    0,    0,    0, 1947,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  249,    0,    0,
    0,    0, 1275,    0, 3278,  361,    0,    0,    0, 2997,
 2998,    0,    0, 3004,    0,    0,    0, 3060,    0,125099,
 3426, 1275, 1275, 1275, 1275, 1275,    0,    0, 2448, 2968,
    0,  418,141991,141991,    0, 2932,    0,    0,    0,    0,
    0, 1478,141991, 3139, 3140,141991, 1478, 3430,11143,11862,
    0, 3161, 3432,    0,    0, 3255, 3431, 3434,    0,70062,
    0,    0,70781, 2956,141991,    0, -158,    0,    0,    0,
    0, 1254,    0, 3153, 3134, 3136, 3440, 2358,141991, 2971,
    0, 1496, 2986, 2990, -128, 2992,  212,    0, 3062, 2775,
 2778,    0,    0,    0,    0, 1500,    0, 2181,    0, 3055,
 3055,    0,    0,    0,    0, 2888,    0,    0,   71, 3236,
 3216,    0,    0, 3448, 3450,    0, 3471, 3118,    0,    0,
 3236,    0, 3470,  748, 3144, 3145, 3147,    0, 1275,   18,
    0,141991,    0, 3087, 2927,    0, 1232,    0, 3033, 1316,
    0,    0, 5670,    0,    0,  361,  361,    0,    0,    0,
    0,    0,    0,    0,141991, 3180,    0,    0,    0,    0,
    0, 3236,141991,    0,    0,    0,    0,    0, 3489,    0,
 1425,141991, 3490,    0,    0,124539,141991,80128,    0,    0,
 3179,    0,    0,    0, 3035,    0,115010,115010,71500,115010,
 3491,115010, 3492, 3496,12581,115010,115010,115010,115010,80847,
 3495, 3121, 3502,115010,115010,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 3230, 3505, 3508,
72219, 3146,115010,    0,115010,    0,54281,55000, 3509,141991,
13300,14019,14738,15457,16176,    0,    0,    0, 4223,108644,
    0,    0,    0,    0, 5451, 3510,  961,55719,16895,115010,
115010,72978,    0,17614,56438,18333, 6046, 7548,    0,    0,
19052,19771,20490,21209,57157,57876,58595,59314,60033,60752,
61471,62190,62909,63628,64347,65066,    0, 1011, 3244, 3251,
    0,    0,    0, 3525,    0,    0,    0,    0,    0,    0,
 3529, 3530,73657, 4025, 3531,    0,    0,    0,    0,141991,
127091,    0, 3538,    0, 3528,    0, 1334, 2562, 2193,106506,
    0,    0, 3271,    0, 1095,    0,    0, 3253,119924, 3389,
115010, 3156,115010, 5487,    0,115010,    0,    0,    0, 3547,
 3253, 3253, 2842,    0,    0,  130, 1869, 1869, 2414, 2414,
80128, 3157,149506,    0,    0, 3549,74376,75095,75814,    0,
 2491,    0,    0, 3553, 2700,    0, 3202,    0,    0, 3185,
  687, 1084, 3195,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 3181, 3191, 3555, 3557, 3560,
 2689,    0,    0,141991,    0,    0, 2932,    0, 3565, 2229,
 3567, 3252,    0, 3252, 1745,115010, 3252, 3279, 3292,115010,
    0,141991, 3314,    0,    0, 3262, 3265, 3268, 5872, 3347,
 1000,    0,    0,    0,    0, 2353,    0,  385, 2602, 3226,
 3597,    0, 2298, 2641, 2890, 2893, 2894,136981, 2330,    0,
    0,    0,    0, 1275, 3603, 3604, 3606, 3607, 3608,    0,
    0,    0,    0,    0,    0,    0,    0, 2643, 2358,    0,
    0, 3590, 3610,    0, 3617,    0,    0,    0, 1478, 1478,
    0,    0,    0,    0,121940, 3231,115010,141991,124033,115010,
 3174,115010,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 5595,127091,    0,    0,109346,    0, 2652,    0,
141991,    0,    0, 3325, 3328,    0, 3331,    0,    0,  -42,
 3245,141991,    0,    0, 1104, 1104, 1500, 2221, 1717, 1403,
141991,150676,    0,    0,    0, 2515,141991,141991,141991,126572,
    0, 1328,    0, 3216,    0, 3412, 3422,    0,    0,    0,
    0,    0,129466,    0, -130,    0, 3202,    0,    0, 3220,
137983, 2969, 2972,    0,127963,  743, 1267, 1591,    0, 2679,
 3428,    0,    0, 3418,    0,    0, 2957, 2958,    0,    0,
 3282,    0,141991,141991, 3395, 1316,    0,    0,    0, 2475,
    0,    0,    0,    0,    0,    0,    0,    0, 1502,    0,
 3642, 1667,    0, 1161,    0,    0,    0,    0, 3643,    0,
    0,    0, 1257,  126,    0, 2558, 3393,    0, 3282,141991,
141991, 1425, 3408, 1492,    0,    0,    0, 3318,    0, 3410,
    0,    0,    0, 3675,    0, 2358,21928,22647,129967,23366,
    0,24085,    0,115010,    0,24804,25523,26242,26961,115712,
    0,    0,27680,28399,115010,    0,    0,115010,110048,115010,
80128, 3413, 3299,    0,115010,115010,115010,    0,    0,    0,
    0,    0,    0,115010,    0,115010,72960, 3301,115010,115010,
115010,115010,    0,65785,65785,115010,    0,115010,    0,115010,
    0,115010,    0,    0,    0,    0,    0,115010,115010,115010,
115010,115010,115010,115010,115010,115010,115010,115010,115010,    0,
    0,    0,115010,115010,    0,    0,    0,115010,115010,    0,
    0, 2685,127091,141991,    0,119924, 3681, 2691,115010, 3416,
    0,    0,    0,115010, 3057,    0, 3253,115010, 3253, 3253,
 2932,119924,115010, 3107, 3683,    0,    0,141991,115010,141991,
    0,110766,    0, 2695,141991, 3685, 3468,    0,141991,141991,
141991,141991,141991,141991,141991,    0,    0,    0,    0,    0,
    0, 3473,    0,    0, 3476,    0, 2428,    0, 2428,    0,
    0,    0,    0,137482,    0,    0,    0,    0,    0,    0,
 3398,    0,    0,121940,121940, 2702,141991, 3411,    0, 3185,
  729, 1207, 3429, 3435,    0, 2353, 3462,  101,   11,    0,
    0, 3243, 3221, 3219,    0,  793, 3710,  385,    0,124539,
 3353,    0,  361,    0,    0,    0,    0,    0, 3316, 3317,
 3716,    0,    0,    0,    0,    0,    0,    0,    0,141991,
 3031,    0,111468,141991,    0, 3427, 3274,    0,    0, 3722,
 2229,115010, 3453,    0,    0,    0,    0, 2095,    0,80128,
 -158, 3405, 3538,    0, 2720,    0,80128,141991,    0,    0,
 2181, 2181, 3328,    0,    0, 3375,    0, 2298,    0,    0,
    0, 3463, 3361,    0, 3739, 3515,    0,    0,    0, 3441,
 3442,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 3058,141991,  -13,    0, 3744, 3210,115010, 1229,    0,
    0,141991,141991,141991,150007,141991,115010,141991,    0,    0,
    0, 3499,126053,    0, 3736,    0,    0,    0,    0,    0,
    0, 3477,    0,    0,    0,    0,    0,    0,  720,    0,
    0,    0,    0,    0,    0,    0, 3480,    0,    0,    0,
    0,    0,    0,    0, 3747,    0,    0, 3755,    0,    0,
141991,    0,    0,    0, 2810,141991, 3438, 3537,    0,    0,
    0,    0,    0, 3380, 3550,    0,    0,    0,  748,138484,
    0, 3089,141991, 3090, 2055,    0,    0, 1688,    0, 1187,
    0, 3451, 3456, 3459, 3460, 3461, 3465,    0,    0, 3464,
 3454, 3467,  688,    0,  178, 3779, 3786,    0,    0,    0,
    0, 2475, 3643, 3643, 2181, 3488,134476,134476,    0,    0,
  361,    0,  361, 3061,    0, 3417,    0,    0,    0, 3336,
    0,    0,    0, 2298,    0, 2824,    0, 2148, 1025, 2983,
 2983, 1722, 2558,    0, 3399,    0, 2181, 3420, 2181, 2181,
 2181, 3808,    0, 3274,138985,    0,    0,    0,    0, 3802,
  185,    0, 3803,  194, 3563,    0,141991,141991,    0,    0,
    0,    0, 3819,150562, 2181,    0,    0,    0,    0, 3501,
 3831,    0,    0,    0,    0,29118,    0,    0,    0,    0,
106506,29837,    0,    0,30556,76533,77252,    0,    0,115010,
 3443,31275, 2841,66504,31994,32713,115010,115010,67223,77971,
67942,68661, 2849,115010, 3832, 3844,78690,33432, 8267, 8986,
34151,34870,35589,36308,37027,37746,38465,39184,39903,40622,
41341,42060,42779,43498,79431,79449,    0,    0,    0, 2320,
    0,    0,    0,115010, 3253,119924,115010, 3253,115010, 3847,
    0, 3849, 3623, 3031,    0, 3856, 5612, 3205,    0, 2853,
    0,    0, 3537,    0,129466,    0,    0, 3497, 3498, 3500,
 3503, 3507, 3511, 3512,    0,    0, 1832, 1984, 2294,    0,
    0,    0,    0,  410,139486,    0,148003,121940,    0,    0,
 2171,    0,    0,    0,    0,141991,141991,141991,141991,141991,
141991,141991,    0,    0,    0,    0,    0, 3394,    0,    0,
    0,    0, 1275,    0,    0, 3564,  134,    0,    0, 3514,
    0, 3886,    0,    0, 3523, 3061, 3888, 3469, 3472,    0,
 3889,141991, 2168,    0, 3035,    0,80128,    0, 1478, 3287,
    0,121940, 3661, 3619,    0,    0,    0, 3574,    0,109346,
 2358,    0,    0,    0,    0,136981,    0, 3609,    0, 3228,
 3237,115010,    0,    0,    0,    0,    0,112170,    0,115010,
 3524,80128,    0,    0,    0,    0,    0, 3614,    0,    0,
80128,    0,    0,    0,    0, 3516,    0,    0,127091, 1105,
 3911,127091,115010,    0, 3537, 3893,    0,    0,  716,    0,
 3236, 3236,    0,    0,    0, 3537,139987,141991,  -22, 3611,
    0,  267,    0,    0,  361,    0,141991,    0,    0,    0,
130468, 1831,    0,    0,    0,    0,    0,    0, 3593, 1275,
 3594,141991, 3688,  324, 3079,130969, 3433,    0,    0, 3923,
    0,    0, 3541, 3637, 3551, 3684, 3647, 3689, 3236,    0,
    0, 3568,    0,    0,141991, 3334, 3663,141991, 3663, 3677,
    0,    0,    0,  851,    0, 2298, 3546,    0, 2181,    0,
    0,    0,    0, 3537,    0,    0,    0,    0,    0,  267,
    0,    0, 1161,    0, 3282, 2473,    0,    0,    0,    0,
138484, 2983, 1305,  780,    0,    0,    0,    0, 3625, 3192,
 3384, 4645, 5829, 3628,    0,    0,    0, 3540,    0, 3542,
    0,    0,    0,    0,    0, 3964,    0,    0, 2861,    0,
    0,    0,123531, 2863, 3965,    0,    0, 3969, 1583,    0,
    0, 3656,134977,140488,    0,    0,    0,    0,    0,115010,
 3973,115010,    0,115010, 1077,    0,    0,115010,    0,    0,
44217,44936,115010,115010,115010,115010,115010,    0,80128,    0,
    0,115010, 3703,115010,    0,115010,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,141991, 3285,115010,    0, 2320, 3253,115010, 3253,    0,
    0,115010, -111,    0,115010, 3474,141991, 3682,    0,141991,
 3959,    0,141991, 3236,    0,    0,    0,    0,    0,    0,
    0,  413,132472,  413,    0, 3473,    0, 3476,    0,    0,
    0,    0,    0, 3572,    0,  268,141991,148504,    0,    0,
 2328,    0,    0,    0,115010, 3985,    0,    0,141991, 3982,
 3713, 3714, 3715, 3718, 3719, 3720, 3723,    0,    0,  180,
    0,141991,    0,    0, 3599, 3599,  832,    0,    0, 3055,
    0,    0, 3289, 3290,    0,    0,    0, 3616, 2358,    0,
141991, 2229,115010,115010, 3294,    0,    0,    0,    0,    0,
141991,    0, 4000,141991,    0,    0, 4005, 3324, 3324, 4007,
80128,    0, 4008, 3749,    0,127091,    0,    0, 1575,    0,
    0, 3538, 3561, 3477, 3758,    0,115010, 3538,80128,  341,
    0, 3444,    0, 3772,    0,    0,141991,  341,141991,    0,
    0, 3447,    0,    0,    0,    0,    0,    0, 1421, 3688,
 3433,    0,  789,    0, 3782,    0,    0,    0, 3721,    0,
 3725,    0,    0,    0,    0,    0,    0,   58,    0, 3800,
115010,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  560,141991,    0, 3663,    0,    0,  851, 3791, 3731,
    0,    0, 2473,    0,    0,    0,    0, 1255,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 3328,    0,    0,
    0,    0,    0,    0,    0,    0,141991, 3671,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 3579,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 3484,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 3487,
 2291,    0,    0,    0, 2181,    0,    0,    0,    0,    0,
 3430, 4035,    0,    0, 3776,127584,150562, 1275, 1674,    0,
    0, 2181, 3179,    0,    0, 2876,    0,132973,    0,141991,
    0,80128,    0,45655,80128, 3664,115010,115010, 3778,46374,
    0,    0,47093,47812,48531,80128, 9705,10424, 2111,    0,
49250,49969,    0,115010, 3327,79431, 3253, 3121,    0,    0,
 3414,80128, 3327,    0,115010,    0, 4021, 2898,    0, 3537,
    0,    0,    0,    0,    0,    0,    0,    0, 3781,    0,
  268,141991,141991,141991,141991,141991,141991,148504,148504, 3382,
    0,    0,    0,  268, 3734,139486,    0, 3835,    0,140989,
    0,    0,    0, 2358, 3676,    0,141991,    0,    0,    0,
    0,    0,    0,    0,    0,  262,  262,    0, 4061,    0,
 3797,    0, 3724, 3680, 3437,    0,    0,    0, 3403, 3701,
    0,    0,    0,141991, 4077,    0,    0, 4074,    0,80128,
    0,141991, 2643,    0,    0,    0,    0,    0,    0, 3726,
    0,115010,116414, 3702,126572, 3538,    0,    0,    0,    0,
115010,115010, 3810,    0,126572,    0, 4081, 5670, 5670,    0,
    0, 3814,    0,    0, 4082,    0, 3795, 3796, 2428,    0,
    0,  735,    0,    0,    0,    0,    0,    0,    0,50688,
    0,    0,    0,    0,    0,    0,    0,133474,    0, 3728,
 2181,    0, 1255, 3790,    0,    0,    0,    0, 3328,    0,
    0, 1687,    0,    0,    0,    0,    0,    0, 2908,141490,
 4094, 2181,    0,    0,    0,115010,127584, 2181, 1275,   53,
    0,    0, 4095,    0,    0,    0,134977,    0,    0,    0,
    0,    0,    0, 4091,    0,115010,    0, 3729,    0,    0,
    0,    0,    0,115010,    0,115010,    0,    0,    0,    0,
    0,80128,    0, 4097, 3285,    0,    0,   51,    0, 4099,
 6088,    0,    0,    0,    0,  413,  413,  413,  413,  413,
  413,  413, 3773,132472,    0,    0,    0,    0,    0,    0,
    0,    0,    0,141991,    0,    0,    0,    0,141991,    0,
    0,    0, 3676,  833,    0,    0, 2912,    0,    0,    0,
    0,    0,    0,    0,    0,    0,141991, 1721,141991,    0,
    0,    0,    0, 1724,    0,    0,109346,115010, 4098,    0,
 3882,    0,    0,    0,141991,129466, 3202, 2924,106506,    0,
80128,126572,    0,80128,80128,141991,  977, 1037,    0, 3614,
 3850,    0,    0, 4111,141991, 2428, 2428, 3665, 3858,    0,
 3890,    0,    0,    0, 3600,    0,    0, 1039, 4112,141991,
135478,    0,    0,    0,134476,    0,136981,    0,    0,    0,
 3445, 3446,    0,    0,    0,    0,    0,141991,    0, 4096,
    0,    0,    0,    0,    0,  967, 4115,  100,51407, 4119,
 3804,    0,    2,    0,    0, 3061,    0, 4126,141991,141991,
    0,115010,80128,52126,    0, 3327,102246,102246, 3513,    0,
 3466,    0,    0,115010, 1899,141991,  268,  268,  268,  268,
  268,  268,  268,    0,    0,    0,    0,    0,    0,    0,
 3613,    0,    0,  262,  262,  262,  262,  262,  262,  262,
    0,    0,    0, 1317,    0,    0,    0,    0, 2947,    0,
141991, 4128,    0, 1457,    0, 3537,    0,    0,52845,    0,
 3876, 3614,126572,    0,    0,141991,141991,  385, 3732,    0,
 3883, 3917,    0,126572, 2932,    0, 3794, 3665, 1453,    0,
    0, 3552,    0,    0,  767,    0, 1039, 3534, 3380,    0,
    0,    0,    0,    0,    0,    0,    0, 3674,    0,    0,
    0,141490,    0, 2181,    0, 3620, 1898, 1942, 3602,    0,
    0,    0,    0, 3912,    0,    0,    0,    0, 2181,    0,
 3740,    0,    0,    0,    0,    0,    0, 4152,102964, 3543,
 3478, 4614,    0,    0,    0,    0,    0,80128,    0,    0,
 2351,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,149506, 1457, 3643, 3930,    0,  -22,
 4158,    0,    0,126572,    0,    0, 1037,    0,    0,    0,
    0,    0,126572, 3910,    0,    0,    0,    0, 4159,141991,
    0, 3872,    0, 3537,    0, 3537, 3907,    0,    0,    0,
    0, 3550,    0,141991,141991,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  100,  609,    0,    0,141991, 3874,
    0, 3554, 3494, 4811, 3942,    0,    0,    0,    0,    0,
 4165,115010,    0,    0, 3644, 4166,    0, 2298, 3838, 2298,
    0,    0,    0, 1325,    0,    0,    0,141991,    0, 2428,
141991,    0,    0,    0, 3933,    0,    0,    0,  361,    0,
    0,    0, 3730, 3733, 3008,    0, 4178,    0,    0,    0,
    0,    0,103682,    0,80128,  940, 1091,    0, 2358,    0,
 2473,    0,    0,    0, 1325, 3799, 3909,115010, 2206,115010,
    0,    0, 3859,    0, 4188, 3933,    0,    0,    0,    0,
    0,141991,    0,    0, 3577, 3544, 5158,    0,115010, 3902,
    0,115010, 1285,    0, 2852,    0,    0, 3010, 3015,117116,
    0,115010,117818,80128, 3813, 3854, 3821,80128, 1307, 3665,
 3875, 3878,    0,    0,    0, 1904,    0,141991,    0,    0,
    0,    0, 3826,    0, 3834,    0, 3848,    0,    0,    0,
    0,    0,149005,    0,    0,80128, 3641,    0,80128, 3646,
80128,    0,    0,    0, 1253, 1253,    0, 3960,    0, 3830,
    0,    0, 3922,141991, 3665,    0,    0,    0, 3016, 3932,
    0, 1321,    0,143995,115010, 3651,115010,115010, 3825, 1727,
    0,    0,    0, 4227, 1223, 3665, 2428,    0,    0,    0,
 2168,    0, 3869,    0,    0,    0,115010,80128,80128,    0,
    0,    0,    0, 1223, 3840, 3550,    0,    0, 3859,    0,
 3855,    0, 4237,80128,    0,  267,  361, 3665, 2168, 4246,
    0,    0,    0,    0, 3862,109346, 4237, 4254, 3023,109346,
    0, 3032,    0,
};
static int yyrindex[] = {                                   3897,
    0,  992, 1830,    0,    0,    0,    0,    0,    0,    0,
    0,  903,    0,    0,    0,    0,    0,    0,    0,    0,
 4299,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1448,    0,    0,  323,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1668,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 3976,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1668,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,98344,    0,    0,    0, 3913,    0, 4038,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1596,112888,
 1443,    0,    0,    0,  352,    0, 1204,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 4043,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 4043,    0,    0,    0,    0,
    0,    0,  215,    0,    0, 1204,    0,    0,    0, 4047,
    0,    0,    0, 1841,    0,    0,    0,    0,    0,    0,
 4043,    0,    0, 1934,    0,    0,    0,    0,    0,    0,
    0,    0,150709,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  919,    0, 4272,    0, 4051,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 4053,    0,    0,    0,    0,    0,    0,    0,
    0,  665,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2073,    0,    0, 2090,    0,    0,    0,    0,    0,
    0,    0, 2096,    0,  318,    0, 6229,    0,131470,    0,
    0,131971,144496,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 3920,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 4053,    0, 2102,    0,    0,    0,
    0,    0,    0,144997,    0,    0,    0,145498,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1561,    0,    0,    0,    0,113606,104400,    0,
    0, 3921, 1063,    0, 2106, 2085,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  297,    0,
    0,    0,    0,    0, 2118,    0,    0,    0,    0,    0,
 2118,    0,    0,    0,    0,  208,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2549,    0,    0,    0,    0, 2118,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  231, 2106,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
60873,    0,    0,    0,    0,    0,    0,    0,    0,    0,
61592,    0,    0,    0,    0,    0,    0,    0,    0, 8386,
    0,    0,    0,    0,    0, 6948, 7667,    0,    0,    0,
    0,54402,    0,    0,    0,62311,63030,    0,    0,    0,
    0,63749,64468,    0,    0,    0,    0,    0,    0, 9105,
 9824,10543,11262,11981,12700,13419,14138,14857,15576,16295,
17014,17733,18452,19171,19890,55121,55840,65187,20609,21328,
22047,56559,65906,22766,23485,24204,24923,25642,26361,27080,
57278,27799,28518,29237,29956,30675,31394,32113,32832,33551,
34270,34989,35708,36427,37146,37865,38584,39303,40022,40741,
    0,    0,41460,42179,42898,66625,67344,68063,68782,69501,
70220,70939,71658,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,43617,44336,45055,45774,72377,57997,
46493,47212,58716, 6948, 7667,47931,48650,73096,73815,49369,
    0,    0,    0,    0,    0,50088,50807,51526,52245,59435,
60154,52964,53683,    0,    0, 3897,    0,    0,    0, 2143,
77410,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  367,    0,78129,    0,
    0,    0,    0,  971,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,74534,75253,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,75972,
    0, 1277,    0, 3373,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2610,    0,    0,    0,
    0, 2144, 2706, 3377,    0,    0,    0, 3706,    0,    0,
 4210,    0,    0, 4469,    0,    0,    0,    0,    0, 3903,
 4525,    0,    0, 3962, 4210,    0,    0,    0,    0,    0,
    0,    0,    0, 2967,    0,    0,    0,    0,    0,    0,
 4539, 4777,    0, 4015,  329, 4469,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 3990,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1598,    0,    0,    0, 3897,
    0,    0,    0,    0, 1163,    0,    0,    0, 2207,    0,
    0,    0,    0,    0,    0, 4054,    0,    0, 3935,  236,
 4054,    0,  213,    0,    0,    0,    0,  286,    0,    0,
    0, 3897,    0,  635,    0,    0,    0,    0, 1737, 4525,
 1094,    0,    0, 1684, 2038,    0,  218,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1204,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 4054, 1340, 1444,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 3897,    0, 1449, 4287,  278,    0,    0,
    0,    0,    0,118520,    0,118520,    0, 3897,    0,    0,
118520,118520,93737, 4290, 3897,118520,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 3894,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,118520,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 3897,
80286,    0,81005,    0,    0,    0,69380,53564,    0,    0,
    0,76691,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,119222,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 4290,    0,    0,    0,    0,
    0,    0,  318,    0,    0, 6727,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 3897, 3997,    0,
    0,    0,    0,    0,    0,    0,    0,95805,    0,    0,
    0,    0, 3373,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 4210,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2273,    0,
    0,  665,    0,    0,    0, 3897,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1626,    0,    0,
    0,    0, 1243,    0,    0,99004,    0, 1064,    0,  770,
    0,    0, 1876,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2280,    0,    0,    0, 2106,    0,    0,
 1444,    0, 3993,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  651,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 4064, 4069,    0,    0,    0,    0,145999,    0,    0,    0,
    0,    0, 2284,    0,  207,  211,  223,    0,    0, 1118,
 1444,    0,    0, 2301,    0,    0,    0,    0,    0, 4037,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  330,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 4039,    0,150480,    0,    0,    0,    0,    0,    0,    0,
 4298,    0,    0,    0,  296,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 3037,
    0, 4300,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 5280, 5493, 5663,125255,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,81566,    0,78848,    0,    0,    0,
    0,    0, 2336,    0,    0, 2707,    0,94441,    0, 3897,
    0,    0,    0,    0,    0,    0,    0,90921,    0,    0,
    0,    0,    0,95145,    0,    0,    0,    0,    0,    0,
85993,86697,    0,    0,    0,79567,83162,83881,81724,82443,
  656,    0,  216,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2143,    0, 4080, 6745, 7443,146500,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 3977, 8162, 4059,
    0,    0,    0,    0,    0,    0, 3897,    0,    0, 3997,
 2598, 4017,    0, 4017, 3997,    0, 4017,    0,    0,    0,
97166,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 3756,   57,    0,    0,    0, 4850,
    0,    0,    0,    0,    0,    0,    0,    0, 2341,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,99522,
    0,    0,    0,    0,    0,    0,    0,  231, 2106,    0,
    0,    0,    0,    0,    0,  939,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2276,    0,    0,    0,    0,
 1436,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1419,
    0,147001,    0, 4084,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  179,    0,    0,128464,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2118,
 2346,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 4052,    0,  232, 2832,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1985,    0,    0,    0,  281,    0,    0,    0, 3914,    0,
    0,    0, 2350,    0, 1650, 3877,  714,    0,    0,    0,
    0, 4039,    0, 4058,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2106,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1386,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 4315, 4315,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,91625,    0,87401,92329,
 3897,    0,    0,  251,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  309, 7498,    0, 1004,    0,  277,    0,  277,    0,
    0,    0,    0,    0,    0,96506,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,95805,    0,146500,
    0,    0,    0,    0,    0,   57,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 3955,    0,    0,    0,    0,
 4929,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  197,    0,
  278,    0,    0,    0,    0,    0,    0,    0,    0, 1610,
 1069,    0,  616,    0,    0,    0,    0,    0,    0, 3012,
    0,    0, 2361,    0,    0,    0, 3043,    0,    0,    0,
    0,    0, 2430,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2545,    0, 2586, 2499,    0,    0,    0, 2613,
 2666, 2747,    0,    0,    0, 2755,    0,    0,    0,    0,
    0,    0, 1683,    0,    0,    0,    0,    0,    0,    0,
    0, 4306,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 3051,    0,
    0,    0, 4054, 4054,    0,    0,  725,  523,  922,    0,
    0,    0,  236,  307,  408,    0,    0,    0,    0, 1578,
    0,    0,    0, 1172, 2116,    0,    0,    0,    0, 3857,
 1643,  273,  284,  285,  305,  316,  317,    0, 4054,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 3914, 3914,    0,    0,    0,    0,    0, 1278,
    0,    0,    0, 3759,  218,    0,    0,    0,    0, 1310,
 1444,    0,    0,    0,    0,    0,    0,    0,    0,  291,
 3998,    0, 3877,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 4043,    0,    0, 4043,    0,    0,    0,    0,    0,    0,
    0,    0, 3972,    0,    0,    0,    0,    0,    0, 4328,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 3897,    0,    0,    0,    0, 4329,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  158,    0,    0,    0,    0,84585,
    0,    0,    0,    0,88105,    0,    0,93033,    0,    0,
    0,    0,    0,  189,    0,    0,  162, 4036,    0,    0,
    0,    0, 4310,    0,    0,    0, 4054,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  235,    0,    0, 2015,    0,    0,    0,
 3997,    0,    0,97826,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 5008,    0,    0,    0,    0,
 2386,    0, 3946,    0,  296,    0, 1171,    0,    0,    0,
    0,    0,    0,  404,    0,    0,    0,    0,    0,    0,
 2106,    0,    0,    0,    0,    0,    0, 2451,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 4319,    0,    0,
    0, 4321,    0,    0,    0,    0,    0, 4323,    0,    0,
 4325,    0,    0,    0,    0, 4085,    0,    0,    0, 3897,
    0,    0,    0,    0, 1022,    0,    0,    0, 4103,128965,
    0,    0,    0,    0,    0, 1586,    0,    0,  188,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 4345,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2401,    0, 4079,    0, 4079,    0,
    0,    0,  351,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2413,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  331,  539,    0,    0,    0,
 1578,  291,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  944,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  781,    0,    0,
    0,    0,    0,    0,150505,    0,    0,    0,  447,    0,
    0,    0, 4287,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 4092,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 4353,    0,
    0,    0, 3780,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  160,    0,    0,85289,88809,    0,89513,    0,
    0,    0,  175,    0,    0,  165,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  242,    0,  242,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2435,    0, 1031,    0,    0,
 2215,    0,    0,    0,    0,    0,    0,    0,    0, 2482,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2435,
    0,    0,    0,    0, 1937, 1937, 4040,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2106,    0,
    0, 2437,    0,    0, 1597,    0,    0,    0,    0,    0,
    0,    0, 1128,    0,    0,    0,    0, 3935,  884,    0,
 4338,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  274,    0,    0,    0,    0,    0, 4340, 4342, 4346,
    0,    0,    0,    0,    0,    0,    0, 3054,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2875,
 5625,    0, 4259,    0, 5641,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2153,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 4079,    0,    0, 4079,    0,    0,    0,    0,    0,
    0,    0, 3283,    0,    0,    0, 1335,    0,    0,  281,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  204,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  886,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  991,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2487,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,120428,120932,    0,    0,    0,    0,    0,    0,
    0, 4363,    0,    0, 3991,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 3069,    0,    0,    0,    0,
    0,    0,    0,    0, 4370,  158,90217,  306,    0,    0,
 4371,  173, 4370,    0,    0,    0,    0,    0,    0, 3074,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2435,    0,    0,    0,    0,    0,    0, 1031, 1259,  265,
    0,    0,    0, 2435,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  303,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2435, 2435,    0, 4068,    0,
 4879,    0, 3955,    0,    0,    0,    0,    0,    0, 4927,
    0,    0,    0,    0,    0,    0,    0, 2253,    0,  239,
    0,    0, 3034, 2873,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1193, 1154,    0,    0,    0,    0,
    0,    0,    0,    0, 1193,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 3904,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2490,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2503, 1131,    0,    0,    0,    0,    0,    0,  300,
    0,    0,    0,    0,    0,    0, 4287,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  169,    0,    0,  160,    0,    0,    0,    0,    0,
  295,    0,    0,    0,    0,  242,  242,  242,  242,  242,
  242,  242,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1529,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2847,    0,
    0,    0,    0,    0,    0,    0,  289,    0, 3897,    0,
 1685, 1193,    0, 4105, 4107,    0,    0,    0,    0, 4149,
    0,    0,    0,    0,    0,    0,    0, 2234,    0,    0,
    0,    0,    0,    0,    0,    0,  584,    0, 2511,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2513,    0,    0,    0,
    0,    0,    0,    0,    0, 1212,    0,    0,    0,    0,
    0,    0, 3091,    0,    0, 4370,    0,    0,    0,    0,
    0,    0,    0,    0,  269,    0, 2435, 2435, 2435, 2435,
 2435, 2435, 2435,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2435, 2435, 2435, 2435, 2435, 2435, 2435,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 3155,    0,    0,  426,    0,    0,    0, 1804,
125534, 4323, 1193,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 4123, 1193, 3897,    0,    0, 2234, 3976,    0,
    0,    0, 4971, 4971,    0,  808,    0,    0, 1071,    0,
    0,    0,    0,    0,    0,    0,    0,  721,    0,    0,
  204,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  946,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  337,    0,    0,
 4382,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  216,    0, 3914, 3978,    0,  942,
    0,    0,    0, 1193,    0,    0,    0,    0,    0,    0,
    0,    0, 1193,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2307,    0, 2307,    0,    0,    0,    0,
    0,  408,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 3092,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  320,    0,    0,    0, 3980,    0,
    0,    0, 1922,    0,    0,    0,    0,    0,    0, 1062,
    0,    0,    0, 5411, 1967,    0,    0, 1159,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 4386,    0,    0,    0, 2106,    0,
 3793,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  357,    0, 5655, 1967,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1940,    0,    0,    0, 2017,    0, 2234,
 3452, 5167,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,125406,    0,    0, 3098,    0,125279, 2089,127807,
 2183,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 5821,    0,    0,    0,    0,    0,
  197,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1399,    0, 5821, 4376,    0,    0,    0,
 3946,    0,    0,    0,    0,    0,    0, 3109, 2250,    0,
    0,    0,    0,    0,    0,  408,    0,    0,69885,  197,
    0,    0,  299, 3125,    0,    0,    0, 5821, 3946,    0,
    0,    0,    0,    0,    0,    0,  325,    0,    0,    0,
    0,    0,    0,
};
static int yycindex[] = {                                      0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 3905,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2524,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1258,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 3692,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 3787,    0,
    0,   -8,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 3698,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 3958,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 4400,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 4395,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 4396,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 4151,    0,    0,    0,    0,
 4154,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 4155,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 4402, 4405,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  802,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 4156,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 4146,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1168,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  861,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 4065,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 3717,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 4153,    0,    0, 4157,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 4412,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 4195,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 4072,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2016,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 4417,    0,
    0,    0, 4170, 4171,    0,    0,    0,    0, 4102,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 4071,
 1273,    0,    0,    0,    0,    0,    0,    0, 4176,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 4172,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 4182,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 3961,    0,    0,    0,
    0,    0,    0,  879,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 4437,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 3884,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1678, 1956,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 3936,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 3891, 3899,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 4454,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 4101,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2233,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 4235,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1286,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2296,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  909,    0,    0,    0,    0, 4457,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,
};
static int yygindex[] = {                                      0,
    0,    0,    0,    0, 4500,    0,    0, 2597, 3026,    0,
 3036, 3038, 1847, 3041,    0, 1850, 3044,    0, 1856,-2260,
    0, 1353,    0,    0,    0,    0,    0,-2396, 1012, 1014,
 3042, 2258, 1838, 1213,    0,    0,    0,-2262,    0, 1981,
 1296,    0,    0, 1087,    0,    0, 2862,    0,    0,    0,
    0,    0,    0, 4109,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1375,    0,    0,    0, 1121,-1831, 1432,
-1957,  849, 2041,    0, 1686,-1894, 3738, 1390,    0, 4464,
 2100,    0,    0,  836,    0,-2632, 4453,    0,    0,    0,
    0,  724,    0,    0,    0,    0,  947,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2070,    0,
    0, 1415,-2183,    0,    0,  769, 4132,  837,    0,-1896,
 -570,    0, 3392,    0,  727,    0, 2039, 1408, 1707,    0,
    0,    0,    0,  537,-2137,    0,-2486,    0, -379,  868,
    0,  664,    0, 1720,-2133,    0,-2481,  547,  637,  636,
  606,  120,-1843,-1839,  -40,    0,    0,-1191,-1943,    0,
 1506,    0,  958,-2272, 1508,  111,-1829,-1796,   93,  807,
 -533, -634,    0,    0,   89,    0, 2942,-1663,    0,    0,
 3895, 2506,    0, 2505,-1120,    0,    0, 3002,    0,    0,
 2588,-1343,-1252,    0,    0,    0,    0,-2276,-1469,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
-3209, 1045, 1848, 1849,    0,    0,    0,  603,    0,  605,
    0,    0,  706,    0,    0,    0,    0,-1138,-1661,    0,
    0,    0,    0, 2226,    0,  921,    0, 1859,    0,  819,
    0,    0,    0,    0,    0, 4628, 3188, 2776,    0,    0,
    0, 1652,  109,    0,    0,    0,   50,    0,    0,    0,
-1114,    0, 2115,    0, 1416,    0,-1849, 3391,-1890,    0,
    0,    0,    0, 2629,    0, 2180,    0, 2600,    0,    0,
    0,    0,  810,  925,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 3066,    0, 2637,    0, 1096,    0,    0,
 3027,    0,    0,    0,-1897,-2478,    0,    0, -643,    0,
 3011, 2146,-2381, -764,    0,    0,    0,-2336,    0,    0,
 -762,    0,    0, 3522,    0, -858,    0,    0,    0,    0,
    0,    0,    0, 4514,    0,    0,    0,    0,    0,    0,
    0,    0, 3158,    0,    0,    0, 1314,    0,    0,    0,
    0,    0,    0,    0, 2375,    0, 1326,    0,    0, 1637,
    0,    0,    0, 1140,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 3504, 3938,-1383,    7,    0,
    0,    0,-1001,    0, 4256, 3992,-1614,    0,    0, 1395,
    0,    0,    0, 3943,    0, 3481,    0, 2732,    0,    0,
    0,-1317,-1903, 3234,    0,    0, 1691,    0, 3248,    0,
    0,    0,    0,    0,    0, 2439, 2185,  110, 2820,    0,
    0, 1173,    0,-1263,    0,    0, 1041,    0,-1851, 3415,
    0, 1263,    0,    0,  757,    0,-1172,    0,    0, 2756,
-1522,    0,    0, 3975, 2014,    0,    0, 4730,    0,-2585,
-3299, 2001, 4735,    0, 1214, 1215,    0,    0, 4736,    0,
    0, 4741,    0,    0, 4747,    0, -832, 3218, 2357,-2169,
 2431,    0,-2204,-2642,-1156,-2219,  803,    0,-1340, -758,
-1352,-1328,-1000,    0,    0,    0,    0,    0,    0,    0,
    0, 3333,    0,    0,    0,    0,    0,    0,    0, 2936,
    0, 4322,    0,    0,    0,-1410,    0, 2240, 2232,    0,
 1028, 3937, 3979, 3115, 3926, -657,  421,    0, 1180,    0,
    0,-1813,-1905,    0, 2525, -875, -881, 2789,    0,-1225,
-1598, 3774, 3771,    0, 3335, -980,-1019, 3386, 3222, 3235,
-1170,-1178, -714,-1561,-1556,-1550,    0,  -64,  -54,-1864,
 -827,    0, -116,-1482,-1491, -672,    0,-1910,    0,    0,
    0,    0,    0,    0,    0,  987,    0,    0, 1146,    0,
    0,    0,    0, 2620,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,-2755,-2626, 1302,    0,
    0,    0,    0,    0,    0,    0, 3397,    0,    0,    0,
    0,    0,-1889,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1533,    0,-2010,    0,    0, -738,-1545,    0,
 -110, 2492, -816, -127,   47, 1993,-2257,    0,  -67, 4674,
    0,   59,  -74,-1223, -448, -553, -107,  -70,    6,    8,
  -55,  -71,-1970, 1487, -232,   49,-1417,  -14,    0,    0,
 3045,    0, 2516, -161,  354,    0,    0, 3340,  764,    0,
    0,    0,    0,   -5, 2122,    0,-2008, 1495,    0,    0,
 3506,    0, -784,-1376,-2468,    0,    0,    0,    0,  121,
 -407, 1906,    0,    0,-2340,-2956,    0,    0,    0,-1998,
    0,  841,    0, -736,-1892,-2674,    0,    0,    0,-1219,
    0,    0,    0,-1591,    0,    0,    0,    0, -718, 1451,
-1430,    0,-2288,    0,    0,    0, 2712,    0, -537, 1211,
    0,    0, 1378, 1081,    0,    0, 1244,    0,    0,-2656,
-2153,    0,    0, 1003,  902, 2031,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,-2392,
-1298,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 3605,    0,
    0,    0,    0,    0,    0,    0, 3696,    0,    0,    0,
    0,    0,    0, -516,    0, 4827,    0,    0,    0, -668,
    0,-1481,    0,    0,    0, 1808,    0, -809,    0, 1379,
-1391, 1293,    0,    0,    0,    0, 1090,    0,    0,-1505,
    0,    0,    0, 1833,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  937,    0,
    0,    0,    0, -386,    0,    0,    0,    0, 1246,    0,
    0,-1498,    0,    0,    0,    0,    0,    0,    0,    0,
 1359,    0,    0,    0,    0,
};
#define YYTABLESIZE 151455
static int yytable[] = {                                     424,
  430,  571,  444,  670,  556,  780,   55,  662,  586,  658,
 1319,  594, 1310, 1298, 1924,  661, 1722, 1122, 1117, 1297,
  429,  423, 1729,  583, 1404, 1407,  610, 1844,  675, 1251,
  798, 1199, 1202,  635, 1637, 1570,  611, 1971, 1548, 1264,
 1240, 1265,  781, 1569, 2072, 1409, 1226,  660, 1148,  655,
 2367, 1622, 2662, 2297, 2663,  665,  554,  557,  668,  566,
  569,  572,  579,  424,  584,  587,  424,  595,  569, 1267,
  664,  602, 1804, 1200, 1203, 1566, 2097,  614,  557,  566,
  569, 2074,  579, 1259,  424,  584, 2075,  587,  424,  595,
  569,  639, 2076, 2458,  602,  826, 2321, 2077,  651, 2713,
  424,  654,  557, 2357,  651,  566,  569,  572,  579, 2436,
  424,  584,  587,  667,  595,  569,  639, 2015, 2016,  602,
 1621,  677,  423,  422,  424,  424, 2765, 3048,  569, 2578,
 2437,  688,  663,  568,  601, 2756, 2757, 2758,  613, 2202,
 2021,  568, 1402, 1402, 1408, 1685, 1242,  423, 1401, 1403,
 1890, 2036, 2846, 2847, 2081, 2081, 2981,  601, 1957, 3106,
 1262, 2005, 2006, 1962, 1968, 3132, 2982, 2858, 2775, 2735,
 1992, 2099, 2911, 2786, 1662, 1165, 1302, 2983, 2372,  659,
 1952, 1665,  674, 2779,  676, 1189, 1191,  580,  669, 2508,
 2505, 1294, 2092, 2538, 1568, 2207, 3422,  644, 1985,  787,
 1987,  685, 1981,  411,  617, 1985,  828, 1060,  627, 1988,
  826,  633,  717, 1982,  767, 1858,  621,  287, 1578, 2839,
 2052, 2562,  827, 3005,  422, 1852, 1990, 3159,  642, 1448,
 1420,  383, 2356,  832,  102,  305, 1546,  527, 1408,  558,
 2032,  100, 1817, 2841, 2522, 1244,  545, 3679,  680,  422,
 1634,   22, 2842,  672, 2665, 1781, 1418, 2542, 1602, 2994,
 3230, 2543,  411,  849, 2361,  828, 1060, 2026, 1948,  826,
 2539,  524,  833,  767, 1802,  771,  287, 1448, 3020, 1408,
  298,  827, 1408,  834,  830,  841, 1517, 1230, 3090, 1420,
  383, 1856, 1918,  102,  305, 1463, 1021, 1408, 1502, 3098,
  100, 1600, 1527, 2540,  829, 3300,  310, 1883, 2361, 1993,
 1954, 1487, 1404, 1407, 3097,  832,  831,  736,  824, 1524,
 1540, 1691, 2343, 2361, 1504, 3623, 1693,  771, 1208,  260,
  404,  833,  658, 1703,  845, 1991, 1448, 2813, 3639,  298,
  186, 3102,  834,  830,  841, 1978, 1857,  527, 3750, 3283,
  384, 1570,   98, 1702, 1463, 1021,  503, 1502, 2027, 1569,
 3702, 1527, 1474,  829, 1833,  310, 1740, 3156, 2688, 3041,
 2670, 1997, 3640,  136,  832,  831,  736, 1992, 1524, 2690,
 2454, 1198,  136, 1504, 1245,  778, 2018, 1208,  260,  404,
 1194, 1546, 3279, 1508, 1246, 1436, 2143,  503, 1404, 1795,
  503, 3389, 2489, 1409, 1028, 1923, 1437, 1740, 2743,  384,
 1740,  430, 3035, 3641, 1581,  503,  557,  566,  569,  579,
  424,  584,  587,  424,  569, 1740,  602, 1201,   89, 1307,
  444,  429, 1408, 2702, 1807, 2703, 1251, 3237, 2489, 1631,
 2836,  761,  527, 3317, 1409,  606,  607,  769, 1492, 2691,
 1028,  545,  294, 3005,  779, 1509, 3300, 2019, 2318, 1740,
 1804, 1947, 1409, 1194, 1570, 1702, 1889, 3744,  115, 1851,
  828, 1060, 1569,  767,  826, 3412,  524, 2342,  767, 3751,
 2749, 1522, 3805,  767,  469,  710,  827,  176,  527,  601,
  176,  767, 2436, 2519,  771, 1979, 1529,  545,  102, 1571,
  137, 2855, 1408,  771, 3624,  100, 2000,  828, 1060, 2277,
 1945,  826, 1719, 2437, 1720,  767,  828, 1060, 1408, 1998,
  826, 2455,  524,  827,  767, 3317,  364, 3490, 2361,  716,
 1649, 3317,  827, 2689, 1955, 1402,  833,  839,  262, 1204,
 1642, 1809,  706,  566,  627,  844,  712,  834,  830,  841,
 1408,  805,  527,  708,  841, 3036, 1402, 1402, 1402, 1402,
 1402, 1408, 1836, 1837, 1838, 1839, 1840, 2272,  829, 2923,
 1408,  364,  658,  833,  828, 2328, 2329, 1690,  826,  832,
  831,  469,  833, 1006,  834,  830,  841, 1418,  828, 1060,
  827,  841,  826,  834,  830,  841,  767,  262,   98, 1514,
  841, 1834, 1420,  186,  827,  829, 2630,  524, 3103, 3280,
 1408, 1116, 2817,  846,  829, 1404,  832,  831, 3124, 1408,
 1746, 1747, 1856, 1545, 1120,  832,  831, 1006,  602, 2878,
 2879, 3336, 3337,  566,  320, 3388, 2213,   24, 2492, 1231,
  833,  566, 1006, 1804, 1540,  373, 1922, 2331, 1601, 3485,
  869,  834,  830, 1021,  833, 1741, 1404,  852,  602, 1187,
 3152, 1408, 1802, 3112, 1411,  834,  830, 1409, 2873,  260,
  404,  572,  829,  559, 1404, 1408, 2665, 1857, 1167, 1783,
 2026, 1170, 1882,  832,  831,  430,  829,  430, 1177,  469,
  373,  836, 1448,  320, 1917,  772, 1741,  832,  831, 1741,
  602, 2361, 2333,  772, 2542, 1173, 1624,  429, 2543,  869,
 3290,  736, 1121,  335, 1741, 1409,  587, 2539, 1981, 1418,
  388,  853, 1474, 1411, 1190, 1190, 1190, 1190, 1956, 1982,
 2551,  364, 1502, 3314, 1420, 1409, 1491, 1486, 1740, 1269,
 1279, 1408, 1408, 1852, 2335, 1988,  285, 1208, 1741, 1474,
 2540, 1545, 1603, 1420, 1856,  825, 3578,  610, 1504, 1474,
 1740, 1408, 1304,  836, 3013, 2109, 4069, 1290, 2109, 1454,
 4072, 2027,  335,  614, 1951, 1409, 3318, 2837, 1545,  388,
  338, 1448,  852, 2109, 1409, 2109,  469, 1121, 1545,  469,
 3642,  285,  557,  566,  569,  579,  584,  587,  424,  569,
 1448, 2049,  602, 3495, 1570,  285, 1121, 1009, 1404, 1857,
 1454, 2707, 1569, 1454, 1914,  761,  424,  310, 1463,  852,
 1951, 1502,  572, 1916, 2786, 1312, 1409, 2838, 1454, 2208,
  622,  102,  469, 1121,  852, 2728, 2712,  772,  100,  338,
 1409,  176, 1524,  503, 1566, 1802, 3004, 1504, 1310, 3299,
  373, 1009,  841,  294, 2911, 2911, 3158, 2096, 3318, 2001,
 1276, 2361, 2619, 1858, 3318,  601, 1009, 1273,  285,  285,
 1740, 1521, 1273, 2053, 2667, 1653, 1148, 1448,  263, 1404,
 3758, 1485, 1510, 2035, 3143, 1889,  469,  285, 2109,  412,
  412, 1985, 1652, 1408, 2632, 3496, 3497, 3498, 3499, 3500,
 3501, 3502, 1187, 3114, 3893, 1285, 1409, 1409,  871, 1448,
 1511, 1545, 2084, 1985, 2085, 1987,  527, 1981, 1270, 2276,
 1985, 1280,  772, 2070, 1988,  545, 1409, 1404, 1982, 1274,
 2739,  772,  285, 3707, 3708,  318, 1284, 1402, 1404, 1856,
 1300,  412,  524, 2215,  828, 1060, 1993, 1404,  826, 1993,
  524,  871,  767,  636, 3947, 3125, 2917, 2671,  310, 3163,
  827, 1187, 1092, 1568, 3152, 1092, 1575, 1952, 3162, 3160,
  737, 1856, 1991, 3450, 1991, 1991, 1991, 3405, 2518, 1510,
 1092, 3173, 1092, 3126,  455, 1408,  188, 1404, 2109, 1958,
 3408, 1187, 1961, 1453, 1857, 2732, 1404, 2088, 1478, 1456,
  545, 2109, 2240, 1165, 2161, 2039, 2158, 3579, 2040, 2081,
  833, 2857, 1412, 2865, 1992,  388, 1992, 1992, 1992, 2109,
 3694,  834,  830,  841, 3646, 3146, 1857, 1741,  841,  737,
 2108, 2770, 1410, 1454, 2109,  318, 1411, 1474, 1404, 3827,
  606,  607,  829, 1883, 2677, 1411, 1457,   99, 2041, 1741,
 1187,  871, 1404,  832,  831, 1740,  469, 3174, 1409, 3830,
  388, 1540, 1467, 1450, 2618, 2911, 1545, 1289, 1363,  871,
  310, 2235, 2472, 2241, 2108, 3554,  335, 3686, 3092, 1647,
  469, 1454,  469, 1643, 1786,   49,  579, 1740, 2109, 2108,
 1310,  677,  851,  280,  455, 1787, 2050, 3349, 3563,  444,
 2864, 1454, 1540, 1467, 1450, 1540,  871, 3082, 3569, 1363,
 3088, 2308, 1363, 2833,  310, 2678, 2322, 1061, 1404, 1404,
 1540, 1467, 1450,  610,   70, 1535, 2696, 1363, 1534,  310,
  339, 3664, 3665, 3666, 3667, 3668, 3669, 3670, 1404,  445,
  693, 2834,  127,  331,  139, 3149, 2327,  524, 2715,  815,
 1409, 3400,  280,  469, 1479, 2771,  424, 3889, 1010, 1741,
  335,  335,  853,  610,  424, 2583, 1604, 2473, 1411,  610,
 1536, 2360,  610, 1597,  606,  607, 1061, 3175, 1819, 1606,
  614, 2697, 1616, 3894, 3450, 1092,  815, 1411, 1788,  339,
 2352, 1418,  163, 1511, 1512,  815, 3661,  335, 1092, 3800,
  255, 3939, 1010, 1630, 1650,  545, 1454,  770,  450,  140,
 3414, 1557,  653,   52, 1536, 2360, 1092, 1010, 1605, 1404,
  388,  853, 1557,  610,  610, 3925, 3821,  338,  338, 1536,
 2360, 1092, 1820, 1656, 1657, 3647, 3648, 3649, 3650, 3651,
 3652, 3653, 1352,  335,  770, 2735, 3467, 2446, 3350,  188,
 1914, 2640, 1139,  770,  817, 1139,  815, 1454, 2283, 1821,
  469, 1951, 1630, 1518,  331, 3684, 3580,  815, 1571,  851,
 1404, 1290, 1454, 1454, 2160, 3693, 2511,  270,  524, 1576,
 1531,  707, 3019, 2557,  335, 3691, 2534,  713, 1300, 3752,
 1511,  817, 1454,   99, 2108, 1187, 1118, 3803, 3828, 3695,
  817, 1352, 2283, 3107,  694, 2242, 3227, 1686, 3692, 1835,
  331, 3095, 3096, 2285,  569,  446,  469, 2283,  450, 1429,
  166, 1187, 2781, 2782, 1402,  770, 1467, 1450, 3415, 3736,
 2620, 3417, 1363, 1813,  271, 3050,  270, 3883, 3093, 3886,
 1402, 1854, 3696, 3402, 1741, 4025, 2631, 2679, 2510, 2491,
 3150,  331, 3942, 3697, 1264, 2109, 1265, 3940, 2829, 3139,
 1478,  817, 1404, 2360,  737,  255,  255, 3176, 2374,  280,
  280, 4057,  817, 3290, 1467, 1450, 1741, 1443, 3257, 1814,
 1363, 1061, 1792,   72, 1187, 1458, 1921, 1694, 1213, 2243,
 1363, 1363, 2210,  271, 1467, 1450, 3662,  447, 1806, 1815,
 1363,  129, 2244, 1397, 3052, 1935, 1936, 1937, 1938, 1939,
 3874, 3083, 3148, 3067, 3376, 2478, 3806,  653, 1805, 1789,
  373, 3073,  639, 4062, 1454, 1288, 2205, 3818, 1804, 1540,
 1845, 1804,  373, 2042, 2043, 1457,  614,  566, 2211, 3718,
 1363, 1052, 1448, 1632, 2874, 4051, 3698, 1319, 1557, 1363,
 3737,  595,  653,  677,  448, 3631, 3868,  280, 1454,  450,
 1630, 2973, 2109,  373, 2436,  373, 2813, 2108, 2190, 2191,
 1310,  310, 1310, 4065, 2436, 1262, 1457,  610, 3997, 1457,
 1723, 1724,  610, 1448, 1139, 2437, 1790, 2814, 1319, 1557,
 1454, 1363, 1557,  341, 1457, 2437, 3738, 1853,  456, 1467,
 1450, 1448, 1632, 1363,  695, 1363, 1319, 1557, 3943, 1822,
 3258, 3552, 2680,  784, 3291, 1139, 1479,  457, 1806, 1177,
 2361, 3950, 2283, 4028, 1630, 2681, 2984, 3875, 1190, 1630,
 2365, 1190, 2057,  610,  454, 3604, 3877, 3739, 1953, 1214,
  746,   15, 1536, 2014, 4048, 2501, 1052, 1108, 1540, 3719,
 1977, 1536, 1092,  268,  270, 1139, 1352, 3351,   10,  455,
 1321, 1951, 2474,  373, 1806, 1467, 1450, 1450, 2875, 1404,
 1407, 1363, 1363,  117, 1352, 2876, 4064,  339,  339,  819,
 3976,  310,  785, 1630, 1953, 1467, 1450,  597, 3916, 1951,
 2208, 1363, 1327, 2245, 2502, 1323, 1413, 1471,  767, 1630,
 1625, 1321, 3995, 2192, 1536, 1536, 1139,  603,  767, 1362,
  273,  271, 1725, 3687,  341, 4019, 4032,  614, 3424, 1321,
 3922, 3756, 2360,  815, 2360, 1322,  469, 2700,  695,  469,
 1802, 2063, 2058, 1802, 1626, 3444, 1323, 1413, 1471, 1951,
  852,  268, 2816, 2018, 1951, 1679,  469,  620,  424, 1633,
 1362, 2436,  604, 4020, 1323, 1413, 1471,  424,   13, 1092,
  341, 1312, 2112, 1139,  820, 1680, 1322, 1189, 1362,  455,
 2093,  746, 2437,  117, 1536, 3923, 1109, 3699,  975,  976,
 1816,  770,  146, 1107, 1322, 2737, 3326, 2049, 2049, 1408,
 1630, 2475, 3917, 1536,  147, 2283, 2365, 1643,  273, 1457,
 1288,  341, 2064, 4021, 3918, 3790, 1448,  767, 1633, 3977,
 2501, 1319, 1557, 2534, 2019,  569, 2682,  645, 1450, 1681,
  622,  606,  148, 1363, 1107, 3361, 1189, 1107,  817, 1627,
  695, 3996, 1981, 3397,  671, 1804,  370,  975,  976, 2212,
 2100, 2817, 1107,  660, 1402, 4033, 3231, 1457, 2506,  646,
 2966, 3928, 1450, 1583, 1448, 3791, 2440, 2008, 3387, 2504,
 1557, 3919, 1982, 1557, 1288, 1584, 2371, 1457, 1649, 1288,
 1557, 1557, 2844, 2863, 1448, 1557,  373,  373, 3920, 1319,
 1557, 2106, 2436, 1557, 1450,  614, 1806,   61, 2148, 2072,
 2072, 4031, 3928, 2436, 2278,  370, 1585, 1557, 1586, 1630,
 2009, 1630, 1630, 2437, 3797, 3398, 1805, 2547, 1557, 4002,
 4045, 2101, 2455, 2265, 2437, 1363, 1557, 2311, 1327, 2049,
 1557, 1539, 4049, 1288, 1321,  648, 2074, 2074, 1845, 1557,
 4059, 2075, 2075, 3811, 1493, 1494, 1495, 2076, 2076, 1288,
  317, 2866, 2077, 2077, 3399, 1557, 2201,  656,  373,  373,
  751,  373, 1630,  495,  695, 3239,   64, 1478,  373, 1323,
 1413, 1471,  671, 2350, 4053, 3033, 1557, 1682, 3798,  595,
 4044, 1557, 1457, 1362, 4046, 1461, 3370, 3371, 2548, 1448,
  469,  149, 1557, 1557, 1319, 1557, 2476,  579,   67, 1322,
  495, 4067, 1321, 2436,  610,  610, 1587,  285, 3058,  317,
 2010,  752, 2436,  150, 1204,   61, 1635, 2380, 1413, 1471,
 1441, 2381,  151,  761, 2437, 1442, 1461, 1268, 2011, 3060,
 2477, 1362, 2079, 2437,  606,  607, 3240, 1323, 1413, 1471,
 1288, 1362, 1362, 1191, 1461, 1557, 1264, 1802, 1457, 1457,
 1496, 1362, 1205, 2754, 3551, 1448, 1448, 2754,  660,  686,
  677, 1557, 1557, 1177,  614, 2012, 1557, 1322, 1457, 1107,
 1107,  285,  495, 1107,  152, 1448, 1107, 1268, 1413, 1806,
 1635, 1557, 1557,  780,   64, 1635,  639, 1413, 1107, 3987,
  672, 1362, 2880,  153, 2881,  607,  455, 2359, 2809, 1805,
 1362, 3278, 1191,  689,  695, 1264,  614, 1321,  679, 2368,
  690,  495, 2379,  566,  579, 2439,   67, 2882, 4006,  604,
  781, 2369, 4016, 1479, 1373, 1853,  660, 1625,  614, 1413,
 3064, 4041, 2883, 2487,  906, 1953,  614, 1210, 1105, 1635,
 2471,  370, 1362, 1413, 1471,  683, 1264, 1139, 1265, 1288,
  139, 1288, 1288, 3987, 1362, 1635, 1362, 1107,  566,  579,
  455, 1626,  660, 3377, 1373, 1373,  784, 2373, 1373, 1892,
 2544,  906, 1322, 3378,  660, 1211,  142,  655, 1107, 2810,
 4042, 1893, 1087, 1373, 1107,  680,  370, 1105, 1139, 2452,
 2370, 1139, 1327, 3379,  364,  566,  579, 2465, 2811, 1082,
 1457, 2470, 1288, 1894,  247, 2275, 1139, 1448, 2079, 1413,
 1413, 1180, 1204, 1557,  614, 1527, 2812, 1107, 3672, 1588,
 1589, 1663, 1362, 1362,  364, 1015,  364,  550,  695, 1413,
 1471,  660,  691, 3673, 1457,  785,  247, 2254,  692, 2649,
 1204, 1087, 1362, 2650, 1436,  671, 1635,  364,  660, 1461,
 1687, 1897,  739, 1227, 1251, 1437, 1627,  678, 1082, 1438,
 1607, 3454, 1002, 2079, 2275, 2486, 1457, 3115,  247, 1015,
 1180, 2256,  364, 1608, 1527, 2563, 1478, 1478, 1696, 3676,
 3527,  655, 3128, 3153, 1015, 2652,  550,  112,  113, 2365,
 3455, 1590, 1591,  655, 1592,  673, 3822, 1461, 1806,  614,
  364, 1593, 2541, 3590, 3677, 1557, 1002, 2079, 3380, 3381,
 3382,  739, 1227,  679, 1264, 1204, 1023, 1461, 1805, 1570,
 1570, 1002,  640, 2636, 1375, 2638, 3356, 1569, 1569,  695,
  614,  641, 2257, 1204,  424,  566,  579,  602,  557,  569,
  569, 2258,  156,  501, 1441, 1439,  370, 1440, 1107, 1442,
  655,  677,  495, 1698, 2996, 1635, 2648, 1635, 1635,  595,
 1853, 1413, 1405,  672,  696, 1375, 2259,  655, 1375,  677,
  677, 1704,  430, 3551, 1362, 1023, 1204, 3424,  697, 2997,
 1264,  679, 1223, 1375,  501, 1411,  156,  501, 1373, 1528,
  680, 2645, 2673,  847, 2998, 1312,  610,  610, 4003,  673,
 2651,  156,  501, 1405, 4004,  156, 2733, 2734, 1635,  652,
  754,  673, 2653, 2654, 1750, 1806,  469,  679,  676,  614,
  698, 1405, 1461, 1139, 1139, 2748, 1411, 1139,  139,  679,
 1139,  699, 1479, 1479,  681, 1953, 1373, 4005, 1264, 1373,
  495, 1223, 1139, 1806, 1411,  740, 1373, 1373, 1528,  156,
 1212, 1373,  847, 1264,  142, 1058, 1373,  469,  680, 1373,
  469,  495,  678, 1953,  156,  702, 1362,  495,  673,  754,
 1529, 1441, 1439, 1373, 1440,  469, 1442,  703,  557, 1264,
 2718,  714, 3601, 3602, 1373,  673,  679, 2755, 2112, 2112,
 2112, 2755, 1373, 1806,  680, 1216, 1373,  743, 2439, 1912,
  495, 3558, 1121,  679,  740, 1373,  680, 3929, 1461, 1212,
 1684, 1139, 1660, 1953, 1058, 1565, 1245, 2897, 1953,  744,
 1028, 1373,  469,  755, 3440, 1661, 1246, 1913, 1633, 1529,
  678, 1632, 1139, 2510,  772, 2851, 2780, 1264, 1139, 1033,
  610,  614,  610,  610,  104,  762, 1364, 1373, 1799, 1564,
 2848, 1443, 2850, 2852, 1216,  614,  677, 1264, 2804, 1373,
 1049, 1373, 1565,  680, 2206, 3840,  678, 1028, 1436, 1684,
 1264, 1139,  610,  770,  610,  610,  610,  788,  678, 1437,
  680,  469, 2889, 1438, 2891, 2892, 2893, 1364, 1375, 3841,
 1364,  126,  587, 2853, 1479, 1892,  249, 2645, 1033,  264,
  610, 3522, 2645,  104,   94, 1364, 2365, 1893, 1577, 3842,
 2912, 1373,  352, 2366,   97, 2806, 2801, 2807,   15, 1049,
  324, 1479,  425,  676,  677, 3117, 1405, 1373, 1373, 1894,
  639, 1479, 1373, 3843,  100,  678, 1375,  772, 3118, 1375,
 1895, 2231,  566,  579, 1443,  799, 1375, 1375, 3015, 1411,
  126, 1375,  678, 1892, 2231,  249, 1375,  801,  264, 1375,
  677, 2880,  803, 2881, 3000, 1893, 2231, 1404, 1407, 2231,
 1478,  352,  677, 1375, 1405, 4063, 3022, 1897, 1251,  324,
 3023,  425, 3492, 2725, 1375, 1405, 2882, 1894, 3769, 3001,
 3770,  676, 1375, 2726, 1405, 1436, 1375, 1411, 1895, 3478,
 2226, 2883, 1139, 3010, 3002, 1375, 1437, 1411, 1411, 3479,
 1438, 2656, 2226,  645, 1561, 2226, 1562, 1411,  767, 1235,
 3973, 1375, 3025, 3975, 1478,  822, 1951,  676,  767,  677,
 2287, 1432, 1431, 1433, 1405, 1897, 1951,  606,  607,  676,
  614, 2227, 2675, 1405, 1233, 1234,  677, 1375, 2685,  103,
  106,  109, 2299, 2227,  631, 2298, 2227, 1411,  830, 1375,
  587, 1375,  430,  677,  610,  831, 1411, 3016, 2264,  837,
 3101,  424,  566,  579,  602,  557,  569,  569, 1235, 1373,
 2264,  630, 3012, 2264, 2700, 1405,  840, 1408, 1898, 1436,
 4014, 2304, 4015, 3021, 2303,  857,  676, 1033,  841, 1405,
 1437, 2452, 2349, 3120, 1438, 2348,  848, 3047, 1411, 1033,
 1364, 1375, 1688,  676, 1692, 1128, 2079,  677, 1049, 1697,
 1699, 2110, 1411, 1101, 1705, 2288, 1479, 1375, 1375, 1113,
 1049,  761, 1375, 2110,  697, 2617, 2110, 3024, 2203, 1106,
 1033, 2622, 1033, 1115, 1443, 2642, 1898, 1375, 2641, 3026,
 3027, 1751, 2672, 1121, 2290, 1443, 1128, 2079, 1364, 1128,
 2079, 1049, 2093, 1049, 1806, 1405, 1405, 1806, 1364, 1364,
 2731, 1373, 1168, 2730, 1128, 2079, 1128, 2079, 1364, 1169,
 1479, 1397,  614,  639, 1805, 1405, 3086, 1805, 1411, 1411,
 3728, 1171, 2804, 1178,  610, 2291,  614,  875,  876,  877,
  878,  879, 2115,  881, 3155, 2309, 2310,  614, 1411, 3955,
 2276,  614, 1181, 1951, 2115,  700, 1179, 2115, 1364, 3956,
 3957, 1183, 2276,  700, 2524, 2276, 1184, 1364,  888,  889,
 3141, 1185, 2493, 3145, 3293, 3294, 3295, 3296, 3297, 3298,
 1033,  371, 1417, 3100,  875,  876,  877,  878,  879, 1186,
  881,  606,  607, 2292, 1188, 1418, 1414, 3116, 3164, 3165,
 2784, 1049, 2494, 2783, 2495, 1195,  614, 1197, 3122, 1364,
  883,  884, 3129, 2293, 2869,  888,  889, 2868, 1209, 1375,
 1310, 1364,  394, 1364, 2217, 2496, 2294, 1194, 2525, 1419,
 1217, 2927, 1219, 2526, 1443,  143, 1420, 1414,  614, 2938,
  371, 1221, 2937, 2979, 1421, 1223, 1443, 1228,  424,  614,
 2497, 3228, 1236, 3233, 2868, 1414, 2906, 1405, 1941, 1942,
 1943, 1422, 1365, 1423,  466, 2217, 3458, 2801, 2217, 3457,
 3249, 3313, 1235, 1424, 1365, 1425, 1426, 1427, 2498, 1253,
 1411,  394, 1365, 2217, 1951, 3321, 3322, 2527, 3494, 1364,
 1364, 3493, 1237, 1194, 1241, 1951, 1365, 3273, 3607, 2252,
 1252, 3606, 3663, 2528, 1283, 1632, 1258, 1365, 1287, 1364,
 3251, 1375, 3284, 1128, 3688,  614, 1139, 1443,  614, 1128,
 2079, 1293, 1194, 1429, 2253, 2375, 2376, 2377,  587,  144,
 1128, 1128, 1128, 1292, 2254, 1128,  145, 3793, 1128, 2255,
 2730, 1295,  587,  587, 1365,  258,  258, 1303, 1194, 1405,
 1128, 1194,    4,    7,  430, 2079, 1128, 1139, 3572, 3573,
 1139, 1462, 1564, 2658, 2659, 1128, 1194,  424, 2256, 1320,
  146, 1321, 1411, 1317, 3328, 1139, 2645, 1139, 3859, 2645,
 1322, 3860,  147, 1420, 1324, 1325, 3357,  975,  976, 3342,
 1326, 1327, 1194, 1033, 1033, 1951, 3365, 3745, 3933,  424,
 3980, 3932, 1462, 3979, 1951, 3982, 4029, 1328, 3981, 3932,
  148, 1806, 1338, 4071, 1049, 1049, 2730, 1329, 1330, 1128,
 1462, 3368, 4073, 1339, 1420, 2730, 3946, 1740, 1331, 2257,
 1740, 1805,  614, 1484,  614, 1332, 1484, 1334, 2258, 1335,
 1128, 1364, 1420, 1413,  536, 1336, 1128,  536, 1441, 1439,
 1194, 1440, 1337, 1442, 1128, 1365, 1128, 1340, 2089, 2050,
 1414, 2079, 2050, 2259,  469, 1033, 1033,  469, 1033, 1128,
 1194, 3453, 1342, 1344, 1128, 1033,  371, 1349, 3416, 1128,
  394, 2051, 1445, 1194, 2051, 1445, 1049, 1049,  670, 1049,
 1350,  670,  394, 2645, 1351, 3395, 1049, 1892, 1352,  666,
 2217, 2217,  666, 2529,  395, 2530, 2531, 2217, 1414, 1893,
  610, 1128,  424, 1430, 1443,  667, 1353,  394,  667, 2217,
 3441,  371, 1354,  394, 1355,  394, 1356,  610, 1414,  373,
 1357, 1894,  679, 1364, 3433,  682, 2270, 3456, 1358, 2273,
 1359, 3506, 1895, 1360, 1415, 3911, 3508, 3913, 1361, 1047,
 1896, 1363, 1444, 1364, 1365, 1366, 2532, 1367, 1368,  373,
 1369,  373,  394,  395, 1370, 1371, 1372, 1373, 1414,  149,
  392, 1374, 1375, 1376, 1139, 1377, 1378, 1414, 1379, 1897,
 1139, 3507,  373,  424, 3510,  614, 1380, 3512, 2217, 1139,
 1381,  150, 1382, 1139, 3010, 1383, 1139, 1384, 3521, 3509,
  151, 1385, 1386, 1387, 1388, 3463, 1389,  373,  857, 2217,
 1128, 1139, 1390, 1391, 1394, 2217, 1395, 1139, 1396, 1414,
 1139, 1397, 1398,  394, 3745, 1462, 1139, 1399, 1445, 1446,
 1447, 1448,  404, 1414,  392,  373, 1449,  566,  587,  579,
  584,  587,  667,  595,  602, 1450, 3464, 1420, 2217, 1451,
 1454,  587,  152, 1452, 1480,  587, 1498, 1481, 1482, 1500,
 1139, 1501,  614, 1502, 1432, 1431, 1433, 1503, 2626, 1505,
 1506,  153, 1436, 1462, 3529, 3530, 3531, 3532, 3533, 3534,
 1139,  371, 3622, 1437, 1516, 1518, 1128, 1438, 1520, 3047,
 1898,  404, 1523, 1462, 1524, 1420, 1525, 1845, 1526, 1414,
 1414, 1530, 1536, 1542, 1547, 1543,  610, 3513, 1572, 1580,
 2439, 1139, 1598, 1617, 1629, 1420, 3598, 1139,   15, 1414,
 2439, 1635,  394, 1643, 1646, 1640, 1153,  610, 1658, 1659,
 1953, 1671, 1676,  610, 1672, 1139, 1674, 3613, 1730, 1753,
 1953, 1677, 1333, 3621, 1759,  875,  876, 1973, 1974,  879,
 1760,  881,  751, 3596, 1777, 1420, 1778,  875,  876,  877,
  878,  879,  395,  881,  606,  607, 1153, 1153, 1139, 1346,
 1153, 1785, 1139, 1796,  395, 3610,  888,  889, 1810, 2217,
 1800, 1826, 3313,  883,  884, 1153, 1825, 1153,  888,  889,
 1842, 1877,  424, 1128, 1858, 1860, 1887, 3658, 1462,  395,
 1900,  504, 1861, 1862, 1902,  395, 1420,  395, 1903, 1904,
 1928, 1905, 1925, 1926, 3249, 1934, 3178, 1153,  807, 1927,
 1420, 1959, 1960, 1632, 1965, 1967, 1969, 1970,  808, 1987,
 1985,  809, 1986, 1991, 1984, 1994,  394,  394, 1996,  587,
 1999, 3179,  504, 2003,  395,  504, 2004, 3180, 2002, 3657,
 1917, 1414,  397, 2017,  587, 2020, 2029, 3181, 2030, 2022,
  504, 2031, 2033, 2038, 2046, 2047, 1416, 2048,  699, 2062,
 3182, 1139,  424, 2054,  424, 1417, 2056, 2089, 2098, 2107,
 3726, 2121, 2123, 2113, 1462, 2131, 1420, 1420, 1213, 2124,
  424,  614, 2132, 2135, 3342, 2136, 3675, 2439, 2137,  810,
 1047, 2112, 2147, 2159, 3754,  395, 1420, 2193,  394,  394,
  614,  394, 3368, 2140, 2194, 2195,  397, 1953,  394, 2196,
 2197, 2200, 1419, 2204, 2218, 3723, 3596,  404, 3183, 1420,
 3727, 2203,  761,  811, 2209, 1421, 2221, 1421,  812, 2227,
 2222, 2223, 2232, 3733,  813, 2246, 2236, 1139, 2249, 2247,
 2250, 2238, 2452, 2251, 1422, 2266, 1423, 2267, 3184, 2248,
  975,  976, 3185, 2274,  572,  614, 1424, 3186, 1425, 1426,
 1427, 3706,  404, 3187, 2268, 1428, 2275, 2279, 3808, 2280,
  404,  614, 2281,   72, 1153, 2282, 2284, 2302, 2305, 2300,
 1153, 2306, 2307, 2312, 2313, 3188, 2314, 2315, 2316, 1153,
 2323, 1153, 1153, 1153,  395, 2324, 1153, 2325,   72, 1153,
  404, 2338,  404, 2358, 2351, 2332, 1845, 2352,   72,  610,
 2355, 1153,  814,   72, 2461, 2443, 3755, 1153, 2439, 3838,
 1153,  557, 3810,  404,  610, 2444, 1153, 2466, 1420, 2439,
 2467, 2479, 2645, 2480, 3847, 2481, 2482, 2488, 1953, 2503,
 2483, 3189,   72, 2513, 1139, 1154, 2535, 3891,  404, 1953,
 2546, 3819, 2552, 2555, 2556, 2579, 2580, 3610,  815, 2588,
 1153, 2621, 1549, 2635, 2646, 1550, 2633,  504,  504, 2624,
 1556, 2647, 2668, 1560,  504, 2660,  404, 1563, 2661, 2687,
 1153, 1556, 2683, 2695,  431, 1154, 1154, 2694, 2684, 1154,
 2701, 2705, 2708, 2709,  432, 1236, 2710,  433, 1139, 2719,
 2720, 1153,  816,   72, 1154, 2722, 1154, 1153,  395,  395,
 2693, 1153,   72, 2729, 2723, 2736, 2740, 1153, 2742, 2741,
 1845,  817,  404, 2750, 2744, 2745, 1432, 1431, 1433, 2439,
 2365, 3190,  404,   87, 2768, 1153, 1154,   72, 2439, 1139,
 1153, 2763, 1139, 2751, 2787,  424, 3924, 2773, 2769, 1953,
 3191, 2772, 2774, 2788, 1236,  504, 2792, 1139, 1953, 3723,
  639, 2823, 2794, 2802, 2805,  434, 2824, 3880, 1153, 2825,
 2826, 2827, 1153, 2830,  572, 2828,  504, 2841, 1678, 2831,
  395,  395,  504,  395, 2842, 2849, 2861, 2894, 2888, 1689,
  395,  404, 2832, 2860, 1695,  435, 1430, 3967, 1700,  436,
 2900, 2901, 2906, 2112,  437, 2902,  572, 2914, 1721, 2890,
  438, 2915, 2940, 1727, 1728,  504, 2924, 1731, 1732, 1733,
 1734, 1735, 1739, 1745, 2941, 1748, 1749, 2970, 1752, 2971,
 1754, 1755, 1756, 1757, 1758, 2972, 2974, 1761, 1762, 1763,
 1764, 1765, 1766, 1767, 1768, 1769, 1770, 1771, 1772, 1773,
 1774, 1775, 1776, 2977, 3034, 2985, 2986,  572, 2987, 3031,
 3037, 2988, 1793, 1794, 1678, 2989, 3039, 3040, 3042, 2990,
 2991, 1153, 3045, 3053, 3043, 3988, 3051, 3044,  504, 1047,
 1808, 3054, 3056, 3074, 3061, 3076, 3065, 1818,  439, 2764,
 3087, 3091, 1824,  572, 3105, 3066, 3119, 3121, 1831, 1832,
 3123, 1158, 3131, 1154, 3130, 3133, 3134, 1841, 1977, 1154,
 1047, 1847, 1848, 1849, 1047, 3135, 3137, 1047, 1154, 3136,
 1154, 1154, 1154, 3142, 3138, 1154, 3140, 3143, 1154,  424,
 3147, 3154, 3177, 3222,  440, 3223, 3192, 1417, 3221, 1977,
 1154, 1158, 1158, 3225, 3234, 1158, 1154, 1153, 3238, 1154,
 1418, 4027, 3242, 3253, 1148, 1154, 3269, 3285, 3274, 3287,
 1158, 3315, 1158, 1238, 3327, 3300, 3329, 3330, 3331, 3346,
 2962, 3332, 3333, 3334, 1139, 1139, 3335, 3352, 3353, 1258,
 3362, 1139, 3355, 3366, 1419, 3369, 3372, 3375, 3374, 1154,
  404, 1420, 1158, 1139, 2749, 1148, 3385,  441, 1148, 1421,
 3392, 2813,  404, 3409, 3406, 3420, 3391, 1252, 3407, 1154,
 3421, 3434, 3435, 1148, 3446, 1148, 1422, 3396, 1423, 3448,
 3469, 3466, 3483, 1028, 1432, 1431, 1433,  404, 1424, 1238,
 1154, 1426, 1427,  404, 3436,  404, 1154, 3437, 1258, 3514,
 1154, 3503, 3488, 3516, 3537, 1148, 1154, 3518, 3538, 3524,
 3542, 3545, 2697, 3543, 1153, 3544, 3547, 3548, 1238, 3562,
 3556, 3571, 1139, 3566, 1154, 3574, 1252, 3575, 3597, 1154,
 3576, 3577,  404, 3600, 3611, 3626, 3630, 3635, 1429, 3643,
  404, 3681, 3654, 1139, 1238, 3682, 3632, 1238, 3704, 1139,
 3705, 3709, 3711, 3712, 3715, 3721, 3734, 1154, 3743, 3748,
 3749, 1154, 1238, 3729, 3730, 3753, 3766, 3795, 1706, 1707,
 1708, 1709, 1710, 1711, 1712, 1713, 3781, 3804, 3812, 3767,
 3814, 3813, 1139, 3823, 3820, 3832, 3835, 3844, 1238, 3846,
 3839, 3848, 3851,  404, 3857, 3869, 3856, 3872, 3878, 3879,
 3881, 3887, 3897, 3903,  404, 3904, 3910, 3899, 3908, 1173,
 3900, 2117, 2118, 3912, 2120, 2797, 2122, 3934, 3953, 1158,
 2126, 2127, 2128, 2129, 3952, 1158, 3959, 3963, 2133, 2134,
 3969, 3974, 3992, 3930, 1158, 3970, 3931, 1158, 1158, 3993,
 3994, 1158, 3998, 4010, 1158, 4000, 1238, 2141, 4013, 4017,
 1173, 4012, 4018, 1173, 3996, 3995, 1158, 4026,  280, 4037,
 1154, 4030, 1158, 2155, 2157, 1158, 1238, 4043, 1173, 4052,
 1173, 1158, 1148, 4040, 2164, 2165, 4056, 1714, 1148, 1238,
 1947, 4060, 1432, 1431, 1433, 4066, 1416, 1148, 4068, 1148,
 1148, 1148,  404, 4070, 1148, 1417, 1327, 1148,    1,  280,
 1173, 1375,  280, 1715, 1454, 1158,  419, 1258, 1418, 1148,
 1540,  434, 1329, 1139, 1061, 1148, 2275,  280, 1148, 1328,
 2068, 1126, 1314,  574, 1148, 1158, 1425, 2048, 1430,  524,
 1738, 1397, 1032,  580, 1047, 1252, 1154, 1430,  575,  556,
 1739,  565, 1419,  527,   73, 2217, 1158, 2219,   94, 1420,
 2220, 1402, 1158,  581,  555, 1882, 1158, 1421, 1148,  367,
  566, 1194, 1158, 1288,  621,  841,  169,  897, 2109, 2012,
  469, 1989, 1479, 1258, 1422, 1540, 1423,  642, 1148,  687,
 1158,  651, 3338,  632,  466, 1158, 1424,  608, 1425, 1426,
 1427,  600, 1681, 1883, 2041, 1428,  643, 1845,  688, 1148,
 1531, 1252, 1258, 2013,  536, 1148,  404,  404, 2047, 1148,
 1983, 1877,  651, 1158,  450, 1148, 1540, 1158,  732, 1540,
  733,  702, 1997,  401, 1047,  402, 1998,    0, 1258,   16,
 1252, 1258,   18, 1148, 1540,   16, 1429,   28, 1148,   31,
   33,   37,   43, 1154,   40,   46, 1258,   40,   40,   55,
   58, 1716, 1717,   76,   79,   87, 1252,   82,   91, 1252,
   76,   85,   33,   40,   40,  112, 1148, 1173, 1164,   40,
 1148,  115, 1258, 1173, 1252,   40,  121,  133,  404,  404,
  136,  404, 1173,  124, 1416, 1173, 1173,  136,  404, 1173,
  145, 1556, 1173, 1417, 1560,  148, 2340,  151,  160,   25,
 1252,  154,   33, 2995, 1173, 2283, 1418, 2999, 1906, 1164,
 1173, 2347, 1164, 1173, 3003, 3655, 1158, 3656, 1907, 1173,
 1908, 2666, 3030, 1909, 1126, 1911, 1910, 1164, 3517, 1164,
 1258, 2904, 3452, 3620,  280,  280, 2154, 2110, 1142,  705,
 1419,  280, 3429, 3599, 3403, 2859,  596, 1420, 3161, 3428,
 1258, 1282, 2791, 1173, 3833, 1421,  634, 3890, 1252, 1164,
 3735, 2845, 3419, 1258, 3867, 1126,  709, 3836, 1126, 1148,
 1537, 3892, 1422, 1173, 1423, 2899, 3430, 3171, 1252, 1142,
 4055, 3826, 1142, 1126, 1424, 1126, 1425, 1426, 1427, 3965,
 3172, 1252, 1158, 1428, 1173, 4058, 3999, 1142, 4001, 1142,
 1173, 4023, 3393, 3773, 1173, 3394, 3871, 2545, 2549, 1180,
 1173, 2442, 2102, 2028, 3703, 1126, 4035, 3084, 3085, 4036,
 3951, 2760,  280, 3817, 3081, 3876, 1430,   33, 1173, 1142,
 2233, 3286, 2872, 1173, 1429, 2364, 3438, 1628, 2796, 3888,
 1855, 3831, 2363,  280, 2469, 1148, 2856, 1993, 2566,  280,
 3685, 1540, 1540, 3505, 2572,  684, 2051, 2082, 1540, 2575,
 2686, 1173, 2576, 2577, 2141, 1173, 3515, 3546, 3541, 2582,
 1047, 2584, 3348, 1432, 1431, 1433, 3671, 1932, 2585, 1194,
 2586,  701,  280, 2589, 2590, 2591, 2592, 1527, 3535, 3536,
 2597, 1208, 2598, 1174, 2599, 1545, 2600, 1574, 2334, 1158,
 1888, 3323, 2601, 2602, 2603, 2604, 2605, 2606, 2607, 2608,
 2609, 2610, 2611, 2612, 2271, 1891, 2674, 2613, 2614, 3627,
 3680, 3794, 2615, 2616, 4009, 2337, 1164, 1215, 3049,   58,
 3057, 1683, 1164, 2623,   60,   61, 3659, 3660, 2625, 1540,
   64, 1164, 2628, 1540, 1164, 1164,   67, 3978, 1164, 1949,
 2714, 1164, 1148, 2637, 2762, 2216, 1047, 1823,  711, 3837,
 1540, 2199, 2887, 1164, 1173, 2895, 1540, 2087, 1301, 1164,
 3724, 2341, 1164, 1255, 1323, 1393, 1145, 1392, 1164, 1782,
 1846, 3866, 1126, 3765, 2596, 1975, 3636, 1780, 1126, 3108,
 3468, 2704,  657, 3511, 3504, 2676, 1142, 1126, 1976, 1540,
 1126, 1126, 1142, 1881, 1126, 3029, 4008, 1126, 3232, 2537,
 1673, 1142, 1164, 3731, 1142, 1142, 3555, 1145, 1142, 1126,
 1145, 1142, 3618, 3845, 1430, 1126, 3714, 3885, 1126, 3966,
 3109, 1596, 1164, 1142, 1126, 1145, 1515, 1145,  142, 1142,
 1173, 3343, 1142, 3850, 3945, 3638, 3325, 2717, 1142, 1136,
    0, 3732,    0, 1164,    0,    0,    0,    0,    0, 1164,
    0,    0, 1540, 1164,    0,    0,    0, 1145, 1126, 1164,
 1432, 1431, 1433,    0,    0, 1416,    0,    0, 1276,    0,
    0,    0, 1142,    0, 1417,    0,    0, 1164, 1126,    0,
 1136,    0, 1164, 1136,    0,    0,    0, 1418,    0,    0,
    0,    0, 1142,    0,    0,    0,    0,    0, 1136, 1126,
 1136,    0, 2752,    0,    0, 1126,    0,    0,    0, 1126,
 1164, 2761,    0, 1142, 1164, 1126, 1260,    0, 1134, 1142,
    0, 1419,    0, 1142,    0,    0,    0, 1276, 1420, 1142,
    0,    0,    0, 1126, 3193,    0, 1421, 1173, 1126,    0,
 3194,    0,    0,    0,    0,    0,    0, 1142,    0,    0,
 3195,    0, 1142, 1422,    0, 1423,    0,    0,    0, 1134,
  481,    0, 1134, 3196,    0, 1424, 1126, 1425, 1426, 1427,
 1126,    0,    0,    0, 1428, 1260,    0, 1134,    0, 1134,
 1142,    0,    0,    0, 1142,    0,    0,    0,    0, 3774,
 3775, 3776, 3777, 3778, 3779, 3780,    0, 1139,    0,    0,
    0,  481,    0,    0,  481,    0, 3783, 3784, 3785, 3786,
 3787, 3788, 3789, 1164,    0, 1429,    0,    0,    0,  481,
    0, 3197,    0,    0, 1145,    0,    0,    0,    0,    0,
 1145,    0,    0,    0,    0,    0,    0,    0, 1139, 1145,
    0, 1139, 1145, 1145,    0,    0, 1145,    0,    0, 1145,
    0, 3198,    0,    0,    0, 3199, 1139,    0, 1139,    0,
 3200, 1145, 1416,    0,    0,    0, 3201, 1145,    0, 1126,
 1145, 1417,    0,    0,    0,    0, 1145,    0,    0,    0,
    0,    0,    0, 1142, 1418, 1047,    0,    0, 3202, 1164,
    0,    0,    0,    0, 2141,    0,    0, 1136,    0,    0,
    0, 2931, 2932, 1136,    0,    0,    0,    0, 2939,    0,
 1145,    0,    0,    0, 1136, 1136, 1136,    0, 1419, 1136,
    0,    0, 1136,    0,    0, 1420,    0,    0,    0,    0,
 1145,    0,    0, 1421, 1136,    0, 1276,    0, 2965,    0,
 1136, 2967,    0, 2969, 3203, 1126,    0, 3204,    0, 1136,
 1422, 1145, 1423,    0,    0,    0,  505, 1145,    0, 1142,
    0, 1145, 1424,    0, 1425, 1426, 1427, 1145,    0,    0,
    0, 1428,    0,    0,    0,    0, 1134,    0,    0,    0,
    0,    0, 1134,    0, 1260, 1145,    0,    0,    0,    0,
 1145,    0,    0, 1134, 1134, 1134, 1164,  505, 1134,    0,
  505, 1134, 1276, 1136,    0, 1430,    0, 1432, 1431, 1433,
    0,    0, 1429, 1134,    0,  505,    0,    0, 1145, 1134,
    0,    0, 1145,    0, 1136,    0,    0,    0, 1134,    0,
 1136, 1276,    0,    0, 3205,    0,  482,  481, 1136,    0,
 1136,    0,    0,  482, 2347,    0,    0,    0,    0,    0,
 1260,    0, 1126, 3206,    0, 1139,    0, 1276, 1136,    0,
 1276, 1139, 3071, 1136,    0,    0, 1142,    0,    0,    0,
    0,    0,    0, 1139, 1139, 1276,    0, 1139,    0, 1260,
 1139,    0, 1134,    0,    0,    0,    0, 3089,    0,    0,
    0,    0, 1139,    0,    0, 1136,    0,    0, 1139,    0,
    0, 1276,    0, 1134,    0, 1260,    0, 1139, 1260, 1134,
    0, 2127, 2127, 2064, 2127, 2127, 2127,    0,    0, 1134,
 3858, 1145,    0, 1260,  482,    0,    0,    0,    0, 2127,
 2127, 2127,    0,    0,    0,    0,    0, 1134,    0,    0,
    0,    0, 1134,    0,    0,  482,    0,    0,    0, 1260,
    0,  482,    0,    0,    0,    0,    0,    0,    0, 1276,
 2127, 1139,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1134,    0,    0,    0,    0, 1276,
    0,    0, 1139,    0,  482,    0,    0,    0, 1139,    0,
    0,    0, 1276,    0, 1136,    0,    0, 1145, 1139,    0,
  483,    0, 1430,    0,    0,    0,    0, 1260,    0, 1416,
    0,    0,    0,    0,    0,    0, 1139,    0, 1417,    0,
    0, 1139,    0,    0,    0,    0,    0, 1260,    0,    0,
    0, 1418,  505,  505, 3252,    0, 3254,    0, 3255,  505,
 1260,  483, 3260,    0,  483,    0,    0, 3263, 3264, 3265,
 3266, 3267,    0, 1139,    0,    0, 3268,    0, 3271,  483,
 3272,    0,    0,    0,    0, 1419,    0,    0,    0,    0,
 1136,    0, 1420, 1134,    0,    0,    0,    0, 3276,    0,
 1421,    0, 3277,    0,    0,    0, 1047,    0,    0, 3282,
    0,    0, 3901,    0,    0,    0,    0, 1422,    0, 1423,
 1432, 1431, 1433,    0, 1145,    0,    0,    0,    0, 1424,
    0, 1425, 1426, 1427,    0,    0,    0, 3902, 1428,    0,
  505,    0,    0,    0, 2128, 2128, 2065, 2128, 2128, 2128,
    0, 2127,    0,    0,    0, 2127, 1432, 1431, 1433,    0,
 2127,  505, 2128, 2128, 2128,    0, 2127,  505,    0, 1134,
 2127,    0, 1139, 2127,    0,    0,    0,    0,    0, 1429,
    0,    0,    0,    0,    0,    0,    0, 3360,    0,    0,
    0,    0,    0, 2128,    0,    0,    0, 1136,    0,    0,
  505,    0,    0,    0,    0,    0,    0, 2127,    0,    0,
    0,    0,    0,    0, 2127,    0,    0,    0,    0,    0,
    0,    0, 2127,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2163,    0,    0,    0,    0, 2127,
    0, 2127,    0,    0,    0,    0,    0,    0, 1139, 1564,
 1090, 2127,    0, 2127, 2127, 2127,    0,    0,    0,    0,
 2127,    0, 1565,  505,  454, 3410,    0, 1028,    0,    0,
    0,    0,    0,    0,    0, 2163, 1134,    0, 2163,    0,
    0, 1432, 1431, 1433,    0,    0,    0,    0,    0,    0,
    0, 1090,    0, 2163, 1090,    0,  485,  483,    0,    0,
    0, 2127,    0,  485,    0,  454,    0,    0,  454, 1090,
    0,    0,    0,    0, 2173, 2173, 2060, 2173, 2173, 2173,
    0,    0, 1416,  454, 1564,    0,    0,    0,    0,    0,
    0, 1417, 2173, 2173, 2173,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1418,    0,    0, 2127, 2127, 2127,
 2127, 2127, 2127, 2127, 2127, 1139,    0,    0, 1416,    0,
    0,    0,    0, 2173, 2128,    0,    0, 1417, 2128, 1430,
    0,    0,    0, 2128,    0,    0,    0,    0, 1419, 2128,
 1418,    0,    0, 2128,  485, 1420, 2128,    0,    0,    0,
    0, 2141, 3255, 1421,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  485,    0,    0, 3482,    0,
 1422,  485, 1423,    0, 1419,    0,    0,    0,    0, 3491,
 2128, 1420, 1424,    0, 1425, 1426, 1427, 2128,    0, 1421,
  501, 1428,    0,    0,    0, 2128,    0,    0,    0,    0,
    0,    0,    0,    0,  485,    0, 1422,    0, 1423,    0,
    0,    0, 2128,    0, 2128,    0, 2127,    0, 1424, 3971,
 1425, 1426, 1427,    0, 2128,    0, 2128, 2128, 2128,    0,
    0,  501, 1429, 2128,  501,    0,    0,    0,    0,    0,
    0,    0, 2127, 1416, 3972,    0,    0,    0,    0,  501,
    0, 2127, 1417,    0,    0,  857,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1418, 1047, 3561, 1429,    0,
 2163, 2163,    0,    0, 2128, 3564, 3565, 2163, 1706, 1707,
 1708, 1709, 1710, 1711, 1712, 1713, 1090, 1090,    0, 2163,
    0,    0,    0, 1090, 2173,    0,    0,    0, 2173, 1419,
  454,  454,    0, 2173,    0, 1090, 1420,  454,    0, 2173,
    0,    0,    0, 2173, 1421,    0, 2173,    0,    0,    0,
 2128, 2128, 2128, 2128, 2128, 2128, 2128, 2128,    0,    0,
  857, 1422,    0, 1423,    0,    0,    0,    0,    0,    0,
 3619,    0,    0, 1424,    0, 1425, 1426, 1427,    0,    0,
 2173,    0, 1428,    0,    0,    0,  860, 2173, 2163,    0,
 2141,    0,    0,    0,    0, 2173,    0,    0, 3633,    0,
 3634,    0,    0,    0, 1090,    0,    0,    0,    0, 2163,
    0,    0, 2173,  862, 2173, 2163,    0, 1714,  454,    0,
 2127, 2127,    0, 1429, 2173, 1090, 2173, 2173, 2173,    0,
    0, 1090,    0, 2173,  875,  876,  877,  878,  879,  454,
  881,  606,  607, 1715,    0,  454,    0,    0, 2163,    0,
    0,    0, 1430,    0,    0,    0,    0,    0,    0, 2128,
  883,  884,    0,    0, 1090,  888,  889,    0,    0,    0,
    0, 2347, 3360,    0, 2173,    0,    0,    0,  454,  872,
    0,    0,    0, 3689,    0, 2128, 2171,    0, 1430, 2170,
    0,    0,    0,    0, 2128,  874,  501,  501, 1978,    0,
    0,    0,    0,  501,    0, 1432, 1431, 1433,    0,  875,
  876,  877,  878,  879,    0,  881,  606,  607,    0,    0,
 2173, 2173, 2173, 2173, 2173, 2173, 2173, 2173, 3207,    0,
    0,    0,    0,    0, 3208,  883,  884,  885,  886,  887,
  888,  889,  890,  891, 3209,    0, 1863, 1432, 1431, 1433,
  893,  894,    0,    0,    0,    0, 2141, 3210,    0,  898,
    0, 3762, 3762,    0,    0,    0,    0,    0, 3768,    0,
    0, 1864,    0,   68,    0,    0,    0, 1865,    0, 2163,
    0,    0, 1866,    0,  501,    0,   69, 1867,   70,    0,
 1868, 1716, 1717,    0,    0,    0,    0,    0,   71,    0,
    0,    0,    0,    0,   72,  501,    0,    0,   73,    0,
    0,  501,    0, 1430,   74, 3211,    0,   75,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   76, 2091, 2173,
    0,    0,    0, 2128, 2128,    0,    0,  975,  976,    0,
    0,    0,    0,    0,  501, 3212,    0,    0, 1979, 3213,
    0,    0,    0,    0, 3214, 2173,    0,    0, 1869,    0,
 3215,    0,    0,    0, 2173,    0,    0,    0, 2091, 2091,
    0, 2091, 2091, 2091, 2100,    0,    0,    0,    0,    0,
    0,    0, 3216, 3854,    0,   77, 2091, 2091, 1870,    0,
    0, 2091,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1871,    0,    0,    0, 1416,    0,    0,
  974,    0,  975,  976,  977,   78, 1417, 2975,    0,   79,
    0,    0,    0,    0,   80, 1872,    0,    0,    0, 1418,
   81,    0,    0,    0,    0,    0,    0,    0, 3217,    0,
    0, 3218,    0,    0,    0,    0,    0,    0,    0, 1416,
    0,    0,   82,    0,    0,    0,    0,    0, 1417,    0,
    0,    0,    0, 1419,    0,    0,    0,    0,    0,    0,
 1420, 1418,    0, 1004, 1005,    0,    0,    0, 1421,    0,
    0, 1873,    0,    0, 1874,    0, 3905,    0,    0,    0,
    0,    0, 1012,    0,    0, 1422,    0, 1423,    0,    0,
    0,    0,    0, 2173, 2173, 1419,    0, 1424,   83, 1425,
 1426, 1427, 1420,    0,    0,    0, 1428,    0,    0,    0,
 1421,    0,    0,    0,    0,    0,    0, 3937, 3219,    0,
    0,    0,    0,    0,    0,    0,    0, 1422,    0, 1423,
    0,    0, 3954,    0, 3958,    0,    0, 3220,    0, 1424,
    0, 1425, 1426, 1427,   84,    0,    0, 1429, 1428,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 3986,    0, 3989, 3991,    0,    0,
    0,    0,    0,    0,    0, 2091,    0, 2091,    0,    0,
 1875,    0, 2091, 2091,    0, 2091, 2091, 2091,   85, 1429,
    0,    0, 2091,    0,    0,    0,    0, 2091, 2091,    0,
 2091,    0, 2091, 2091,    0, 2091,    0,   86, 2091, 2091,
 2091,    0,    0,    0,    0, 2091,    0, 2091, 2091,    0,
    0,    0, 2091,    0, 2091,    0, 2091, 2091,    0, 3986,
 2091, 4038, 4039, 2091,    0, 2091,    0, 2091, 2091,    0,
 2091, 2091, 2091,    0, 2091, 2091, 2091,    0,    0,    0,
 2091, 4054, 2091, 2091, 2091,    0,    0,    0, 2091,    0,
    0,    0, 2091,    0, 2091, 2091, 2091, 2091,    0, 2091,
    0, 2091, 2091,    0, 2091, 2091, 2091,    0, 2091,    0,
 2347,    0, 2091,    0, 2347,    0, 2091,    0, 2091,    0,
 2091,    0, 2091, 2091, 2091, 2091, 2091,    0, 2091, 2091,
 2091,    0,    0,    0, 2091,    0, 2091, 2091,    0,    0,
 2091, 2091, 2091,    0,    0, 2091,    0, 2091,    0,    0,
 2091, 2091, 2091, 2091,   87, 2091,    0, 2091, 2091, 2091,
 2091, 2091, 2091, 2091, 2091,    0,    0, 1430, 2091,    0,
 2091, 2091,    0,    0, 2091,    0,    0,    0,    0,    0,
    0, 2091,    0, 2091,    0, 2091, 2091, 2091, 2091, 2091,
 2091, 2091, 2091, 2091, 2091, 2091, 2091, 2091,    0, 2091,
 2091, 2091, 2091,    0, 2091, 2091,    0,    0,    0, 1430,
    0,    0, 2091, 2091, 2091, 2091, 2091, 2091, 2091, 2091,
 2091, 2091, 2091, 2091, 2091,    0, 2091, 2091, 2091, 2091,
 2091,    0, 2091, 2091, 2091, 2091, 2091, 2091, 2091, 2091,
    0,    0, 2091, 2091, 2091, 2091, 2091, 2091, 2091,    0,
    0, 2091, 2091, 2091, 2091, 2091, 2091, 2091, 2091, 2091,
    0, 2091,    0, 2091, 2091, 2091,    0, 2091, 2091,    0,
 2091, 2091, 2091, 2091, 2091, 2091, 2091, 2091, 2091, 2091,
 2091, 2091, 2091, 2091, 2091, 2091, 2091, 2091, 2091, 2091,
 2091, 2091,    0, 2091, 2091, 2091, 2091, 2091, 2091,    0,
 2091, 2091, 2091, 2091,    0, 2091, 3644, 2091, 2091, 2091,
 2091, 2091, 2091, 2091, 2091, 2091, 2091, 2091, 2091, 2091,
 2091, 2091, 2091, 2091, 2091,    0, 2091, 2091, 2091, 2091,
    0, 2091, 2091, 2091, 2091, 2091,    0, 2091, 2091, 2091,
 2091, 2091, 2091, 2091, 2091, 2091, 2091, 2091, 2091, 2091,
    0, 2091, 2091, 2091, 2091, 2091, 2091,    0, 2091, 2091,
 2091, 2091, 2091, 2091, 2091, 2091,    0, 2091, 2091, 2091,
 2091,    0, 2091, 2091, 2091, 2091, 2091, 2091,    0,    0,
 2091, 2091, 2091, 2091, 2091, 2091, 2091, 2091, 2091, 2091,
    0, 2091, 2091, 2091, 2091, 2091, 2091, 2091, 2091, 2091,
 2091, 2091,    0, 2091, 2091, 2091, 2091, 2091, 2091, 2091,
 2091, 2091, 2091, 2091, 2091, 2091, 2091, 2091, 2091, 2091,
 2091, 2091,    0, 2091, 2091, 2091, 2091, 2091, 2091, 2091,
 2091, 2091,    0, 2091, 2091, 2091, 2091, 2091, 2091, 2091,
 2091, 2091, 2091, 2091, 2091,    0, 2091, 2091, 2091,    0,
 2091,    0, 2091, 2091, 2091, 2091, 2091, 2091, 2091, 2091,
 2091, 2091, 2091, 2091, 2091, 2091, 2091, 1733, 2091, 2091,
 2091, 2091, 2091, 2091, 2091, 2091, 2091, 2091, 2091, 2091,
 2091, 2091, 2091, 2091, 2091, 2091, 2091, 2091, 2091,    0,
    0, 2091, 2091,    0,    0, 2091,    0, 2091, 2091, 2091,
 2091, 2091, 2091, 2091, 2091, 2091,    0,  718, 1733, 1733,
 1733, 1733, 1733,    0, 1733,    0,    0,    0,    0,    0,
    0,   86,  719,    0,    0,    0, 1733, 1733, 1733, 1733,
    0,    0,  720,    0,    0,    0,   86,    0,  721,   87,
    0,    0,  722,  723,    0,    0,   86,    0,  724,    0,
    0,  725,   86,    0,   87,    0,    0,   86,    0,    0,
 1733,  726,   86,    0,   87,   86,    0,    0,    0,    0,
   87,    0,    0,    0,    0,   87,    0,    0,    0,    0,
   87,    0,    0,   87,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  727,    0,    0,   70,    0,    0,    0,    0,  728,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   71,   86,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  729,
    0,   87,    0,  730,    0,    0,    0,    0,  731,    0,
    0,    0,    0,   86,  732,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   86,    0,
    0,   87,    0,    0,    0,    0,  733,  734,    0,    0,
    0,    0,    0,    0,    0,    0,   87,    0,    0,    0,
   86,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   87,    0,
    0,    0,    0,    0, 1733, 1733, 1733,    0,    0, 1733,
    0, 1733, 1733, 1733,    0, 1733, 1733,    0, 1733,    0,
    0,    0,  735, 1733, 1733,  736, 1733, 1733, 1733, 1733,
 1733, 1733,    0,    0, 1733,    0,   86, 1733,    0,   86,
    0,    0,    0,    0, 1733,    0, 1733, 1733, 1733, 1733,
 1733, 1733, 1733, 1733,   87,    0, 1733,   87,    0, 1733,
    0, 1733, 1733,    0,    0, 1733, 1733, 1733,    0, 1733,
 1733, 1733, 1733, 1733, 1733, 1733,    0,    0,    0, 1733,
 1733, 1733, 1733, 1733,    0,    0,    0, 1733,    0,    0,
    0,    0,    0,    0,    0, 1733, 1733, 1733, 1733, 1733,
 1733,    0,    0,    0, 1733, 1733,    0, 1733,    0, 1733,
    0, 1733, 1733, 1733,    0, 1733,    0, 1733, 1733, 1733,
    0, 1733, 1733, 1733, 1733, 1733,    0, 1733, 1733,    0,
    0,  737, 1733, 1733,    0, 1733, 1733,    0, 1733, 1733,
 1733, 1733,    0,    0, 1733,   86, 1733,    0, 1733, 1733,
 1733, 1733, 1733,    0, 1733,    0, 1733,    0, 1733, 1733,
 1733, 1733, 1733,   87,    0, 1733, 1733, 1733,    0, 1733,
 1733, 1733,    0,    0,    0,    0,    0,    0,    0,    0,
 1733, 1733, 1733,    0, 1733, 1733, 1733,    0,    0,    0,
    0,    0, 1733,    0,    0,    0, 1733,    0, 1733, 1733,
 1733, 1733,    0, 1733,    0, 1733, 1733, 1733, 1733, 1733,
 1733, 1733, 1733,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1733, 1733,    0, 1733, 1733, 1733,    0,    0,
    0,    0, 1733, 1733, 1733, 1733, 1733,    0, 1733,    0,
    0, 1733, 1733,    0,    0,    0, 1733, 1733,    0,    0,
 1733, 1733, 1733, 1733, 1733, 1733, 1733, 1733, 1733,    0,
 1733,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1733, 1733, 1733, 1733, 1733, 1733, 1733, 1733, 1733, 1733,
 1733, 1733, 1733, 1733, 1733, 1733, 1733, 1733, 1733, 1733,
 1733,    0, 1733, 1733, 1733, 1733, 1733, 1733,    0, 1733,
 1733, 1733, 1733,    0, 1733,    0, 1733, 1733, 1733, 1733,
 1733, 1733, 1733, 1733, 1733, 1733, 1733, 1733, 1733, 1733,
 1733, 1733, 1733, 1733,    0, 1733, 1733, 1733, 1733,    0,
 1733, 1733, 1733, 1733, 1733,    0, 1733, 1733, 1733, 1733,
 1733, 1733, 1733, 1733, 1733, 1733, 1733, 1733, 1733, 1733,
 1733, 1733, 1733, 1733, 1733, 1733,    0, 1733, 1733, 1733,
 1733, 1733, 1733, 1733, 1733,    0, 1733, 1733,    0,    0,
    0, 1733, 1733, 1733, 1733, 1733, 1733,    0,    0, 1733,
 1733, 1733, 1733, 1733, 1733, 1733, 1733, 1733, 2173,    0,
    0, 2172,    0, 1733,    0, 1733, 1733, 1733, 1733, 1733,
 1733,    0, 1733,    0,    0,    0,    0, 1432, 1431, 1433,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1733,
 1733,    0, 1733, 1733, 1733, 1733, 1733, 1733, 1733, 1733,
 1733,    0, 1733, 1733, 1733, 1733, 1733, 1733, 1733, 1733,
 1733, 1733, 1733, 1733,    0, 1733, 1733, 1733,    0, 1733,
    0,    0,    0, 1733, 1733, 1733, 1733, 1733, 1733, 1733,
 1733, 1733, 1733, 1733, 1733, 1733, 1735, 1733, 1733,    0,
    0,    0,    0,    0, 1733, 1733, 1733, 1733, 1733, 1733,
 1733, 1733, 1733, 1733, 1733, 1733, 1733, 1733, 1733, 1733,
 1733, 1733,    0,    0, 1733,    0, 1733, 1733, 1733, 1733,
 1733, 1733, 1733, 1733, 1733,    0,    0, 1735, 1735, 1735,
 1735, 1735,    0, 1735,    0,    0,    0,   84,    0,    0,
    0,    0,    0,    0,    0, 1735, 1735, 1735, 1735,    0,
    0,    0,   93,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   84,    0,    0,    0,    0,    0,   84,    0,
    0,    0,    0,   84,    0,    0,    0,    0,   84, 1735,
    0,   84,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   90,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   97,    0,    0,
    0,    0,    0,    0,    0,    0,    0,   90,    0,    0,
    0,    0,    0,   90,    0,    0,    0,    0,   90, 1416,
    0,    0,    0,   90,    0,    0,   90,    0, 1417,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   84,
    0, 1418,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   84,
    0,    0,    0,    0,    0, 1419,    0,    0,    0,    0,
    0,    0, 1420,    0,   84,    0,    0,    0,    0,    0,
 1421,    0,    0,    0,   90,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   84, 1422,    0, 1423,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1424,
    0, 1425, 1426, 1427,   90,    0,    0,    0, 1428,    0,
    0,    0,    0, 1735, 1735, 1735,    0,    0, 1735,   90,
 1735, 1735, 1735,    0, 1735, 1735,    0, 1735,    0,    0,
    0,    0, 1735, 1735,    0, 1735, 1735, 1735, 1735, 1735,
 1735,   90,   84, 1735,    0,   84, 1735,    0,    0, 1429,
    0,    0,    0, 1735,    0, 1735, 1735, 1735, 1735, 1735,
 1735, 1735, 1735,    0,    0, 1735,    0,    0, 1735,    0,
 1735, 1735,    0,    0, 1735, 1735, 1735,    0, 1735, 1735,
 1735, 1735, 1735, 1735, 1735,    0,    0,    0, 1735, 1735,
 1735, 1735, 1735,    0,    0,    0, 1735,   90,    0,    0,
   90,    0,    0,    0, 1735, 1735, 1735, 1735, 1735, 1735,
    0,    0,    0, 1735, 1735,    0, 1735,    0, 1735,    0,
 1735, 1735, 1735,    0, 1735,    0, 1735, 1735, 1735,    0,
 1735, 1735, 1735, 1735, 1735,    0, 1735, 1735,    0,    0,
    0, 1735, 1735,    0, 1735, 1735,    0, 1735, 1735, 1735,
 1735,   84,    0, 1735,    0, 1735,    0, 1735, 1735, 1735,
 1735, 1735,    0, 1735,    0, 1735,    0, 1735, 1735, 1735,
 1735, 1735,    0,    0, 1735, 1735, 1735,    0, 1735, 1735,
 1735,    0,    0,    0,    0,    0,    0,    0,    0, 1735,
 1735, 1735,    0, 1735, 1735, 1735,    0,    0,    0,    0,
    0, 1735,    0,    0,    0, 1735,   90, 1735, 1735, 1735,
 1735,    0, 1735,    0, 1735, 1735, 1735, 1735, 1735, 1735,
 1735, 1735,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1735, 1735,    0, 1735, 1735, 1735,    0,    0, 1430,
    0, 1735, 1735, 1735, 1735, 1735,    0, 1735,    0,    0,
 1735, 1735,    0,    0,    0, 1735, 1735,    0,    0, 1735,
 1735, 1735, 1735, 1735, 1735, 1735, 1735, 1735,    0, 1735,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1735,
 1735, 1735, 1735, 1735, 1735, 1735, 1735, 1735, 1735, 1735,
 1735, 1735, 1735, 1735, 1735, 1735, 1735, 1735, 1735, 1735,
    0, 1735, 1735, 1735, 1735, 1735, 1735,    0, 1735, 1735,
 1735, 1735,    0, 1735,    0, 1735, 1735, 1735, 1735, 1735,
 1735, 1735, 1735, 1735, 1735, 1735, 1735, 1735, 1735, 1735,
 1735, 1735, 1735,    0, 1735, 1735, 1735, 1735,    0, 1735,
 1735, 1735, 1735, 1735,    0, 1735, 1735, 1735, 1735, 1735,
 1735, 1735, 1735, 1735, 1735, 1735, 1735, 1735, 1735, 1735,
 1735, 1735, 1735, 1735, 1735,    0, 1735, 1735, 1735, 1735,
 1735, 1735, 1735, 1735,    0, 1735, 1735,    0,    0,    0,
 1735, 1735, 1735, 1735, 1735, 1735,    0,    0, 1735, 1735,
 1735, 1735, 1735, 1735, 1735, 1735, 1735, 2945,    0,    0,
 2944,    0, 1735,    0, 1735, 1735, 1735, 1735, 1735, 1735,
    0, 1735,    0,    0,    0,    0, 1432, 1431, 1433,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1735, 1735,
    0, 1735, 1735, 1735, 1735, 1735, 1735, 1735, 1735, 1735,
    0, 1735, 1735, 1735, 1735, 1735, 1735, 1735, 1735, 1735,
 1735, 1735, 1735,    0, 1735, 1735, 1735,    0, 1735,    0,
    0,    0, 1735, 1735, 1735, 1735, 1735, 1735, 1735, 1735,
 1735, 1735, 1735, 1735, 1735, 2102, 1735, 1735,    0,    0,
    0,    0,    0, 1735, 1735, 1735, 1735, 1735, 1735, 1735,
 1735, 1735, 1735, 1735, 1735, 1735, 1735, 1735, 1735, 1735,
 1735,    0,    0, 1735,    0, 1735, 1735, 1735, 1735, 1735,
 1735, 1735, 1735, 1735,    0, 2072, 2102, 2102, 2102, 2102,
 2102, 2102, 2102,    0,    0,    0,   85,    0,    0,    0,
    0,    0,    0, 2102, 2102, 2102, 2102, 2102,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,   85,    0,    0,    0,    0,    0,   85,    0,    0,
    1,    0,   85,    0,    0,    0, 2102,   85, 2102,    0,
   85,    0,    0,    0,    0,    0,    0,    2,    0,    0,
    0,    0,    0,    0,    0,    3,    0,    0,    0,    0,
    0,    0,    0,    4,    0,    5,    0,    0,    0,    0,
    6,    0,    0,    0,    0,    0,    7,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1416,    0,
    8,    0,    0,    0,    0,    0,    0, 1417,    0,    9,
    0,    0,    0,    0,    0,    0,    0,    0,   85,    0,
 1418,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,   10,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   85,    0,
    0,    0,    0,    0, 1419,    0,    0,    0,    0,    0,
    0, 1420,    0,   85,    0,    0,    0,    0,    0, 1421,
    0,    0,    0,    0,    0,   11,    0,   12,    0,    0,
   13,    0,    0,    0,    0,   85, 1422,    0, 1423,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1424,    0,
 1425, 1426, 1427,    0,   14,    0,    0, 1428,    0,    0,
    0,    0, 2102,    0, 2102,    0,   15, 2102,    0, 2102,
 2102, 2102,    0, 2102, 2102,    0, 2102,    0,    0,    0,
    0,    0, 2102,    0, 2102, 2102, 2102, 2102,    0, 2102,
    0,   85, 2102,    0,   85, 2102,    0,    0, 1429,    0,
    0,    0, 2102,    0, 2102, 2102,   16, 2102, 2102, 2102,
 2102, 2102,    0,    0, 2102,    0,    0, 2102,    0, 2102,
 2102,   17,   18, 2102, 2102, 2102,    0, 2102, 2102, 2102,
 2102, 2102, 2102, 2102,    0,    0,    0, 2102, 2102, 2102,
 2102, 2102,    0,   19,    0, 2102,    0,    0,    0,    0,
    0,    0,    0, 2102, 2102, 2102, 2102, 2102, 2102,    0,
    0,    0, 2102, 2102,    0, 2102,    0, 2102,    0, 2102,
 2102, 2102,    0, 2102,    0, 2102, 2102, 2102,    0, 2102,
 2102, 2102, 2102, 2102,    0, 2102, 2102,    0,    0,    0,
    0, 2102,    0, 2102, 2102,    0,    0, 2102, 2102, 2102,
   85,    0, 2102,    0, 2102,    0,    0, 2102, 2102, 2102,
 2102,    0, 2102,    0, 2102,    0, 2102, 2102, 2102, 2102,
 2102,    0,    0, 2102, 2102, 2102,    0, 2102, 2102,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2102, 2102,
 2102,    0, 2102, 2102, 2102,    0,    0,    0,    0,    0,
 2102,    0,    0,    0, 2102,    0, 2102, 2102, 2102, 2102,
    0, 2102,    0, 2102, 2102, 2102, 2102, 2102, 2102, 2102,
 2102,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2102, 2102,    0, 2102, 2102, 2102,    0,    0, 1430,    0,
 2102, 2102, 2102, 2102, 2102,    0, 2102,    0,    0, 2102,
 2102,    0,    0,    0, 2102, 2102,    0,    0, 2102, 2102,
 2102, 2102, 2102, 2102, 2102, 2102, 2102,    0, 2102,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2102, 2102,
 2102, 2102, 2102, 2102, 2102, 2102, 2102, 2102, 2102, 2102,
 2102, 2102, 2102, 2102, 2102, 2102, 2102, 2102, 2102,    0,
 2102, 2102, 2102, 2102, 2102, 2102,    0, 2102, 2102, 2102,
 2102,    0, 2102,    0, 2102, 2102, 2102, 2102, 2102, 2102,
 2102, 2102, 2102, 2102, 2102, 2102, 2102, 2102, 2102, 2102,
 2102, 2102,    0, 2102, 2102, 2102, 2102,    0, 2102, 2102,
 2102, 2102, 2102,    0, 2102, 2102, 2102, 2102, 2102, 2102,
 2102, 2102, 2102, 2102, 2102, 2102, 2102, 2102, 2102, 2102,
 2102, 2102, 2102, 2102, 2102, 2102, 2102, 2102, 2102, 2102,
 2102, 2102, 2102,    0, 2102, 2102,    0,    0,    0, 2102,
 2102, 2102, 2102, 2102, 2102,    0,    0, 2102, 2102, 2102,
 2102, 2102, 2102, 2102, 2102, 2102, 2947,    0,    0, 2946,
    0, 2102,    0, 2102, 2102, 2102, 2102, 2102, 2102,    0,
 2102,    0,    0,    0,    0, 1432, 1431, 1433,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2102, 2102,    0,
 2102, 2102, 2102, 2102, 2102, 2102, 2102, 2102, 2102,    0,
 2102, 2102, 2102, 2102, 2102, 2102, 2102, 2102, 2102, 2102,
 2102, 2102,    0, 2102, 2102, 2102,    0, 2102,    0,    0,
    0, 2102, 2102, 2102, 2102, 2102, 2102, 2102, 2102, 2102,
 2102, 2102, 2102, 2102, 2139, 2102, 2102,    0,    0,    0,
    0,    0, 2102, 2102, 2102, 2102, 2102, 2102, 2102, 2102,
 2102, 2102, 2102, 2102, 2102, 2102, 2102, 2102, 2102, 2102,
    0,    0, 2102,    0, 2102, 2102, 2102, 2102, 2102, 2102,
 2102, 2102, 2102,    0, 1896, 2139, 2139, 2139, 2139, 2139,
 2139, 2139,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2139, 2139, 2139, 2139, 2139,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2139,    0, 2139,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1416,    0,    0,
    0,    0,    0,    0,    0,    0, 1417,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1418,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1419,    0,    0,    0,    0,    0,    0,
 1420,    0,    0,    0,    0,    0,    0,    0, 1421,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1422,    0, 1423,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1424,    0, 1425,
 1426, 1427,    0,    0,    0,    0, 1428,    0,    0,    0,
    0, 2139,    0, 2139,    0,    0, 2139,    0, 2139, 2139,
 2139,    0, 2139, 2139,    0, 2139,    0,    0,    0,    0,
    0, 2139,    0, 2139, 2139, 2139, 2139,    0, 2139,    0,
    0, 2139,    0,    0, 2139,    0,    0, 1429,    0,    0,
    0, 2139,    0, 2139, 2139,    0, 2139, 2139, 2139, 2139,
 2139,    0,    0, 2139,    0,    0, 2139,    0, 2139, 2139,
    0,    0, 2139, 2139, 2139,    0, 2139, 2139, 2139, 2139,
 2139, 2139, 2139,    0,    0,    0, 2139, 2139, 2139, 2139,
 2139,    0,    0,    0, 2139,    0,    0,    0,    0,    0,
    0,    0, 2139, 2139, 2139, 2139, 2139, 2139,    0,    0,
    0, 2139, 2139,    0, 2139,    0, 2139,    0, 2139, 2139,
 2139,    0, 2139,    0, 2139, 2139, 2139,    0, 2139, 2139,
 2139, 2139, 2139,    0, 2139, 2139,    0,    0,    0,    0,
 2139,    0, 2139, 2139,    0,    0, 2139, 2139, 2139,    0,
    0, 2139,    0, 2139,    0,    0, 2139, 2139, 2139, 2139,
    0, 2139,    0, 2139,    0, 2139, 2139, 2139, 2139, 2139,
    0,    0, 2139, 2139, 2139,    0, 2139, 2139,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2139, 2139, 2139,
    0, 2139, 2139, 2139,    0,    0,    0,    0,    0, 2139,
    0,    0,    0, 2139,    0, 2139, 2139, 2139, 2139,    0,
 2139,    0, 2139, 2139, 2139, 2139, 2139, 2139, 2139, 2139,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2139,
 2139,    0, 2139, 2139, 2139,    0,    0, 1430,    0, 2139,
 2139, 2139, 2139, 2139,    0, 2139,    0,    0, 2139, 2139,
    0,    0,    0, 2139, 2139,    0,    0, 2139, 2139, 2139,
 2139, 2139, 2139, 2139, 2139, 2139,    0, 2139,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2139, 2139, 2139,
 2139, 2139, 2139, 2139, 2139, 2139, 2139, 2139, 2139, 2139,
 2139, 2139, 2139, 2139, 2139, 2139, 2139, 2139,    0, 2139,
 2139, 2139, 2139, 2139, 2139,    0, 2139, 2139, 2139, 2139,
    0, 2139,    0, 2139, 2139, 2139, 2139, 2139, 2139, 2139,
 2139, 2139, 2139, 2139, 2139, 2139, 2139, 2139, 2139, 2139,
 2139,    0, 2139, 2139, 2139, 2139,    0, 2139, 2139, 2139,
 2139, 2139,    0, 2139, 2139, 2139, 2139, 2139, 2139, 2139,
 2139, 2139, 2139, 2139, 2139, 2139, 2139, 2139, 2139, 2139,
 2139, 2139, 2139, 2139, 2139, 2139, 2139, 2139, 2139, 2139,
 2139, 2139,    0, 2139, 2139,    0,    0,    0, 2139, 2139,
 2139, 2139, 2139, 2139,    0,    0, 2139, 2139, 2139, 2139,
 2139, 2139, 2139, 2139, 2139, 3475,    0,    0, 3474,    0,
 2139,    0, 2139, 2139, 2139, 2139, 2139, 2139,    0, 2139,
    0,    0,    0,    0, 1432, 1431, 1433,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2139, 2139,    0, 2139,
 2139, 2139, 2139, 2139, 2139, 2139, 2139, 2139,    0, 2139,
 2139, 2139, 2139, 2139, 2139, 2139, 2139, 2139, 2139, 2139,
 2139,    0, 2139, 2139, 2139,    0, 2139,    0,    0,    0,
 2139, 2139, 2139, 2139, 2139, 2139, 2139, 2139, 2139, 2139,
 2139, 2139, 2139, 2141, 2139, 2139,    0,    0,    0,    0,
    0, 2139, 2139, 2139, 2139, 2139, 2139, 2139, 2139, 2139,
 2139, 2139, 2139, 2139, 2139, 2139, 2139, 2139, 2139,    0,
    0, 2139,    0, 2139, 2139, 2139, 2139, 2139, 2139, 2139,
 2139, 2139,    0, 1897, 2141, 2141, 2141, 2141, 2141, 2141,
 2141,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2141, 2141, 2141, 2141, 2141,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2141,    0, 2141,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1416,    0,    0,    0,
    0,    0,    0,    0,    0, 1417,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1418,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1419,    0,    0,    0,    0,    0,    0, 1420,
    0,    0,    0,    0,    0,    0,    0, 1421,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1422,    0, 1423,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1424,    0, 1425, 1426,
 1427,    0,    0,    0,    0, 1428,    0,    0,    0,    0,
 2141,    0, 2141,    0,    0, 2141,    0, 2141, 2141, 2141,
    0, 2141, 2141,    0, 2141,    0,    0,    0,    0,    0,
 2141,    0, 2141, 2141, 2141, 2141,    0, 2141,    0,    0,
 2141,    0,    0, 2141,    0,    0, 1429,    0,    0,    0,
 2141,    0, 2141, 2141,    0, 2141, 2141, 2141, 2141, 2141,
    0,    0, 2141,    0,    0, 2141,    0, 2141, 2141,    0,
    0, 2141, 2141, 2141,    0, 2141, 2141, 2141, 2141, 2141,
 2141, 2141,    0,    0,    0, 2141, 2141, 2141, 2141, 2141,
    0,    0,    0, 2141,    0,    0,    0,    0,    0,    0,
    0, 2141, 2141, 2141, 2141, 2141, 2141,    0,    0,    0,
 2141, 2141,    0, 2141,    0, 2141,    0, 2141, 2141, 2141,
    0, 2141,    0, 2141, 2141, 2141,    0, 2141, 2141, 2141,
 2141, 2141,    0, 2141, 2141,    0,    0,    0,    0, 2141,
    0, 2141, 2141,    0,    0, 2141, 2141, 2141,    0,    0,
 2141,    0, 2141,    0,    0, 2141, 2141, 2141, 2141,    0,
 2141,    0, 2141,    0, 2141, 2141, 2141, 2141, 2141,    0,
    0, 2141, 2141, 2141,    0, 2141, 2141,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2141, 2141, 2141,    0,
 2141, 2141, 2141,    0,    0,    0,    0,    0, 2141,    0,
    0,    0, 2141,    0, 2141, 2141, 2141, 2141,    0, 2141,
    0, 2141, 2141, 2141, 2141, 2141, 2141, 2141, 2141,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2141, 2141,
    0, 2141, 2141, 2141,    0,    0, 1430,    0, 2141, 2141,
 2141, 2141, 2141,    0, 2141,    0,    0, 2141, 2141,    0,
    0,    0, 2141, 2141,    0,    0, 2141, 2141, 2141, 2141,
 2141, 2141, 2141, 2141, 2141,    0, 2141,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2141, 2141, 2141, 2141,
 2141, 2141, 2141, 2141, 2141, 2141, 2141, 2141, 2141, 2141,
 2141, 2141, 2141, 2141, 2141, 2141, 2141,    0, 2141, 2141,
 2141, 2141, 2141, 2141,    0, 2141, 2141, 2141, 2141,    0,
 2141,    0, 2141, 2141, 2141, 2141, 2141, 2141, 2141, 2141,
 2141, 2141, 2141, 2141, 2141, 2141, 2141, 2141, 2141, 2141,
    0, 2141, 2141, 2141, 2141,    0, 2141, 2141, 2141, 2141,
 2141,    0, 2141, 2141, 2141, 2141, 2141, 2141, 2141, 2141,
 2141, 2141, 2141, 2141, 2141, 2141, 2141, 2141, 2141, 2141,
 2141, 2141, 2141, 2141, 2141, 2141, 2141, 2141, 2141, 2141,
 2141,    0, 2141, 2141,    0,    0,    0, 2141, 2141, 2141,
 2141, 2141, 2141,    0,    0, 2141, 2141, 2141, 2141, 2141,
 2141, 2141, 2141, 2141, 3477,    0,    0,    0,    0, 2141,
    0, 2141, 2141, 2141, 2141, 2141, 2141,    0, 2141,    0,
    0,    0,    0, 1432, 1431, 1433,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2141, 2141,    0, 2141, 2141,
 2141, 2141, 2141, 2141, 2141, 2141, 2141,    0, 2141, 2141,
 2141, 2141, 2141, 2141, 2141, 2141, 2141, 2141, 2141, 2141,
    0, 2141, 2141, 2141,    0, 2141,    0,    0,    0, 2141,
 2141, 2141, 2141, 2141, 2141, 2141, 2141, 2141, 2141, 2141,
 2141, 2141, 2143, 2141, 2141,    0,    0,    0,    0,    0,
 2141, 2141, 2141, 2141, 2141, 2141, 2141, 2141, 2141, 2141,
 2141, 2141, 2141, 2141, 2141, 2141, 2141, 2141,    0,    0,
 2141,    0, 2141, 2141, 2141, 2141, 2141, 2141, 2141, 2141,
 2141,    0, 1899, 2143, 2143, 2143, 2143, 2143, 2143, 2143,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2143, 2143, 2143, 2143, 2143,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2143,    0, 2143,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1416,    0,    0,    0,    0,
    0,    0,    0,    0, 1417,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1418,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 3476,    0,    0,    0,    0,
    0, 1419,    0,    0,    0,    0,    0,    0, 1420,    0,
    0,    0,    0,    0,    0,    0, 1421,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1422,    0, 1423,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1424,    0, 1425, 1426, 1427,
    0,    0,    0,    0, 1428,    0,    0,    0,    0, 2143,
    0, 2143,    0,    0, 2143,    0, 2143, 2143, 2143,    0,
 2143, 2143,    0, 2143,    0,    0,    0,    0,    0, 2143,
    0, 2143, 2143, 2143, 2143,    0, 2143,    0,    0, 2143,
    0,    0, 2143,    0,    0, 1429,    0,    0,    0, 2143,
    0, 2143, 2143,    0, 2143, 2143, 2143, 2143, 2143,    0,
    0, 2143,    0,    0, 2143,    0, 2143, 2143,    0,    0,
 2143, 2143, 2143,    0, 2143, 2143, 2143, 2143, 2143, 2143,
 2143,    0,    0,    0, 2143, 2143, 2143, 2143, 2143,    0,
    0,    0, 2143,    0,    0,    0,    0,    0,    0,    0,
 2143, 2143, 2143, 2143, 2143, 2143,    0,    0,    0, 2143,
 2143,    0, 2143,    0, 2143,    0, 2143, 2143, 2143,    0,
 2143,    0, 2143, 2143, 2143,    0, 2143, 2143, 2143, 2143,
 2143,    0, 2143, 2143,    0,    0,    0,    0, 2143,    0,
 2143, 2143,    0,    0, 2143, 2143, 2143,    0,    0, 2143,
    0, 2143,    0,    0, 2143, 2143, 2143, 2143,    0, 2143,
    0, 2143,    0, 2143, 2143, 2143, 2143, 2143,    0,    0,
 2143, 2143, 2143,    0, 2143, 2143,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2143, 2143, 2143,    0, 2143,
 2143, 2143,    0,    0,    0,    0,    0, 2143,    0,    0,
    0, 2143,    0, 2143, 2143, 2143, 2143,    0, 2143,    0,
 2143, 2143, 2143, 2143, 2143, 2143, 2143, 2143,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2143, 2143,    0,
 2143, 2143, 2143,    0,    0, 1430,    0, 2143, 2143, 2143,
 2143, 2143,    0, 2143,    0,    0, 2143, 2143,    0,    0,
    0, 2143, 2143,    0,    0, 2143, 2143, 2143, 2143, 2143,
 2143, 2143, 2143, 2143,    0, 2143,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2143, 2143, 2143, 2143, 2143,
 2143, 2143, 2143, 2143, 2143, 2143, 2143, 2143, 2143, 2143,
 2143, 2143, 2143, 2143, 2143, 2143,    0, 2143, 2143, 2143,
 2143, 2143, 2143,    0, 2143, 2143, 2143, 2143,    0, 2143,
    0, 2143, 2143, 2143, 2143, 2143, 2143, 2143, 2143, 2143,
 2143, 2143, 2143, 2143, 2143, 2143, 2143, 2143, 2143,    0,
 2143, 2143, 2143, 2143,    0, 2143, 2143, 2143, 2143, 2143,
    0, 2143, 2143, 2143, 2143, 2143, 2143, 2143, 2143, 2143,
 2143, 2143, 2143, 2143, 2143, 2143, 2143, 2143, 2143, 2143,
 2143, 2143, 2143, 2143, 2143, 2143, 2143, 2143, 2143, 2143,
    0, 2143, 2143,    0,    0,    0, 2143, 2143, 2143, 2143,
 2143, 2143,    0,    0, 2143, 2143, 2143, 2143, 2143, 2143,
 2143, 2143, 2143, 1963,    0,    0,    0,    0, 2143,    0,
 2143, 2143, 2143, 2143, 2143, 2143,    0, 2143,    0,    0,
    0,    0, 1432, 1431, 1433,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2143, 2143,    0, 2143, 2143, 2143,
 2143, 2143, 2143, 2143, 2143, 2143,    0, 2143, 2143, 2143,
 2143, 2143, 2143, 2143, 2143, 2143, 2143, 2143, 2143,    0,
 2143, 2143, 2143,    0, 2143,    0,    0,    0, 2143, 2143,
 2143, 2143, 2143, 2143, 2143, 2143, 2143, 2143, 2143, 2143,
 2143, 2144, 2143, 2143,    0,    0,    0,    0,    0, 2143,
 2143, 2143, 2143, 2143, 2143, 2143, 2143, 2143, 2143, 2143,
 2143, 2143, 2143, 2143, 2143, 2143, 2143,    0,    0, 2143,
    0, 2143, 2143, 2143, 2143, 2143, 2143, 2143, 2143, 2143,
    0, 1900, 2144, 2144, 2144, 2144, 2144, 2144, 2144,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2144,
 2144, 2144, 2144, 2144,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2144,    0, 2144,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1416,    0,    0,    0,    0,    0,
    0,    0,    0, 1417,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1418,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1419,    0,    0,    0,    0,    0,    0, 1420,    0,    0,
    0,    0,    0,    0,    0, 1421,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1422,    0, 1423,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1424,    0, 1425, 1426, 1427,    0,
    0,    0,    0, 1428,    0,    0,    0,    0, 2144,    0,
 2144,    0,    0, 2144,    0, 2144, 2144, 2144,    0, 2144,
 2144,    0, 2144,    0,    0,    0,    0,    0, 2144,    0,
 2144, 2144, 2144, 2144,    0, 2144,    0,    0, 2144,    0,
    0, 2144,    0,    0, 1429,    0,    0,    0, 2144,    0,
 2144, 2144,    0, 2144, 2144, 2144, 2144, 2144,    0,    0,
 2144,    0,    0, 2144,    0, 2144, 2144,    0,    0, 2144,
 2144, 2144,    0, 2144, 2144, 2144, 2144, 2144, 2144, 2144,
    0,    0,    0, 2144, 2144, 2144, 2144, 2144,    0,    0,
    0, 2144,    0,    0,    0,    0,    0,    0,    0, 2144,
 2144, 2144, 2144, 2144, 2144,    0,    0,    0, 2144, 2144,
    0, 2144,    0, 2144,    0, 2144, 2144, 2144,    0, 2144,
    0, 2144, 2144, 2144,    0, 2144, 2144, 2144, 2144, 2144,
    0, 2144, 2144,    0,    0,    0,    0, 2144,    0, 2144,
 2144,    0,    0, 2144, 2144, 2144,    0,    0, 2144,    0,
 2144,    0,    0, 2144, 2144, 2144, 2144,    0, 2144,    0,
 2144,    0, 2144, 2144, 2144, 2144, 2144,    0,    0, 2144,
 2144, 2144,    0, 2144, 2144,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2144, 2144, 2144,    0, 2144, 2144,
 2144,    0,    0,    0,    0,    0, 2144,    0,    0,    0,
 2144,    0, 2144, 2144, 2144, 2144,    0, 2144,    0, 2144,
 2144, 2144, 2144, 2144, 2144, 2144, 2144,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2144, 2144,    0, 2144,
 2144, 2144,    0,    0, 1430,    0, 2144, 2144, 2144, 2144,
 2144,    0, 2144,    0,    0, 2144, 2144,    0,    0,    0,
 2144, 2144,    0,    0, 2144, 2144, 2144, 2144, 2144, 2144,
 2144, 2144, 2144,    0, 2144,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2144, 2144, 2144, 2144, 2144, 2144,
 2144, 2144, 2144, 2144, 2144, 2144, 2144, 2144, 2144, 2144,
 2144, 2144, 2144, 2144, 2144,    0, 2144, 2144, 2144, 2144,
 2144, 2144,    0, 2144, 2144, 2144, 2144,    0, 2144,    0,
 2144, 2144, 2144, 2144, 2144, 2144, 2144, 2144, 2144, 2144,
 2144, 2144, 2144, 2144, 2144, 2144, 2144, 2144,    0, 2144,
 2144, 2144, 2144,    0, 2144, 2144, 2144, 2144, 2144,    0,
 2144, 2144, 2144, 2144, 2144, 2144, 2144, 2144, 2144, 2144,
 2144, 2144, 2144, 2144, 2144, 2144, 2144, 2144, 2144, 2144,
 2144, 2144, 2144, 2144, 2144, 2144, 2144, 2144, 2144,    0,
 2144, 2144,    0,    0,    0, 2144, 2144, 2144, 2144, 2144,
 2144,    0,    0, 2144, 2144, 2144, 2144, 2144, 2144, 2144,
 2144, 2144, 1964,    0,    0,    0,    0, 2144,    0, 2144,
 2144, 2144, 2144, 2144, 2144,    0, 2144,    0,    0,    0,
    0, 1432, 1431, 1433,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2144, 2144,    0, 2144, 2144, 2144, 2144,
 2144, 2144, 2144, 2144, 2144,    0, 2144, 2144, 2144, 2144,
 2144, 2144, 2144, 2144, 2144, 2144, 2144, 2144,    0, 2144,
 2144, 2144,    0, 2144,    0,    0,    0, 2144, 2144, 2144,
 2144, 2144, 2144, 2144, 2144, 2144, 2144, 2144, 2144, 2144,
 2145, 2144, 2144,    0,    0,    0,    0,    0, 2144, 2144,
 2144, 2144, 2144, 2144, 2144, 2144, 2144, 2144, 2144, 2144,
 2144, 2144, 2144, 2144, 2144, 2144,    0,    0, 2144,    0,
 2144, 2144, 2144, 2144, 2144, 2144, 2144, 2144, 2144,    0,
 1901, 2145, 2145, 2145, 2145, 2145, 2145, 2145,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2145, 2145,
 2145, 2145, 2145,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2145,    0, 2145,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1416,    0,    0,    0,    0,    0,    0,
    0,    0, 1417,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1418,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1419,
    0,    0,    0,    0,    0,    0, 1420,    0,    0,    0,
    0,    0,    0,    0, 1421,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1422,    0, 1423,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1424,    0, 1425, 1426, 1427,    0,    0,
    0,    0, 1428,    0,    0,    0,    0, 2145,    0, 2145,
    0,    0, 2145,    0, 2145, 2145, 2145,    0, 2145, 2145,
    0, 2145,    0,    0,    0,    0,    0, 2145,    0, 2145,
 2145, 2145, 2145,    0, 2145,    0,    0, 2145,    0,    0,
 2145,    0,    0, 1429,    0,    0,    0, 2145,    0, 2145,
 2145,    0, 2145, 2145, 2145, 2145, 2145,    0,    0, 2145,
    0,    0, 2145,    0, 2145, 2145,    0,    0, 2145, 2145,
 2145,    0, 2145, 2145, 2145, 2145, 2145, 2145, 2145,    0,
    0,    0, 2145, 2145, 2145, 2145, 2145,    0,    0,    0,
 2145,    0,    0,    0,    0,    0,    0,    0, 2145, 2145,
 2145, 2145, 2145, 2145,    0,    0,    0, 2145, 2145,    0,
 2145,    0, 2145,    0, 2145, 2145, 2145,    0, 2145,    0,
 2145, 2145, 2145,    0, 2145, 2145, 2145, 2145, 2145,    0,
 2145, 2145,    0,    0,    0,    0, 2145,    0, 2145, 2145,
    0,    0, 2145, 2145, 2145,    0,    0, 2145,    0, 2145,
    0,    0, 2145, 2145, 2145, 2145,    0, 2145,    0, 2145,
    0, 2145, 2145, 2145, 2145, 2145,    0,    0, 2145, 2145,
 2145,    0, 2145, 2145,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2145, 2145, 2145,    0, 2145, 2145, 2145,
    0,    0,    0,    0,    0, 2145,    0,    0,    0, 2145,
    0, 2145, 2145, 2145, 2145,    0, 2145,    0, 2145, 2145,
 2145, 2145, 2145, 2145, 2145, 2145,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2145, 2145,    0, 2145, 2145,
 2145,    0,    0, 1430,    0, 2145, 2145, 2145, 2145, 2145,
    0, 2145,    0,    0, 2145, 2145,    0,    0,    0, 2145,
 2145,    0,    0, 2145, 2145, 2145, 2145, 2145, 2145, 2145,
 2145, 2145,    0, 2145,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2145, 2145, 2145, 2145, 2145, 2145, 2145,
 2145, 2145, 2145, 2145, 2145, 2145, 2145, 2145, 2145, 2145,
 2145, 2145, 2145, 2145,    0, 2145, 2145, 2145, 2145, 2145,
 2145,    0, 2145, 2145, 2145, 2145,    0, 2145,    0, 2145,
 2145, 2145, 2145, 2145, 2145, 2145, 2145, 2145, 2145, 2145,
 2145, 2145, 2145, 2145, 2145, 2145, 2145,    0, 2145, 2145,
 2145, 2145,    0, 2145, 2145, 2145, 2145, 2145,    0, 2145,
 2145, 2145, 2145, 2145, 2145, 2145, 2145, 2145, 2145, 2145,
 2145, 2145, 2145, 2145, 2145, 2145, 2145, 2145, 2145, 2145,
 2145, 2145, 2145, 2145, 2145, 2145, 2145, 2145,    0, 2145,
 2145,    0,    0,    0, 2145, 2145, 2145, 2145, 2145, 2145,
    0,    0, 2145, 2145, 2145, 2145, 2145, 2145, 2145, 2145,
 2145, 2125,    0,    0,    0,    0, 2145,    0, 2145, 2145,
 2145, 2145, 2145, 2145,    0, 2145,    0,    0,    0,    0,
 1432, 1431, 1433,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2145, 2145,    0, 2145, 2145, 2145, 2145, 2145,
 2145, 2145, 2145, 2145,    0, 2145, 2145, 2145, 2145, 2145,
 2145, 2145, 2145, 2145, 2145, 2145, 2145,    0, 2145, 2145,
 2145,    0, 2145,    0,    0,    0, 2145, 2145, 2145, 2145,
 2145, 2145, 2145, 2145, 2145, 2145, 2145, 2145, 2145, 2146,
 2145, 2145,    0,    0,    0,    0,    0, 2145, 2145, 2145,
 2145, 2145, 2145, 2145, 2145, 2145, 2145, 2145, 2145, 2145,
 2145, 2145, 2145, 2145, 2145,    0,    0, 2145,    0, 2145,
 2145, 2145, 2145, 2145, 2145, 2145, 2145, 2145,    0, 1903,
 2146, 2146, 2146, 2146, 2146, 2146, 2146,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2146, 2146, 2146,
 2146, 2146,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2146,    0, 2146,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1416,    0,    0,    0,    0,    0,    0,    0,
    0, 1417,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1418,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1419,    0,
    0,    0,    0,    0,    0, 1420,    0,    0,    0,    0,
    0,    0,    0, 1421,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1422,    0, 1423,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1424,    0, 1425, 1426, 1427,    0,    0,    0,
    0, 1428,    0,    0,    0,    0, 2146,    0, 2146,    0,
    0, 2146,    0, 2146, 2146, 2146,    0, 2146, 2146,    0,
 2146,    0,    0,    0,    0,    0, 2146,    0, 2146, 2146,
 2146, 2146,    0, 2146,    0,    0, 2146,    0,    0, 2146,
    0,    0, 1429,    0,    0,    0, 2146,    0, 2146, 2146,
    0, 2146, 2146, 2146, 2146, 2146,    0,    0, 2146,    0,
    0, 2146,    0, 2146, 2146,    0,    0, 2146, 2146, 2146,
    0, 2146, 2146, 2146, 2146, 2146, 2146, 2146,    0,    0,
    0, 2146, 2146, 2146, 2146, 2146,    0,    0,    0, 2146,
    0,    0,    0,    0,    0,    0,    0, 2146, 2146, 2146,
 2146, 2146, 2146,    0,    0,    0, 2146, 2146,    0, 2146,
    0, 2146,    0, 2146, 2146, 2146,    0, 2146,    0, 2146,
 2146, 2146,    0, 2146, 2146, 2146, 2146, 2146,    0, 2146,
 2146,    0,    0,    0,    0, 2146,    0, 2146, 2146,    0,
    0, 2146, 2146, 2146,    0,    0, 2146,    0, 2146,    0,
    0, 2146, 2146, 2146, 2146,    0, 2146,    0, 2146,    0,
 2146, 2146, 2146, 2146, 2146,    0,    0, 2146, 2146, 2146,
    0, 2146, 2146,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2146, 2146, 2146,    0, 2146, 2146, 2146,    0,
    0,    0,    0,    0, 2146,    0,    0,    0, 2146,    0,
 2146, 2146, 2146, 2146,    0, 2146,    0, 2146, 2146, 2146,
 2146, 2146, 2146, 2146, 2146,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2146, 2146,    0, 2146, 2146, 2146,
    0,    0, 1430,    0, 2146, 2146, 2146, 2146, 2146,    0,
 2146,    0,    0, 2146, 2146,    0,    0,    0, 2146, 2146,
    0,    0, 2146, 2146, 2146, 2146, 2146, 2146, 2146, 2146,
 2146,    0, 2146,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2146, 2146, 2146, 2146, 2146, 2146, 2146, 2146,
 2146, 2146, 2146, 2146, 2146, 2146, 2146, 2146, 2146, 2146,
 2146, 2146, 2146,    0, 2146, 2146, 2146, 2146, 2146, 2146,
    0, 2146, 2146, 2146, 2146,    0, 2146,    0, 2146, 2146,
 2146, 2146, 2146, 2146, 2146, 2146, 2146, 2146, 2146, 2146,
 2146, 2146, 2146, 2146, 2146, 2146,    0, 2146, 2146, 2146,
 2146,    0, 2146, 2146, 2146, 2146, 2146,    0, 2146, 2146,
 2146, 2146, 2146, 2146, 2146, 2146, 2146, 2146, 2146, 2146,
 2146, 2146, 2146, 2146, 2146, 2146, 2146, 2146, 2146, 2146,
 2146, 2146, 2146, 2146, 2146, 2146, 2146,    0, 2146, 2146,
    0,    0,    0, 2146, 2146, 2146, 2146, 2146, 2146,    0,
    0, 2146, 2146, 2146, 2146, 2146, 2146, 2146, 2146, 2146,
 2149,    0,    0,    0,    0, 2146,    0, 2146, 2146, 2146,
 2146, 2146, 2146,    0, 2146,    0,    0,    0,    0, 1432,
 1431, 1433,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2146, 2146,    0, 2146, 2146, 2146, 2146, 2146, 2146,
 2146, 2146, 2146,    0, 2146, 2146, 2146, 2146, 2146, 2146,
 2146, 2146, 2146, 2146, 2146, 2146,    0, 2146, 2146, 2146,
    0, 2146,    0,    0,    0, 2146, 2146, 2146, 2146, 2146,
 2146, 2146, 2146, 2146, 2146, 2146, 2146, 2146, 2147, 2146,
 2146,    0,    0,    0,    0,    0, 2146, 2146, 2146, 2146,
 2146, 2146, 2146, 2146, 2146, 2146, 2146, 2146, 2146, 2146,
 2146, 2146, 2146, 2146,    0,    0, 2146,    0, 2146, 2146,
 2146, 2146, 2146, 2146, 2146, 2146, 2146,    0, 1904, 2147,
 2147, 2147, 2147, 2147, 2147, 2147,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2147, 2147, 2147, 2147,
 2147,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2147,
    0, 2147,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1416,    0,    0,    0,    0,    0,    0,    0,    0,
 1417,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1418,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1419,    0,    0,
    0,    0,    0,    0, 1420,    0,    0,    0,    0,    0,
    0,    0, 1421,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1422,
    0, 1423,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1424,    0, 1425, 1426, 1427,    0,    0,    0,    0,
 1428,    0,    0,    0,    0, 2147,    0, 2147,    0,    0,
 2147,    0, 2147, 2147, 2147,    0, 2147, 2147,    0, 2147,
    0,    0,    0,    0,    0, 2147,    0, 2147, 2147, 2147,
 2147,    0, 2147,    0,    0, 2147,    0,    0, 2147,    0,
    0, 1429,    0,    0,    0, 2147,    0, 2147, 2147,    0,
 2147, 2147, 2147, 2147, 2147,    0,    0, 2147,    0,    0,
 2147,    0, 2147, 2147,    0,    0, 2147, 2147, 2147,    0,
 2147, 2147, 2147, 2147, 2147, 2147, 2147,    0,    0,    0,
 2147, 2147, 2147, 2147, 2147,    0,    0,    0, 2147,    0,
    0,    0,    0,    0,    0,    0, 2147, 2147, 2147, 2147,
 2147, 2147,    0,    0,    0, 2147, 2147,    0, 2147,    0,
 2147,    0, 2147, 2147, 2147,    0, 2147,    0, 2147, 2147,
 2147,    0, 2147, 2147, 2147, 2147, 2147,    0, 2147, 2147,
    0,    0,    0,    0, 2147,    0, 2147, 2147,    0,    0,
 2147, 2147, 2147,    0,    0, 2147,    0, 2147,    0,    0,
 2147, 2147, 2147, 2147,    0, 2147,    0, 2147,    0, 2147,
 2147, 2147, 2147, 2147,    0,    0, 2147, 2147, 2147,    0,
 2147, 2147,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2147, 2147, 2147,    0, 2147, 2147, 2147,    0,    0,
    0,    0,    0, 2147,    0,    0,    0, 2147,    0, 2147,
 2147, 2147, 2147,    0, 2147,    0, 2147, 2147, 2147, 2147,
 2147, 2147, 2147, 2147,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2147, 2147,    0, 2147, 2147, 2147,    0,
    0, 1430,    0, 2147, 2147, 2147, 2147, 2147,    0, 2147,
    0,    0, 2147, 2147,    0,    0,    0, 2147, 2147,    0,
    0, 2147, 2147, 2147, 2147, 2147, 2147, 2147, 2147, 2147,
    0, 2147,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2147, 2147, 2147, 2147, 2147, 2147, 2147, 2147, 2147,
 2147, 2147, 2147, 2147, 2147, 2147, 2147, 2147, 2147, 2147,
 2147, 2147,    0, 2147, 2147, 2147, 2147, 2147, 2147,    0,
 2147, 2147, 2147, 2147,    0, 2147,    0, 2147, 2147, 2147,
 2147, 2147, 2147, 2147, 2147, 2147, 2147, 2147, 2147, 2147,
 2147, 2147, 2147, 2147, 2147,    0, 2147, 2147, 2147, 2147,
    0, 2147, 2147, 2147, 2147, 2147,    0, 2147, 2147, 2147,
 2147, 2147, 2147, 2147, 2147, 2147, 2147, 2147, 2147, 2147,
 2147, 2147, 2147, 2147, 2147, 2147, 2147, 2147, 2147, 2147,
 2147, 2147, 2147, 2147, 2147, 2147,    0, 2147, 2147,    0,
    0,    0, 2147, 2147, 2147, 2147, 2147, 2147,    0,    0,
 2147, 2147, 2147, 2147, 2147, 2147, 2147, 2147, 2147, 2150,
    0,    0,    0,    0, 2147,    0, 2147, 2147, 2147, 2147,
 2147, 2147,    0, 2147,    0,    0,    0,    0, 1432, 1431,
 1433,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2147, 2147,    0, 2147, 2147, 2147, 2147, 2147, 2147, 2147,
 2147, 2147,    0, 2147, 2147, 2147, 2147, 2147, 2147, 2147,
 2147, 2147, 2147, 2147, 2147,    0, 2147, 2147, 2147,    0,
 2147,    0,    0,    0, 2147, 2147, 2147, 2147, 2147, 2147,
 2147, 2147, 2147, 2147, 2147, 2147, 2147, 2148, 2147, 2147,
    0,    0,    0,    0,    0, 2147, 2147, 2147, 2147, 2147,
 2147, 2147, 2147, 2147, 2147, 2147, 2147, 2147, 2147, 2147,
 2147, 2147, 2147,    0,    0, 2147,    0, 2147, 2147, 2147,
 2147, 2147, 2147, 2147, 2147, 2147,    0, 1908, 2148, 2148,
 2148, 2148, 2148, 2148, 2148,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2148, 2148, 2148, 2148, 2148,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2148,    0,
 2148,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1416,    0,    0,    0,    0,    0,    0,    0,    0, 1417,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1418,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1419,    0,    0,    0,
    0,    0,    0, 1420,    0,    0,    0,    0,    0,    0,
    0, 1421,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1422,    0,
 1423,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1424,    0, 1425, 1426, 1427,    0,    0,    0,    0, 1428,
    0,    0,    0,    0, 2148,    0, 2148,    0,    0, 2148,
    0, 2148, 2148, 2148,    0, 2148, 2148,    0, 2148,    0,
    0,    0,    0,    0, 2148,    0, 2148, 2148, 2148, 2148,
    0, 2148,    0,    0, 2148,    0,    0, 2148,    0,    0,
 1429,    0,    0,    0, 2148,    0, 2148, 2148,    0, 2148,
 2148, 2148, 2148, 2148,    0,    0, 2148,    0,    0, 2148,
    0, 2148, 2148,    0,    0, 2148, 2148, 2148,    0, 2148,
 2148, 2148, 2148, 2148, 2148, 2148,    0,    0,    0, 2148,
 2148, 2148, 2148, 2148,    0,    0,    0, 2148,    0,    0,
    0,    0,    0,    0,    0, 2148, 2148, 2148, 2148, 2148,
 2148,    0,    0,    0, 2148, 2148,    0, 2148,    0, 2148,
    0, 2148, 2148, 2148,    0, 2148,    0, 2148, 2148, 2148,
    0, 2148, 2148, 2148, 2148, 2148,    0, 2148, 2148,    0,
    0,    0,    0, 2148,    0, 2148, 2148,    0,    0, 2148,
 2148, 2148,    0,    0, 2148,    0, 2148,    0,    0, 2148,
 2148, 2148, 2148,    0, 2148,    0, 2148,    0, 2148, 2148,
 2148, 2148, 2148,    0,    0, 2148, 2148, 2148,    0, 2148,
 2148,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2148, 2148, 2148,    0, 2148, 2148, 2148,    0,    0,    0,
    0,    0, 2148,    0,    0,    0, 2148,    0, 2148, 2148,
 2148, 2148,    0, 2148,    0, 2148, 2148, 2148, 2148, 2148,
 2148, 2148, 2148,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2148, 2148,    0, 2148, 2148, 2148,    0,    0,
 1430,    0, 2148, 2148, 2148, 2148, 2148,    0, 2148,    0,
    0, 2148, 2148,    0,    0,    0, 2148, 2148,    0,    0,
 2148, 2148, 2148, 2148, 2148, 2148, 2148, 2148, 2148,    0,
 2148,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2148, 2148, 2148, 2148, 2148, 2148, 2148, 2148, 2148, 2148,
 2148, 2148, 2148, 2148, 2148, 2148, 2148, 2148, 2148, 2148,
 2148,    0, 2148, 2148, 2148, 2148, 2148, 2148,    0, 2148,
 2148, 2148, 2148,    0, 2148,    0, 2148, 2148, 2148, 2148,
 2148, 2148, 2148, 2148, 2148, 2148, 2148, 2148, 2148, 2148,
 2148, 2148, 2148, 2148,    0, 2148, 2148, 2148, 2148,    0,
 2148, 2148, 2148, 2148, 2148,    0, 2148, 2148, 2148, 2148,
 2148, 2148, 2148, 2148, 2148, 2148, 2148, 2148, 2148, 2148,
 2148, 2148, 2148, 2148, 2148, 2148, 2148, 2148, 2148, 2148,
 2148, 2148, 2148, 2148, 2148,    0, 2148, 2148,    0,    0,
    0, 2148, 2148, 2148, 2148, 2148, 2148,    0,    0, 2148,
 2148, 2148, 2148, 2148, 2148, 2148, 2148, 2148, 2151,    0,
    0,    0,    0, 2148,    0, 2148, 2148, 2148, 2148, 2148,
 2148,    0, 2148,    0,    0,    0,    0, 1432, 1431, 1433,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2148,
 2148,    0, 2148, 2148, 2148, 2148, 2148, 2148, 2148, 2148,
 2148,    0, 2148, 2148, 2148, 2148, 2148, 2148, 2148, 2148,
 2148, 2148, 2148, 2148,    0, 2148, 2148, 2148,    0, 2148,
    0,    0,    0, 2148, 2148, 2148, 2148, 2148, 2148, 2148,
 2148, 2148, 2148, 2148, 2148, 2148, 2149, 2148, 2148,    0,
    0,    0,    0,    0, 2148, 2148, 2148, 2148, 2148, 2148,
 2148, 2148, 2148, 2148, 2148, 2148, 2148, 2148, 2148, 2148,
 2148, 2148,    0,    0, 2148,    0, 2148, 2148, 2148, 2148,
 2148, 2148, 2148, 2148, 2148,    0, 1910, 2149, 2149, 2149,
 2149, 2149, 2149, 2149,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2149, 2149, 2149, 2149, 2149,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2149,    0, 2149,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1416,
    0,    0,    0,    0,    0,    0,    0,    0, 1417,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1418,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1419,    0,    0,    0,    0,
    0,    0, 1420,    0,    0,    0,    0,    0,    0,    0,
 1421,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1422,    0, 1423,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1424,
    0, 1425, 1426, 1427,    0,    0,    0,    0, 1428,    0,
    0,    0,    0, 2149,    0, 2149,    0,    0, 2149,    0,
 2149, 2149, 2149,    0, 2149, 2149,    0, 2149,    0,    0,
    0,    0,    0, 2149,    0, 2149, 2149, 2149, 2149,    0,
 2149,    0,    0, 2149,    0,    0, 2149,    0,    0, 1429,
    0,    0,    0, 2149,    0, 2149, 2149,    0, 2149, 2149,
 2149, 2149, 2149,    0,    0, 2149,    0,    0, 2149,    0,
 2149, 2149,    0,    0, 2149, 2149, 2149,    0, 2149, 2149,
 2149, 2149, 2149, 2149, 2149,    0,    0,    0, 2149, 2149,
 2149, 2149, 2149,    0,    0,    0, 2149,    0,    0,    0,
    0,    0,    0,    0, 2149, 2149, 2149, 2149, 2149, 2149,
    0,    0,    0, 2149, 2149,    0, 2149,    0, 2149,    0,
 2149, 2149, 2149,    0, 2149,    0, 2149, 2149, 2149,    0,
 2149, 2149, 2149, 2149, 2149,    0, 2149, 2149,    0,    0,
    0,    0, 2149,    0, 2149, 2149,    0,    0, 2149, 2149,
 2149,    0,    0, 2149,    0, 2149,    0,    0, 2149, 2149,
 2149, 2149,    0, 2149,    0, 2149,    0, 2149, 2149, 2149,
 2149, 2149,    0,    0, 2149, 2149, 2149,    0, 2149, 2149,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2149,
 2149, 2149,    0, 2149, 2149, 2149,    0,    0,    0,    0,
    0, 2149,    0,    0,    0, 2149,    0, 2149, 2149, 2149,
 2149,    0, 2149,    0, 2149, 2149, 2149, 2149, 2149, 2149,
 2149, 2149,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2149, 2149,    0, 2149, 2149, 2149,    0,    0, 1430,
    0, 2149, 2149, 2149, 2149, 2149,    0, 2149,    0,    0,
 2149, 2149,    0,    0,    0, 2149, 2149,    0,    0, 2149,
 2149, 2149, 2149, 2149, 2149, 2149, 2149, 2149,    0, 2149,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2149,
 2149, 2149, 2149, 2149, 2149, 2149, 2149, 2149, 2149, 2149,
 2149, 2149, 2149, 2149, 2149, 2149, 2149, 2149, 2149, 2149,
    0, 2149, 2149, 2149, 2149, 2149, 2149,    0, 2149, 2149,
 2149, 2149,    0, 2149,    0, 2149, 2149, 2149, 2149, 2149,
 2149, 2149, 2149, 2149, 2149, 2149, 2149, 2149, 2149, 2149,
 2149, 2149, 2149,    0, 2149, 2149, 2149, 2149,    0, 2149,
 2149, 2149, 2149, 2149,    0, 2149, 2149, 2149, 2149, 2149,
 2149, 2149, 2149, 2149, 2149, 2149, 2149, 2149, 2149, 2149,
 2149, 2149, 2149, 2149, 2149, 2149, 2149, 2149, 2149, 2149,
 2149, 2149, 2149, 2149,    0, 2149, 2149,    0,    0,    0,
 2149, 2149, 2149, 2149, 2149, 2149,    0,    0, 2149, 2149,
 2149, 2149, 2149, 2149, 2149, 2149, 2149, 2152,    0,    0,
    0,    0, 2149,    0, 2149, 2149, 2149, 2149, 2149, 2149,
    0, 2149,    0,    0,    0,    0, 1432, 1431, 1433,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2149, 2149,
    0, 2149, 2149, 2149, 2149, 2149, 2149, 2149, 2149, 2149,
    0, 2149, 2149, 2149, 2149, 2149, 2149, 2149, 2149, 2149,
 2149, 2149, 2149,    0, 2149, 2149, 2149,    0, 2149,    0,
    0,    0, 2149, 2149, 2149, 2149, 2149, 2149, 2149, 2149,
 2149, 2149, 2149, 2149, 2149, 2150, 2149, 2149,    0,    0,
    0,    0,    0, 2149, 2149, 2149, 2149, 2149, 2149, 2149,
 2149, 2149, 2149, 2149, 2149, 2149, 2149, 2149, 2149, 2149,
 2149,    0,    0, 2149,    0, 2149, 2149, 2149, 2149, 2149,
 2149, 2149, 2149, 2149,    0, 1911, 2150, 2150, 2150, 2150,
 2150, 2150, 2150,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2150, 2150, 2150, 2150, 2150,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2150,    0, 2150,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1416,    0,
    0,    0,    0,    0,    0,    0,    0, 1417,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1418,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1419,    0,    0,    0,    0,    0,
    0, 1420,    0,    0,    0,    0,    0,    0,    0, 1421,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1422,    0, 1423,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1424,    0,
 1425, 1426, 1427,    0,    0,    0,    0, 1428,    0,    0,
    0,    0, 2150,    0, 2150,    0,    0, 2150,    0, 2150,
 2150, 2150,    0, 2150, 2150,    0, 2150,    0,    0,    0,
    0,    0, 2150,    0, 2150, 2150, 2150, 2150,    0, 2150,
    0,    0, 2150,    0,    0, 2150,    0,    0, 1429,    0,
    0,    0, 2150,    0, 2150, 2150,    0, 2150, 2150, 2150,
 2150, 2150,    0,    0, 2150,    0,    0, 2150,    0, 2150,
 2150,    0,    0, 2150, 2150, 2150,    0, 2150, 2150, 2150,
 2150, 2150, 2150, 2150,    0,    0,    0, 2150, 2150, 2150,
 2150, 2150,    0,    0,    0, 2150,    0,    0,    0,    0,
    0,    0,    0, 2150, 2150, 2150, 2150, 2150, 2150,    0,
    0,    0, 2150, 2150,    0, 2150,    0, 2150,    0, 2150,
 2150, 2150,    0, 2150,    0, 2150, 2150, 2150,    0, 2150,
 2150, 2150, 2150, 2150,    0, 2150, 2150,    0,    0,    0,
    0, 2150,    0, 2150, 2150,    0,    0, 2150, 2150, 2150,
    0,    0, 2150,    0, 2150,    0,    0, 2150, 2150, 2150,
 2150,    0, 2150,    0, 2150,    0, 2150, 2150, 2150, 2150,
 2150,    0,    0, 2150, 2150, 2150,    0, 2150, 2150,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2150, 2150,
 2150,    0, 2150, 2150, 2150,    0,    0,    0,    0,    0,
 2150,    0,    0,    0, 2150,    0, 2150, 2150, 2150, 2150,
    0, 2150,    0, 2150, 2150, 2150, 2150, 2150, 2150, 2150,
 2150,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2150, 2150,    0, 2150, 2150, 2150,    0,    0, 1430,    0,
 2150, 2150, 2150, 2150, 2150,    0, 2150,    0,    0, 2150,
 2150,    0,    0,    0, 2150, 2150,    0,    0, 2150, 2150,
 2150, 2150, 2150, 2150, 2150, 2150, 2150,    0, 2150,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2150, 2150,
 2150, 2150, 2150, 2150, 2150, 2150, 2150, 2150, 2150, 2150,
 2150, 2150, 2150, 2150, 2150, 2150, 2150, 2150, 2150,    0,
 2150, 2150, 2150, 2150, 2150, 2150,    0, 2150, 2150, 2150,
 2150,    0, 2150,    0, 2150, 2150, 2150, 2150, 2150, 2150,
 2150, 2150, 2150, 2150, 2150, 2150, 2150, 2150, 2150, 2150,
 2150, 2150,    0, 2150, 2150, 2150, 2150,    0, 2150, 2150,
 2150, 2150, 2150,    0, 2150, 2150, 2150, 2150, 2150, 2150,
 2150, 2150, 2150, 2150, 2150, 2150, 2150, 2150, 2150, 2150,
 2150, 2150, 2150, 2150, 2150, 2150, 2150, 2150, 2150, 2150,
 2150, 2150, 2150,    0, 2150, 2150,    0,    0,    0, 2150,
 2150, 2150, 2150, 2150, 2150,    0,    0, 2150, 2150, 2150,
 2150, 2150, 2150, 2150, 2150, 2150, 2153,    0,    0,    0,
    0, 2150,    0, 2150, 2150, 2150, 2150, 2150, 2150,    0,
 2150,    0,    0,    0,    0, 1432, 1431, 1433,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2150, 2150,    0,
 2150, 2150, 2150, 2150, 2150, 2150, 2150, 2150, 2150,    0,
 2150, 2150, 2150, 2150, 2150, 2150, 2150, 2150, 2150, 2150,
 2150, 2150,    0, 2150, 2150, 2150,    0, 2150,    0,    0,
    0, 2150, 2150, 2150, 2150, 2150, 2150, 2150, 2150, 2150,
 2150, 2150, 2150, 2150, 2151, 2150, 2150,    0,    0,    0,
    0,    0, 2150, 2150, 2150, 2150, 2150, 2150, 2150, 2150,
 2150, 2150, 2150, 2150, 2150, 2150, 2150, 2150, 2150, 2150,
    0,    0, 2150,    0, 2150, 2150, 2150, 2150, 2150, 2150,
 2150, 2150, 2150,    0, 1912, 2151, 2151, 2151, 2151, 2151,
 2151, 2151,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2151, 2151, 2151, 2151, 2151,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2151,    0, 2151,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1416,    0,    0,
    0,    0,    0,    0,    0,    0, 1417,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1418,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1419,    0,    0,    0,    0,    0,    0,
 1420,    0,    0,    0,    0,    0,    0,    0, 1421,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1422,    0, 1423,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1424,    0, 1425,
 1426, 1427,    0,    0,    0,    0, 1428,    0,    0,    0,
    0, 2151,    0, 2151,    0,    0, 2151,    0, 2151, 2151,
 2151,    0, 2151, 2151,    0, 2151,    0,    0,    0,    0,
    0, 2151,    0, 2151, 2151, 2151, 2151,    0, 2151,    0,
    0, 2151,    0,    0, 2151,    0,    0, 1429,    0,    0,
    0, 2151,    0, 2151, 2151,    0, 2151, 2151, 2151, 2151,
 2151,    0,    0, 2151,    0,    0, 2151,    0, 2151, 2151,
    0,    0, 2151, 2151, 2151,    0, 2151, 2151, 2151, 2151,
 2151, 2151, 2151,    0,    0,    0, 2151, 2151, 2151, 2151,
 2151,    0,    0,    0, 2151,    0,    0,    0,    0,    0,
    0,    0, 2151, 2151, 2151, 2151, 2151, 2151,    0,    0,
    0, 2151, 2151,    0, 2151,    0, 2151,    0, 2151, 2151,
 2151,    0, 2151,    0, 2151, 2151, 2151,    0, 2151, 2151,
 2151, 2151, 2151,    0, 2151, 2151,    0,    0,    0,    0,
 2151,    0, 2151, 2151,    0,    0, 2151, 2151, 2151,    0,
    0, 2151,    0, 2151,    0,    0, 2151, 2151, 2151, 2151,
    0, 2151,    0, 2151,    0, 2151, 2151, 2151, 2151, 2151,
    0,    0, 2151, 2151, 2151,    0, 2151, 2151,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2151, 2151, 2151,
    0, 2151, 2151, 2151,    0,    0,    0,    0,    0, 2151,
    0,    0,    0, 2151,    0, 2151, 2151, 2151, 2151,    0,
 2151,    0, 2151, 2151, 2151, 2151, 2151, 2151, 2151, 2151,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2151,
 2151,    0, 2151, 2151, 2151,    0,    0, 1430,    0, 2151,
 2151, 2151, 2151, 2151,    0, 2151,    0,    0, 2151, 2151,
    0,    0,    0, 2151, 2151,    0,    0, 2151, 2151, 2151,
 2151, 2151, 2151, 2151, 2151, 2151,    0, 2151,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2151, 2151, 2151,
 2151, 2151, 2151, 2151, 2151, 2151, 2151, 2151, 2151, 2151,
 2151, 2151, 2151, 2151, 2151, 2151, 2151, 2151,    0, 2151,
 2151, 2151, 2151, 2151, 2151,    0, 2151, 2151, 2151, 2151,
    0, 2151,    0, 2151, 2151, 2151, 2151, 2151, 2151, 2151,
 2151, 2151, 2151, 2151, 2151, 2151, 2151, 2151, 2151, 2151,
 2151,    0, 2151, 2151, 2151, 2151,    0, 2151, 2151, 2151,
 2151, 2151,    0, 2151, 2151, 2151, 2151, 2151, 2151, 2151,
 2151, 2151, 2151, 2151, 2151, 2151, 2151, 2151, 2151, 2151,
 2151, 2151, 2151, 2151, 2151, 2151, 2151, 2151, 2151, 2151,
 2151, 2151,    0, 2151, 2151,    0,    0,    0, 2151, 2151,
 2151, 2151, 2151, 2151,    0,    0, 2151, 2151, 2151, 2151,
 2151, 2151, 2151, 2151, 2151, 2163,    0,    0,    0,    0,
 2151,    0, 2151, 2151, 2151, 2151, 2151, 2151,    0, 2151,
    0,    0,    0,    0, 1432, 1431, 1433,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2151, 2151,    0, 2151,
 2151, 2151, 2151, 2151, 2151, 2151, 2151, 2151,    0, 2151,
 2151, 2151, 2151, 2151, 2151, 2151, 2151, 2151, 2151, 2151,
 2151,    0, 2151, 2151, 2151,    0, 2151,    0,    0,    0,
 2151, 2151, 2151, 2151, 2151, 2151, 2151, 2151, 2151, 2151,
 2151, 2151, 2151, 2152, 2151, 2151,    0,    0,    0,    0,
    0, 2151, 2151, 2151, 2151, 2151, 2151, 2151, 2151, 2151,
 2151, 2151, 2151, 2151, 2151, 2151, 2151, 2151, 2151,    0,
    0, 2151,    0, 2151, 2151, 2151, 2151, 2151, 2151, 2151,
 2151, 2151,    0, 1913, 2152, 2152, 2152, 2152, 2152, 2152,
 2152,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2152, 2152, 2152, 2152, 2152,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2152,    0, 2152,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1416,    0,    0,    0,
    0,    0,    0,    0,    0, 1417,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1418,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1419,    0,    0,    0,    0,    0,    0, 1420,
    0,    0,    0,    0,    0,    0,    0, 1421,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1422,    0, 1423,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1424,    0, 1425, 1426,
 1427,    0,    0,    0,    0, 1428,    0,    0,    0,    0,
 2152,    0, 2152,    0,    0, 2152,    0, 2152, 2152, 2152,
    0, 2152, 2152,    0, 2152,    0,    0,    0,    0,    0,
 2152,    0, 2152, 2152, 2152, 2152,    0, 2152,    0,    0,
 2152,    0,    0, 2152,    0,    0, 1429,    0,    0,    0,
 2152,    0, 2152, 2152,    0, 2152, 2152, 2152, 2152, 2152,
    0,    0, 2152,    0,    0, 2152,    0, 2152, 2152,    0,
    0, 2152, 2152, 2152,    0, 2152, 2152, 2152, 2152, 2152,
 2152, 2152,    0,    0,    0, 2152, 2152, 2152, 2152, 2152,
    0,    0,    0, 2152,    0,    0,    0,    0,    0,    0,
    0, 2152, 2152, 2152, 2152, 2152, 2152,    0,    0,    0,
 2152, 2152,    0, 2152,    0, 2152,    0, 2152, 2152, 2152,
    0, 2152,    0, 2152, 2152, 2152,    0, 2152, 2152, 2152,
 2152, 2152,    0, 2152, 2152,    0,    0,    0,    0, 2152,
    0, 2152, 2152,    0,    0, 2152, 2152, 2152,    0,    0,
 2152,    0, 2152,    0,    0, 2152, 2152, 2152, 2152,    0,
 2152,    0, 2152,    0, 2152, 2152, 2152, 2152, 2152,    0,
    0, 2152, 2152, 2152,    0, 2152, 2152,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2152, 2152, 2152,    0,
 2152, 2152, 2152,    0,    0,    0,    0,    0, 2152,    0,
    0,    0, 2152,    0, 2152, 2152, 2152, 2152,    0, 2152,
    0, 2152, 2152, 2152, 2152, 2152, 2152, 2152, 2152,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2152, 2152,
    0, 2152, 2152, 2152,    0,    0, 1430,    0, 2152, 2152,
 2152, 2152, 2152,    0, 2152,    0,    0, 2152, 2152,    0,
    0,    0, 2152, 2152,    0,    0, 2152, 2152, 2152, 2152,
 2152, 2152, 2152, 2152, 2152,    0, 2152,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2152, 2152, 2152, 2152,
 2152, 2152, 2152, 2152, 2152, 2152, 2152, 2152, 2152, 2152,
 2152, 2152, 2152, 2152, 2152, 2152, 2152,    0, 2152, 2152,
 2152, 2152, 2152, 2152,    0, 2152, 2152, 2152, 2152,    0,
 2152,    0, 2152, 2152, 2152, 2152, 2152, 2152, 2152, 2152,
 2152, 2152, 2152, 2152, 2152, 2152, 2152, 2152, 2152, 2152,
    0, 2152, 2152, 2152, 2152,    0, 2152, 2152, 2152, 2152,
 2152,    0, 2152, 2152, 2152, 2152, 2152, 2152, 2152, 2152,
 2152, 2152, 2152, 2152, 2152, 2152, 2152, 2152, 2152, 2152,
 2152, 2152, 2152, 2152, 2152, 2152, 2152, 2152, 2152, 2152,
 2152,    0, 2152, 2152,    0,    0,    0, 2152, 2152, 2152,
 2152, 2152, 2152,    0,    0, 2152, 2152, 2152, 2152, 2152,
 2152, 2152, 2152, 2152, 2167,    0,    0,    0,    0, 2152,
    0, 2152, 2152, 2152, 2152, 2152, 2152,    0, 2152,    0,
    0,    0,    0, 1432, 1431, 1433,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2152, 2152,    0, 2152, 2152,
 2152, 2152, 2152, 2152, 2152, 2152, 2152,    0, 2152, 2152,
 2152, 2152, 2152, 2152, 2152, 2152, 2152, 2152, 2152, 2152,
    0, 2152, 2152, 2152,    0, 2152,    0,    0,    0, 2152,
 2152, 2152, 2152, 2152, 2152, 2152, 2152, 2152, 2152, 2152,
 2152, 2152, 2153, 2152, 2152,    0,    0,    0,    0,    0,
 2152, 2152, 2152, 2152, 2152, 2152, 2152, 2152, 2152, 2152,
 2152, 2152, 2152, 2152, 2152, 2152, 2152, 2152,    0,    0,
 2152,    0, 2152, 2152, 2152, 2152, 2152, 2152, 2152, 2152,
 2152,    0, 1915, 2153, 2153, 2153, 2153, 2153, 2153, 2153,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2153, 2153, 2153, 2153, 2153,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2153,    0, 2153,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1416,    0,    0,    0,    0,
    0,    0,    0,    0, 1417,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1418,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1419,    0,    0,    0,    0,    0,    0, 1420,    0,
    0,    0,    0,    0,    0,    0, 1421,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1422,    0, 1423,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1424,    0, 1425, 1426, 1427,
    0,    0,    0,    0, 1428,    0,    0,    0,    0, 2153,
    0, 2153,    0,    0, 2153,    0, 2153, 2153, 2153,    0,
 2153, 2153,    0, 2153,    0,    0,    0,    0,    0, 2153,
    0, 2153, 2153, 2153, 2153,    0, 2153,    0,    0, 2153,
    0,    0, 2153,    0,    0, 1429,    0,    0,    0, 2153,
    0, 2153, 2153,    0, 2153, 2153, 2153, 2153, 2153,    0,
    0, 2153,    0,    0, 2153,    0, 2153, 2153,    0,    0,
 2153, 2153, 2153,    0, 2153, 2153, 2153, 2153, 2153, 2153,
 2153,    0,    0,    0, 2153, 2153, 2153, 2153, 2153,    0,
    0,    0, 2153,    0,    0,    0,    0,    0,    0,    0,
 2153, 2153, 2153, 2153, 2153, 2153,    0,    0,    0, 2153,
 2153,    0, 2153,    0, 2153,    0, 2153, 2153, 2153,    0,
 2153,    0, 2153, 2153, 2153,    0, 2153, 2153, 2153, 2153,
 2153,    0, 2153, 2153,    0,    0,    0,    0, 2153,    0,
 2153, 2153,    0,    0, 2153, 2153, 2153,    0,    0, 2153,
    0, 2153,    0,    0, 2153, 2153, 2153, 2153,    0, 2153,
    0, 2153,    0, 2153, 2153, 2153, 2153, 2153,    0,    0,
 2153, 2153, 2153,    0, 2153, 2153,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2153, 2153, 2153,    0, 2153,
 2153, 2153,    0,    0,    0,    0,    0, 2153,    0,    0,
    0, 2153,    0, 2153, 2153, 2153, 2153,    0, 2153,    0,
 2153, 2153, 2153, 2153, 2153, 2153, 2153, 2153,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2153, 2153,    0,
 2153, 2153, 2153,    0,    0, 1430,    0, 2153, 2153, 2153,
 2153, 2153,    0, 2153,    0,    0, 2153, 2153,    0,    0,
    0, 2153, 2153,    0,    0, 2153, 2153, 2153, 2153, 2153,
 2153, 2153, 2153, 2153,    0, 2153,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2153, 2153, 2153, 2153, 2153,
 2153, 2153, 2153, 2153, 2153, 2153, 2153, 2153, 2153, 2153,
 2153, 2153, 2153, 2153, 2153, 2153,    0, 2153, 2153, 2153,
 2153, 2153, 2153,    0, 2153, 2153, 2153, 2153,    0, 2153,
    0, 2153, 2153, 2153, 2153, 2153, 2153, 2153, 2153, 2153,
 2153, 2153, 2153, 2153, 2153, 2153, 2153, 2153, 2153,    0,
 2153, 2153, 2153, 2153,    0, 2153, 2153, 2153, 2153, 2153,
    0, 2153, 2153, 2153, 2153, 2153, 2153, 2153, 2153, 2153,
 2153, 2153, 2153, 2153, 2153, 2153, 2153, 2153, 2153, 2153,
 2153, 2153, 2153, 2153, 2153, 2153, 2153, 2153, 2153, 2153,
    0, 2153, 2153,    0,    0,    0, 2153, 2153, 2153, 2153,
 2153, 2153,    0,    0, 2153, 2153, 2153, 2153, 2153, 2153,
 2153, 2153, 2153, 2169,    0,    0,    0,    0, 2153,    0,
 2153, 2153, 2153, 2153, 2153, 2153,    0, 2153,    0,    0,
    0,    0, 1432, 1431, 1433,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2153, 2153,    0, 2153, 2153, 2153,
 2153, 2153, 2153, 2153, 2153, 2153,    0, 2153, 2153, 2153,
 2153, 2153, 2153, 2153, 2153, 2153, 2153, 2153, 2153,    0,
 2153, 2153, 2153,    0, 2153,    0,    0,    0, 2153, 2153,
 2153, 2153, 2153, 2153, 2153, 2153, 2153, 2153, 2153, 2153,
 2153, 2154, 2153, 2153,    0,    0,    0,    0,    0, 2153,
 2153, 2153, 2153, 2153, 2153, 2153, 2153, 2153, 2153, 2153,
 2153, 2153, 2153, 2153, 2153, 2153, 2153,    0,    0, 2153,
    0, 2153, 2153, 2153, 2153, 2153, 2153, 2153, 2153, 2153,
    0, 1917, 2154, 2154, 2154, 2154, 2154, 2154, 2154,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2154,
 2154, 2154, 2154, 2154,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2154,    0, 2154,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1416,    0,    0,    0,    0,    0,
    0,    0,    0, 1417,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1418,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1419,    0,    0,    0,    0,    0,    0, 1420,    0,    0,
    0,    0,    0,    0,    0, 1421,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1422,    0, 1423,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1424,    0, 1425, 1426, 1427,    0,
    0,    0,    0, 1428,    0,    0,    0,    0, 2154,    0,
 2154,    0,    0, 2154,    0, 2154, 2154, 2154,    0, 2154,
 2154,    0, 2154,    0,    0,    0,    0,    0, 2154,    0,
 2154, 2154, 2154, 2154,    0, 2154,    0,    0, 2154,    0,
    0, 2154,    0,    0, 1429,    0,    0,    0, 2154,    0,
 2154, 2154,    0, 2154, 2154, 2154, 2154, 2154,    0,    0,
 2154,    0,    0, 2154,    0, 2154, 2154,    0,    0, 2154,
 2154, 2154,    0, 2154, 2154, 2154, 2154, 2154, 2154, 2154,
    0,    0,    0, 2154, 2154, 2154, 2154, 2154,    0,    0,
    0, 2154,    0,    0,    0,    0,    0,    0,    0, 2154,
 2154, 2154, 2154, 2154, 2154,    0,    0,    0, 2154, 2154,
    0, 2154,    0, 2154,    0, 2154, 2154, 2154,    0, 2154,
    0, 2154, 2154, 2154,    0, 2154, 2154, 2154, 2154, 2154,
    0, 2154, 2154,    0,    0,    0,    0, 2154,    0, 2154,
 2154,    0,    0, 2154, 2154, 2154,    0,    0, 2154,    0,
 2154,    0,    0, 2154, 2154, 2154, 2154,    0, 2154,    0,
 2154,    0, 2154, 2154, 2154, 2154, 2154,    0,    0, 2154,
 2154, 2154,    0, 2154, 2154,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2154, 2154, 2154,    0, 2154, 2154,
 2154,    0,    0,    0,    0,    0, 2154,    0,    0,    0,
 2154,    0, 2154, 2154, 2154, 2154,    0, 2154,    0, 2154,
 2154, 2154, 2154, 2154, 2154, 2154, 2154,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2154, 2154,    0, 2154,
 2154, 2154,    0,    0, 1430,    0, 2154, 2154, 2154, 2154,
 2154,    0, 2154,    0,    0, 2154, 2154,    0,    0,    0,
 2154, 2154,    0,    0, 2154, 2154, 2154, 2154, 2154, 2154,
 2154, 2154, 2154,    0, 2154,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2154, 2154, 2154, 2154, 2154, 2154,
 2154, 2154, 2154, 2154, 2154, 2154, 2154, 2154, 2154, 2154,
 2154, 2154, 2154, 2154, 2154,    0, 2154, 2154, 2154, 2154,
 2154, 2154,    0, 2154, 2154, 2154, 2154,    0, 2154,    0,
 2154, 2154, 2154, 2154, 2154, 2154, 2154, 2154, 2154, 2154,
 2154, 2154, 2154, 2154, 2154, 2154, 2154, 2154,    0, 2154,
 2154, 2154, 2154,    0, 2154, 2154, 2154, 2154, 2154,    0,
 2154, 2154, 2154, 2154, 2154, 2154, 2154, 2154, 2154, 2154,
 2154, 2154, 2154, 2154, 2154, 2154, 2154, 2154, 2154, 2154,
 2154, 2154, 2154, 2154, 2154, 2154, 2154, 2154, 2154,    0,
 2154, 2154,    0,    0,    0, 2154, 2154, 2154, 2154, 2154,
 2154,    0,    0, 2154, 2154, 2154, 2154, 2154, 2154, 2154,
 2154, 2154, 2174,    0,    0,    0,    0, 2154,    0, 2154,
 2154, 2154, 2154, 2154, 2154,    0, 2154,    0,    0,    0,
    0, 1432, 1431, 1433,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2154, 2154,    0, 2154, 2154, 2154, 2154,
 2154, 2154, 2154, 2154, 2154,    0, 2154, 2154, 2154, 2154,
 2154, 2154, 2154, 2154, 2154, 2154, 2154, 2154,    0, 2154,
 2154, 2154,    0, 2154,    0,    0,    0, 2154, 2154, 2154,
 2154, 2154, 2154, 2154, 2154, 2154, 2154, 2154, 2154, 2154,
 2155, 2154, 2154,    0,    0,    0,    0,    0, 2154, 2154,
 2154, 2154, 2154, 2154, 2154, 2154, 2154, 2154, 2154, 2154,
 2154, 2154, 2154, 2154, 2154, 2154,    0,    0, 2154,    0,
 2154, 2154, 2154, 2154, 2154, 2154, 2154, 2154, 2154,    0,
 1918, 2155, 2155, 2155, 2155, 2155, 2155, 2155,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2155, 2155,
 2155, 2155, 2155,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2155,    0, 2155,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1416,    0,    0,    0,    0,    0,    0,
    0,    0, 1417,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1418,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1419,
    0,    0,    0,    0,    0,    0, 1420,    0,    0,    0,
    0,    0,    0,    0, 1421,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1422,    0, 1423,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1424,    0, 1425, 1426, 1427,    0,    0,
    0,    0, 1428,    0,    0,    0,    0, 2155,    0, 2155,
    0,    0, 2155,    0, 2155, 2155, 2155,    0, 2155, 2155,
    0, 2155,    0,    0,    0,    0,    0, 2155,    0, 2155,
 2155, 2155, 2155,    0, 2155,    0,    0, 2155,    0,    0,
 2155,    0,    0, 1429,    0,    0,    0, 2155,    0, 2155,
 2155,    0, 2155, 2155, 2155, 2155, 2155,    0,    0, 2155,
    0,    0, 2155,    0, 2155, 2155,    0,    0, 2155, 2155,
 2155,    0, 2155, 2155, 2155, 2155, 2155, 2155, 2155,    0,
    0,    0, 2155, 2155, 2155, 2155, 2155,    0,    0,    0,
 2155,    0,    0,    0,    0,    0,    0,    0, 2155, 2155,
 2155, 2155, 2155, 2155,    0,    0,    0, 2155, 2155,    0,
 2155,    0, 2155,    0, 2155, 2155, 2155,    0, 2155,    0,
 2155, 2155, 2155,    0, 2155, 2155, 2155, 2155, 2155,    0,
 2155, 2155,    0,    0,    0,    0, 2155,    0, 2155, 2155,
    0,    0, 2155, 2155, 2155,    0,    0, 2155,    0, 2155,
    0,    0, 2155, 2155, 2155, 2155,    0, 2155,    0, 2155,
    0, 2155, 2155, 2155, 2155, 2155,    0,    0, 2155, 2155,
 2155,    0, 2155, 2155,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2155, 2155, 2155,    0, 2155, 2155, 2155,
    0,    0,    0,    0,    0, 2155,    0,    0,    0, 2155,
    0, 2155, 2155, 2155, 2155,    0, 2155,    0, 2155, 2155,
 2155, 2155, 2155, 2155, 2155, 2155,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2155, 2155,    0, 2155, 2155,
 2155,    0,    0, 1430,    0, 2155, 2155, 2155, 2155, 2155,
    0, 2155,    0,    0, 2155, 2155,    0,    0,    0, 2155,
 2155,    0,    0, 2155, 2155, 2155, 2155, 2155, 2155, 2155,
 2155, 2155,    0, 2155,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2155, 2155, 2155, 2155, 2155, 2155, 2155,
 2155, 2155, 2155, 2155, 2155, 2155, 2155, 2155, 2155, 2155,
 2155, 2155, 2155, 2155,    0, 2155, 2155, 2155, 2155, 2155,
 2155,    0, 2155, 2155, 2155, 2155,    0, 2155,    0, 2155,
 2155, 2155, 2155, 2155, 2155, 2155, 2155, 2155, 2155, 2155,
 2155, 2155, 2155, 2155, 2155, 2155, 2155,    0, 2155, 2155,
 2155, 2155,    0, 2155, 2155, 2155, 2155, 2155,    0, 2155,
 2155, 2155, 2155, 2155, 2155, 2155, 2155, 2155, 2155, 2155,
 2155, 2155, 2155, 2155, 2155, 2155, 2155, 2155, 2155, 2155,
 2155, 2155, 2155, 2155, 2155, 2155, 2155, 2155,    0, 2155,
 2155,    0,    0,    0, 2155, 2155, 2155, 2155, 2155, 2155,
    0,    0, 2155, 2155, 2155, 2155, 2155, 2155, 2155, 2155,
 2155, 2175,    0,    0,    0,    0, 2155,    0, 2155, 2155,
 2155, 2155, 2155, 2155,    0, 2155,    0,    0,    0,    0,
 1432, 1431, 1433,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2155, 2155,    0, 2155, 2155, 2155, 2155, 2155,
 2155, 2155, 2155, 2155,    0, 2155, 2155, 2155, 2155, 2155,
 2155, 2155, 2155, 2155, 2155, 2155, 2155,    0, 2155, 2155,
 2155,    0, 2155,    0,    0,    0, 2155, 2155, 2155, 2155,
 2155, 2155, 2155, 2155, 2155, 2155, 2155, 2155, 2155, 2156,
 2155, 2155,    0,    0,    0,    0,    0, 2155, 2155, 2155,
 2155, 2155, 2155, 2155, 2155, 2155, 2155, 2155, 2155, 2155,
 2155, 2155, 2155, 2155, 2155,    0,    0, 2155,    0, 2155,
 2155, 2155, 2155, 2155, 2155, 2155, 2155, 2155,    0, 1919,
 2156, 2156, 2156, 2156, 2156, 2156, 2156,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2156, 2156, 2156,
 2156, 2156,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2156,    0, 2156,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1416,    0,    0,    0,    0,    0,    0,    0,
    0, 1417,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1418,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1419,    0,
    0,    0,    0,    0,    0, 1420,    0,    0,    0,    0,
    0,    0,    0, 1421,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1422,    0, 1423,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1424,    0, 1425, 1426, 1427,    0,    0,    0,
    0, 1428,    0,    0,    0,    0, 2156,    0, 2156,    0,
    0, 2156,    0, 2156, 2156, 2156,    0, 2156, 2156,    0,
 2156,    0,    0,    0,    0,    0, 2156,    0, 2156, 2156,
 2156, 2156,    0, 2156,    0,    0, 2156,    0,    0, 2156,
    0,    0, 1429,    0,    0,    0, 2156,    0, 2156, 2156,
    0, 2156, 2156, 2156, 2156, 2156,    0,    0, 2156,    0,
    0, 2156,    0, 2156, 2156,    0,    0, 2156, 2156, 2156,
    0, 2156, 2156, 2156, 2156, 2156, 2156, 2156,    0,    0,
    0, 2156, 2156, 2156, 2156, 2156,    0,    0,    0, 2156,
    0,    0,    0,    0,    0,    0,    0, 2156, 2156, 2156,
 2156, 2156, 2156,    0,    0,    0, 2156, 2156,    0, 2156,
    0, 2156,    0, 2156, 2156, 2156,    0, 2156,    0, 2156,
 2156, 2156,    0, 2156, 2156, 2156, 2156, 2156,    0, 2156,
 2156,    0,    0,    0,    0, 2156,    0, 2156, 2156,    0,
    0, 2156, 2156, 2156,    0,    0, 2156,    0, 2156,    0,
    0, 2156, 2156, 2156, 2156,    0, 2156,    0, 2156,    0,
 2156, 2156, 2156, 2156, 2156,    0,    0, 2156, 2156, 2156,
    0, 2156, 2156,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2156, 2156, 2156,    0, 2156, 2156, 2156,    0,
    0,    0,    0,    0, 2156,    0,    0,    0, 2156,    0,
 2156, 2156, 2156, 2156,    0, 2156,    0, 2156, 2156, 2156,
 2156, 2156, 2156, 2156, 2156,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2156, 2156,    0, 2156, 2156, 2156,
    0,    0, 1430,    0, 2156, 2156, 2156, 2156, 2156,    0,
 2156,    0,    0, 2156, 2156,    0,    0,    0, 2156, 2156,
    0,    0, 2156, 2156, 2156, 2156, 2156, 2156, 2156, 2156,
 2156,    0, 2156,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2156, 2156, 2156, 2156, 2156, 2156, 2156, 2156,
 2156, 2156, 2156, 2156, 2156, 2156, 2156, 2156, 2156, 2156,
 2156, 2156, 2156,    0, 2156, 2156, 2156, 2156, 2156, 2156,
    0, 2156, 2156, 2156, 2156,    0, 2156,    0, 2156, 2156,
 2156, 2156, 2156, 2156, 2156, 2156, 2156, 2156, 2156, 2156,
 2156, 2156, 2156, 2156, 2156, 2156,    0, 2156, 2156, 2156,
 2156,    0, 2156, 2156, 2156, 2156, 2156,    0, 2156, 2156,
 2156, 2156, 2156, 2156, 2156, 2156, 2156, 2156, 2156, 2156,
 2156, 2156, 2156, 2156, 2156, 2156, 2156, 2156, 2156, 2156,
 2156, 2156, 2156, 2156, 2156, 2156, 2156,    0, 2156, 2156,
    0,    0,    0, 2156, 2156, 2156, 2156, 2156, 2156,    0,
    0, 2156, 2156, 2156, 2156, 2156, 2156, 2156, 2156, 2156,
 2176,    0,    0,    0,    0, 2156,    0, 2156, 2156, 2156,
 2156, 2156, 2156,    0, 2156,    0,    0,    0,    0, 1432,
 1431, 1433,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2156, 2156,    0, 2156, 2156, 2156, 2156, 2156, 2156,
 2156, 2156, 2156,    0, 2156, 2156, 2156, 2156, 2156, 2156,
 2156, 2156, 2156, 2156, 2156, 2156,    0, 2156, 2156, 2156,
    0, 2156,    0,    0,    0, 2156, 2156, 2156, 2156, 2156,
 2156, 2156, 2156, 2156, 2156, 2156, 2156, 2156, 2160, 2156,
 2156,    0,    0,    0,    0,    0, 2156, 2156, 2156, 2156,
 2156, 2156, 2156, 2156, 2156, 2156, 2156, 2156, 2156, 2156,
 2156, 2156, 2156, 2156,    0,    0, 2156,    0, 2156, 2156,
 2156, 2156, 2156, 2156, 2156, 2156, 2156,    0, 1920, 2160,
 2160, 2160, 2160, 2160, 2160, 2160,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2160, 2160, 2160, 2160,
 2160,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2160,
    0, 2160,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1416,    0,    0,    0,    0,    0,    0,    0,    0,
 1417,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1418,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1419,    0,    0,
    0,    0,    0,    0, 1420,    0,    0,    0,    0,    0,
    0,    0, 1421,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1422,
    0, 1423,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1424,    0, 1425, 1426, 1427,    0,    0,    0,    0,
 1428,    0,    0,    0,    0, 2160,    0, 2160,    0,    0,
 2160,    0, 2160, 2160, 2160,    0, 2160, 2160,    0, 2160,
    0,    0,    0,    0,    0, 2160,    0, 2160, 2160, 2160,
 2160,    0, 2160,    0,    0, 2160,    0,    0, 2160,    0,
    0, 1429,    0,    0,    0, 2160,    0, 2160, 2160,    0,
 2160, 2160, 2160, 2160, 2160,    0,    0, 2160,    0,    0,
 2160,    0, 2160, 2160,    0,    0, 2160, 2160, 2160,    0,
 2160, 2160, 2160, 2160, 2160, 2160, 2160,    0,    0,    0,
 2160, 2160, 2160, 2160, 2160,    0,    0,    0, 2160,    0,
    0,    0,    0,    0,    0,    0, 2160, 2160, 2160, 2160,
 2160, 2160,    0,    0,    0, 2160, 2160,    0, 2160,    0,
 2160,    0, 2160, 2160, 2160,    0, 2160,    0, 2160, 2160,
 2160,    0, 2160, 2160, 2160, 2160, 2160,    0, 2160, 2160,
    0,    0,    0,    0, 2160,    0, 2160, 2160,    0,    0,
 2160, 2160, 2160,    0,    0, 2160,    0, 2160,    0,    0,
 2160, 2160, 2160, 2160,    0, 2160,    0, 2160,    0, 2160,
 2160, 2160, 2160, 2160,    0,    0, 2160, 2160, 2160,    0,
 2160, 2160,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2160, 2160, 2160,    0, 2160, 2160, 2160,    0,    0,
    0,    0,    0, 2160,    0,    0,    0, 2160,    0, 2160,
 2160, 2160, 2160,    0, 2160,    0, 2160, 2160, 2160, 2160,
 2160, 2160, 2160, 2160,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2160, 2160,    0, 2160, 2160, 2160,    0,
    0, 1430,    0, 2160, 2160, 2160, 2160, 2160,    0, 2160,
    0,    0, 2160, 2160,    0,    0,    0, 2160, 2160,    0,
    0, 2160, 2160, 2160, 2160, 2160, 2160, 2160, 2160, 2160,
    0, 2160,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2160, 2160, 2160, 2160, 2160, 2160, 2160, 2160, 2160,
 2160, 2160, 2160, 2160, 2160, 2160, 2160, 2160, 2160, 2160,
 2160, 2160,    0, 2160, 2160, 2160, 2160, 2160, 2160,    0,
 2160, 2160, 2160, 2160,    0, 2160,    0, 2160, 2160, 2160,
 2160, 2160, 2160, 2160, 2160, 2160, 2160, 2160, 2160, 2160,
 2160, 2160, 2160, 2160, 2160,    0, 2160, 2160, 2160, 2160,
    0, 2160, 2160, 2160, 2160, 2160,    0, 2160, 2160, 2160,
 2160, 2160, 2160, 2160, 2160, 2160, 2160, 2160, 2160, 2160,
 2160, 2160, 2160, 2160, 2160, 2160, 2160, 2160, 2160, 2160,
 2160, 2160, 2160, 2160, 2160, 2160,    0, 2160, 2160,    0,
    0,    0, 2160, 2160, 2160, 2160, 2160, 2160,    0,    0,
 2160, 2160, 2160, 2160, 2160, 2160, 2160, 2160, 2160, 2177,
    0,    0,    0,    0, 2160,    0, 2160, 2160, 2160, 2160,
 2160, 2160,    0, 2160,    0,    0,    0,    0, 1432, 1431,
 1433,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2160, 2160,    0, 2160, 2160, 2160, 2160, 2160, 2160, 2160,
 2160, 2160,    0, 2160, 2160, 2160, 2160, 2160, 2160, 2160,
 2160, 2160, 2160, 2160, 2160,    0, 2160, 2160, 2160,    0,
 2160,    0,    0,    0, 2160, 2160, 2160, 2160, 2160, 2160,
 2160, 2160, 2160, 2160, 2160, 2160, 2160, 2161, 2160, 2160,
    0,    0,    0,    0,    0, 2160, 2160, 2160, 2160, 2160,
 2160, 2160, 2160, 2160, 2160, 2160, 2160, 2160, 2160, 2160,
 2160, 2160, 2160,    0,    0, 2160,    0, 2160, 2160, 2160,
 2160, 2160, 2160, 2160, 2160, 2160,    0, 1921, 2161, 2161,
 2161, 2161, 2161, 2161, 2161,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2161, 2161, 2161, 2161, 2161,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2161,    0,
 2161,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1416,    0,    0,    0,    0,    0,    0,    0,    0, 1417,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1418,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1419,    0,    0,    0,
    0,    0,    0, 1420,    0,    0,    0,    0,    0,    0,
    0, 1421,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1422,    0,
 1423,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1424,    0, 1425, 1426, 1427,    0,    0,    0,    0, 1428,
    0,    0,    0,    0, 2161,    0, 2161,    0,    0, 2161,
    0, 2161, 2161, 2161,    0, 2161, 2161,    0, 2161,    0,
    0,    0,    0,    0, 2161,    0, 2161, 2161, 2161, 2161,
    0, 2161,    0,    0, 2161,    0,    0, 2161,    0,    0,
 1429,    0,    0,    0, 2161,    0, 2161, 2161,    0, 2161,
 2161, 2161, 2161, 2161,    0,    0, 2161,    0,    0, 2161,
    0, 2161, 2161,    0,    0, 2161, 2161, 2161,    0, 2161,
 2161, 2161, 2161, 2161, 2161, 2161,    0,    0,    0, 2161,
 2161, 2161, 2161, 2161,    0,    0,    0, 2161,    0,    0,
    0,    0,    0,    0,    0, 2161, 2161, 2161, 2161, 2161,
 2161,    0,    0,    0, 2161, 2161,    0, 2161,    0, 2161,
    0, 2161, 2161, 2161,    0, 2161,    0, 2161, 2161, 2161,
    0, 2161, 2161, 2161, 2161, 2161,    0, 2161, 2161,    0,
    0,    0,    0, 2161,    0, 2161, 2161,    0,    0, 2161,
 2161, 2161,    0,    0, 2161,    0, 2161,    0,    0, 2161,
 2161, 2161, 2161,    0, 2161,    0, 2161,    0, 2161, 2161,
 2161, 2161, 2161,    0,    0, 2161, 2161, 2161,    0, 2161,
 2161,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2161, 2161, 2161,    0, 2161, 2161, 2161,    0,    0,    0,
    0,    0, 2161,    0,    0,    0, 2161,    0, 2161, 2161,
 2161, 2161,    0, 2161,    0, 2161, 2161, 2161, 2161, 2161,
 2161, 2161, 2161,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2161, 2161,    0, 2161, 2161, 2161,    0,    0,
 1430,    0, 2161, 2161, 2161, 2161, 2161,    0, 2161,    0,
    0, 2161, 2161,    0,    0,    0, 2161, 2161,    0,    0,
 2161, 2161, 2161, 2161, 2161, 2161, 2161, 2161, 2161,    0,
 2161,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2161, 2161, 2161, 2161, 2161, 2161, 2161, 2161, 2161, 2161,
 2161, 2161, 2161, 2161, 2161, 2161, 2161, 2161, 2161, 2161,
 2161,    0, 2161, 2161, 2161, 2161, 2161, 2161,    0, 2161,
 2161, 2161, 2161,    0, 2161,    0, 2161, 2161, 2161, 2161,
 2161, 2161, 2161, 2161, 2161, 2161, 2161, 2161, 2161, 2161,
 2161, 2161, 2161, 2161,    0, 2161, 2161, 2161, 2161,    0,
 2161, 2161, 2161, 2161, 2161,    0, 2161, 2161, 2161, 2161,
 2161, 2161, 2161, 2161, 2161, 2161, 2161, 2161, 2161, 2161,
 2161, 2161, 2161, 2161, 2161, 2161, 2161, 2161, 2161, 2161,
 2161, 2161, 2161, 2161, 2161,    0, 2161, 2161,    0,    0,
    0, 2161, 2161, 2161, 2161, 2161, 2161,    0,    0, 2161,
 2161, 2161, 2161, 2161, 2161, 2161, 2161, 2161, 2558,    0,
    0,    0,    0, 2161,    0, 2161, 2161, 2161, 2161, 2161,
 2161,    0, 2161,    0,    0,    0,    0, 1432, 1431, 1433,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2161,
 2161,    0, 2161, 2161, 2161, 2161, 2161, 2161, 2161, 2161,
 2161,    0, 2161, 2161, 2161, 2161, 2161, 2161, 2161, 2161,
 2161, 2161, 2161, 2161,    0, 2161, 2161, 2161,    0, 2161,
    0,    0,    0, 2161, 2161, 2161, 2161, 2161, 2161, 2161,
 2161, 2161, 2161, 2161, 2161, 2161, 2162, 2161, 2161,    0,
    0,    0,    0,    0, 2161, 2161, 2161, 2161, 2161, 2161,
 2161, 2161, 2161, 2161, 2161, 2161, 2161, 2161, 2161, 2161,
 2161, 2161,    0,    0, 2161,    0, 2161, 2161, 2161, 2161,
 2161, 2161, 2161, 2161, 2161,    0, 1922, 2162, 2162, 2162,
 2162, 2162, 2162, 2162,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2162, 2162, 2162, 2162, 2162,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2162,    0, 2162,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1416,
    0,    0,    0,    0,    0,    0,    0,    0, 1417,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1418,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1419,    0,    0,    0,    0,
    0,    0, 1420,    0,    0,    0,    0,    0,    0,    0,
 1421,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1422,    0, 1423,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1424,
    0, 1425, 1426, 1427,    0,    0,    0,    0, 1428,    0,
    0,    0,    0, 2162,    0, 2162,    0,    0, 2162,    0,
 2162, 2162, 2162,    0, 2162, 2162,    0, 2162,    0,    0,
    0,    0,    0, 2162,    0, 2162, 2162, 2162, 2162,    0,
 2162,    0,    0, 2162,    0,    0, 2162,    0,    0, 1429,
    0,    0,    0, 2162,    0, 2162, 2162,    0, 2162, 2162,
 2162, 2162, 2162,    0,    0, 2162,    0,    0, 2162,    0,
 2162, 2162,    0,    0, 2162, 2162, 2162,    0, 2162, 2162,
 2162, 2162, 2162, 2162, 2162,    0,    0,    0, 2162, 2162,
 2162, 2162, 2162,    0,    0,    0, 2162,    0,    0,    0,
    0,    0,    0,    0, 2162, 2162, 2162, 2162, 2162, 2162,
    0,    0,    0, 2162, 2162,    0, 2162,    0, 2162,    0,
 2162, 2162, 2162,    0, 2162,    0, 2162, 2162, 2162,    0,
 2162, 2162, 2162, 2162, 2162,    0, 2162, 2162,    0,    0,
    0,    0, 2162,    0, 2162, 2162,    0,    0, 2162, 2162,
 2162,    0,    0, 2162,    0, 2162,    0,    0, 2162, 2162,
 2162, 2162,    0, 2162,    0, 2162,    0, 2162, 2162, 2162,
 2162, 2162,    0,    0, 2162, 2162, 2162,    0, 2162, 2162,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2162,
 2162, 2162,    0, 2162, 2162, 2162,    0,    0,    0,    0,
    0, 2162,    0,    0,    0, 2162,    0, 2162, 2162, 2162,
 2162,    0, 2162,    0, 2162, 2162, 2162, 2162, 2162, 2162,
 2162, 2162,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2162, 2162,    0, 2162, 2162, 2162,    0,    0, 1430,
    0, 2162, 2162, 2162, 2162, 2162,    0, 2162,    0,    0,
 2162, 2162,    0,    0,    0, 2162, 2162,    0,    0, 2162,
 2162, 2162, 2162, 2162, 2162, 2162, 2162, 2162,    0, 2162,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2162,
 2162, 2162, 2162, 2162, 2162, 2162, 2162, 2162, 2162, 2162,
 2162, 2162, 2162, 2162, 2162, 2162, 2162, 2162, 2162, 2162,
    0, 2162, 2162, 2162, 2162, 2162, 2162,    0, 2162, 2162,
 2162, 2162,    0, 2162,    0, 2162, 2162, 2162, 2162, 2162,
 2162, 2162, 2162, 2162, 2162, 2162, 2162, 2162, 2162, 2162,
 2162, 2162, 2162,    0, 2162, 2162, 2162, 2162,    0, 2162,
 2162, 2162, 2162, 2162,    0, 2162, 2162, 2162, 2162, 2162,
 2162, 2162, 2162, 2162, 2162, 2162, 2162, 2162, 2162, 2162,
 2162, 2162, 2162, 2162, 2162, 2162, 2162, 2162, 2162, 2162,
 2162, 2162, 2162, 2162,    0, 2162, 2162,    0,    0,    0,
 2162, 2162, 2162, 2162, 2162, 2162,    0,    0, 2162, 2162,
 2162, 2162, 2162, 2162, 2162, 2162, 2162, 2559,    0,    0,
    0,    0, 2162,    0, 2162, 2162, 2162, 2162, 2162, 2162,
    0, 2162,    0,    0,    0,    0, 1432, 1431, 1433,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2162, 2162,
    0, 2162, 2162, 2162, 2162, 2162, 2162, 2162, 2162, 2162,
    0, 2162, 2162, 2162, 2162, 2162, 2162, 2162, 2162, 2162,
 2162, 2162, 2162,    0, 2162, 2162, 2162,    0, 2162,    0,
    0,    0, 2162, 2162, 2162, 2162, 2162, 2162, 2162, 2162,
 2162, 2162, 2162, 2162, 2162, 2166, 2162, 2162,    0,    0,
    0,    0,    0, 2162, 2162, 2162, 2162, 2162, 2162, 2162,
 2162, 2162, 2162, 2162, 2162, 2162, 2162, 2162, 2162, 2162,
 2162,    0,    0, 2162,    0, 2162, 2162, 2162, 2162, 2162,
 2162, 2162, 2162, 2162,    0, 1926, 2166, 2166, 2166, 2166,
 2166, 2166, 2166,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2166, 2166, 2166, 2166, 2166,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2166,    0, 2166,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1416,    0,
    0,    0,    0,    0,    0,    0,    0, 1417,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1418,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1419,    0,    0,    0,    0,    0,
    0, 1420,    0,    0,    0,    0,    0,    0,    0, 1421,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1422,    0, 1423,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1424,    0,
 1425, 1426, 1427,    0,    0,    0,    0, 1428,    0,    0,
    0,    0, 2166,    0, 2166,    0,    0, 2166,    0, 2166,
 2166, 2166,    0, 2166, 2166,    0, 2166,    0,    0,    0,
    0,    0, 2166,    0, 2166, 2166, 2166, 2166,    0, 2166,
    0,    0, 2166,    0,    0, 2166,    0,    0, 1429,    0,
    0,    0, 2166,    0, 2166, 2166,    0, 2166, 2166, 2166,
 2166, 2166,    0,    0, 2166,    0,    0, 2166,    0, 2166,
 2166,    0,    0, 2166, 2166, 2166,    0, 2166, 2166, 2166,
 2166, 2166, 2166, 2166,    0,    0,    0, 2166, 2166, 2166,
 2166, 2166,    0,    0,    0, 2166,    0,    0,    0,    0,
    0,    0,    0, 2166, 2166, 2166, 2166, 2166, 2166,    0,
    0,    0, 2166, 2166,    0, 2166,    0, 2166,    0, 2166,
 2166, 2166,    0, 2166,    0, 2166, 2166, 2166,    0, 2166,
 2166, 2166, 2166, 2166,    0, 2166, 2166,    0,    0,    0,
    0, 2166,    0, 2166, 2166,    0,    0, 2166, 2166, 2166,
    0,    0, 2166,    0, 2166,    0,    0, 2166, 2166, 2166,
 2166,    0, 2166,    0, 2166,    0, 2166, 2166, 2166, 2166,
 2166,    0,    0, 2166, 2166, 2166,    0, 2166, 2166,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2166, 2166,
 2166,    0, 2166, 2166, 2166,    0,    0,    0,    0,    0,
 2166,    0,    0,    0, 2166,    0, 2166, 2166, 2166, 2166,
    0, 2166,    0, 2166, 2166, 2166, 2166, 2166, 2166, 2166,
 2166,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2166, 2166,    0, 2166, 2166, 2166,    0,    0, 1430,    0,
 2166, 2166, 2166, 2166, 2166,    0, 2166,    0,    0, 2166,
 2166,    0,    0,    0, 2166, 2166,    0,    0, 2166, 2166,
 2166, 2166, 2166, 2166, 2166, 2166, 2166,    0, 2166,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2166, 2166,
 2166, 2166, 2166, 2166, 2166, 2166, 2166, 2166, 2166, 2166,
 2166, 2166, 2166, 2166, 2166, 2166, 2166, 2166, 2166,    0,
 2166, 2166, 2166, 2166, 2166, 2166,    0, 2166, 2166, 2166,
 2166,    0, 2166,    0, 2166, 2166, 2166, 2166, 2166, 2166,
 2166, 2166, 2166, 2166, 2166, 2166, 2166, 2166, 2166, 2166,
 2166, 2166,    0, 2166, 2166, 2166, 2166,    0, 2166, 2166,
 2166, 2166, 2166,    0, 2166, 2166, 2166, 2166, 2166, 2166,
 2166, 2166, 2166, 2166, 2166, 2166, 2166, 2166, 2166, 2166,
 2166, 2166, 2166, 2166, 2166, 2166, 2166, 2166, 2166, 2166,
 2166, 2166, 2166,    0, 2166, 2166,    0,    0,    0, 2166,
 2166, 2166, 2166, 2166, 2166,    0,    0, 2166, 2166, 2166,
 2166, 2166, 2166, 2166, 2166, 2166, 2564,    0,    0,    0,
    0, 2166,    0, 2166, 2166, 2166, 2166, 2166, 2166,    0,
 2166,    0,    0,    0,    0, 1432, 1431, 1433,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2166, 2166,    0,
 2166, 2166, 2166, 2166, 2166, 2166, 2166, 2166, 2166,    0,
 2166, 2166, 2166, 2166, 2166, 2166, 2166, 2166, 2166, 2166,
 2166, 2166,    0, 2166, 2166, 2166,    0, 2166,    0,    0,
    0, 2166, 2166, 2166, 2166, 2166, 2166, 2166, 2166, 2166,
 2166, 2166, 2166, 2166, 2167, 2166, 2166,    0,    0,    0,
    0,    0, 2166, 2166, 2166, 2166, 2166, 2166, 2166, 2166,
 2166, 2166, 2166, 2166, 2166, 2166, 2166, 2166, 2166, 2166,
    0,    0, 2166,    0, 2166, 2166, 2166, 2166, 2166, 2166,
 2166, 2166, 2166,    0, 1927, 2167, 2167, 2167, 2167, 2167,
 2167, 2167,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2167, 2167, 2167, 2167, 2167,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2167,    0, 2167,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1416,    0,    0,
    0,    0,    0,    0,    0,    0, 1417,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1418,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1419,    0,    0,    0,    0,    0,    0,
 1420,    0,    0,    0,    0,    0,    0,    0, 1421,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1422,    0, 1423,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1424,    0, 1425,
 1426, 1427,    0,    0,    0,    0, 1428,    0,    0,    0,
    0, 2167,    0, 2167,    0,    0, 2167,    0, 2167, 2167,
 2167,    0, 2167, 2167,    0, 2167,    0,    0,    0,    0,
    0, 2167,    0, 2167, 2167, 2167, 2167,    0, 2167,    0,
    0, 2167,    0,    0, 2167,    0,    0, 1429,    0,    0,
    0, 2167,    0, 2167, 2167,    0, 2167, 2167, 2167, 2167,
 2167,    0,    0, 2167,    0,    0, 2167,    0, 2167, 2167,
    0,    0, 2167, 2167, 2167,    0, 2167, 2167, 2167, 2167,
 2167, 2167, 2167,    0,    0,    0, 2167, 2167, 2167, 2167,
 2167,    0,    0,    0, 2167,    0,    0,    0,    0,    0,
    0,    0, 2167, 2167, 2167, 2167, 2167, 2167,    0,    0,
    0, 2167, 2167,    0, 2167,    0, 2167,    0, 2167, 2167,
 2167,    0, 2167,    0, 2167, 2167, 2167,    0, 2167, 2167,
 2167, 2167, 2167,    0, 2167, 2167,    0,    0,    0,    0,
 2167,    0, 2167, 2167,    0,    0, 2167, 2167, 2167,    0,
    0, 2167,    0, 2167,    0,    0, 2167, 2167, 2167, 2167,
    0, 2167,    0, 2167,    0, 2167, 2167, 2167, 2167, 2167,
    0,    0, 2167, 2167, 2167,    0, 2167, 2167,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2167, 2167, 2167,
    0, 2167, 2167, 2167,    0,    0,    0,    0,    0, 2167,
    0,    0,    0, 2167,    0, 2167, 2167, 2167, 2167,    0,
 2167,    0, 2167, 2167, 2167, 2167, 2167, 2167, 2167, 2167,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2167,
 2167,    0, 2167, 2167, 2167,    0,    0, 1430,    0, 2167,
 2167, 2167, 2167, 2167,    0, 2167,    0,    0, 2167, 2167,
    0,    0,    0, 2167, 2167,    0,    0, 2167, 2167, 2167,
 2167, 2167, 2167, 2167, 2167, 2167,    0, 2167,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2167, 2167, 2167,
 2167, 2167, 2167, 2167, 2167, 2167, 2167, 2167, 2167, 2167,
 2167, 2167, 2167, 2167, 2167, 2167, 2167, 2167,    0, 2167,
 2167, 2167, 2167, 2167, 2167,    0, 2167, 2167, 2167, 2167,
    0, 2167,    0, 2167, 2167, 2167, 2167, 2167, 2167, 2167,
 2167, 2167, 2167, 2167, 2167, 2167, 2167, 2167, 2167, 2167,
 2167,    0, 2167, 2167, 2167, 2167,    0, 2167, 2167, 2167,
 2167, 2167,    0, 2167, 2167, 2167, 2167, 2167, 2167, 2167,
 2167, 2167, 2167, 2167, 2167, 2167, 2167, 2167, 2167, 2167,
 2167, 2167, 2167, 2167, 2167, 2167, 2167, 2167, 2167, 2167,
 2167, 2167,    0, 2167, 2167,    0,    0,    0, 2167, 2167,
 2167, 2167, 2167, 2167,    0,    0, 2167, 2167, 2167, 2167,
 2167, 2167, 2167, 2167, 2167, 2565,    0,    0,    0,    0,
 2167,    0, 2167, 2167, 2167, 2167, 2167, 2167,    0, 2167,
    0,    0,    0,    0, 1432, 1431, 1433,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2167, 2167,    0, 2167,
 2167, 2167, 2167, 2167, 2167, 2167, 2167, 2167,    0, 2167,
 2167, 2167, 2167, 2167, 2167, 2167, 2167, 2167, 2167, 2167,
 2167,    0, 2167, 2167, 2167,    0, 2167,    0,    0,    0,
 2167, 2167, 2167, 2167, 2167, 2167, 2167, 2167, 2167, 2167,
 2167, 2167, 2167, 2168, 2167, 2167,    0,    0,    0,    0,
    0, 2167, 2167, 2167, 2167, 2167, 2167, 2167, 2167, 2167,
 2167, 2167, 2167, 2167, 2167, 2167, 2167, 2167, 2167,    0,
    0, 2167,    0, 2167, 2167, 2167, 2167, 2167, 2167, 2167,
 2167, 2167,    0, 1928, 2168, 2168, 2168, 2168, 2168, 2168,
 2168,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2168, 2168, 2168, 2168, 2168,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2168,    0, 2168,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1416,    0,    0,    0,
    0,    0,    0,    0,    0, 1417,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1418,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1419,    0,    0,    0,    0,    0,    0, 1420,
    0,    0,    0,    0,    0,    0,    0, 1421,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1422,    0, 1423,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1424,    0, 1425, 1426,
 1427,    0,    0,    0,    0, 1428,    0,    0,    0,    0,
 2168,    0, 2168,    0,    0, 2168,    0, 2168, 2168, 2168,
    0, 2168, 2168,    0, 2168,    0,    0,    0,    0,    0,
 2168,    0, 2168, 2168, 2168, 2168,    0, 2168,    0,    0,
 2168,    0,    0, 2168,    0,    0, 1429,    0,    0,    0,
 2168,    0, 2168, 2168,    0, 2168, 2168, 2168, 2168, 2168,
    0,    0, 2168,    0,    0, 2168,    0, 2168, 2168,    0,
    0, 2168, 2168, 2168,    0, 2168, 2168, 2168, 2168, 2168,
 2168, 2168,    0,    0,    0, 2168, 2168, 2168, 2168, 2168,
    0,    0,    0, 2168,    0,    0,    0,    0,    0,    0,
    0, 2168, 2168, 2168, 2168, 2168, 2168,    0,    0,    0,
 2168, 2168,    0, 2168,    0, 2168,    0, 2168, 2168, 2168,
    0, 2168,    0, 2168, 2168, 2168,    0, 2168, 2168, 2168,
 2168, 2168,    0, 2168, 2168,    0,    0,    0,    0, 2168,
    0, 2168, 2168,    0,    0, 2168, 2168, 2168,    0,    0,
 2168,    0, 2168,    0,    0, 2168, 2168, 2168, 2168,    0,
 2168,    0, 2168,    0, 2168, 2168, 2168, 2168, 2168,    0,
    0, 2168, 2168, 2168,    0, 2168, 2168,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2168, 2168, 2168,    0,
 2168, 2168, 2168,    0,    0,    0,    0,    0, 2168,    0,
    0,    0, 2168,    0, 2168, 2168, 2168, 2168,    0, 2168,
    0, 2168, 2168, 2168, 2168, 2168, 2168, 2168, 2168,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2168, 2168,
    0, 2168, 2168, 2168,    0,    0, 1430,    0, 2168, 2168,
 2168, 2168, 2168,    0, 2168,    0,    0, 2168, 2168,    0,
    0,    0, 2168, 2168,    0,    0, 2168, 2168, 2168, 2168,
 2168, 2168, 2168, 2168, 2168,    0, 2168,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2168, 2168, 2168, 2168,
 2168, 2168, 2168, 2168, 2168, 2168, 2168, 2168, 2168, 2168,
 2168, 2168, 2168, 2168, 2168, 2168, 2168,    0, 2168, 2168,
 2168, 2168, 2168, 2168,    0, 2168, 2168, 2168, 2168,    0,
 2168,    0, 2168, 2168, 2168, 2168, 2168, 2168, 2168, 2168,
 2168, 2168, 2168, 2168, 2168, 2168, 2168, 2168, 2168, 2168,
    0, 2168, 2168, 2168, 2168,    0, 2168, 2168, 2168, 2168,
 2168,    0, 2168, 2168, 2168, 2168, 2168, 2168, 2168, 2168,
 2168, 2168, 2168, 2168, 2168, 2168, 2168, 2168, 2168, 2168,
 2168, 2168, 2168, 2168, 2168, 2168, 2168, 2168, 2168, 2168,
 2168,    0, 2168, 2168,    0,    0,    0, 2168, 2168, 2168,
 2168, 2168, 2168,    0,    0, 2168, 2168, 2168, 2168, 2168,
 2168, 2168, 2168, 2168, 2567,    0,    0,    0,    0, 2168,
    0, 2168, 2168, 2168, 2168, 2168, 2168,    0, 2168,    0,
    0,    0,    0, 1432, 1431, 1433,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2168, 2168,    0, 2168, 2168,
 2168, 2168, 2168, 2168, 2168, 2168, 2168,    0, 2168, 2168,
 2168, 2168, 2168, 2168, 2168, 2168, 2168, 2168, 2168, 2168,
    0, 2168, 2168, 2168,    0, 2168,    0,    0,    0, 2168,
 2168, 2168, 2168, 2168, 2168, 2168, 2168, 2168, 2168, 2168,
 2168, 2168, 2169, 2168, 2168,    0,    0,    0,    0,    0,
 2168, 2168, 2168, 2168, 2168, 2168, 2168, 2168, 2168, 2168,
 2168, 2168, 2168, 2168, 2168, 2168, 2168, 2168,    0,    0,
 2168,    0, 2168, 2168, 2168, 2168, 2168, 2168, 2168, 2168,
 2168,    0, 1929, 2169, 2169, 2169, 2169, 2169, 2169, 2169,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2169, 2169, 2169, 2169, 2169,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2169,    0, 2169,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1416,    0,    0,    0,    0,
    0,    0,    0,    0, 1417,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1418,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1419,    0,    0,    0,    0,    0,    0, 1420,    0,
    0,    0,    0,    0,    0,    0, 1421,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1422,    0, 1423,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1424,    0, 1425, 1426, 1427,
    0,    0,    0,    0, 1428,    0,    0,    0,    0, 2169,
    0, 2169,    0,    0, 2169,    0, 2169, 2169, 2169,    0,
 2169, 2169,    0, 2169,    0,    0,    0,    0,    0, 2169,
    0, 2169, 2169, 2169, 2169,    0, 2169,    0,    0, 2169,
    0,    0, 2169,    0,    0, 1429,    0,    0,    0, 2169,
    0, 2169, 2169,    0, 2169, 2169, 2169, 2169, 2169,    0,
    0, 2169,    0,    0, 2169,    0, 2169, 2169,    0,    0,
 2169, 2169, 2169,    0, 2169, 2169, 2169, 2169, 2169, 2169,
 2169,    0,    0,    0, 2169, 2169, 2169, 2169, 2169,    0,
    0,    0, 2169,    0,    0,    0,    0,    0,    0,    0,
 2169, 2169, 2169, 2169, 2169, 2169,    0,    0,    0, 2169,
 2169,    0, 2169,    0, 2169,    0, 2169, 2169, 2169,    0,
 2169,    0, 2169, 2169, 2169,    0, 2169, 2169, 2169, 2169,
 2169,    0, 2169, 2169,    0,    0,    0,    0, 2169,    0,
 2169, 2169,    0,    0, 2169, 2169, 2169,    0,    0, 2169,
    0, 2169,    0,    0, 2169, 2169, 2169, 2169,    0, 2169,
    0, 2169,    0, 2169, 2169, 2169, 2169, 2169,    0,    0,
 2169, 2169, 2169,    0, 2169, 2169,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2169, 2169, 2169,    0, 2169,
 2169, 2169,    0,    0,    0,    0,    0, 2169,    0,    0,
    0, 2169,    0, 2169, 2169, 2169, 2169,    0, 2169,    0,
 2169, 2169, 2169, 2169, 2169, 2169, 2169, 2169,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2169, 2169,    0,
 2169, 2169, 2169,    0,    0, 1430,    0, 2169, 2169, 2169,
 2169, 2169,    0, 2169,    0,    0, 2169, 2169,    0,    0,
    0, 2169, 2169,    0,    0, 2169, 2169, 2169, 2169, 2169,
 2169, 2169, 2169, 2169,    0, 2169,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2169, 2169, 2169, 2169, 2169,
 2169, 2169, 2169, 2169, 2169, 2169, 2169, 2169, 2169, 2169,
 2169, 2169, 2169, 2169, 2169, 2169,    0, 2169, 2169, 2169,
 2169, 2169, 2169,    0, 2169, 2169, 2169, 2169,    0, 2169,
    0, 2169, 2169, 2169, 2169, 2169, 2169, 2169, 2169, 2169,
 2169, 2169, 2169, 2169, 2169, 2169, 2169, 2169, 2169,    0,
 2169, 2169, 2169, 2169,    0, 2169, 2169, 2169, 2169, 2169,
    0, 2169, 2169, 2169, 2169, 2169, 2169, 2169, 2169, 2169,
 2169, 2169, 2169, 2169, 2169, 2169, 2169, 2169, 2169, 2169,
 2169, 2169, 2169, 2169, 2169, 2169, 2169, 2169, 2169, 2169,
    0, 2169, 2169,    0,    0,    0, 2169, 2169, 2169, 2169,
 2169, 2169,    0,    0, 2169, 2169, 2169, 2169, 2169, 2169,
 2169, 2169, 2169, 2568,    0,    0,    0,    0, 2169,    0,
 2169, 2169, 2169, 2169, 2169, 2169,    0, 2169,    0,    0,
    0,    0, 1432, 1431, 1433,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2169, 2169,    0, 2169, 2169, 2169,
 2169, 2169, 2169, 2169, 2169, 2169,    0, 2169, 2169, 2169,
 2169, 2169, 2169, 2169, 2169, 2169, 2169, 2169, 2169,    0,
 2169, 2169, 2169,    0, 2169,    0,    0,    0, 2169, 2169,
 2169, 2169, 2169, 2169, 2169, 2169, 2169, 2169, 2169, 2169,
 2169, 2172, 2169, 2169,    0,    0,    0,    0,    0, 2169,
 2169, 2169, 2169, 2169, 2169, 2169, 2169, 2169, 2169, 2169,
 2169, 2169, 2169, 2169, 2169, 2169, 2169,    0,    0, 2169,
    0, 2169, 2169, 2169, 2169, 2169, 2169, 2169, 2169, 2169,
    0, 1931, 2172, 2172, 2172, 2172, 2172, 2172, 2172,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2172,
 2172, 2172, 2172, 2172,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2172,    0, 2172,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1416,    0,    0,    0,    0,    0,
    0,    0,    0, 1417,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1418,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1419,    0,    0,    0,    0,    0,    0, 1420,    0,    0,
    0,    0,    0,    0,    0, 1421,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1422,    0, 1423,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1424,    0, 1425, 1426, 1427,    0,
    0,    0,    0, 1428,    0,    0,    0,    0, 2172,    0,
 2172,    0,    0, 2172,    0, 2172, 2172, 2172,    0, 2172,
 2172,    0, 2172,    0,    0,    0,    0,    0, 2172,    0,
 2172, 2172, 2172, 2172,    0, 2172,    0,    0, 2172,    0,
    0, 2172,    0,    0, 1429,    0,    0,    0, 2172,    0,
 2172, 2172,    0, 2172, 2172, 2172, 2172, 2172,    0,    0,
 2172,    0,    0, 2172,    0, 2172, 2172,    0,    0, 2172,
 2172, 2172,    0, 2172, 2172, 2172, 2172, 2172, 2172, 2172,
    0,    0,    0, 2172, 2172, 2172, 2172, 2172,    0,    0,
    0, 2172,    0,    0,    0,    0,    0,    0,    0, 2172,
 2172, 2172, 2172, 2172, 2172,    0,    0,    0, 2172, 2172,
    0, 2172,    0, 2172,    0, 2172, 2172, 2172,    0, 2172,
    0, 2172, 2172, 2172,    0, 2172, 2172, 2172, 2172, 2172,
    0, 2172, 2172,    0,    0,    0,    0, 2172,    0, 2172,
 2172,    0,    0, 2172, 2172, 2172,    0,    0, 2172,    0,
 2172,    0,    0, 2172, 2172, 2172, 2172,    0, 2172,    0,
 2172,    0, 2172, 2172, 2172, 2172, 2172,    0,    0, 2172,
 2172, 2172,    0, 2172, 2172,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2172, 2172, 2172,    0, 2172, 2172,
 2172,    0,    0,    0,    0,    0, 2172,    0,    0,    0,
 2172,    0, 2172, 2172, 2172, 2172,    0, 2172,    0, 2172,
 2172, 2172, 2172, 2172, 2172, 2172, 2172,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2172, 2172,    0, 2172,
 2172, 2172,    0,    0, 1430,    0, 2172, 2172, 2172, 2172,
 2172,    0, 2172,    0,    0, 2172, 2172,    0,    0,    0,
 2172, 2172,    0,    0, 2172, 2172, 2172, 2172, 2172, 2172,
 2172, 2172, 2172,    0, 2172,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2172, 2172, 2172, 2172, 2172, 2172,
 2172, 2172, 2172, 2172, 2172, 2172, 2172, 2172, 2172, 2172,
 2172, 2172, 2172, 2172, 2172,    0, 2172, 2172, 2172, 2172,
 2172, 2172,    0, 2172, 2172, 2172, 2172,    0, 2172,    0,
 2172, 2172, 2172, 2172, 2172, 2172, 2172, 2172, 2172, 2172,
 2172, 2172, 2172, 2172, 2172, 2172, 2172, 2172,    0, 2172,
 2172, 2172, 2172,    0, 2172, 2172, 2172, 2172, 2172,    0,
 2172, 2172, 2172, 2172, 2172, 2172, 2172, 2172, 2172, 2172,
 2172, 2172, 2172, 2172, 2172, 2172, 2172, 2172, 2172, 2172,
 2172, 2172, 2172, 2172, 2172, 2172, 2172, 2172, 2172,    0,
 2172, 2172,    0,    0,    0, 2172, 2172, 2172, 2172, 2172,
 2172,    0,    0, 2172, 2172, 2172, 2172, 2172, 2172, 2172,
 2172, 2172, 2569,    0,    0,    0,    0, 2172,    0, 2172,
 2172, 2172, 2172, 2172, 2172,    0, 2172,    0,    0,    0,
    0, 1432, 1431, 1433,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2172, 2172,    0, 2172, 2172, 2172, 2172,
 2172, 2172, 2172, 2172, 2172,    0, 2172, 2172, 2172, 2172,
 2172, 2172, 2172, 2172, 2172, 2172, 2172, 2172,    0, 2172,
 2172, 2172,    0, 2172,    0,    0,    0, 2172, 2172, 2172,
 2172, 2172, 2172, 2172, 2172, 2172, 2172, 2172, 2172, 2172,
 2174, 2172, 2172,    0,    0,    0,    0,    0, 2172, 2172,
 2172, 2172, 2172, 2172, 2172, 2172, 2172, 2172, 2172, 2172,
 2172, 2172, 2172, 2172, 2172, 2172,    0,    0, 2172,    0,
 2172, 2172, 2172, 2172, 2172, 2172, 2172, 2172, 2172,    0,
 1932, 2174, 2174, 2174, 2174, 2174, 2174, 2174,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2174, 2174,
 2174, 2174, 2174,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2174,    0, 2174,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1416,    0,    0,    0,    0,    0,    0,
    0,    0, 1417,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1418,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1419,
    0,    0,    0,    0,    0,    0, 1420,    0,    0,    0,
    0,    0,    0,    0, 1421,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1422,    0, 1423,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1424,    0, 1425, 1426, 1427,    0,    0,
    0,    0, 1428,    0,    0,    0,    0, 2174,    0, 2174,
    0,    0, 2174,    0, 2174, 2174, 2174,    0, 2174, 2174,
    0, 2174,    0,    0,    0,    0,    0, 2174,    0, 2174,
 2174, 2174, 2174,    0, 2174,    0,    0, 2174,    0,    0,
 2174,    0,    0, 1429,    0,    0,    0, 2174,    0, 2174,
 2174,    0, 2174, 2174, 2174, 2174, 2174,    0,    0, 2174,
    0,    0, 2174,    0, 2174, 2174,    0,    0, 2174, 2174,
 2174,    0, 2174, 2174, 2174, 2174, 2174, 2174, 2174,    0,
    0,    0, 2174, 2174, 2174, 2174, 2174,    0,    0,    0,
 2174,    0,    0,    0,    0,    0,    0,    0, 2174, 2174,
 2174, 2174, 2174, 2174,    0,    0,    0, 2174, 2174,    0,
 2174,    0, 2174,    0, 2174, 2174, 2174,    0, 2174,    0,
 2174, 2174, 2174,    0, 2174, 2174, 2174, 2174, 2174,    0,
 2174, 2174,    0,    0,    0,    0, 2174,    0, 2174, 2174,
    0,    0, 2174, 2174, 2174,    0,    0, 2174,    0, 2174,
    0,    0, 2174, 2174, 2174, 2174,    0, 2174,    0, 2174,
    0, 2174, 2174, 2174, 2174, 2174,    0,    0, 2174, 2174,
 2174,    0, 2174, 2174,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2174, 2174, 2174,    0, 2174, 2174, 2174,
    0,    0,    0,    0,    0, 2174,    0,    0,    0, 2174,
    0, 2174, 2174, 2174, 2174,    0, 2174,    0, 2174, 2174,
 2174, 2174, 2174, 2174, 2174, 2174,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2174, 2174,    0, 2174, 2174,
 2174,    0,    0, 1430,    0, 2174, 2174, 2174, 2174, 2174,
    0, 2174,    0,    0, 2174, 2174,    0,    0,    0, 2174,
 2174,    0,    0, 2174, 2174, 2174, 2174, 2174, 2174, 2174,
 2174, 2174,    0, 2174,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2174, 2174, 2174, 2174, 2174, 2174, 2174,
 2174, 2174, 2174, 2174, 2174, 2174, 2174, 2174, 2174, 2174,
 2174, 2174, 2174, 2174,    0, 2174, 2174, 2174, 2174, 2174,
 2174,    0, 2174, 2174, 2174, 2174,    0, 2174,    0, 2174,
 2174, 2174, 2174, 2174, 2174, 2174, 2174, 2174, 2174, 2174,
 2174, 2174, 2174, 2174, 2174, 2174, 2174,    0, 2174, 2174,
 2174, 2174,    0, 2174, 2174, 2174, 2174, 2174,    0, 2174,
 2174, 2174, 2174, 2174, 2174, 2174, 2174, 2174, 2174, 2174,
 2174, 2174, 2174, 2174, 2174, 2174, 2174, 2174, 2174, 2174,
 2174, 2174, 2174, 2174, 2174, 2174, 2174, 2174,    0, 2174,
 2174,    0,    0,    0, 2174, 2174, 2174, 2174, 2174, 2174,
    0,    0, 2174, 2174, 2174, 2174, 2174, 2174, 2174, 2174,
 2174, 2570,    0,    0,    0,    0, 2174,    0, 2174, 2174,
 2174, 2174, 2174, 2174,    0, 2174,    0,    0,    0,    0,
 1432, 1431, 1433,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2174, 2174,    0, 2174, 2174, 2174, 2174, 2174,
 2174, 2174, 2174, 2174,    0, 2174, 2174, 2174, 2174, 2174,
 2174, 2174, 2174, 2174, 2174, 2174, 2174,    0, 2174, 2174,
 2174,    0, 2174,    0,    0,    0, 2174, 2174, 2174, 2174,
 2174, 2174, 2174, 2174, 2174, 2174, 2174, 2174, 2174, 2175,
 2174, 2174,    0,    0,    0,    0,    0, 2174, 2174, 2174,
 2174, 2174, 2174, 2174, 2174, 2174, 2174, 2174, 2174, 2174,
 2174, 2174, 2174, 2174, 2174,    0,    0, 2174,    0, 2174,
 2174, 2174, 2174, 2174, 2174, 2174, 2174, 2174,    0, 1933,
 2175, 2175, 2175, 2175, 2175, 2175, 2175,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2175, 2175, 2175,
 2175, 2175,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2175,    0, 2175,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1416,    0,    0,    0,    0,    0,    0,    0,
    0, 1417,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1418,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1419,    0,
    0,    0,    0,    0,    0, 1420,    0,    0,    0,    0,
    0,    0,    0, 1421,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1422,    0, 1423,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1424,    0, 1425, 1426, 1427,    0,    0,    0,
    0, 1428,    0,    0,    0,    0, 2175,    0, 2175,    0,
    0, 2175,    0, 2175, 2175, 2175,    0, 2175, 2175,    0,
 2175,    0,    0,    0,    0,    0, 2175,    0, 2175, 2175,
 2175, 2175,    0, 2175,    0,    0, 2175,    0,    0, 2175,
    0,    0, 1429,    0,    0,    0, 2175,    0, 2175, 2175,
    0, 2175, 2175, 2175, 2175, 2175,    0,    0, 2175,    0,
    0, 2175,    0, 2175, 2175,    0,    0, 2175, 2175, 2175,
    0, 2175, 2175, 2175, 2175, 2175, 2175, 2175,    0,    0,
    0, 2175, 2175, 2175, 2175, 2175,    0,    0,    0, 2175,
    0,    0,    0,    0,    0,    0,    0, 2175, 2175, 2175,
 2175, 2175, 2175,    0,    0,    0, 2175, 2175,    0, 2175,
    0, 2175,    0, 2175, 2175, 2175,    0, 2175,    0, 2175,
 2175, 2175,    0, 2175, 2175, 2175, 2175, 2175,    0, 2175,
 2175,    0,    0,    0,    0, 2175,    0, 2175, 2175,    0,
    0, 2175, 2175, 2175,    0,    0, 2175,    0, 2175,    0,
    0, 2175, 2175, 2175, 2175,    0, 2175,    0, 2175,    0,
 2175, 2175, 2175, 2175, 2175,    0,    0, 2175, 2175, 2175,
    0, 2175, 2175,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2175, 2175, 2175,    0, 2175, 2175, 2175,    0,
    0,    0,    0,    0, 2175,    0,    0,    0, 2175,    0,
 2175, 2175, 2175, 2175,    0, 2175,    0, 2175, 2175, 2175,
 2175, 2175, 2175, 2175, 2175,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2175, 2175,    0, 2175, 2175, 2175,
    0,    0, 1430,    0, 2175, 2175, 2175, 2175, 2175,    0,
 2175,    0,    0, 2175, 2175,    0,    0,    0, 2175, 2175,
    0,    0, 2175, 2175, 2175, 2175, 2175, 2175, 2175, 2175,
 2175,    0, 2175,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2175, 2175, 2175, 2175, 2175, 2175, 2175, 2175,
 2175, 2175, 2175, 2175, 2175, 2175, 2175, 2175, 2175, 2175,
 2175, 2175, 2175,    0, 2175, 2175, 2175, 2175, 2175, 2175,
    0, 2175, 2175, 2175, 2175,    0, 2175,    0, 2175, 2175,
 2175, 2175, 2175, 2175, 2175, 2175, 2175, 2175, 2175, 2175,
 2175, 2175, 2175, 2175, 2175, 2175,    0, 2175, 2175, 2175,
 2175,    0, 2175, 2175, 2175, 2175, 2175,    0, 2175, 2175,
 2175, 2175, 2175, 2175, 2175, 2175, 2175, 2175, 2175, 2175,
 2175, 2175, 2175, 2175, 2175, 2175, 2175, 2175, 2175, 2175,
 2175, 2175, 2175, 2175, 2175, 2175, 2175,    0, 2175, 2175,
    0,    0,    0, 2175, 2175, 2175, 2175, 2175, 2175,    0,
    0, 2175, 2175, 2175, 2175, 2175, 2175, 2175, 2175, 2175,
 2573,    0,    0,    0,    0, 2175,    0, 2175, 2175, 2175,
 2175, 2175, 2175,    0, 2175,    0,    0,    0,    0, 1432,
 1431, 1433,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2175, 2175,    0, 2175, 2175, 2175, 2175, 2175, 2175,
 2175, 2175, 2175,    0, 2175, 2175, 2175, 2175, 2175, 2175,
 2175, 2175, 2175, 2175, 2175, 2175,    0, 2175, 2175, 2175,
    0, 2175,    0,    0,    0, 2175, 2175, 2175, 2175, 2175,
 2175, 2175, 2175, 2175, 2175, 2175, 2175, 2175, 2178, 2175,
 2175,    0,    0,    0,    0,    0, 2175, 2175, 2175, 2175,
 2175, 2175, 2175, 2175, 2175, 2175, 2175, 2175, 2175, 2175,
 2175, 2175, 2175, 2175,    0,    0, 2175,    0, 2175, 2175,
 2175, 2175, 2175, 2175, 2175, 2175, 2175,    0, 1934, 2178,
 2178, 2178, 2178, 2178, 2178, 2178,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2178, 2178, 2178, 2178,
 2178,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2178,
    0, 2178,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1416,    0,    0,    0,    0,    0,    0,    0,    0,
 1417,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1418,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1419,    0,    0,
    0,    0,    0,    0, 1420,    0,    0,    0,    0,    0,
    0,    0, 1421,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1422,
    0, 1423,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1424,    0, 1425, 1426, 1427,    0,    0,    0,    0,
 1428,    0,    0,    0,    0, 2178,    0, 2178,    0,    0,
 2178,    0, 2178, 2178, 2178,    0, 2178, 2178,    0, 2178,
    0,    0,    0,    0,    0, 2178,    0, 2178, 2178, 2178,
 2178,    0, 2178,    0,    0, 2178,    0,    0, 2178,    0,
    0, 1429,    0,    0,    0, 2178,    0, 2178, 2178,    0,
 2178, 2178, 2178, 2178, 2178,    0,    0, 2178,    0,    0,
 2178,    0, 2178, 2178,    0,    0, 2178, 2178, 2178,    0,
 2178, 2178, 2178, 2178, 2178, 2178, 2178,    0,    0,    0,
 2178, 2178, 2178, 2178, 2178,    0,    0,    0, 2178,    0,
    0,    0,    0,    0,    0,    0, 2178, 2178, 2178, 2178,
 2178, 2178,    0,    0,    0, 2178, 2178,    0, 2178,    0,
 2178,    0, 2178, 2178, 2178,    0, 2178,    0, 2178, 2178,
 2178,    0, 2178, 2178, 2178, 2178, 2178,    0, 2178, 2178,
    0,    0,    0,    0, 2178,    0, 2178, 2178,    0,    0,
 2178, 2178, 2178,    0,    0, 2178,    0, 2178,    0,    0,
 2178, 2178, 2178, 2178,    0, 2178,    0, 2178,    0, 2178,
 2178, 2178, 2178, 2178,    0,    0, 2178, 2178, 2178,    0,
 2178, 2178,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2178, 2178, 2178,    0, 2178, 2178, 2178,    0,    0,
    0,    0,    0, 2178,    0,    0,    0, 2178,    0, 2178,
 2178, 2178, 2178,    0, 2178,    0, 2178, 2178, 2178, 2178,
 2178, 2178, 2178, 2178,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2178, 2178,    0, 2178, 2178, 2178,    0,
    0, 1430,    0, 2178, 2178, 2178, 2178, 2178,    0, 2178,
    0,    0, 2178, 2178,    0,    0,    0, 2178, 2178,    0,
    0, 2178, 2178, 2178, 2178, 2178, 2178, 2178, 2178, 2178,
    0, 2178,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2178, 2178, 2178, 2178, 2178, 2178, 2178, 2178, 2178,
 2178, 2178, 2178, 2178, 2178, 2178, 2178, 2178, 2178, 2178,
 2178, 2178,    0, 2178, 2178, 2178, 2178, 2178, 2178,    0,
 2178, 2178, 2178, 2178,    0, 2178,    0, 2178, 2178, 2178,
 2178, 2178, 2178, 2178, 2178, 2178, 2178, 2178, 2178, 2178,
 2178, 2178, 2178, 2178, 2178,    0, 2178, 2178, 2178, 2178,
    0, 2178, 2178, 2178, 2178, 2178,    0, 2178, 2178, 2178,
 2178, 2178, 2178, 2178, 2178, 2178, 2178, 2178, 2178, 2178,
 2178, 2178, 2178, 2178, 2178, 2178, 2178, 2178, 2178, 2178,
 2178, 2178, 2178, 2178, 2178, 2178,    0, 2178, 2178,    0,
    0,    0, 2178, 2178, 2178, 2178, 2178, 2178,    0,    0,
 2178, 2178, 2178, 2178, 2178, 2178, 2178, 2178, 2178, 2574,
    0,    0,    0,    0, 2178,    0, 2178, 2178, 2178, 2178,
 2178, 2178,    0, 2178,    0,    0,    0,    0, 1432, 1431,
 1433,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2178, 2178,    0, 2178, 2178, 2178, 2178, 2178, 2178, 2178,
 2178, 2178,    0, 2178, 2178, 2178, 2178, 2178, 2178, 2178,
 2178, 2178, 2178, 2178, 2178,    0, 2178, 2178, 2178,    0,
 2178,    0,    0,    0, 2178, 2178, 2178, 2178, 2178, 2178,
 2178, 2178, 2178, 2178, 2178, 2178, 2178, 2180, 2178, 2178,
    0,    0,    0,    0,    0, 2178, 2178, 2178, 2178, 2178,
 2178, 2178, 2178, 2178, 2178, 2178, 2178, 2178, 2178, 2178,
 2178, 2178, 2178,    0,    0, 2178,    0, 2178, 2178, 2178,
 2178, 2178, 2178, 2178, 2178, 2178,    0, 1935, 2180, 2180,
 2180, 2180, 2180, 2180, 2180,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2180, 2180, 2180, 2180, 2180,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2180,    0,
 2180,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1416,    0,    0,    0,    0,    0,    0,    0,    0, 1417,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1418,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1419,    0,    0,    0,
    0,    0,    0, 1420,    0,    0,    0,    0,    0,    0,
    0, 1421,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1422,    0,
 1423,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1424,    0, 1425, 1426, 1427,    0,    0,    0,    0, 1428,
    0,    0,    0,    0, 2180,    0, 2180,    0,    0, 2180,
    0, 2180, 2180, 2180,    0, 2180, 2180,    0, 2180,    0,
    0,    0,    0,    0, 2180,    0, 2180, 2180, 2180, 2180,
    0, 2180,    0,    0, 2180,    0,    0, 2180,    0,    0,
 1429,    0,    0,    0, 2180,    0, 2180, 2180,    0, 2180,
 2180, 2180, 2180, 2180,    0,    0, 2180,    0,    0, 2180,
    0, 2180, 2180,    0,    0, 2180, 2180, 2180,    0, 2180,
 2180, 2180, 2180, 2180, 2180, 2180,    0,    0,    0, 2180,
 2180, 2180, 2180, 2180,    0,    0,    0, 2180,    0,    0,
    0,    0,    0,    0,    0, 2180, 2180, 2180, 2180, 2180,
 2180,    0,    0,    0, 2180, 2180,    0, 2180,    0, 2180,
    0, 2180, 2180, 2180,    0, 2180,    0, 2180, 2180, 2180,
    0, 2180, 2180, 2180, 2180, 2180,    0, 2180, 2180,    0,
    0,    0,    0, 2180,    0, 2180, 2180,    0,    0, 2180,
 2180, 2180,    0,    0, 2180,    0, 2180,    0,    0, 2180,
 2180, 2180, 2180,    0, 2180,    0, 2180,    0, 2180, 2180,
 2180, 2180, 2180,    0,    0, 2180, 2180, 2180,    0, 2180,
 2180,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2180, 2180, 2180,    0, 2180, 2180, 2180,    0,    0,    0,
    0,    0, 2180,    0,    0,    0, 2180,    0, 2180, 2180,
 2180, 2180,    0, 2180,    0, 2180, 2180, 2180, 2180, 2180,
 2180, 2180, 2180,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2180, 2180,    0, 2180, 2180, 2180,    0,    0,
 1430,    0, 2180, 2180, 2180, 2180, 2180,    0, 2180,    0,
    0, 2180, 2180,    0,    0,    0, 2180, 2180,    0,    0,
 2180, 2180, 2180, 2180, 2180, 2180, 2180, 2180, 2180,    0,
 2180,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2180, 2180, 2180, 2180, 2180, 2180, 2180, 2180, 2180, 2180,
 2180, 2180, 2180, 2180, 2180, 2180, 2180, 2180, 2180, 2180,
 2180,    0, 2180, 2180, 2180, 2180, 2180, 2180,    0, 2180,
 2180, 2180, 2180,    0, 2180,    0, 2180, 2180, 2180, 2180,
 2180, 2180, 2180, 2180, 2180, 2180, 2180, 2180, 2180, 2180,
 2180, 2180, 2180, 2180,    0, 2180, 2180, 2180, 2180,    0,
 2180, 2180, 2180, 2180, 2180,    0, 2180, 2180, 2180, 2180,
 2180, 2180, 2180, 2180, 2180, 2180, 2180, 2180, 2180, 2180,
 2180, 2180, 2180, 2180, 2180, 2180, 2180, 2180, 2180, 2180,
 2180, 2180, 2180, 2180, 2180,    0, 2180, 2180,    0,    0,
    0, 2180, 2180, 2180, 2180, 2180, 2180,    0,    0, 2180,
 2180, 2180, 2180, 2180, 2180, 2180, 2180, 2180, 2916,    0,
    0,    0,    0, 2180,    0, 2180, 2180, 2180, 2180, 2180,
 2180,    0, 2180,    0,    0,    0,    0, 1432, 1431, 1433,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2180,
 2180,    0, 2180, 2180, 2180, 2180, 2180, 2180, 2180, 2180,
 2180,    0, 2180, 2180, 2180, 2180, 2180, 2180, 2180, 2180,
 2180, 2180, 2180, 2180,    0, 2180, 2180, 2180,    0, 2180,
    0,    0,    0, 2180, 2180, 2180, 2180, 2180, 2180, 2180,
 2180, 2180, 2180, 2180, 2180, 2180, 2182, 2180, 2180,    0,
    0,    0,    0,    0, 2180, 2180, 2180, 2180, 2180, 2180,
 2180, 2180, 2180, 2180, 2180, 2180, 2180, 2180, 2180, 2180,
 2180, 2180,    0,    0, 2180,    0, 2180, 2180, 2180, 2180,
 2180, 2180, 2180, 2180, 2180,    0, 1936, 2182, 2182, 2182,
 2182, 2182, 2182, 2182,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2182, 2182, 2182, 2182, 2182,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2182,    0, 2182,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1416,
    0,    0,    0,    0,    0,    0,    0,    0, 1417,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1418,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1419,    0,    0,    0,    0,
    0,    0, 1420,    0,    0,    0,    0,    0,    0,    0,
 1421,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1422,    0, 1423,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1424,
    0, 1425, 1426, 1427,    0,    0,    0,    0, 1428,    0,
    0,    0,    0, 2182,    0, 2182,    0,    0, 2182,    0,
 2182, 2182, 2182,    0, 2182, 2182,    0, 2182,    0,    0,
    0,    0,    0, 2182,    0, 2182, 2182, 2182, 2182,    0,
 2182,    0,    0, 2182,    0,    0, 2182,    0,    0, 1429,
    0,    0,    0, 2182,    0, 2182, 2182,    0, 2182, 2182,
 2182, 2182, 2182,    0,    0, 2182,    0,    0, 2182,    0,
 2182, 2182,    0,    0, 2182, 2182, 2182,    0, 2182, 2182,
 2182, 2182, 2182, 2182, 2182,    0,    0,    0, 2182, 2182,
 2182, 2182, 2182,    0,    0,    0, 2182,    0,    0,    0,
    0,    0,    0,    0, 2182, 2182, 2182, 2182, 2182, 2182,
    0,    0,    0, 2182, 2182,    0, 2182,    0, 2182,    0,
 2182, 2182, 2182,    0, 2182,    0, 2182, 2182, 2182,    0,
 2182, 2182, 2182, 2182, 2182,    0, 2182, 2182,    0,    0,
    0,    0, 2182,    0, 2182, 2182,    0,    0, 2182, 2182,
 2182,    0,    0, 2182,    0, 2182,    0,    0, 2182, 2182,
 2182, 2182,    0, 2182,    0, 2182,    0, 2182, 2182, 2182,
 2182, 2182,    0,    0, 2182, 2182, 2182,    0, 2182, 2182,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2182,
 2182, 2182,    0, 2182, 2182, 2182,    0,    0,    0,    0,
    0, 2182,    0,    0,    0, 2182,    0, 2182, 2182, 2182,
 2182,    0, 2182,    0, 2182, 2182, 2182, 2182, 2182, 2182,
 2182, 2182,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2182, 2182,    0, 2182, 2182, 2182,    0,    0, 1430,
    0, 2182, 2182, 2182, 2182, 2182,    0, 2182,    0,    0,
 2182, 2182,    0,    0,    0, 2182, 2182,    0,    0, 2182,
 2182, 2182, 2182, 2182, 2182, 2182, 2182, 2182,    0, 2182,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2182,
 2182, 2182, 2182, 2182, 2182, 2182, 2182, 2182, 2182, 2182,
 2182, 2182, 2182, 2182, 2182, 2182, 2182, 2182, 2182, 2182,
    0, 2182, 2182, 2182, 2182, 2182, 2182,    0, 2182, 2182,
 2182, 2182,    0, 2182,    0, 2182, 2182, 2182, 2182, 2182,
 2182, 2182, 2182, 2182, 2182, 2182, 2182, 2182, 2182, 2182,
 2182, 2182, 2182,    0, 2182, 2182, 2182, 2182,    0, 2182,
 2182, 2182, 2182, 2182,    0, 2182, 2182, 2182, 2182, 2182,
 2182, 2182, 2182, 2182, 2182, 2182, 2182, 2182, 2182, 2182,
 2182, 2182, 2182, 2182, 2182, 2182, 2182, 2182, 2182, 2182,
 2182, 2182, 2182, 2182,    0, 2182, 2182,    0,    0,    0,
 2182, 2182, 2182, 2182, 2182, 2182,    0,    0, 2182, 2182,
 2182, 2182, 2182, 2182, 2182, 2182, 2182, 2918,    0,    0,
    0,    0, 2182,    0, 2182, 2182, 2182, 2182, 2182, 2182,
    0, 2182,    0,    0,    0,    0, 1432, 1431, 1433,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2182, 2182,
    0, 2182, 2182, 2182, 2182, 2182, 2182, 2182, 2182, 2182,
    0, 2182, 2182, 2182, 2182, 2182, 2182, 2182, 2182, 2182,
 2182, 2182, 2182,    0, 2182, 2182, 2182,    0, 2182,    0,
    0,    0, 2182, 2182, 2182, 2182, 2182, 2182, 2182, 2182,
 2182, 2182, 2182, 2182, 2182, 2183, 2182, 2182,    0,    0,
    0,    0,    0, 2182, 2182, 2182, 2182, 2182, 2182, 2182,
 2182, 2182, 2182, 2182, 2182, 2182, 2182, 2182, 2182, 2182,
 2182,    0,    0, 2182,    0, 2182, 2182, 2182, 2182, 2182,
 2182, 2182, 2182, 2182,    0, 1941, 2183, 2183, 2183, 2183,
 2183, 2183, 2183,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2183, 2183, 2183, 2183, 2183,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2183,    0, 2183,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1416,    0,
    0,    0,    0,    0,    0,    0,    0, 1417,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1418,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1419,    0,    0,    0,    0,    0,
    0, 1420,    0,    0,    0,    0,    0,    0,    0, 1421,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1422,    0, 1423,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1424,    0,
 1425, 1426, 1427,    0,    0,    0,    0, 1428,    0,    0,
    0,    0, 2183,    0, 2183,    0,    0, 2183,    0, 2183,
 2183, 2183,    0, 2183, 2183,    0, 2183,    0,    0,    0,
    0,    0, 2183,    0, 2183, 2183, 2183, 2183,    0, 2183,
    0,    0, 2183,    0,    0, 2183,    0,    0, 1429,    0,
    0,    0, 2183,    0, 2183, 2183,    0, 2183, 2183, 2183,
 2183, 2183,    0,    0, 2183,    0,    0, 2183,    0, 2183,
 2183,    0,    0, 2183, 2183, 2183,    0, 2183, 2183, 2183,
 2183, 2183, 2183, 2183,    0,    0,    0, 2183, 2183, 2183,
 2183, 2183,    0,    0,    0, 2183,    0,    0,    0,    0,
    0,    0,    0, 2183, 2183, 2183, 2183, 2183, 2183,    0,
    0,    0, 2183, 2183,    0, 2183,    0, 2183,    0, 2183,
 2183, 2183,    0, 2183,    0, 2183, 2183, 2183,    0, 2183,
 2183, 2183, 2183, 2183,    0, 2183, 2183,    0,    0,    0,
    0, 2183,    0, 2183, 2183,    0,    0, 2183, 2183, 2183,
    0,    0, 2183,    0, 2183,    0,    0, 2183, 2183, 2183,
 2183,    0, 2183,    0, 2183,    0, 2183, 2183, 2183, 2183,
 2183,    0,    0, 2183, 2183, 2183,    0, 2183, 2183,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2183, 2183,
 2183,    0, 2183, 2183, 2183,    0,    0,    0,    0,    0,
 2183,    0,    0,    0, 2183,    0, 2183, 2183, 2183, 2183,
    0, 2183,    0, 2183, 2183, 2183, 2183, 2183, 2183, 2183,
 2183,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2183, 2183,    0, 2183, 2183, 2183,    0,    0, 1430,    0,
 2183, 2183, 2183, 2183, 2183,    0, 2183,    0,    0, 2183,
 2183,    0,    0,    0, 2183, 2183,    0,    0, 2183, 2183,
 2183, 2183, 2183, 2183, 2183, 2183, 2183,    0, 2183,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2183, 2183,
 2183, 2183, 2183, 2183, 2183, 2183, 2183, 2183, 2183, 2183,
 2183, 2183, 2183, 2183, 2183, 2183, 2183, 2183, 2183,    0,
 2183, 2183, 2183, 2183, 2183, 2183,    0, 2183, 2183, 2183,
 2183,    0, 2183,    0, 2183, 2183, 2183, 2183, 2183, 2183,
 2183, 2183, 2183, 2183, 2183, 2183, 2183, 2183, 2183, 2183,
 2183, 2183,    0, 2183, 2183, 2183, 2183,    0, 2183, 2183,
 2183, 2183, 2183,    0, 2183, 2183, 2183, 2183, 2183, 2183,
 2183, 2183, 2183, 2183, 2183, 2183, 2183, 2183, 2183, 2183,
 2183, 2183, 2183, 2183, 2183, 2183, 2183, 2183, 2183, 2183,
 2183, 2183, 2183,    0, 2183, 2183,    0,    0,    0, 2183,
 2183, 2183, 2183, 2183, 2183,    0,    0, 2183, 2183, 2183,
 2183, 2183, 2183, 2183, 2183, 2183, 2919,    0,    0,    0,
    0, 2183,    0, 2183, 2183, 2183, 2183, 2183, 2183,    0,
 2183,    0,    0,    0,    0, 1432, 1431, 1433,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2183, 2183,    0,
 2183, 2183, 2183, 2183, 2183, 2183, 2183, 2183, 2183,    0,
 2183, 2183, 2183, 2183, 2183, 2183, 2183, 2183, 2183, 2183,
 2183, 2183,    0, 2183, 2183, 2183,    0, 2183,    0,    0,
    0, 2183, 2183, 2183, 2183, 2183, 2183, 2183, 2183, 2183,
 2183, 2183, 2183, 2183, 2184, 2183, 2183,    0,    0,    0,
    0,    0, 2183, 2183, 2183, 2183, 2183, 2183, 2183, 2183,
 2183, 2183, 2183, 2183, 2183, 2183, 2183, 2183, 2183, 2183,
    0,    0, 2183,    0, 2183, 2183, 2183, 2183, 2183, 2183,
 2183, 2183, 2183,    0, 1942, 2184, 2184, 2184, 2184, 2184,
 2184, 2184,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2184, 2184, 2184, 2184, 2184,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2184,    0, 2184,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1416,    0,    0,
    0,    0,    0,    0,    0,    0, 1417,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1418,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1419,    0,    0,    0,    0,    0,    0,
 1420,    0,    0,    0,    0,    0,    0,    0, 1421,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1422,    0, 1423,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1424,    0, 1425,
 1426, 1427,    0,    0,    0,    0, 1428,    0,    0,    0,
    0, 2184,    0, 2184,    0,    0, 2184,    0, 2184, 2184,
 2184,    0, 2184, 2184,    0, 2184,    0,    0,    0,    0,
    0, 2184,    0, 2184, 2184, 2184, 2184,    0, 2184,    0,
    0, 2184,    0,    0, 2184,    0,    0, 1429,    0,    0,
    0, 2184,    0, 2184, 2184,    0, 2184, 2184, 2184, 2184,
 2184,    0,    0, 2184,    0,    0, 2184,    0, 2184, 2184,
    0,    0, 2184, 2184, 2184,    0, 2184, 2184, 2184, 2184,
 2184, 2184, 2184,    0,    0,    0, 2184, 2184, 2184, 2184,
 2184,    0,    0,    0, 2184,    0,    0,    0,    0,    0,
    0,    0, 2184, 2184, 2184, 2184, 2184, 2184,    0,    0,
    0, 2184, 2184,    0, 2184,    0, 2184,    0, 2184, 2184,
 2184,    0, 2184,    0, 2184, 2184, 2184,    0, 2184, 2184,
 2184, 2184, 2184,    0, 2184, 2184,    0,    0,    0,    0,
 2184,    0, 2184, 2184,    0,    0, 2184, 2184, 2184,    0,
    0, 2184,    0, 2184,    0,    0, 2184, 2184, 2184, 2184,
    0, 2184,    0, 2184,    0, 2184, 2184, 2184, 2184, 2184,
    0,    0, 2184, 2184, 2184,    0, 2184, 2184,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2184, 2184, 2184,
    0, 2184, 2184, 2184,    0,    0,    0,    0,    0, 2184,
    0,    0,    0, 2184,    0, 2184, 2184, 2184, 2184,    0,
 2184,    0, 2184, 2184, 2184, 2184, 2184, 2184, 2184, 2184,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2184,
 2184,    0, 2184, 2184, 2184,    0,    0, 1430,    0, 2184,
 2184, 2184, 2184, 2184,    0, 2184,    0,    0, 2184, 2184,
    0,    0,    0, 2184, 2184,    0,    0, 2184, 2184, 2184,
 2184, 2184, 2184, 2184, 2184, 2184,    0, 2184,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2184, 2184, 2184,
 2184, 2184, 2184, 2184, 2184, 2184, 2184, 2184, 2184, 2184,
 2184, 2184, 2184, 2184, 2184, 2184, 2184, 2184,    0, 2184,
 2184, 2184, 2184, 2184, 2184,    0, 2184, 2184, 2184, 2184,
    0, 2184,    0, 2184, 2184, 2184, 2184, 2184, 2184, 2184,
 2184, 2184, 2184, 2184, 2184, 2184, 2184, 2184, 2184, 2184,
 2184,    0, 2184, 2184, 2184, 2184,    0, 2184, 2184, 2184,
 2184, 2184,    0, 2184, 2184, 2184, 2184, 2184, 2184, 2184,
 2184, 2184, 2184, 2184, 2184, 2184, 2184, 2184, 2184, 2184,
 2184, 2184, 2184, 2184, 2184, 2184, 2184, 2184, 2184, 2184,
 2184, 2184,    0, 2184, 2184,    0,    0,    0, 2184, 2184,
 2184, 2184, 2184, 2184,    0,    0, 2184, 2184, 2184, 2184,
 2184, 2184, 2184, 2184, 2184, 2926,    0,    0,    0,    0,
 2184,    0, 2184, 2184, 2184, 2184, 2184, 2184,    0, 2184,
    0,    0,    0,    0, 1432, 1431, 1433,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2184, 2184,    0, 2184,
 2184, 2184, 2184, 2184, 2184, 2184, 2184, 2184,    0, 2184,
 2184, 2184, 2184, 2184, 2184, 2184, 2184, 2184, 2184, 2184,
 2184,    0, 2184, 2184, 2184,    0, 2184,    0,    0,    0,
 2184, 2184, 2184, 2184, 2184, 2184, 2184, 2184, 2184, 2184,
 2184, 2184, 2184, 2185, 2184, 2184,    0,    0,    0,    0,
    0, 2184, 2184, 2184, 2184, 2184, 2184, 2184, 2184, 2184,
 2184, 2184, 2184, 2184, 2184, 2184, 2184, 2184, 2184,    0,
    0, 2184,    0, 2184, 2184, 2184, 2184, 2184, 2184, 2184,
 2184, 2184,    0, 1944, 2185, 2185, 2185, 2185, 2185, 2185,
 2185,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2185, 2185, 2185, 2185, 2185,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2185,    0, 2185,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1416,    0,    0,    0,
    0,    0,    0,    0,    0, 1417,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1418,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1419,    0,    0,    0,    0,    0,    0, 1420,
    0,    0,    0,    0,    0,    0,    0, 1421,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1422,    0, 1423,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1424,    0, 1425, 1426,
 1427,    0,    0,    0,    0, 1428,    0,    0,    0,    0,
 2185,    0, 2185,    0,    0, 2185,    0, 2185, 2185, 2185,
    0, 2185, 2185,    0, 2185,    0,    0,    0,    0,    0,
 2185,    0, 2185, 2185, 2185, 2185,    0, 2185,    0,    0,
 2185,    0,    0, 2185,    0,    0, 1429,    0,    0,    0,
 2185,    0, 2185, 2185,    0, 2185, 2185, 2185, 2185, 2185,
    0,    0, 2185,    0,    0, 2185,    0, 2185, 2185,    0,
    0, 2185, 2185, 2185,    0, 2185, 2185, 2185, 2185, 2185,
 2185, 2185,    0,    0,    0, 2185, 2185, 2185, 2185, 2185,
    0,    0,    0, 2185,    0,    0,    0,    0,    0,    0,
    0, 2185, 2185, 2185, 2185, 2185, 2185,    0,    0,    0,
 2185, 2185,    0, 2185,    0, 2185,    0, 2185, 2185, 2185,
    0, 2185,    0, 2185, 2185, 2185,    0, 2185, 2185, 2185,
 2185, 2185,    0, 2185, 2185,    0,    0,    0,    0, 2185,
    0, 2185, 2185,    0,    0, 2185, 2185, 2185,    0,    0,
 2185,    0, 2185,    0,    0, 2185, 2185, 2185, 2185,    0,
 2185,    0, 2185,    0, 2185, 2185, 2185, 2185, 2185,    0,
    0, 2185, 2185, 2185,    0, 2185, 2185,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2185, 2185, 2185,    0,
 2185, 2185, 2185,    0,    0,    0,    0,    0, 2185,    0,
    0,    0, 2185,    0, 2185, 2185, 2185, 2185,    0, 2185,
    0, 2185, 2185, 2185, 2185, 2185, 2185, 2185, 2185,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2185, 2185,
    0, 2185, 2185, 2185,    0,    0, 1430,    0, 2185, 2185,
 2185, 2185, 2185,    0, 2185,    0,    0, 2185, 2185,    0,
    0,    0, 2185, 2185,    0,    0, 2185, 2185, 2185, 2185,
 2185, 2185, 2185, 2185, 2185,    0, 2185,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2185, 2185, 2185, 2185,
 2185, 2185, 2185, 2185, 2185, 2185, 2185, 2185, 2185, 2185,
 2185, 2185, 2185, 2185, 2185, 2185, 2185,    0, 2185, 2185,
 2185, 2185, 2185, 2185,    0, 2185, 2185, 2185, 2185,    0,
 2185,    0, 2185, 2185, 2185, 2185, 2185, 2185, 2185, 2185,
 2185, 2185, 2185, 2185, 2185, 2185, 2185, 2185, 2185, 2185,
    0, 2185, 2185, 2185, 2185,    0, 2185, 2185, 2185, 2185,
 2185,    0, 2185, 2185, 2185, 2185, 2185, 2185, 2185, 2185,
 2185, 2185, 2185, 2185, 2185, 2185, 2185, 2185, 2185, 2185,
 2185, 2185, 2185, 2185, 2185, 2185, 2185, 2185, 2185, 2185,
 2185,    0, 2185, 2185,    0,    0,    0, 2185, 2185, 2185,
 2185, 2185, 2185,    0,    0, 2185, 2185, 2185, 2185, 2185,
 2185, 2185, 2185, 2185, 2929,    0,    0,    0,    0, 2185,
    0, 2185, 2185, 2185, 2185, 2185, 2185,    0, 2185,    0,
    0,    0,    0, 1432, 1431, 1433,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2185, 2185,    0, 2185, 2185,
 2185, 2185, 2185, 2185, 2185, 2185, 2185,    0, 2185, 2185,
 2185, 2185, 2185, 2185, 2185, 2185, 2185, 2185, 2185, 2185,
    0, 2185, 2185, 2185,    0, 2185,    0,    0,    0, 2185,
 2185, 2185, 2185, 2185, 2185, 2185, 2185, 2185, 2185, 2185,
 2185, 2185, 2186, 2185, 2185,    0,    0,    0,    0,    0,
 2185, 2185, 2185, 2185, 2185, 2185, 2185, 2185, 2185, 2185,
 2185, 2185, 2185, 2185, 2185, 2185, 2185, 2185,    0,    0,
 2185,    0, 2185, 2185, 2185, 2185, 2185, 2185, 2185, 2185,
 2185,    0, 1945, 2186, 2186, 2186, 2186, 2186, 2186, 2186,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2186, 2186, 2186, 2186, 2186,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2186,    0, 2186,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1416,    0,    0,    0,    0,
    0,    0,    0,    0, 1417,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1418,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1419,    0,    0,    0,    0,    0,    0, 1420,    0,
    0,    0,    0,    0,    0,    0, 1421,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1422,    0, 1423,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1424,    0, 1425, 1426, 1427,
    0,    0,    0,    0, 1428,    0,    0,    0,    0, 2186,
    0, 2186,    0,    0, 2186,    0, 2186, 2186, 2186,    0,
 2186, 2186,    0, 2186,    0,    0,    0,    0,    0, 2186,
    0, 2186, 2186, 2186, 2186,    0, 2186,    0,    0, 2186,
    0,    0, 2186,    0,    0, 1429,    0,    0,    0, 2186,
    0, 2186, 2186,    0, 2186, 2186, 2186, 2186, 2186,    0,
    0, 2186,    0,    0, 2186,    0, 2186, 2186,    0,    0,
 2186, 2186, 2186,    0, 2186, 2186, 2186, 2186, 2186, 2186,
 2186,    0,    0,    0, 2186, 2186, 2186, 2186, 2186,    0,
    0,    0, 2186,    0,    0,    0,    0,    0,    0,    0,
 2186, 2186, 2186, 2186, 2186, 2186,    0,    0,    0, 2186,
 2186,    0, 2186,    0, 2186,    0, 2186, 2186, 2186,    0,
 2186,    0, 2186, 2186, 2186,    0, 2186, 2186, 2186, 2186,
 2186,    0, 2186, 2186,    0,    0,    0,    0, 2186,    0,
 2186, 2186,    0,    0, 2186, 2186, 2186,    0,    0, 2186,
    0, 2186,    0,    0, 2186, 2186, 2186, 2186,    0, 2186,
    0, 2186,    0, 2186, 2186, 2186, 2186, 2186,    0,    0,
 2186, 2186, 2186,    0, 2186, 2186,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2186, 2186, 2186,    0, 2186,
 2186, 2186,    0,    0,    0,    0,    0, 2186,    0,    0,
    0, 2186,    0, 2186, 2186, 2186, 2186,    0, 2186,    0,
 2186, 2186, 2186, 2186, 2186, 2186, 2186, 2186,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2186, 2186,    0,
 2186, 2186, 2186,    0,    0, 1430,    0, 2186, 2186, 2186,
 2186, 2186,    0, 2186,    0,    0, 2186, 2186,    0,    0,
    0, 2186, 2186,    0,    0, 2186, 2186, 2186, 2186, 2186,
 2186, 2186, 2186, 2186,    0, 2186,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2186, 2186, 2186, 2186, 2186,
 2186, 2186, 2186, 2186, 2186, 2186, 2186, 2186, 2186, 2186,
 2186, 2186, 2186, 2186, 2186, 2186,    0, 2186, 2186, 2186,
 2186, 2186, 2186,    0, 2186, 2186, 2186, 2186,    0, 2186,
    0, 2186, 2186, 2186, 2186, 2186, 2186, 2186, 2186, 2186,
 2186, 2186, 2186, 2186, 2186, 2186, 2186, 2186, 2186,    0,
 2186, 2186, 2186, 2186,    0, 2186, 2186, 2186, 2186, 2186,
    0, 2186, 2186, 2186, 2186, 2186, 2186, 2186, 2186, 2186,
 2186, 2186, 2186, 2186, 2186, 2186, 2186, 2186, 2186, 2186,
 2186, 2186, 2186, 2186, 2186, 2186, 2186, 2186, 2186, 2186,
    0, 2186, 2186,    0,    0,    0, 2186, 2186, 2186, 2186,
 2186, 2186,    0,    0, 2186, 2186, 2186, 2186, 2186, 2186,
 2186, 2186, 2186, 2930,    0,    0,    0,    0, 2186,    0,
 2186, 2186, 2186, 2186, 2186, 2186,    0, 2186,    0,    0,
    0,    0, 1432, 1431, 1433,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2186, 2186,    0, 2186, 2186, 2186,
 2186, 2186, 2186, 2186, 2186, 2186,    0, 2186, 2186, 2186,
 2186, 2186, 2186, 2186, 2186, 2186, 2186, 2186, 2186,    0,
 2186, 2186, 2186,    0, 2186,    0,    0,    0, 2186, 2186,
 2186, 2186, 2186, 2186, 2186, 2186, 2186, 2186, 2186, 2186,
 2186, 2187, 2186, 2186,    0,    0,    0,    0,    0, 2186,
 2186, 2186, 2186, 2186, 2186, 2186, 2186, 2186, 2186, 2186,
 2186, 2186, 2186, 2186, 2186, 2186, 2186,    0,    0, 2186,
    0, 2186, 2186, 2186, 2186, 2186, 2186, 2186, 2186, 2186,
    0, 1948, 2187, 2187, 2187, 2187, 2187, 2187, 2187,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2187,
 2187, 2187, 2187, 2187,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2187,    0, 2187,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1416,    0,    0,    0,    0,    0,
    0,    0,    0, 1417,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1418,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1419,    0,    0,    0,    0,    0,    0, 1420,    0,    0,
    0,    0,    0,    0,    0, 1421,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1422,    0, 1423,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1424,    0, 1425, 1426, 1427,    0,
    0,    0,    0, 1428,    0,    0,    0,    0, 2187,    0,
 2187,    0,    0, 2187,    0, 2187, 2187, 2187,    0, 2187,
 2187,    0, 2187,    0,    0,    0,    0,    0, 2187,    0,
 2187, 2187, 2187, 2187,    0, 2187,    0,    0, 2187,    0,
    0, 2187,    0,    0, 1429,    0,    0,    0, 2187,    0,
 2187, 2187,    0, 2187, 2187, 2187, 2187, 2187,    0,    0,
 2187,    0,    0, 2187,    0, 2187, 2187,    0,    0, 2187,
 2187, 2187,    0, 2187, 2187, 2187, 2187, 2187, 2187, 2187,
    0,    0,    0, 2187, 2187, 2187, 2187, 2187,    0,    0,
    0, 2187,    0,    0,    0,    0,    0,    0,    0, 2187,
 2187, 2187, 2187, 2187, 2187,    0,    0,    0, 2187, 2187,
    0, 2187,    0, 2187,    0, 2187, 2187, 2187,    0, 2187,
    0, 2187, 2187, 2187,    0, 2187, 2187, 2187, 2187, 2187,
    0, 2187, 2187,    0,    0,    0,    0, 2187,    0, 2187,
 2187,    0,    0, 2187, 2187, 2187,    0,    0, 2187,    0,
 2187,    0,    0, 2187, 2187, 2187, 2187,    0, 2187,    0,
 2187,    0, 2187, 2187, 2187, 2187, 2187,    0,    0, 2187,
 2187, 2187,    0, 2187, 2187,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2187, 2187, 2187,    0, 2187, 2187,
 2187,    0,    0,    0,    0,    0, 2187,    0,    0,    0,
 2187,    0, 2187, 2187, 2187, 2187,    0, 2187,    0, 2187,
 2187, 2187, 2187, 2187, 2187, 2187, 2187,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2187, 2187,    0, 2187,
 2187, 2187,    0,    0, 1430,    0, 2187, 2187, 2187, 2187,
 2187,    0, 2187,    0,    0, 2187, 2187,    0,    0,    0,
 2187, 2187,    0,    0, 2187, 2187, 2187, 2187, 2187, 2187,
 2187, 2187, 2187,    0, 2187,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2187, 2187, 2187, 2187, 2187, 2187,
 2187, 2187, 2187, 2187, 2187, 2187, 2187, 2187, 2187, 2187,
 2187, 2187, 2187, 2187, 2187,    0, 2187, 2187, 2187, 2187,
 2187, 2187,    0, 2187, 2187, 2187, 2187,    0, 2187,    0,
 2187, 2187, 2187, 2187, 2187, 2187, 2187, 2187, 2187, 2187,
 2187, 2187, 2187, 2187, 2187, 2187, 2187, 2187,    0, 2187,
 2187, 2187, 2187,    0, 2187, 2187, 2187, 2187, 2187,    0,
 2187, 2187, 2187, 2187, 2187, 2187, 2187, 2187, 2187, 2187,
 2187, 2187, 2187, 2187, 2187, 2187, 2187, 2187, 2187, 2187,
 2187, 2187, 2187, 2187, 2187, 2187, 2187, 2187, 2187,    0,
 2187, 2187,    0,    0,    0, 2187, 2187, 2187, 2187, 2187,
 2187,    0,    0, 2187, 2187, 2187, 2187, 2187, 2187, 2187,
 2187, 2187, 2943,    0,    0,    0,    0, 2187,    0, 2187,
 2187, 2187, 2187, 2187, 2187,    0, 2187,    0,    0,    0,
    0, 1432, 1431, 1433,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2187, 2187,    0, 2187, 2187, 2187, 2187,
 2187, 2187, 2187, 2187, 2187,    0, 2187, 2187, 2187, 2187,
 2187, 2187, 2187, 2187, 2187, 2187, 2187, 2187,    0, 2187,
 2187, 2187,    0, 2187,    0,    0,    0, 2187, 2187, 2187,
 2187, 2187, 2187, 2187, 2187, 2187, 2187, 2187, 2187, 2187,
 2188, 2187, 2187,    0,    0,    0,    0,    0, 2187, 2187,
 2187, 2187, 2187, 2187, 2187, 2187, 2187, 2187, 2187, 2187,
 2187, 2187, 2187, 2187, 2187, 2187,    0,    0, 2187,    0,
 2187, 2187, 2187, 2187, 2187, 2187, 2187, 2187, 2187,    0,
 1949, 2188, 2188, 2188, 2188, 2188, 2188, 2188,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2188, 2188,
 2188, 2188, 2188,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2188,    0, 2188,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1416,    0,    0,    0,    0,    0,    0,
    0,    0, 1417,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1418,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1419,
    0,    0,    0,    0,    0,    0, 1420,    0,    0,    0,
    0,    0,    0,    0, 1421,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1422,    0, 1423,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1424,    0, 1425, 1426, 1427,    0,    0,
    0,    0, 1428,    0,    0,    0,    0, 2188,    0, 2188,
    0,    0, 2188,    0, 2188, 2188, 2188,    0, 2188, 2188,
    0, 2188,    0,    0,    0,    0,    0, 2188,    0, 2188,
 2188, 2188, 2188,    0, 2188,    0,    0, 2188,    0,    0,
 2188,    0,    0, 1429,    0,    0,    0, 2188,    0, 2188,
 2188,    0, 2188, 2188, 2188, 2188, 2188,    0,    0, 2188,
    0,    0, 2188,    0, 2188, 2188,    0,    0, 2188, 2188,
 2188,    0, 2188, 2188, 2188, 2188, 2188, 2188, 2188,    0,
    0,    0, 2188, 2188, 2188, 2188, 2188,    0,    0,    0,
 2188,    0,    0,    0,    0,    0,    0,    0, 2188, 2188,
 2188, 2188, 2188, 2188,    0,    0,    0, 2188, 2188,    0,
 2188,    0, 2188,    0, 2188, 2188, 2188,    0, 2188,    0,
 2188, 2188, 2188,    0, 2188, 2188, 2188, 2188, 2188,    0,
 2188, 2188,    0,    0,    0,    0, 2188,    0, 2188, 2188,
    0,    0, 2188, 2188, 2188,    0,    0, 2188,    0, 2188,
    0,    0, 2188, 2188, 2188, 2188,    0, 2188,    0, 2188,
    0, 2188, 2188, 2188, 2188, 2188,    0,    0, 2188, 2188,
 2188,    0, 2188, 2188,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2188, 2188, 2188,    0, 2188, 2188, 2188,
    0,    0,    0,    0,    0, 2188,    0,    0,    0, 2188,
    0, 2188, 2188, 2188, 2188,    0, 2188,    0, 2188, 2188,
 2188, 2188, 2188, 2188, 2188, 2188,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2188, 2188,    0, 2188, 2188,
 2188,    0,    0, 1430,    0, 2188, 2188, 2188, 2188, 2188,
    0, 2188,    0,    0, 2188, 2188,    0,    0,    0, 2188,
 2188,    0,    0, 2188, 2188, 2188, 2188, 2188, 2188, 2188,
 2188, 2188,    0, 2188,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2188, 2188, 2188, 2188, 2188, 2188, 2188,
 2188, 2188, 2188, 2188, 2188, 2188, 2188, 2188, 2188, 2188,
 2188, 2188, 2188, 2188,    0, 2188, 2188, 2188, 2188, 2188,
 2188,    0, 2188, 2188, 2188, 2188,    0, 2188,    0, 2188,
 2188, 2188, 2188, 2188, 2188, 2188, 2188, 2188, 2188, 2188,
 2188, 2188, 2188, 2188, 2188, 2188, 2188,    0, 2188, 2188,
 2188, 2188,    0, 2188, 2188, 2188, 2188, 2188,    0, 2188,
 2188, 2188, 2188, 2188, 2188, 2188, 2188, 2188, 2188, 2188,
 2188, 2188, 2188, 2188, 2188, 2188, 2188, 2188, 2188, 2188,
 2188, 2188, 2188, 2188, 2188, 2188, 2188, 2188,    0, 2188,
 2188,    0,    0,    0, 2188, 2188, 2188, 2188, 2188, 2188,
    0,    0, 2188, 2188, 2188, 2188, 2188, 2188, 2188, 2188,
 2188, 2948,    0,    0,    0,    0, 2188,    0, 2188, 2188,
 2188, 2188, 2188, 2188,    0, 2188,    0,    0,    0,    0,
 1432, 1431, 1433,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2188, 2188,    0, 2188, 2188, 2188, 2188, 2188,
 2188, 2188, 2188, 2188,    0, 2188, 2188, 2188, 2188, 2188,
 2188, 2188, 2188, 2188, 2188, 2188, 2188,    0, 2188, 2188,
 2188,    0, 2188,    0,    0,    0, 2188, 2188, 2188, 2188,
 2188, 2188, 2188, 2188, 2188, 2188, 2188, 2188, 2188, 2189,
 2188, 2188,    0,    0,    0,    0,    0, 2188, 2188, 2188,
 2188, 2188, 2188, 2188, 2188, 2188, 2188, 2188, 2188, 2188,
 2188, 2188, 2188, 2188, 2188,    0,    0, 2188,    0, 2188,
 2188, 2188, 2188, 2188, 2188, 2188, 2188, 2188,    0, 1950,
 2189, 2189, 2189, 2189, 2189, 2189, 2189,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2189, 2189, 2189,
 2189, 2189,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2189,    0, 2189,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1416,    0,    0,    0,    0,    0,    0,    0,
    0, 1417,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1418,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1419,    0,
    0,    0,    0,    0,    0, 1420,    0,    0,    0,    0,
    0,    0,    0, 1421,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1422,    0, 1423,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1424,    0, 1425, 1426, 1427,    0,    0,    0,
    0, 1428,    0,    0,    0,    0, 2189,    0, 2189,    0,
    0, 2189,    0, 2189, 2189, 2189,    0, 2189, 2189,    0,
 2189,    0,    0,    0,    0,    0, 2189,    0, 2189, 2189,
 2189, 2189,    0, 2189,    0,    0, 2189,    0,    0, 2189,
    0,    0, 1429,    0,    0,    0, 2189,    0, 2189, 2189,
    0, 2189, 2189, 2189, 2189, 2189,    0,    0, 2189,    0,
    0, 2189,    0, 2189, 2189,    0,    0, 2189, 2189, 2189,
    0, 2189, 2189, 2189, 2189, 2189, 2189, 2189,    0,    0,
    0, 2189, 2189, 2189, 2189, 2189,    0,    0,    0, 2189,
    0,    0,    0,    0,    0,    0,    0, 2189, 2189, 2189,
 2189, 2189, 2189,    0,    0,    0, 2189, 2189,    0, 2189,
    0, 2189,    0, 2189, 2189, 2189,    0, 2189,    0, 2189,
 2189, 2189,    0, 2189, 2189, 2189, 2189, 2189,    0, 2189,
 2189,    0,    0,    0,    0, 2189,    0, 2189, 2189,    0,
    0, 2189, 2189, 2189,    0,    0, 2189,    0, 2189,    0,
    0, 2189, 2189, 2189, 2189,    0, 2189,    0, 2189,    0,
 2189, 2189, 2189, 2189, 2189,    0,    0, 2189, 2189, 2189,
    0, 2189, 2189,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2189, 2189, 2189,    0, 2189, 2189, 2189,    0,
    0,    0,    0,    0, 2189,    0,    0,    0, 2189,    0,
 2189, 2189, 2189, 2189,    0, 2189,    0, 2189, 2189, 2189,
 2189, 2189, 2189, 2189, 2189,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2189, 2189,    0, 2189, 2189, 2189,
    0,    0, 1430,    0, 2189, 2189, 2189, 2189, 2189,    0,
 2189,    0,    0, 2189, 2189,    0,    0,    0, 2189, 2189,
    0,    0, 2189, 2189, 2189, 2189, 2189, 2189, 2189, 2189,
 2189,    0, 2189,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2189, 2189, 2189, 2189, 2189, 2189, 2189, 2189,
 2189, 2189, 2189, 2189, 2189, 2189, 2189, 2189, 2189, 2189,
 2189, 2189, 2189,    0, 2189, 2189, 2189, 2189, 2189, 2189,
    0, 2189, 2189, 2189, 2189,    0, 2189,    0, 2189, 2189,
 2189, 2189, 2189, 2189, 2189, 2189, 2189, 2189, 2189, 2189,
 2189, 2189, 2189, 2189, 2189, 2189,    0, 2189, 2189, 2189,
 2189,    0, 2189, 2189, 2189, 2189, 2189,    0, 2189, 2189,
 2189, 2189, 2189, 2189, 2189, 2189, 2189, 2189, 2189, 2189,
 2189, 2189, 2189, 2189, 2189, 2189, 2189, 2189, 2189, 2189,
 2189, 2189, 2189, 2189, 2189, 2189, 2189,    0, 2189, 2189,
    0,    0,    0, 2189, 2189, 2189, 2189, 2189, 2189,    0,
    0, 2189, 2189, 2189, 2189, 2189, 2189, 2189, 2189, 2189,
 2949,    0,    0,    0,    0, 2189,    0, 2189, 2189, 2189,
 2189, 2189, 2189,    0, 2189,    0,    0,    0,    0, 1432,
 1431, 1433,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2189, 2189,    0, 2189, 2189, 2189, 2189, 2189, 2189,
 2189, 2189, 2189,    0, 2189, 2189, 2189, 2189, 2189, 2189,
 2189, 2189, 2189, 2189, 2189, 2189,    0, 2189, 2189, 2189,
    0, 2189,    0,    0,    0, 2189, 2189, 2189, 2189, 2189,
 2189, 2189, 2189, 2189, 2189, 2189, 2189, 2189, 2191, 2189,
 2189,    0,    0,    0,    0,    0, 2189, 2189, 2189, 2189,
 2189, 2189, 2189, 2189, 2189, 2189, 2189, 2189, 2189, 2189,
 2189, 2189, 2189, 2189,    0,    0, 2189,    0, 2189, 2189,
 2189, 2189, 2189, 2189, 2189, 2189, 2189,    0, 1951, 2191,
 2191, 2191, 2191, 2191, 2191, 2191,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2191, 2191, 2191, 2191,
 2191,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2191,
    0, 2191,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1416,    0,    0,    0,    0,    0,    0,    0,    0,
 1417,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1418,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1419,    0,    0,
    0,    0,    0,    0, 1420,    0,    0,    0,    0,    0,
    0,    0, 1421,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1422,
    0, 1423,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1424,    0, 1425, 1426, 1427,    0,    0,    0,    0,
 1428,    0,    0,    0,    0, 2191,    0, 2191,    0,    0,
 2191,    0, 2191, 2191, 2191,    0, 2191, 2191,    0, 2191,
    0,    0,    0,    0,    0, 2191,    0, 2191, 2191, 2191,
 2191,    0, 2191,    0,    0, 2191,    0,    0, 2191,    0,
    0, 1429,    0,    0,    0, 2191,    0, 2191, 2191,    0,
 2191, 2191, 2191, 2191, 2191,    0,    0, 2191,    0,    0,
 2191,    0, 2191, 2191,    0,    0, 2191, 2191, 2191,    0,
 2191, 2191, 2191, 2191, 2191, 2191, 2191,    0,    0,    0,
 2191, 2191, 2191, 2191, 2191,    0,    0,    0, 2191,    0,
    0,    0,    0,    0,    0,    0, 2191, 2191, 2191, 2191,
 2191, 2191,    0,    0,    0, 2191, 2191,    0, 2191,    0,
 2191,    0, 2191, 2191, 2191,    0, 2191,    0, 2191, 2191,
 2191,    0, 2191, 2191, 2191, 2191, 2191,    0, 2191, 2191,
    0,    0,    0,    0, 2191,    0, 2191, 2191,    0,    0,
 2191, 2191, 2191,    0,    0, 2191,    0, 2191,    0,    0,
 2191, 2191, 2191, 2191,    0, 2191,    0, 2191,    0, 2191,
 2191, 2191, 2191, 2191,    0,    0, 2191, 2191, 2191,    0,
 2191, 2191,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2191, 2191, 2191,    0, 2191, 2191, 2191,    0,    0,
    0,    0,    0, 2191,    0,    0,    0, 2191,    0, 2191,
 2191, 2191, 2191,    0, 2191,    0, 2191, 2191, 2191, 2191,
 2191, 2191, 2191, 2191,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2191, 2191,    0, 2191, 2191, 2191,    0,
    0, 1430,    0, 2191, 2191, 2191, 2191, 2191,    0, 2191,
    0,    0, 2191, 2191,    0,    0,    0, 2191, 2191,    0,
    0, 2191, 2191, 2191, 2191, 2191, 2191, 2191, 2191, 2191,
    0, 2191,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2191, 2191, 2191, 2191, 2191, 2191, 2191, 2191, 2191,
 2191, 2191, 2191, 2191, 2191, 2191, 2191, 2191, 2191, 2191,
 2191, 2191,    0, 2191, 2191, 2191, 2191, 2191, 2191,    0,
 2191, 2191, 2191, 2191,    0, 2191,    0, 2191, 2191, 2191,
 2191, 2191, 2191, 2191, 2191, 2191, 2191, 2191, 2191, 2191,
 2191, 2191, 2191, 2191, 2191,    0, 2191, 2191, 2191, 2191,
    0, 2191, 2191, 2191, 2191, 2191,    0, 2191, 2191, 2191,
 2191, 2191, 2191, 2191, 2191, 2191, 2191, 2191, 2191, 2191,
 2191, 2191, 2191, 2191, 2191, 2191, 2191, 2191, 2191, 2191,
 2191, 2191, 2191, 2191, 2191, 2191,    0, 2191, 2191,    0,
    0,    0, 2191, 2191, 2191, 2191, 2191, 2191,    0,    0,
 2191, 2191, 2191, 2191, 2191, 2191, 2191, 2191, 2191, 2950,
    0,    0,    0,    0, 2191,    0, 2191, 2191, 2191, 2191,
 2191, 2191,    0, 2191,    0,    0,    0,    0, 1432, 1431,
 1433,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2191, 2191,    0, 2191, 2191, 2191, 2191, 2191, 2191, 2191,
 2191, 2191,    0, 2191, 2191, 2191, 2191, 2191, 2191, 2191,
 2191, 2191, 2191, 2191, 2191,    0, 2191, 2191, 2191,    0,
 2191,    0,    0,    0, 2191, 2191, 2191, 2191, 2191, 2191,
 2191, 2191, 2191, 2191, 2191, 2191, 2191, 2192, 2191, 2191,
    0,    0,    0,    0,    0, 2191, 2191, 2191, 2191, 2191,
 2191, 2191, 2191, 2191, 2191, 2191, 2191, 2191, 2191, 2191,
 2191, 2191, 2191,    0,    0, 2191,    0, 2191, 2191, 2191,
 2191, 2191, 2191, 2191, 2191, 2191,    0, 1952, 2192, 2192,
 2192, 2192, 2192, 2192, 2192,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2192, 2192, 2192, 2192, 2192,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2192,    0,
 2192,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1416,    0,    0,    0,    0,    0,    0,    0,    0, 1417,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1418,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1419,    0,    0,    0,
    0,    0,    0, 1420,    0,    0,    0,    0,    0,    0,
    0, 1421,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1422,    0,
 1423,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1424,    0, 1425, 1426, 1427,    0,    0,    0,    0, 1428,
    0,    0,    0,    0, 2192,    0, 2192,    0,    0, 2192,
    0, 2192, 2192, 2192,    0, 2192, 2192,    0, 2192,    0,
    0,    0,    0,    0, 2192,    0, 2192, 2192, 2192, 2192,
    0, 2192,    0,    0, 2192,    0,    0, 2192,    0,    0,
 1429,    0,    0,    0, 2192,    0, 2192, 2192,    0, 2192,
 2192, 2192, 2192, 2192,    0,    0, 2192,    0,    0, 2192,
    0, 2192, 2192,    0,    0, 2192, 2192, 2192,    0, 2192,
 2192, 2192, 2192, 2192, 2192, 2192,    0,    0,    0, 2192,
 2192, 2192, 2192, 2192,    0,    0,    0, 2192,    0,    0,
    0,    0,    0,    0,    0, 2192, 2192, 2192, 2192, 2192,
 2192,    0,    0,    0, 2192, 2192,    0, 2192,    0, 2192,
    0, 2192, 2192, 2192,    0, 2192,    0, 2192, 2192, 2192,
    0, 2192, 2192, 2192, 2192, 2192,    0, 2192, 2192,    0,
    0,    0,    0, 2192,    0, 2192, 2192,    0,    0, 2192,
 2192, 2192,    0,    0, 2192,    0, 2192,    0,    0, 2192,
 2192, 2192, 2192,    0, 2192,    0, 2192,    0, 2192, 2192,
 2192, 2192, 2192,    0,    0, 2192, 2192, 2192,    0, 2192,
 2192,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2192, 2192, 2192,    0, 2192, 2192, 2192,    0,    0,    0,
    0,    0, 2192,    0,    0,    0, 2192,    0, 2192, 2192,
 2192, 2192,    0, 2192,    0, 2192, 2192, 2192, 2192, 2192,
 2192, 2192, 2192,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2192, 2192,    0, 2192, 2192, 2192,    0,    0,
 1430,    0, 2192, 2192, 2192, 2192, 2192,    0, 2192,    0,
    0, 2192, 2192,    0,    0,    0, 2192, 2192,    0,    0,
 2192, 2192, 2192, 2192, 2192, 2192, 2192, 2192, 2192,    0,
 2192,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2192, 2192, 2192, 2192, 2192, 2192, 2192, 2192, 2192, 2192,
 2192, 2192, 2192, 2192, 2192, 2192, 2192, 2192, 2192, 2192,
 2192,    0, 2192, 2192, 2192, 2192, 2192, 2192,    0, 2192,
 2192, 2192, 2192,    0, 2192,    0, 2192, 2192, 2192, 2192,
 2192, 2192, 2192, 2192, 2192, 2192, 2192, 2192, 2192, 2192,
 2192, 2192, 2192, 2192,    0, 2192, 2192, 2192, 2192,    0,
 2192, 2192, 2192, 2192, 2192,    0, 2192, 2192, 2192, 2192,
 2192, 2192, 2192, 2192, 2192, 2192, 2192, 2192, 2192, 2192,
 2192, 2192, 2192, 2192, 2192, 2192, 2192, 2192, 2192, 2192,
 2192, 2192, 2192, 2192, 2192,    0, 2192, 2192,    0,    0,
    0, 2192, 2192, 2192, 2192, 2192, 2192,    0,    0, 2192,
 2192, 2192, 2192, 2192, 2192, 2192, 2192, 2192, 2951,    0,
    0,    0,    0, 2192,    0, 2192, 2192, 2192, 2192, 2192,
 2192,    0, 2192,    0,    0,    0,    0, 1432, 1431, 1433,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2192,
 2192,    0, 2192, 2192, 2192, 2192, 2192, 2192, 2192, 2192,
 2192,    0, 2192, 2192, 2192, 2192, 2192, 2192, 2192, 2192,
 2192, 2192, 2192, 2192,    0, 2192, 2192, 2192,    0, 2192,
    0,    0,    0, 2192, 2192, 2192, 2192, 2192, 2192, 2192,
 2192, 2192, 2192, 2192, 2192, 2192, 2193, 2192, 2192,    0,
    0,    0,    0,    0, 2192, 2192, 2192, 2192, 2192, 2192,
 2192, 2192, 2192, 2192, 2192, 2192, 2192, 2192, 2192, 2192,
 2192, 2192,    0,    0, 2192,    0, 2192, 2192, 2192, 2192,
 2192, 2192, 2192, 2192, 2192,    0, 1953, 2193, 2193, 2193,
 2193, 2193, 2193, 2193,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2193, 2193, 2193, 2193, 2193,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2193,    0, 2193,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1416,
    0,    0,    0,    0,    0,    0,    0,    0, 1417,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1418,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1419,    0,    0,    0,    0,
    0,    0, 1420,    0,    0,    0,    0,    0,    0,    0,
 1421,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1422,    0, 1423,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1424,
    0, 1425, 1426, 1427,    0,    0,    0,    0, 1428,    0,
    0,    0,    0, 2193,    0, 2193,    0,    0, 2193,    0,
 2193, 2193, 2193,    0, 2193, 2193,    0, 2193,    0,    0,
    0,    0,    0, 2193,    0, 2193, 2193, 2193, 2193,    0,
 2193,    0,    0, 2193,    0,    0, 2193,    0,    0, 1429,
    0,    0,    0, 2193,    0, 2193, 2193,    0, 2193, 2193,
 2193, 2193, 2193,    0,    0, 2193,    0,    0, 2193,    0,
 2193, 2193,    0,    0, 2193, 2193, 2193,    0, 2193, 2193,
 2193, 2193, 2193, 2193, 2193,    0,    0,    0, 2193, 2193,
 2193, 2193, 2193,    0,    0,    0, 2193,    0,    0,    0,
    0,    0,    0,    0, 2193, 2193, 2193, 2193, 2193, 2193,
    0,    0,    0, 2193, 2193,    0, 2193,    0, 2193,    0,
 2193, 2193, 2193,    0, 2193,    0, 2193, 2193, 2193,    0,
 2193, 2193, 2193, 2193, 2193,    0, 2193, 2193,    0,    0,
    0,    0, 2193,    0, 2193, 2193,    0,    0, 2193, 2193,
 2193,    0,    0, 2193,    0, 2193,    0,    0, 2193, 2193,
 2193, 2193,    0, 2193,    0, 2193,    0, 2193, 2193, 2193,
 2193, 2193,    0,    0, 2193, 2193, 2193,    0, 2193, 2193,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2193,
 2193, 2193,    0, 2193, 2193, 2193,    0,    0,    0,    0,
    0, 2193,    0,    0,    0, 2193,    0, 2193, 2193, 2193,
 2193,    0, 2193,    0, 2193, 2193, 2193, 2193, 2193, 2193,
 2193, 2193,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2193, 2193,    0, 2193, 2193, 2193,    0,    0, 1430,
    0, 2193, 2193, 2193, 2193, 2193,    0, 2193,    0,    0,
 2193, 2193,    0,    0,    0, 2193, 2193,    0,    0, 2193,
 2193, 2193, 2193, 2193, 2193, 2193, 2193, 2193,    0, 2193,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2193,
 2193, 2193, 2193, 2193, 2193, 2193, 2193, 2193, 2193, 2193,
 2193, 2193, 2193, 2193, 2193, 2193, 2193, 2193, 2193, 2193,
    0, 2193, 2193, 2193, 2193, 2193, 2193,    0, 2193, 2193,
 2193, 2193,    0, 2193,    0, 2193, 2193, 2193, 2193, 2193,
 2193, 2193, 2193, 2193, 2193, 2193, 2193, 2193, 2193, 2193,
 2193, 2193, 2193,    0, 2193, 2193, 2193, 2193,    0, 2193,
 2193, 2193, 2193, 2193,    0, 2193, 2193, 2193, 2193, 2193,
 2193, 2193, 2193, 2193, 2193, 2193, 2193, 2193, 2193, 2193,
 2193, 2193, 2193, 2193, 2193, 2193, 2193, 2193, 2193, 2193,
 2193, 2193, 2193, 2193,    0, 2193, 2193,    0,    0,    0,
 2193, 2193, 2193, 2193, 2193, 2193,    0,    0, 2193, 2193,
 2193, 2193, 2193, 2193, 2193, 2193, 2193, 2952,    0,    0,
    0,    0, 2193,    0, 2193, 2193, 2193, 2193, 2193, 2193,
    0, 2193,    0,    0,    0,    0, 1432, 1431, 1433,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2193, 2193,
    0, 2193, 2193, 2193, 2193, 2193, 2193, 2193, 2193, 2193,
    0, 2193, 2193, 2193, 2193, 2193, 2193, 2193, 2193, 2193,
 2193, 2193, 2193,    0, 2193, 2193, 2193,    0, 2193,    0,
    0,    0, 2193, 2193, 2193, 2193, 2193, 2193, 2193, 2193,
 2193, 2193, 2193, 2193, 2193, 2195, 2193, 2193,    0,    0,
    0,    0,    0, 2193, 2193, 2193, 2193, 2193, 2193, 2193,
 2193, 2193, 2193, 2193, 2193, 2193, 2193, 2193, 2193, 2193,
 2193,    0,    0, 2193,    0, 2193, 2193, 2193, 2193, 2193,
 2193, 2193, 2193, 2193,    0, 1954, 2195, 2195, 2195, 2195,
 2195, 2195, 2195,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2195, 2195, 2195, 2195, 2195,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2195,    0, 2195,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1416,    0,
    0,    0,    0,    0,    0,    0,    0, 1417,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1418,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1419,    0,    0,    0,    0,    0,
    0, 1420,    0,    0,    0,    0,    0,    0,    0, 1421,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1422,    0, 1423,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1424,    0,
 1425, 1426, 1427,    0,    0,    0,    0, 1428,    0,    0,
    0,    0, 2195,    0, 2195,    0,    0, 2195,    0, 2195,
 2195, 2195,    0, 2195, 2195,    0, 2195,    0,    0,    0,
    0,    0, 2195,    0, 2195, 2195, 2195, 2195,    0, 2195,
    0,    0, 2195,    0,    0, 2195,    0,    0, 1429,    0,
    0,    0, 2195,    0, 2195, 2195,    0, 2195, 2195, 2195,
 2195, 2195,    0,    0, 2195,    0,    0, 2195,    0, 2195,
 2195,    0,    0, 2195, 2195, 2195,    0, 2195, 2195, 2195,
 2195, 2195, 2195, 2195,    0,    0,    0, 2195, 2195, 2195,
 2195, 2195,    0,    0,    0, 2195,    0,    0,    0,    0,
    0,    0,    0, 2195, 2195, 2195, 2195, 2195, 2195,    0,
    0,    0, 2195, 2195,    0, 2195,    0, 2195,    0, 2195,
 2195, 2195,    0, 2195,    0, 2195, 2195, 2195,    0, 2195,
 2195, 2195, 2195, 2195,    0, 2195, 2195,    0,    0,    0,
    0, 2195,    0, 2195, 2195,    0,    0, 2195, 2195, 2195,
    0,    0, 2195,    0, 2195,    0,    0, 2195, 2195, 2195,
 2195,    0, 2195,    0, 2195,    0, 2195, 2195, 2195, 2195,
 2195,    0,    0, 2195, 2195, 2195,    0, 2195, 2195,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2195, 2195,
 2195,    0, 2195, 2195, 2195,    0,    0,    0,    0,    0,
 2195,    0,    0,    0, 2195,    0, 2195, 2195, 2195, 2195,
    0, 2195,    0, 2195, 2195, 2195, 2195, 2195, 2195, 2195,
 2195,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2195, 2195,    0, 2195, 2195, 2195,    0,    0, 1430,    0,
 2195, 2195, 2195, 2195, 2195,    0, 2195,    0,    0, 2195,
 2195,    0,    0,    0, 2195, 2195,    0,    0, 2195, 2195,
 2195, 2195, 2195, 2195, 2195, 2195, 2195,    0, 2195,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2195, 2195,
 2195, 2195, 2195, 2195, 2195, 2195, 2195, 2195, 2195, 2195,
 2195, 2195, 2195, 2195, 2195, 2195, 2195, 2195, 2195,    0,
 2195, 2195, 2195, 2195, 2195, 2195,    0, 2195, 2195, 2195,
 2195,    0, 2195,    0, 2195, 2195, 2195, 2195, 2195, 2195,
 2195, 2195, 2195, 2195, 2195, 2195, 2195, 2195, 2195, 2195,
 2195, 2195,    0, 2195, 2195, 2195, 2195,    0, 2195, 2195,
 2195, 2195, 2195,    0, 2195, 2195, 2195, 2195, 2195, 2195,
 2195, 2195, 2195, 2195, 2195, 2195, 2195, 2195, 2195, 2195,
 2195, 2195, 2195, 2195, 2195, 2195, 2195, 2195, 2195, 2195,
 2195, 2195, 2195,    0, 2195, 2195,    0,    0,    0, 2195,
 2195, 2195, 2195, 2195, 2195,    0,    0, 2195, 2195, 2195,
 2195, 2195, 2195, 2195, 2195, 2195, 2953,    0,    0,    0,
    0, 2195,    0, 2195, 2195, 2195, 2195, 2195, 2195,    0,
 2195,    0,    0,    0,    0, 1432, 1431, 1433,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2195, 2195,    0,
 2195, 2195, 2195, 2195, 2195, 2195, 2195, 2195, 2195,    0,
 2195, 2195, 2195, 2195, 2195, 2195, 2195, 2195, 2195, 2195,
 2195, 2195,    0, 2195, 2195, 2195,    0, 2195,    0,    0,
    0, 2195, 2195, 2195, 2195, 2195, 2195, 2195, 2195, 2195,
 2195, 2195, 2195, 2195, 2197, 2195, 2195,    0,    0,    0,
    0,    0, 2195, 2195, 2195, 2195, 2195, 2195, 2195, 2195,
 2195, 2195, 2195, 2195, 2195, 2195, 2195, 2195, 2195, 2195,
    0,    0, 2195,    0, 2195, 2195, 2195, 2195, 2195, 2195,
 2195, 2195, 2195,    0, 1916, 2197, 2197, 2197, 2197, 2197,
 2197, 2197,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2197, 2197, 2197, 2197, 2197,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2197,    0, 2197,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1416,    0,    0,
    0,    0,    0,    0,    0,    0, 1417,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1418,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1419,    0,    0,    0,    0,    0,    0,
 1420,    0,    0,    0,    0,    0,    0,    0, 1421,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1422,    0, 1423,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1424,    0, 1425,
 1426, 1427,    0,    0,    0,    0, 1428,    0,    0,    0,
    0, 2197,    0, 2197,    0,    0, 2197,    0, 2197, 2197,
 2197,    0, 2197, 2197,    0, 2197,    0,    0,    0,    0,
    0, 2197,    0, 2197, 2197, 2197, 2197,    0, 2197,    0,
    0, 2197,    0,    0, 2197,    0,    0, 1429,    0,    0,
    0, 2197,    0, 2197, 2197,    0, 2197, 2197, 2197, 2197,
 2197,    0,    0, 2197,    0,    0, 2197,    0, 2197, 2197,
    0,    0, 2197, 2197, 2197,    0, 2197, 2197, 2197, 2197,
 2197, 2197, 2197,    0,    0,    0, 2197, 2197, 2197, 2197,
 2197,    0,    0,    0, 2197,    0,    0,    0,    0,    0,
    0,    0, 2197, 2197, 2197, 2197, 2197, 2197,    0,    0,
    0, 2197, 2197,    0, 2197,    0, 2197,    0, 2197, 2197,
 2197,    0, 2197,    0, 2197, 2197, 2197,    0, 2197, 2197,
 2197, 2197, 2197,    0, 2197, 2197,    0,    0,    0,    0,
 2197,    0, 2197, 2197,    0,    0, 2197, 2197, 2197,    0,
    0, 2197,    0, 2197,    0,    0, 2197, 2197, 2197, 2197,
    0, 2197,    0, 2197,    0, 2197, 2197, 2197, 2197, 2197,
    0,    0, 2197, 2197, 2197,    0, 2197, 2197,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2197, 2197, 2197,
    0, 2197, 2197, 2197,    0,    0,    0,    0,    0, 2197,
    0,    0,    0, 2197,    0, 2197, 2197, 2197, 2197,    0,
 2197,    0, 2197, 2197, 2197, 2197, 2197, 2197, 2197, 2197,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2197,
 2197,    0, 2197, 2197, 2197,    0,    0, 1430,    0, 2197,
 2197, 2197, 2197, 2197,    0, 2197,    0,    0, 2197, 2197,
    0,    0,    0, 2197, 2197,    0,    0, 2197, 2197, 2197,
 2197, 2197, 2197, 2197, 2197, 2197,    0, 2197,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2197, 2197, 2197,
 2197, 2197, 2197, 2197, 2197, 2197, 2197, 2197, 2197, 2197,
 2197, 2197, 2197, 2197, 2197, 2197, 2197, 2197,    0, 2197,
 2197, 2197, 2197, 2197, 2197,    0, 2197, 2197, 2197, 2197,
    0, 2197,    0, 2197, 2197, 2197, 2197, 2197, 2197, 2197,
 2197, 2197, 2197, 2197, 2197, 2197, 2197, 2197, 2197, 2197,
 2197,    0, 2197, 2197, 2197, 2197,    0, 2197, 2197, 2197,
 2197, 2197,    0, 2197, 2197, 2197, 2197, 2197, 2197, 2197,
 2197, 2197, 2197, 2197, 2197, 2197, 2197, 2197, 2197, 2197,
 2197, 2197, 2197, 2197, 2197, 2197, 2197, 2197, 2197, 2197,
 2197, 2197,    0, 2197, 2197,    0,    0,    0, 2197, 2197,
 2197, 2197, 2197, 2197,    0,    0, 2197, 2197, 2197, 2197,
 2197, 2197, 2197, 2197, 2197, 2954,    0,    0,    0,    0,
 2197,    0, 2197, 2197, 2197, 2197, 2197, 2197,    0, 2197,
    0,    0,    0,    0, 1432, 1431, 1433,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2197, 2197,    0, 2197,
 2197, 2197, 2197, 2197, 2197, 2197, 2197, 2197,    0, 2197,
 2197, 2197, 2197, 2197, 2197, 2197, 2197, 2197, 2197, 2197,
 2197,    0, 2197, 2197, 2197,    0, 2197,    0,    0,    0,
 2197, 2197, 2197, 2197, 2197, 2197, 2197, 2197, 2197, 2197,
 2197, 2197, 2197, 2203, 2197, 2197,    0,    0,    0,    0,
    0, 2197, 2197, 2197, 2197, 2197, 2197, 2197, 2197, 2197,
 2197, 2197, 2197, 2197, 2197, 2197, 2197, 2197, 2197,    0,
    0, 2197,    0, 2197, 2197, 2197, 2197, 2197, 2197, 2197,
 2197, 2197,    0, 1955, 2203, 2203, 2203, 2203, 2203, 2203,
 2203,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2203, 2203, 2203, 2203, 2203,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2203,    0, 2203,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1416,    0,    0,    0,
    0,    0,    0,    0,    0, 1417,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1418,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1419,    0,    0,    0,    0,    0,    0, 1420,
    0,    0,    0,    0,    0,    0,    0, 1421,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1422,    0, 1423,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1424,    0, 1425, 1426,
 1427,    0,    0,    0,    0, 1428,    0,    0,    0,    0,
 2203,    0, 2203,    0,    0, 2203,    0, 2203, 2203, 2203,
    0, 2203, 2203,    0, 2203,    0,    0,    0,    0,    0,
 2203,    0, 2203, 2203, 2203, 2203,    0, 2203,    0,    0,
 2203,    0,    0, 2203,    0,    0, 1429,    0,    0,    0,
 2203,    0, 2203, 2203,    0, 2203, 2203, 2203, 2203, 2203,
    0,    0, 2203,    0,    0, 2203,    0, 2203, 2203,    0,
    0, 2203, 2203, 2203,    0, 2203, 2203, 2203, 2203, 2203,
 2203, 2203,    0,    0,    0, 2203, 2203, 2203, 2203, 2203,
    0,    0,    0, 2203,    0,    0,    0,    0,    0,    0,
    0, 2203, 2203, 2203, 2203, 2203, 2203,    0,    0,    0,
 2203, 2203,    0, 2203,    0, 2203,    0, 2203, 2203, 2203,
    0, 2203,    0, 2203, 2203, 2203,    0, 2203, 2203, 2203,
 2203, 2203,    0, 2203, 2203,    0,    0,    0,    0, 2203,
    0, 2203, 2203,    0,    0, 2203, 2203, 2203,    0,    0,
 2203,    0, 2203,    0,    0, 2203, 2203, 2203, 2203,    0,
 2203,    0, 2203,    0, 2203, 2203, 2203, 2203, 2203,    0,
    0, 2203, 2203, 2203,    0, 2203, 2203,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2203, 2203, 2203,    0,
 2203, 2203, 2203,    0,    0,    0,    0,    0, 2203,    0,
    0,    0, 2203,    0, 2203, 2203, 2203, 2203,    0, 2203,
    0, 2203, 2203, 2203, 2203, 2203, 2203, 2203, 2203,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2203, 2203,
    0, 2203, 2203, 2203,    0,    0, 1430,    0, 2203, 2203,
 2203, 2203, 2203,    0, 2203,    0,    0, 2203, 2203,    0,
    0,    0, 2203, 2203,    0,    0, 2203, 2203, 2203, 2203,
 2203, 2203, 2203, 2203, 2203,    0, 2203,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2203, 2203, 2203, 2203,
 2203, 2203, 2203, 2203, 2203, 2203, 2203, 2203, 2203, 2203,
 2203, 2203, 2203, 2203, 2203, 2203, 2203,    0, 2203, 2203,
 2203, 2203, 2203, 2203,    0, 2203, 2203, 2203, 2203,    0,
 2203,    0, 2203, 2203, 2203, 2203, 2203, 2203, 2203, 2203,
 2203, 2203, 2203, 2203, 2203, 2203, 2203, 2203, 2203, 2203,
    0, 2203, 2203, 2203, 2203,    0, 2203, 2203, 2203, 2203,
 2203,    0, 2203, 2203, 2203, 2203, 2203, 2203, 2203, 2203,
 2203, 2203, 2203, 2203, 2203, 2203, 2203, 2203, 2203, 2203,
 2203, 2203, 2203, 2203, 2203, 2203, 2203, 2203, 2203, 2203,
 2203,    0, 2203, 2203,    0,    0,    0, 2203, 2203, 2203,
 2203, 2203, 2203,    0,    0, 2203, 2203, 2203, 2203, 2203,
 2203, 2203, 2203, 2203, 2955,    0,    0,    0,    0, 2203,
    0, 2203, 2203, 2203, 2203, 2203, 2203,    0, 2203,    0,
    0,    0,    0, 1432, 1431, 1433,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2203, 2203,    0, 2203, 2203,
 2203, 2203, 2203, 2203, 2203, 2203, 2203,    0, 2203, 2203,
 2203, 2203, 2203, 2203, 2203, 2203, 2203, 2203, 2203, 2203,
    0, 2203, 2203, 2203,    0, 2203,    0,    0,    0, 2203,
 2203, 2203, 2203, 2203, 2203, 2203, 2203, 2203, 2203, 2203,
 2203, 2203, 2210, 2203, 2203,    0,    0,    0,    0,    0,
 2203, 2203, 2203, 2203, 2203, 2203, 2203, 2203, 2203, 2203,
 2203, 2203, 2203, 2203, 2203, 2203, 2203, 2203,    0,    0,
 2203,    0, 2203, 2203, 2203, 2203, 2203, 2203, 2203, 2203,
 2203,    0, 1909, 2210, 2210, 2210, 2210, 2210, 2210, 2210,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2210, 2210, 2210, 2210, 2210,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2210,    0, 2210,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1416,    0,    0,    0,    0,
    0,    0,    0,    0, 1417,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1418,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1419,    0,    0,    0,    0,    0,    0, 1420,    0,
    0,    0,    0,    0,    0,    0, 1421,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1422,    0, 1423,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1424,    0, 1425, 1426, 1427,
    0,    0,    0,    0, 1428,    0,    0,    0,    0, 2210,
    0, 2210,    0,    0, 2210,    0, 2210, 2210, 2210,    0,
 2210, 2210,    0, 2210,    0,    0,    0,    0,    0, 2210,
    0, 2210, 2210, 2210, 2210,    0, 2210,    0,    0, 2210,
    0,    0, 2210,    0,    0, 1429,    0,    0,    0, 2210,
    0, 2210, 2210,    0, 2210, 2210, 2210, 2210, 2210,    0,
    0, 2210,    0,    0, 2210,    0, 2210, 2210,    0,    0,
 2210, 2210, 2210,    0, 2210, 2210, 2210, 2210, 2210, 2210,
 2210,    0,    0,    0, 2210, 2210, 2210, 2210, 2210,    0,
    0,    0, 2210,    0,    0,    0,    0,    0,    0,    0,
 2210, 2210, 2210, 2210, 2210, 2210,    0,    0,    0, 2210,
 2210,    0, 2210,    0, 2210,    0, 2210, 2210, 2210,    0,
 2210,    0, 2210, 2210, 2210,    0, 2210, 2210, 2210, 2210,
 2210,    0, 2210, 2210,    0,    0,    0,    0, 2210,    0,
 2210, 2210,    0,    0, 2210, 2210, 2210,    0,    0, 2210,
    0, 2210,    0,    0, 2210, 2210, 2210, 2210,    0, 2210,
    0, 2210,    0, 2210, 2210, 2210, 2210, 2210,    0,    0,
 2210, 2210, 2210,    0, 2210, 2210,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2210, 2210, 2210,    0, 2210,
 2210, 2210,    0,    0,    0,    0,    0, 2210,    0,    0,
    0, 2210,    0, 2210, 2210, 2210, 2210,    0, 2210,    0,
 2210, 2210, 2210, 2210, 2210, 2210, 2210, 2210,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2210, 2210,    0,
 2210, 2210, 2210,    0,    0, 1430,    0, 2210, 2210, 2210,
 2210, 2210,    0, 2210,    0,    0, 2210, 2210,    0,    0,
    0, 2210, 2210,    0,    0, 2210, 2210, 2210, 2210, 2210,
 2210, 2210, 2210, 2210,    0, 2210,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2210, 2210, 2210, 2210, 2210,
 2210, 2210, 2210, 2210, 2210, 2210, 2210, 2210, 2210, 2210,
 2210, 2210, 2210, 2210, 2210, 2210,    0, 2210, 2210, 2210,
 2210, 2210, 2210,    0, 2210, 2210, 2210, 2210,    0, 2210,
    0, 2210, 2210, 2210, 2210, 2210, 2210, 2210, 2210, 2210,
 2210, 2210, 2210, 2210, 2210, 2210, 2210, 2210, 2210,    0,
 2210, 2210, 2210, 2210,    0, 2210, 2210, 2210, 2210, 2210,
    0, 2210, 2210, 2210, 2210, 2210, 2210, 2210, 2210, 2210,
 2210, 2210, 2210, 2210, 2210, 2210, 2210, 2210, 2210, 2210,
 2210, 2210, 2210, 2210, 2210, 2210, 2210, 2210, 2210, 2210,
    0, 2210, 2210,    0,    0,    0, 2210, 2210, 2210, 2210,
 2210, 2210,    0,    0, 2210, 2210, 2210, 2210, 2210, 2210,
 2210, 2210, 2210, 2956,    0,    0,    0,    0, 2210,    0,
 2210, 2210, 2210, 2210, 2210, 2210,    0, 2210,    0,    0,
    0,    0, 1432, 1431, 1433,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2210, 2210,    0, 2210, 2210, 2210,
 2210, 2210, 2210, 2210, 2210, 2210,    0, 2210, 2210, 2210,
 2210, 2210, 2210, 2210, 2210, 2210, 2210, 2210, 2210,    0,
 2210, 2210, 2210,    0, 2210,    0,    0,    0, 2210, 2210,
 2210, 2210, 2210, 2210, 2210, 2210, 2210, 2210, 2210, 2210,
 2210, 2278, 2210, 2210,    0,    0,    0,    0,    0, 2210,
 2210, 2210, 2210, 2210, 2210, 2210, 2210, 2210, 2210, 2210,
 2210, 2210, 2210, 2210, 2210, 2210, 2210,    0,    0, 2210,
    0, 2210, 2210, 2210, 2210, 2210, 2210, 2210, 2210, 2210,
    0, 2002, 2278, 2278, 2278, 2278, 2278, 2278, 2278,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2278,
 2278, 2278, 2278, 2278,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2278,    0, 2278,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1416,    0,    0,    0,    0,    0,
    0,    0,    0, 1417,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1418,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1419,    0,    0,    0,    0,    0,    0, 1420,    0,    0,
    0,    0,    0,    0,    0, 1421,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1422,    0, 1423,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1424,    0, 1425, 1426, 1427,    0,
    0,    0,    0, 1428,    0,    0,    0,    0, 2278,    0,
 2278,    0,    0, 2278,    0, 2278, 2278, 2278,    0, 2278,
 2278,    0, 2278,    0,    0,    0,    0,    0, 2278,    0,
 2278, 2278, 2278, 2278,    0, 2278,    0,    0, 2278,    0,
    0, 2278,    0,    0, 1429,    0,    0,    0, 2278,    0,
 2278, 2278,    0, 2278, 2278, 2278, 2278, 2278,    0,    0,
 2278,    0,    0, 2278,    0, 2278, 2278,    0,    0, 2278,
 2278, 2278,    0, 2278, 2278, 2278, 2278, 2278, 2278, 2278,
    0,    0,    0, 2278, 2278, 2278, 2278, 2278,    0,    0,
    0, 2278,    0,    0,    0,    0,    0,    0,    0, 2278,
 2278, 2278, 2278, 2278, 2278,    0,    0,    0, 2278, 2278,
    0, 2278,    0, 2278,    0, 2278, 2278, 2278,    0, 2278,
    0, 2278, 2278, 2278,    0, 2278, 2278, 2278, 2278, 2278,
    0, 2278, 2278,    0,    0,    0,    0, 2278,    0, 2278,
 2278,    0,    0, 2278, 2278, 2278,    0,    0, 2278,    0,
 2278,    0,    0, 2278, 2278, 2278, 2278,    0, 2278,    0,
 2278,    0, 2278, 2278, 2278, 2278, 2278,    0,    0, 2278,
 2278, 2278,    0, 2278, 2278,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2278, 2278, 2278,    0, 2278, 2278,
 2278,    0,    0,    0,    0,    0, 2278,    0,    0,    0,
 2278,    0, 2278, 2278, 2278, 2278,    0, 2278,    0, 2278,
 2278, 2278, 2278, 2278, 2278, 2278, 2278,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2278, 2278,    0, 2278,
 2278, 2278,    0,    0, 1430,    0, 2278, 2278, 2278, 2278,
 2278,    0, 2278,    0,    0, 2278, 2278,    0,    0,    0,
 2278, 2278,    0,    0, 2278, 2278, 2278, 2278, 2278, 2278,
 2278, 2278, 2278,    0, 2278,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2278, 2278, 2278, 2278, 2278, 2278,
 2278, 2278, 2278, 2278, 2278, 2278, 2278, 2278, 2278, 2278,
 2278, 2278, 2278, 2278, 2278,    0, 2278, 2278, 2278, 2278,
 2278, 2278,    0, 2278, 2278, 2278, 2278,    0, 2278,    0,
 2278, 2278, 2278, 2278, 2278, 2278, 2278, 2278, 2278, 2278,
 2278, 2278, 2278, 2278, 2278, 2278, 2278, 2278,    0, 2278,
 2278, 2278, 2278,    0, 2278, 2278, 2278, 2278, 2278,    0,
 2278, 2278, 2278, 2278, 2278, 2278, 2278, 2278, 2278, 2278,
 2278, 2278, 2278, 2278, 2278, 2278, 2278, 2278, 2278, 2278,
 2278, 2278, 2278, 2278, 2278, 2278, 2278, 2278, 2278,    0,
 2278, 2278,    0,    0,    0, 2278, 2278, 2278, 2278, 2278,
 2278,    0,    0, 2278, 2278, 2278, 2278, 2278, 2278, 2278,
 2278, 2278, 2957,    0,    0,    0,    0, 2278,    0, 2278,
 2278, 2278, 2278, 2278, 2278,    0, 2278,    0,    0,    0,
    0, 1432, 1431, 1433,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2278, 2278,    0, 2278, 2278, 2278, 2278,
 2278, 2278, 2278, 2278, 2278,    0, 2278, 2278, 2278, 2278,
 2278, 2278, 2278, 2278, 2278, 2278, 2278, 2278,    0, 2278,
 2278, 2278,    0, 2278,    0,    0,    0, 2278, 2278, 2278,
 2278, 2278, 2278, 2278, 2278, 2278, 2278, 2278, 2278, 2278,
 2279, 2278, 2278,    0,    0,    0,    0,    0, 2278, 2278,
 2278, 2278, 2278, 2278, 2278, 2278, 2278, 2278, 2278, 2278,
 2278, 2278, 2278, 2278, 2278, 2278,    0,    0, 2278,    0,
 2278, 2278, 2278, 2278, 2278, 2278, 2278, 2278, 2278,    0,
 2001, 2279, 2279, 2279, 2279, 2279, 2279, 2279,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2279, 2279,
 2279, 2279, 2279,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2279,    0, 2279,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1416,    0,    0,    0,    0,    0,    0,
    0,    0, 1417,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1418,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1419,
    0,    0,    0,    0,    0,    0, 1420,    0,    0,    0,
    0,    0,    0,    0, 1421,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1422,    0, 1423,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1424,    0, 1425, 1426, 1427,    0,    0,
    0,    0, 1428,    0,    0,    0,    0, 2279,    0, 2279,
    0,    0, 2279,    0, 2279, 2279, 2279,    0, 2279, 2279,
    0, 2279,    0,    0,    0,    0,    0, 2279,    0, 2279,
 2279, 2279, 2279,    0, 2279,    0,    0, 2279,    0,    0,
 2279,    0,    0, 1429,    0,    0,    0, 2279,    0, 2279,
 2279,    0, 2279, 2279, 2279, 2279, 2279,    0,    0, 2279,
    0,    0, 2279,    0, 2279, 2279,    0,    0, 2279, 2279,
 2279,    0, 2279, 2279, 2279, 2279, 2279, 2279, 2279,    0,
    0,    0, 2279, 2279, 2279, 2279, 2279,    0,    0,    0,
 2279,    0,    0,    0,    0,    0,    0,    0, 2279, 2279,
 2279, 2279, 2279, 2279,    0,    0,    0, 2279, 2279,    0,
 2279,    0, 2279,    0, 2279, 2279, 2279,    0, 2279,    0,
 2279, 2279, 2279,    0, 2279, 2279, 2279, 2279, 2279,    0,
 2279, 2279,    0,    0,    0,    0, 2279,    0, 2279, 2279,
    0,    0, 2279, 2279, 2279,    0,    0, 2279,    0, 2279,
    0,    0, 2279, 2279, 2279, 2279,    0, 2279,    0, 2279,
    0, 2279, 2279, 2279, 2279, 2279,    0,    0, 2279, 2279,
 2279,    0, 2279, 2279,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2279, 2279, 2279,    0, 2279, 2279, 2279,
    0,    0,    0,    0,    0, 2279,    0,    0,    0, 2279,
    0, 2279, 2279, 2279, 2279,    0, 2279,    0, 2279, 2279,
 2279, 2279, 2279, 2279, 2279, 2279,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2279, 2279,    0, 2279, 2279,
 2279,    0,    0, 1430,    0, 2279, 2279, 2279, 2279, 2279,
    0, 2279,    0,    0, 2279, 2279,    0,    0,    0, 2279,
 2279,    0,    0, 2279, 2279, 2279, 2279, 2279, 2279, 2279,
 2279, 2279,    0, 2279,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2279, 2279, 2279, 2279, 2279, 2279, 2279,
 2279, 2279, 2279, 2279, 2279, 2279, 2279, 2279, 2279, 2279,
 2279, 2279, 2279, 2279,    0, 2279, 2279, 2279, 2279, 2279,
 2279,    0, 2279, 2279, 2279, 2279,    0, 2279,    0, 2279,
 2279, 2279, 2279, 2279, 2279, 2279, 2279, 2279, 2279, 2279,
 2279, 2279, 2279, 2279, 2279, 2279, 2279,    0, 2279, 2279,
 2279, 2279,    0, 2279, 2279, 2279, 2279, 2279,    0, 2279,
 2279, 2279, 2279, 2279, 2279, 2279, 2279, 2279, 2279, 2279,
 2279, 2279, 2279, 2279, 2279, 2279, 2279, 2279, 2279, 2279,
 2279, 2279, 2279, 2279, 2279, 2279, 2279, 2279,    0, 2279,
 2279,    0,    0,    0, 2279, 2279, 2279, 2279, 2279, 2279,
    0,    0, 2279, 2279, 2279, 2279, 2279, 2279, 2279, 2279,
 2279, 2958,    0,    0,    0,    0, 2279,    0, 2279, 2279,
 2279, 2279, 2279, 2279,    0, 2279,    0,    0,    0,    0,
 1432, 1431, 1433,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2279, 2279,    0, 2279, 2279, 2279, 2279, 2279,
 2279, 2279, 2279, 2279,    0, 2279, 2279, 2279, 2279, 2279,
 2279, 2279, 2279, 2279, 2279, 2279, 2279,    0, 2279, 2279,
 2279,    0, 2279,    0,    0,    0, 2279, 2279, 2279, 2279,
 2279, 2279, 2279, 2279, 2279, 2279, 2279, 2279, 2279, 2272,
 2279, 2279,    0,    0,    0,    0,    0, 2279, 2279, 2279,
 2279, 2279, 2279, 2279, 2279, 2279, 2279, 2279, 2279, 2279,
 2279, 2279, 2279, 2279, 2279,    0,    0, 2279,    0, 2279,
 2279, 2279, 2279, 2279, 2279, 2279, 2279, 2279,    0, 1898,
 2272, 2272, 2272, 2272, 2272, 2272, 2272,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2272, 2272, 2272,
 2272, 2272,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2272,    0, 2272,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1416,    0,    0,    0,    0,    0,    0,    0,
    0, 1417,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1418,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1419,    0,
    0,    0,    0,    0,    0, 1420,    0,    0,    0,    0,
    0,    0,    0, 1421,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1422,    0, 1423,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1424,    0, 1425, 1426, 1427,    0,    0,    0,
    0, 1428,    0,    0,    0,    0, 2272,    0, 2272,    0,
    0, 2272,    0, 2272, 2272, 2272,    0, 2272, 2272,    0,
 2272,    0,    0,    0,    0,    0, 2272,    0, 2272, 2272,
 2272, 2272,    0, 2272,    0,    0, 2272,    0,    0, 2272,
    0,    0, 1429,    0,    0,    0, 2272,    0, 2272, 2272,
    0, 2272, 2272, 2272, 2272, 2272,    0,    0, 2272,    0,
    0, 2272,    0, 2272, 2272,    0,    0, 2272, 2272, 2272,
    0, 2272, 2272, 2272, 2272, 2272, 2272, 2272,    0,    0,
    0, 2272, 2272, 2272, 2272, 2272,    0,    0,    0, 2272,
    0,    0,    0,    0,    0,    0,    0, 2272, 2272, 2272,
 2272, 2272, 2272,    0,    0,    0, 2272, 2272,    0, 2272,
    0, 2272,    0, 2272, 2272, 2272,    0, 2272,    0, 2272,
 2272, 2272,    0, 2272, 2272, 2272, 2272, 2272,    0, 2272,
 2272,    0,    0,    0,    0, 2272,    0, 2272, 2272,    0,
    0, 2272, 2272, 2272,    0,    0, 2272,    0, 2272,    0,
    0, 2272, 2272, 2272, 2272,    0, 2272,    0, 2272,    0,
 2272, 2272, 2272, 2272, 2272,    0,    0, 2272, 2272, 2272,
    0, 2272, 2272,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2272, 2272, 2272,    0, 2272, 2272, 2272,    0,
    0,    0,    0,    0, 2272,    0,    0,    0, 2272,    0,
 2272, 2272, 2272, 2272,    0, 2272,    0, 2272, 2272, 2272,
 2272, 2272, 2272, 2272, 2272,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2272, 2272,    0, 2272, 2272, 2272,
    0,    0, 1430,    0, 2272, 2272, 2272, 2272, 2272,    0,
 2272,    0,    0, 2272, 2272,    0,    0,    0, 2272, 2272,
    0,    0, 2272, 2272, 2272, 2272, 2272, 2272, 2272, 2272,
 2272,    0, 2272,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2272, 2272, 2272, 2272, 2272, 2272, 2272, 2272,
 2272, 2272, 2272, 2272, 2272, 2272, 2272, 2272, 2272, 2272,
 2272, 2272, 2272,    0, 2272, 2272, 2272, 2272, 2272, 2272,
    0, 2272, 2272, 2272, 2272,    0, 2272,    0, 2272, 2272,
 2272, 2272, 2272, 2272, 2272, 2272, 2272, 2272, 2272, 2272,
 2272, 2272, 2272, 2272, 2272, 2272,    0, 2272, 2272, 2272,
 2272,    0, 2272, 2272, 2272, 2272, 2272,    0, 2272, 2272,
 2272, 2272, 2272, 2272, 2272, 2272, 2272, 2272, 2272, 2272,
 2272, 2272, 2272, 2272, 2272, 2272, 2272, 2272, 2272, 2272,
 2272, 2272, 2272, 2272, 2272, 2272, 2272,    0, 2272, 2272,
    0,    0,    0, 2272, 2272, 2272, 2272, 2272, 2272,    0,
    0, 2272, 2272, 2272, 2272, 2272, 2272, 2272, 2272, 2272,
 2959,    0,    0,    0,    0, 2272,    0, 2272, 2272, 2272,
 2272, 2272, 2272,    0, 2272,    0,    0,    0,    0, 1432,
 1431, 1433,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2272, 2272,    0, 2272, 2272, 2272, 2272, 2272, 2272,
 2272, 2272, 2272,    0, 2272, 2272, 2272, 2272, 2272, 2272,
 2272, 2272, 2272, 2272, 2272, 2272,    0, 2272, 2272, 2272,
    0, 2272,    0,    0,    0, 2272, 2272, 2272, 2272, 2272,
 2272, 2272, 2272, 2272, 2272, 2272, 2272, 2272, 2273, 2272,
 2272,    0,    0,    0,    0,    0, 2272, 2272, 2272, 2272,
 2272, 2272, 2272, 2272, 2272, 2272, 2272, 2272, 2272, 2272,
 2272, 2272, 2272, 2272,    0,    0, 2272,    0, 2272, 2272,
 2272, 2272, 2272, 2272, 2272, 2272, 2272,    0, 1902, 2273,
 2273, 2273, 2273, 2273, 2273, 2273,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2273, 2273, 2273, 2273,
 2273,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2273,
    0, 2273,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1416,    0,    0,    0,    0,    0,    0,    0,    0,
 1417,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1418,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1419,    0,    0,
    0,    0,    0,    0, 1420,    0,    0,    0,    0,    0,
    0,    0, 1421,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1422,
    0, 1423,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1424,    0, 1425, 1426, 1427,    0,    0,    0,    0,
 1428,    0,    0,    0,    0, 2273,    0, 2273,    0,    0,
 2273,    0, 2273, 2273, 2273,    0, 2273, 2273,    0, 2273,
    0,    0,    0,    0,    0, 2273,    0, 2273, 2273, 2273,
 2273,    0, 2273,    0,    0, 2273,    0,    0, 2273,    0,
    0, 1429,    0,    0,    0, 2273,    0, 2273, 2273,    0,
 2273, 2273, 2273, 2273, 2273,    0,    0, 2273,    0,    0,
 2273,    0, 2273, 2273,    0,    0, 2273, 2273, 2273,    0,
 2273, 2273, 2273, 2273, 2273, 2273, 2273,    0,    0,    0,
 2273, 2273, 2273, 2273, 2273,    0,    0,    0, 2273,    0,
    0,    0,    0,    0,    0,    0, 2273, 2273, 2273, 2273,
 2273, 2273,    0,    0,    0, 2273, 2273,    0, 2273,    0,
 2273,    0, 2273, 2273, 2273,    0, 2273,    0, 2273, 2273,
 2273,    0, 2273, 2273, 2273, 2273, 2273,    0, 2273, 2273,
    0,    0,    0,    0, 2273,    0, 2273, 2273,    0,    0,
 2273, 2273, 2273,    0,    0, 2273,    0, 2273,    0,    0,
 2273, 2273, 2273, 2273,    0, 2273,    0, 2273,    0, 2273,
 2273, 2273, 2273, 2273,    0,    0, 2273, 2273, 2273,    0,
 2273, 2273,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2273, 2273, 2273,    0, 2273, 2273, 2273,    0,    0,
    0,    0,    0, 2273,    0,    0,    0, 2273,    0, 2273,
 2273, 2273, 2273,    0, 2273,    0, 2273, 2273, 2273, 2273,
 2273, 2273, 2273, 2273,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2273, 2273,    0, 2273, 2273, 2273,    0,
    0, 1430,    0, 2273, 2273, 2273, 2273, 2273,    0, 2273,
    0,    0, 2273, 2273,    0,    0,    0, 2273, 2273,    0,
    0, 2273, 2273, 2273, 2273, 2273, 2273, 2273, 2273, 2273,
    0, 2273,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2273, 2273, 2273, 2273, 2273, 2273, 2273, 2273, 2273,
 2273, 2273, 2273, 2273, 2273, 2273, 2273, 2273, 2273, 2273,
 2273, 2273,    0, 2273, 2273, 2273, 2273, 2273, 2273,    0,
 2273, 2273, 2273, 2273,    0, 2273,    0, 2273, 2273, 2273,
 2273, 2273, 2273, 2273, 2273, 2273, 2273, 2273, 2273, 2273,
 2273, 2273, 2273, 2273, 2273,    0, 2273, 2273, 2273, 2273,
    0, 2273, 2273, 2273, 2273, 2273,    0, 2273, 2273, 2273,
 2273, 2273, 2273, 2273, 2273, 2273, 2273, 2273, 2273, 2273,
 2273, 2273, 2273, 2273, 2273, 2273, 2273, 2273, 2273, 2273,
 2273, 2273, 2273, 2273, 2273, 2273,    0, 2273, 2273,    0,
    0,    0, 2273, 2273, 2273, 2273, 2273, 2273,    0,    0,
 2273, 2273, 2273, 2273, 2273, 2273, 2273, 2273, 2273, 2960,
    0,    0,    0,    0, 2273,    0, 2273, 2273, 2273, 2273,
 2273, 2273,    0, 2273,    0,    0,    0,    0, 1432, 1431,
 1433,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2273, 2273,    0, 2273, 2273, 2273, 2273, 2273, 2273, 2273,
 2273, 2273,    0, 2273, 2273, 2273, 2273, 2273, 2273, 2273,
 2273, 2273, 2273, 2273, 2273,    0, 2273, 2273, 2273,    0,
 2273,    0,    0,    0, 2273, 2273, 2273, 2273, 2273, 2273,
 2273, 2273, 2273, 2273, 2273, 2273, 2273, 2274, 2273, 2273,
    0,    0,    0,    0,    0, 2273, 2273, 2273, 2273, 2273,
 2273, 2273, 2273, 2273, 2273, 2273, 2273, 2273, 2273, 2273,
 2273, 2273, 2273,    0,    0, 2273,    0, 2273, 2273, 2273,
 2273, 2273, 2273, 2273, 2273, 2273,    0, 1905, 2274, 2274,
 2274, 2274, 2274, 2274, 2274,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2274, 2274, 2274, 2274, 2274,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2274,    0,
 2274,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1416,    0,    0,    0,    0,    0,    0,    0,    0, 1417,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1418,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1419,    0,    0,    0,
    0,    0,    0, 1420,    0,    0,    0,    0,    0,    0,
    0, 1421,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1422,    0,
 1423,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1424,    0, 1425, 1426, 1427,    0,    0,    0,    0, 1428,
    0,    0,    0,    0, 2274,    0, 2274,    0,    0, 2274,
    0, 2274, 2274, 2274,    0, 2274, 2274,    0, 2274,    0,
    0,    0,    0,    0, 2274,    0, 2274, 2274, 2274, 2274,
    0, 2274,    0,    0, 2274,    0,    0, 2274,    0,    0,
 1429,    0,    0,    0, 2274,    0, 2274, 2274,    0, 2274,
 2274, 2274, 2274, 2274,    0,    0, 2274,    0,    0, 2274,
    0, 2274, 2274,    0,    0, 2274, 2274, 2274,    0, 2274,
 2274, 2274, 2274, 2274, 2274, 2274,    0,    0,    0, 2274,
 2274, 2274, 2274, 2274,    0,    0,    0, 2274,    0,    0,
    0,    0,    0,    0,    0, 2274, 2274, 2274, 2274, 2274,
 2274,    0,    0,    0, 2274, 2274,    0, 2274,    0, 2274,
    0, 2274, 2274, 2274,    0, 2274,    0, 2274, 2274, 2274,
    0, 2274, 2274, 2274, 2274, 2274,    0, 2274, 2274,    0,
    0,    0,    0, 2274,    0, 2274, 2274,    0,    0, 2274,
 2274, 2274,    0,    0, 2274,    0, 2274,    0,    0, 2274,
 2274, 2274, 2274,    0, 2274,    0, 2274,    0, 2274, 2274,
 2274, 2274, 2274,    0,    0, 2274, 2274, 2274,    0, 2274,
 2274,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2274, 2274, 2274,    0, 2274, 2274, 2274,    0,    0,    0,
    0,    0, 2274,    0,    0,    0, 2274,    0, 2274, 2274,
 2274, 2274,    0, 2274,    0, 2274, 2274, 2274, 2274, 2274,
 2274, 2274, 2274,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2274, 2274,    0, 2274, 2274, 2274,    0,    0,
 1430,    0, 2274, 2274, 2274, 2274, 2274,    0, 2274,    0,
    0, 2274, 2274,    0,    0,    0, 2274, 2274,    0,    0,
 2274, 2274, 2274, 2274, 2274, 2274, 2274, 2274, 2274,    0,
 2274,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2274, 2274, 2274, 2274, 2274, 2274, 2274, 2274, 2274, 2274,
 2274, 2274, 2274, 2274, 2274, 2274, 2274, 2274, 2274, 2274,
 2274,    0, 2274, 2274, 2274, 2274, 2274, 2274,    0, 2274,
 2274, 2274, 2274,    0, 2274,    0, 2274, 2274, 2274, 2274,
 2274, 2274, 2274, 2274, 2274, 2274, 2274, 2274, 2274, 2274,
 2274, 2274, 2274, 2274,    0, 2274, 2274, 2274, 2274,    0,
 2274, 2274, 2274, 2274, 2274,    0, 2274, 2274, 2274, 2274,
 2274, 2274, 2274, 2274, 2274, 2274, 2274, 2274, 2274, 2274,
 2274, 2274, 2274, 2274, 2274, 2274, 2274, 2274, 2274, 2274,
 2274, 2274, 2274, 2274, 2274,    0, 2274, 2274,    0,    0,
    0, 2274, 2274, 2274, 2274, 2274, 2274,    0,    0, 2274,
 2274, 2274, 2274, 2274, 2274, 2274, 2274, 2274, 2961,    0,
    0,    0,    0, 2274,    0, 2274, 2274, 2274, 2274, 2274,
 2274,    0, 2274,    0,    0,    0,    0, 1432, 1431, 1433,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2274,
 2274,    0, 2274, 2274, 2274, 2274, 2274, 2274, 2274, 2274,
 2274,    0, 2274, 2274, 2274, 2274, 2274, 2274, 2274, 2274,
 2274, 2274, 2274, 2274,    0, 2274, 2274, 2274,    0, 2274,
    0,    0,    0, 2274, 2274, 2274, 2274, 2274, 2274, 2274,
 2274, 2274, 2274, 2274, 2274, 2274, 2302, 2274, 2274,    0,
    0,    0,    0,    0, 2274, 2274, 2274, 2274, 2274, 2274,
 2274, 2274, 2274, 2274, 2274, 2274, 2274, 2274, 2274, 2274,
 2274, 2274,    0,    0, 2274,    0, 2274, 2274, 2274, 2274,
 2274, 2274, 2274, 2274, 2274,    0, 1906, 2302, 2302, 2302,
 2302, 2302, 2302, 2302,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2302, 2302, 2302, 2302, 2302,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2302,    0, 2302,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1416,
    0,    0,    0,    0,    0,    0,    0,    0, 1417,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1418,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1419,    0,    0,    0,    0,
    0,    0, 1420,    0,    0,    0,    0,    0,    0,    0,
 1421,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1422,    0, 1423,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1424,
    0, 1425, 1426, 1427,    0,    0,    0,    0, 1428,    0,
    0,    0,    0, 2302,    0, 2302,    0,    0, 2302,    0,
 2302, 2302, 2302,    0, 2302, 2302,    0, 2302,    0,    0,
    0,    0,    0, 2302,    0, 2302, 2302, 2302, 2302,    0,
 2302,    0,    0, 2302,    0,    0, 2302,    0,    0, 1429,
    0,    0,    0, 2302,    0, 2302, 2302,    0, 2302, 2302,
 2302, 2302, 2302,    0,    0, 2302,    0,    0, 2302,    0,
 2302, 2302,    0,    0, 2302, 2302, 2302,    0, 2302, 2302,
 2302, 2302, 2302, 2302, 2302,    0,    0,    0, 2302, 2302,
 2302, 2302, 2302,    0,    0,    0, 2302,    0,    0,    0,
    0,    0,    0,    0, 2302, 2302, 2302, 2302, 2302, 2302,
    0,    0,    0, 2302, 2302,    0, 2302,    0, 2302,    0,
 2302, 2302, 2302,    0, 2302,    0, 2302, 2302, 2302,    0,
 2302, 2302, 2302, 2302, 2302,    0, 2302, 2302,    0,    0,
    0,    0, 2302,    0, 2302, 2302,    0,    0, 2302, 2302,
 2302,    0,    0, 2302,    0, 2302,    0,    0, 2302, 2302,
 2302, 2302,    0, 2302,    0, 2302,    0, 2302, 2302, 2302,
 2302, 2302,    0,    0, 2302, 2302, 2302,    0, 2302, 2302,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2302,
 2302, 2302,    0, 2302, 2302, 2302,    0,    0,    0,    0,
    0, 2302,    0,    0,    0, 2302,    0, 2302, 2302, 2302,
 2302,    0, 2302,    0, 2302, 2302, 2302, 2302, 2302, 2302,
 2302, 2302,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2302, 2302,    0, 2302, 2302, 2302,    0,    0, 1430,
    0, 2302, 2302, 2302, 2302, 2302,    0, 2302,    0,    0,
 2302, 2302,    0,    0,    0, 2302, 2302,    0,    0, 2302,
 2302, 2302, 2302, 2302, 2302, 2302, 2302, 2302,    0, 2302,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2302,
 2302, 2302, 2302, 2302, 2302, 2302, 2302, 2302, 2302, 2302,
 2302, 2302, 2302, 2302, 2302, 2302, 2302, 2302, 2302, 2302,
    0, 2302, 2302, 2302, 2302, 2302, 2302,    0, 2302, 2302,
 2302, 2302,    0, 2302,    0, 2302, 2302, 2302, 2302, 2302,
 2302, 2302, 2302, 2302, 2302, 2302, 2302, 2302, 2302, 2302,
 2302, 2302, 2302,    0, 2302, 2302, 2302, 2302,    0, 2302,
 2302, 2302, 2302, 2302,    0, 2302, 2302, 2302, 2302, 2302,
 2302, 2302, 2302, 2302, 2302, 2302, 2302, 2302, 2302, 2302,
 2302, 2302, 2302, 2302, 2302, 2302, 2302, 2302, 2302, 2302,
 2302, 2302, 2302, 2302,    0, 2302, 2302,    0,    0,    0,
 2302, 2302, 2302, 2302, 2302, 2302,    0,    0, 2302, 2302,
 2302, 2302, 2302, 2302, 2302, 2302, 2302, 3261,    0,    0,
    0,    0, 2302,    0, 2302, 2302, 2302, 2302, 2302, 2302,
    0, 2302,    0,    0,    0,    0, 1432, 1431, 1433,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2302, 2302,
    0, 2302, 2302, 2302, 2302, 2302, 2302, 2302, 2302, 2302,
    0, 2302, 2302, 2302, 2302, 2302, 2302, 2302, 2302, 2302,
 2302, 2302, 2302,    0, 2302, 2302, 2302,    0, 2302,    0,
    0,    0, 2302, 2302, 2302, 2302, 2302, 2302, 2302, 2302,
 2302, 2302, 2302, 2302, 2302, 2303, 2302, 2302,    0,    0,
    0,    0,    0, 2302, 2302, 2302, 2302, 2302, 2302, 2302,
 2302, 2302, 2302, 2302, 2302, 2302, 2302, 2302, 2302, 2302,
 2302,    0,    0, 2302,    0, 2302, 2302, 2302, 2302, 2302,
 2302, 2302, 2302, 2302,    0, 1907, 2303, 2303, 2303, 2303,
 2303, 2303, 2303,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2303, 2303, 2303, 2303, 2303,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2303,    0, 2303,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1416,    0,
    0,    0,    0,    0,    0,    0,    0, 1417,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1418,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1419,    0,    0,    0,    0,    0,
    0, 1420,    0,    0,    0,    0,    0,    0,    0, 1421,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1422,    0, 1423,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1424,    0,
 1425, 1426, 1427,    0,    0,    0,    0, 1428,    0,    0,
    0,    0, 2303,    0, 2303,    0,    0, 2303,    0, 2303,
 2303, 2303,    0, 2303, 2303,    0, 2303,    0,    0,    0,
    0,    0, 2303,    0, 2303, 2303, 2303, 2303,    0, 2303,
    0,    0, 2303,    0,    0, 2303,    0,    0, 1429,    0,
    0,    0, 2303,    0, 2303, 2303,    0, 2303, 2303, 2303,
 2303, 2303,    0,    0, 2303,    0,    0, 2303,    0, 2303,
 2303,    0,    0, 2303, 2303, 2303,    0, 2303, 2303, 2303,
 2303, 2303, 2303, 2303,    0,    0,    0, 2303, 2303, 2303,
 2303, 2303,    0,    0,    0, 2303,    0,    0,    0,    0,
    0,    0,    0, 2303, 2303, 2303, 2303, 2303, 2303,    0,
    0,    0, 2303, 2303,    0, 2303,    0, 2303,    0, 2303,
 2303, 2303,    0, 2303,    0, 2303, 2303, 2303,    0, 2303,
 2303, 2303, 2303, 2303,    0, 2303, 2303,    0,    0,    0,
    0, 2303,    0, 2303, 2303,    0,    0, 2303, 2303, 2303,
    0,    0, 2303,    0, 2303,    0,    0, 2303, 2303, 2303,
 2303,    0, 2303,    0, 2303,    0, 2303, 2303, 2303, 2303,
 2303,    0,    0, 2303, 2303, 2303,    0, 2303, 2303,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2303, 2303,
 2303,    0, 2303, 2303, 2303,    0,    0,    0,    0,    0,
 2303,    0,    0,    0, 2303,    0, 2303, 2303, 2303, 2303,
    0, 2303,    0, 2303, 2303, 2303, 2303, 2303, 2303, 2303,
 2303,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2303, 2303,    0, 2303, 2303, 2303,    0,    0, 1430,    0,
 2303, 2303, 2303, 2303, 2303,    0, 2303,    0,    0, 2303,
 2303,    0,    0,    0, 2303, 2303,    0,    0, 2303, 2303,
 2303, 2303, 2303, 2303, 2303, 2303, 2303,    0, 2303,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2303, 2303,
 2303, 2303, 2303, 2303, 2303, 2303, 2303, 2303, 2303, 2303,
 2303, 2303, 2303, 2303, 2303, 2303, 2303, 2303, 2303,    0,
 2303, 2303, 2303, 2303, 2303, 2303,    0, 2303, 2303, 2303,
 2303,    0, 2303,    0, 2303, 2303, 2303, 2303, 2303, 2303,
 2303, 2303, 2303, 2303, 2303, 2303, 2303, 2303, 2303, 2303,
 2303, 2303,    0, 2303, 2303, 2303, 2303,    0, 2303, 2303,
 2303, 2303, 2303,    0, 2303, 2303, 2303, 2303, 2303, 2303,
 2303, 2303, 2303, 2303, 2303, 2303, 2303, 2303, 2303, 2303,
 2303, 2303, 2303, 2303, 2303, 2303, 2303, 2303, 2303, 2303,
 2303, 2303, 2303,    0, 2303, 2303,    0,    0,    0, 2303,
 2303, 2303, 2303, 2303, 2303,    0,    0, 2303, 2303, 2303,
 2303, 2303, 2303, 2303, 2303, 2303, 3262,    0,    0,    0,
    0, 2303,    0, 2303, 2303, 2303, 2303, 2303, 2303,    0,
 2303,    0,    0,    0,    0, 1432, 1431, 1433,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2303, 2303,    0,
 2303, 2303, 2303, 2303, 2303, 2303, 2303, 2303, 2303,    0,
 2303, 2303, 2303, 2303, 2303, 2303, 2303, 2303, 2303, 2303,
 2303, 2303,    0, 2303, 2303, 2303,    0, 2303,    0,    0,
    0, 2303, 2303, 2303, 2303, 2303, 2303, 2303, 2303, 2303,
 2303, 2303, 2303, 2303, 2307, 2303, 2303,    0,    0,    0,
    0,    0, 2303, 2303, 2303, 2303, 2303, 2303, 2303, 2303,
 2303, 2303, 2303, 2303, 2303, 2303, 2303, 2303, 2303, 2303,
    0,    0, 2303,    0, 2303, 2303, 2303, 2303, 2303, 2303,
 2303, 2303, 2303,    0, 1959, 2307, 2307, 2307, 2307, 2307,
 2307, 2307,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2307, 2307, 2307, 2307, 2307,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2307,    0, 2307,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1416,    0,    0,
    0,    0,    0,    0,    0,    0, 1417,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1418,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1419,    0,    0,    0,    0,    0,    0,
 1420,    0,    0,    0,    0,    0,    0,    0, 1421,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1422,    0, 1423,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1424,    0, 1425,
 1426, 1427,    0,    0,    0,    0, 1428,    0,    0,    0,
    0, 2307,    0, 2307,    0,    0, 2307,    0, 2307, 2307,
 2307,    0, 2307, 2307,    0, 2307,    0,    0,    0,    0,
    0, 2307,    0, 2307, 2307, 2307, 2307,    0, 2307,    0,
    0, 2307,    0,    0, 2307,    0,    0, 1429,    0,    0,
    0, 2307,    0, 2307, 2307,    0, 2307, 2307, 2307, 2307,
 2307,    0,    0, 2307,    0,    0, 2307,    0, 2307, 2307,
    0,    0, 2307, 2307, 2307,    0, 2307, 2307, 2307, 2307,
 2307, 2307, 2307,    0,    0,    0, 2307, 2307, 2307, 2307,
 2307,    0,    0,    0, 2307,    0,    0,    0,    0,    0,
    0,    0, 2307, 2307, 2307, 2307, 2307, 2307,    0,    0,
    0, 2307, 2307,    0, 2307,    0, 2307,    0, 2307, 2307,
 2307,    0, 2307,    0, 2307, 2307, 2307,    0, 2307, 2307,
 2307, 2307, 2307,    0, 2307, 2307,    0,    0,    0,    0,
 2307,    0, 2307, 2307,    0,    0, 2307, 2307, 2307,    0,
    0, 2307,    0, 2307,    0,    0, 2307, 2307, 2307, 2307,
    0, 2307,    0, 2307,    0, 2307, 2307, 2307, 2307, 2307,
    0,    0, 2307, 2307, 2307,    0, 2307, 2307,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2307, 2307, 2307,
    0, 2307, 2307, 2307,    0,    0,    0,    0,    0, 2307,
    0,    0,    0, 2307,    0, 2307, 2307, 2307, 2307,    0,
 2307,    0, 2307, 2307, 2307, 2307, 2307, 2307, 2307, 2307,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2307,
 2307,    0, 2307, 2307, 2307,    0,    0, 1430,    0, 2307,
 2307, 2307, 2307, 2307,    0, 2307,    0,    0, 2307, 2307,
    0,    0,    0, 2307, 2307,    0,    0, 2307, 2307, 2307,
 2307, 2307, 2307, 2307, 2307, 2307,    0, 2307,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2307, 2307, 2307,
 2307, 2307, 2307, 2307, 2307, 2307, 2307, 2307, 2307, 2307,
 2307, 2307, 2307, 2307, 2307, 2307, 2307, 2307,    0, 2307,
 2307, 2307, 2307, 2307, 2307,    0, 2307, 2307, 2307, 2307,
    0, 2307,    0, 2307, 2307, 2307, 2307, 2307, 2307, 2307,
 2307, 2307, 2307, 2307, 2307, 2307, 2307, 2307, 2307, 2307,
 2307,    0, 2307, 2307, 2307, 2307,    0, 2307, 2307, 2307,
 2307, 2307,    0, 2307, 2307, 2307, 2307, 2307, 2307, 2307,
 2307, 2307, 2307, 2307, 2307, 2307, 2307, 2307, 2307, 2307,
 2307, 2307, 2307, 2307, 2307, 2307, 2307, 2307, 2307, 2307,
 2307, 2307,    0, 2307, 2307,    0,    0,    0, 2307, 2307,
 2307, 2307, 2307, 2307,    0,    0, 2307, 2307, 2307, 2307,
 2307, 2307, 2307, 2307, 2307, 3465,    0,    0,    0,    0,
 2307,    0, 2307, 2307, 2307, 2307, 2307, 2307,    0, 2307,
    0,    0,    0,    0, 1432, 1431, 1433,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2307, 2307,    0, 2307,
 2307, 2307, 2307, 2307, 2307, 2307, 2307, 2307,    0, 2307,
 2307, 2307, 2307, 2307, 2307, 2307, 2307, 2307, 2307, 2307,
 2307,    0, 2307, 2307, 2307,    0, 2307,    0,    0,    0,
 2307, 2307, 2307, 2307, 2307, 2307, 2307, 2307, 2307, 2307,
 2307, 2307, 2307, 2310, 2307, 2307,    0,    0,    0,    0,
    0, 2307, 2307, 2307, 2307, 2307, 2307, 2307, 2307, 2307,
 2307, 2307, 2307, 2307, 2307, 2307, 2307, 2307, 2307,    0,
    0, 2307,    0, 2307, 2307, 2307, 2307, 2307, 2307, 2307,
 2307, 2307,    0, 1978, 2310, 2310, 2310, 2310, 2310, 2310,
 2310,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2310, 2310, 2310, 2310, 2310,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2310,    0, 2310,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1416,    0,    0,    0,
    0,    0,    0,    0,    0, 1417,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1418,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1419,    0,    0,    0,    0,    0,    0, 1420,
    0,    0,    0,    0,    0,    0,    0, 1421,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1422,    0, 1423,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1424,    0, 1425, 1426,
 1427,    0,    0,    0,    0, 1428,    0,    0,    0,    0,
 2310,    0, 2310,    0,    0, 2310,    0, 2310, 2310, 2310,
    0, 2310, 2310,    0, 2310,    0,    0,    0,    0,    0,
 2310,    0, 2310, 2310, 2310, 2310,    0, 2310,    0,    0,
 2310,    0,    0, 2310,    0,    0, 1429,    0,    0,    0,
 2310,    0, 2310, 2310,    0, 2310, 2310, 2310, 2310, 2310,
    0,    0, 2310,    0,    0, 2310,    0, 2310, 2310,    0,
    0, 2310, 2310, 2310,    0, 2310, 2310, 2310, 2310, 2310,
 2310, 2310,    0,    0,    0, 2310, 2310, 2310, 2310, 2310,
    0,    0,    0, 2310,    0,    0,    0,    0,    0,    0,
    0, 2310, 2310, 2310, 2310, 2310, 2310,    0,    0,    0,
 2310, 2310,    0, 2310,    0, 2310,    0, 2310, 2310, 2310,
    0, 2310,    0, 2310, 2310, 2310,    0, 2310, 2310, 2310,
 2310, 2310,    0, 2310, 2310,    0,    0,    0,    0, 2310,
    0, 2310, 2310,    0,    0, 2310, 2310, 2310,    0,    0,
 2310,    0, 2310,    0,    0, 2310, 2310, 2310, 2310,    0,
 2310,    0, 2310,    0, 2310, 2310, 2310, 2310, 2310,    0,
    0, 2310, 2310, 2310,    0, 2310, 2310,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2310, 2310, 2310,    0,
 2310, 2310, 2310,    0,    0,    0,    0,    0, 2310,    0,
    0,    0, 2310,    0, 2310, 2310, 2310, 2310,    0, 2310,
    0, 2310, 2310, 2310, 2310, 2310, 2310, 2310, 2310,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2310, 2310,
    0, 2310, 2310, 2310,    0,    0, 1430,    0, 2310, 2310,
 2310, 2310, 2310,    0, 2310,    0,    0, 2310, 2310,    0,
    0,    0, 2310, 2310,    0,    0, 2310, 2310, 2310, 2310,
 2310, 2310, 2310, 2310, 2310,    0, 2310,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2310, 2310, 2310, 2310,
 2310, 2310, 2310, 2310, 2310, 2310, 2310, 2310, 2310, 2310,
 2310, 2310, 2310, 2310, 2310, 2310, 2310,    0, 2310, 2310,
 2310, 2310, 2310, 2310,    0, 2310, 2310, 2310, 2310,    0,
 2310,    0, 2310, 2310, 2310, 2310, 2310, 2310, 2310, 2310,
 2310, 2310, 2310, 2310, 2310, 2310, 2310, 2310, 2310, 2310,
    0, 2310, 2310, 2310, 2310,    0, 2310, 2310, 2310, 2310,
 2310,    0, 2310, 2310, 2310, 2310, 2310, 2310, 2310, 2310,
 2310, 2310, 2310, 2310, 2310, 2310, 2310, 2310, 2310, 2310,
 2310, 2310, 2310, 2310, 2310, 2310, 2310, 2310, 2310, 2310,
 2310,    0, 2310, 2310,    0,    0,    0, 2310, 2310, 2310,
 2310, 2310, 2310,    0,    0, 2310, 2310, 2310, 2310, 2310,
 2310, 2310, 2310, 2310, 3470,    0,    0,    0,    0, 2310,
    0, 2310, 2310, 2310, 2310, 2310, 2310,    0, 2310,    0,
    0,    0,    0, 1432, 1431, 1433,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2310, 2310,    0, 2310, 2310,
 2310, 2310, 2310, 2310, 2310, 2310, 2310,    0, 2310, 2310,
 2310, 2310, 2310, 2310, 2310, 2310, 2310, 2310, 2310, 2310,
    0, 2310, 2310, 2310,    0, 2310,    0,    0,    0, 2310,
 2310, 2310, 2310, 2310, 2310, 2310, 2310, 2310, 2310, 2310,
 2310, 2310, 2323, 2310, 2310,    0,    0,    0,    0,    0,
 2310, 2310, 2310, 2310, 2310, 2310, 2310, 2310, 2310, 2310,
 2310, 2310, 2310, 2310, 2310, 2310, 2310, 2310,    0,    0,
 2310,    0, 2310, 2310, 2310, 2310, 2310, 2310, 2310, 2310,
 2310,    0, 1923, 2323, 2323, 2323, 2323, 2323, 2323, 2323,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2323, 2323, 2323, 2323, 2323,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2323,    0, 2323,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1416,    0,    0,    0,    0,
    0,    0,    0,    0, 1417,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1418,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1419,    0,    0,    0,    0,    0,    0, 1420,    0,
    0,    0,    0,    0,    0,    0, 1421,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1422,    0, 1423,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1424,    0, 1425, 1426, 1427,
    0,    0,    0,    0, 1428,    0,    0,    0,    0, 2323,
    0, 2323,    0,    0, 2323,    0, 2323, 2323, 2323,    0,
 2323, 2323,    0, 2323,    0,    0,    0,    0,    0, 2323,
    0, 2323, 2323, 2323, 2323,    0, 2323,    0,    0, 2323,
    0,    0, 2323,    0,    0, 1429,    0,    0,    0, 2323,
    0, 2323, 2323,    0, 2323, 2323, 2323, 2323, 2323,    0,
    0, 2323,    0,    0, 2323,    0, 2323, 2323,    0,    0,
 2323, 2323, 2323,    0, 2323, 2323, 2323, 2323, 2323, 2323,
 2323,    0,    0,    0, 2323, 2323, 2323, 2323, 2323,    0,
    0,    0, 2323,    0,    0,    0,    0,    0,    0,    0,
 2323, 2323, 2323, 2323, 2323, 2323,    0,    0,    0, 2323,
 2323,    0, 2323,    0, 2323,    0, 2323, 2323, 2323,    0,
 2323,    0, 2323, 2323, 2323,    0, 2323, 2323, 2323, 2323,
 2323,    0, 2323, 2323,    0,    0,    0,    0, 2323,    0,
 2323, 2323,    0,    0, 2323, 2323, 2323,    0,    0, 2323,
    0, 2323,    0,    0, 2323, 2323, 2323, 2323,    0, 2323,
    0, 2323,    0, 2323, 2323, 2323, 2323, 2323,    0,    0,
 2323, 2323, 2323,    0, 2323, 2323,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2323, 2323, 2323,    0, 2323,
 2323, 2323,    0,    0,    0,    0,    0, 2323,    0,    0,
    0, 2323,    0, 2323, 2323, 2323, 2323,    0, 2323,    0,
 2323, 2323, 2323, 2323, 2323, 2323, 2323, 2323,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2323, 2323,    0,
 2323, 2323, 2323,    0,    0, 1430,    0, 2323, 2323, 2323,
 2323, 2323,    0, 2323,    0,    0, 2323, 2323,    0,    0,
    0, 2323, 2323,    0,    0, 2323, 2323, 2323, 2323, 2323,
 2323, 2323, 2323, 2323,    0, 2323,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2323, 2323, 2323, 2323, 2323,
 2323, 2323, 2323, 2323, 2323, 2323, 2323, 2323, 2323, 2323,
 2323, 2323, 2323, 2323, 2323, 2323,    0, 2323, 2323, 2323,
 2323, 2323, 2323,    0, 2323, 2323, 2323, 2323,    0, 2323,
    0, 2323, 2323, 2323, 2323, 2323, 2323, 2323, 2323, 2323,
 2323, 2323, 2323, 2323, 2323, 2323, 2323, 2323, 2323,    0,
 2323, 2323, 2323, 2323,    0, 2323, 2323, 2323, 2323, 2323,
    0, 2323, 2323, 2323, 2323, 2323, 2323, 2323, 2323, 2323,
 2323, 2323, 2323, 2323, 2323, 2323, 2323, 2323, 2323, 2323,
 2323, 2323, 2323, 2323, 2323, 2323, 2323, 2323, 2323, 2323,
    0, 2323, 2323,    0,    0,    0, 2323, 2323, 2323, 2323,
 2323, 2323,    0,    0, 2323, 2323, 2323, 2323, 2323, 2323,
 2323, 2323, 2323, 3471,    0,    0,    0,    0, 2323,    0,
 2323, 2323, 2323, 2323, 2323, 2323,    0, 2323,    0,    0,
    0,    0, 1432, 1431, 1433,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2323, 2323,    0, 2323, 2323, 2323,
 2323, 2323, 2323, 2323, 2323, 2323,    0, 2323, 2323, 2323,
 2323, 2323, 2323, 2323, 2323, 2323, 2323, 2323, 2323,    0,
 2323, 2323, 2323,    0, 2323,    0,    0,    0, 2323, 2323,
 2323, 2323, 2323, 2323, 2323, 2323, 2323, 2323, 2323, 2323,
 2323, 2324, 2323, 2323,    0,    0,    0,    0,    0, 2323,
 2323, 2323, 2323, 2323, 2323, 2323, 2323, 2323, 2323, 2323,
 2323, 2323, 2323, 2323, 2323, 2323, 2323,    0,    0, 2323,
    0, 2323, 2323, 2323, 2323, 2323, 2323, 2323, 2323, 2323,
    0, 1924, 2324, 2324, 2324, 2324, 2324, 2324, 2324,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2324,
 2324, 2324, 2324, 2324,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2324,    0, 2324,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1416,    0,    0,    0,    0,    0,
    0,    0,    0, 1417,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1418,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1419,    0,    0,    0,    0,    0,    0, 1420,    0,    0,
    0,    0,    0,    0,    0, 1421,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1422,    0, 1423,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1424,    0, 1425, 1426, 1427,    0,
    0,    0,    0, 1428,    0,    0,    0,    0, 2324,    0,
 2324,    0,    0, 2324,    0, 2324, 2324, 2324,    0, 2324,
 2324,    0, 2324,    0,    0,    0,    0,    0, 2324,    0,
 2324, 2324, 2324, 2324,    0, 2324,    0,    0, 2324,    0,
    0, 2324,    0,    0, 1429,    0,    0,    0, 2324,    0,
 2324, 2324,    0, 2324, 2324, 2324, 2324, 2324,    0,    0,
 2324,    0,    0, 2324,    0, 2324, 2324,    0,    0, 2324,
 2324, 2324,    0, 2324, 2324, 2324, 2324, 2324, 2324, 2324,
    0,    0,    0, 2324, 2324, 2324, 2324, 2324,    0,    0,
    0, 2324,    0,    0,    0,    0,    0,    0,    0, 2324,
 2324, 2324, 2324, 2324, 2324,    0,    0,    0, 2324, 2324,
    0, 2324,    0, 2324,    0, 2324, 2324, 2324,    0, 2324,
    0, 2324, 2324, 2324,    0, 2324, 2324, 2324, 2324, 2324,
    0, 2324, 2324,    0,    0,    0,    0, 2324,    0, 2324,
 2324,    0,    0, 2324, 2324, 2324,    0,    0, 2324,    0,
 2324,    0,    0, 2324, 2324, 2324, 2324,    0, 2324,    0,
 2324,    0, 2324, 2324, 2324, 2324, 2324,    0,    0, 2324,
 2324, 2324,    0, 2324, 2324,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2324, 2324, 2324,    0, 2324, 2324,
 2324,    0,    0,    0,    0,    0, 2324,    0,    0,    0,
 2324,    0, 2324, 2324, 2324, 2324,    0, 2324,    0, 2324,
 2324, 2324, 2324, 2324, 2324, 2324, 2324,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2324, 2324,    0, 2324,
 2324, 2324,    0,    0, 1430,    0, 2324, 2324, 2324, 2324,
 2324,    0, 2324,    0,    0, 2324, 2324,    0,    0,    0,
 2324, 2324,    0,    0, 2324, 2324, 2324, 2324, 2324, 2324,
 2324, 2324, 2324,    0, 2324,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2324, 2324, 2324, 2324, 2324, 2324,
 2324, 2324, 2324, 2324, 2324, 2324, 2324, 2324, 2324, 2324,
 2324, 2324, 2324, 2324, 2324,    0, 2324, 2324, 2324, 2324,
 2324, 2324,    0, 2324, 2324, 2324, 2324,    0, 2324,    0,
 2324, 2324, 2324, 2324, 2324, 2324, 2324, 2324, 2324, 2324,
 2324, 2324, 2324, 2324, 2324, 2324, 2324, 2324,    0, 2324,
 2324, 2324, 2324,    0, 2324, 2324, 2324, 2324, 2324,    0,
 2324, 2324, 2324, 2324, 2324, 2324, 2324, 2324, 2324, 2324,
 2324, 2324, 2324, 2324, 2324, 2324, 2324, 2324, 2324, 2324,
 2324, 2324, 2324, 2324, 2324, 2324, 2324, 2324, 2324,    0,
 2324, 2324,    0,    0,    0, 2324, 2324, 2324, 2324, 2324,
 2324,    0,    0, 2324, 2324, 2324, 2324, 2324, 2324, 2324,
 2324, 2324, 3472,    0,    0,    0,    0, 2324,    0, 2324,
 2324, 2324, 2324, 2324, 2324,    0, 2324,    0,    0,    0,
    0, 1432, 1431, 1433,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2324, 2324,    0, 2324, 2324, 2324, 2324,
 2324, 2324, 2324, 2324, 2324,    0, 2324, 2324, 2324, 2324,
 2324, 2324, 2324, 2324, 2324, 2324, 2324, 2324,    0, 2324,
 2324, 2324,    0, 2324,    0,    0,    0, 2324, 2324, 2324,
 2324, 2324, 2324, 2324, 2324, 2324, 2324, 2324, 2324, 2324,
 2333, 2324, 2324,    0,    0,    0,    0,    0, 2324, 2324,
 2324, 2324, 2324, 2324, 2324, 2324, 2324, 2324, 2324, 2324,
 2324, 2324, 2324, 2324, 2324, 2324,    0,    0, 2324,    0,
 2324, 2324, 2324, 2324, 2324, 2324, 2324, 2324, 2324,    0,
 1930, 2333, 2333, 2333, 2333, 2333, 2333, 2333,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2333, 2333,
 2333, 2333, 2333,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2333,    0, 2333,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1416,    0,    0,    0,    0,    0,    0,
    0,    0, 1417,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1418,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1419,
    0,    0,    0,    0,    0,    0, 1420,    0,    0,    0,
    0,    0,    0,    0, 1421,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1422,    0, 1423,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1424,    0, 1425, 1426, 1427,    0,    0,
    0,    0, 1428,    0,    0,    0,    0, 2333,    0, 2333,
    0,    0, 2333,    0, 2333, 2333, 2333,    0, 2333, 2333,
    0, 2333,    0,    0,    0,    0,    0, 2333,    0, 2333,
 2333, 2333, 2333,    0, 2333,    0,    0, 2333,    0,    0,
 2333,    0,    0, 1429,    0,    0,    0, 2333,    0, 2333,
 2333,    0, 2333, 2333, 2333, 2333, 2333,    0,    0, 2333,
    0,    0, 2333,    0, 2333, 2333,    0,    0, 2333, 2333,
 2333,    0, 2333, 2333, 2333, 2333, 2333, 2333, 2333,    0,
    0,    0, 2333, 2333, 2333, 2333, 2333,    0,    0,    0,
 2333,    0,    0,    0,    0,    0,    0,    0, 2333, 2333,
 2333, 2333, 2333, 2333,    0,    0,    0, 2333, 2333,    0,
 2333,    0, 2333,    0, 2333, 2333, 2333,    0, 2333,    0,
 2333, 2333, 2333,    0, 2333, 2333, 2333, 2333, 2333,    0,
 2333, 2333,    0,    0,    0,    0, 2333,    0, 2333, 2333,
    0,    0, 2333, 2333, 2333,    0,    0, 2333,    0, 2333,
    0,    0, 2333, 2333, 2333, 2333,    0, 2333,    0, 2333,
    0, 2333, 2333, 2333, 2333, 2333,    0,    0, 2333, 2333,
 2333,    0, 2333, 2333,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2333, 2333, 2333,    0, 2333, 2333, 2333,
    0,    0,    0,    0,    0, 2333,    0,    0,    0, 2333,
    0, 2333, 2333, 2333, 2333,    0, 2333,    0, 2333, 2333,
 2333, 2333, 2333, 2333, 2333, 2333,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2333, 2333,    0, 2333, 2333,
 2333,    0,    0, 1430,    0, 2333, 2333, 2333, 2333, 2333,
    0, 2333,    0,    0, 2333, 2333,    0,    0,    0, 2333,
 2333,    0,    0, 2333, 2333, 2333, 2333, 2333, 2333, 2333,
 2333, 2333,    0, 2333,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2333, 2333, 2333, 2333, 2333, 2333, 2333,
 2333, 2333, 2333, 2333, 2333, 2333, 2333, 2333, 2333, 2333,
 2333, 2333, 2333, 2333,    0, 2333, 2333, 2333, 2333, 2333,
 2333,    0, 2333, 2333, 2333, 2333,    0, 2333,    0, 2333,
 2333, 2333, 2333, 2333, 2333, 2333, 2333, 2333, 2333, 2333,
 2333, 2333, 2333, 2333, 2333, 2333, 2333,    0, 2333, 2333,
 2333, 2333,    0, 2333, 2333, 2333, 2333, 2333,    0, 2333,
 2333, 2333, 2333, 2333, 2333, 2333, 2333, 2333, 2333, 2333,
 2333, 2333, 2333, 2333, 2333, 2333, 2333, 2333, 2333, 2333,
 2333, 2333, 2333, 2333, 2333, 2333, 2333, 2333,    0, 2333,
 2333,    0,    0,    0, 2333, 2333, 2333, 2333, 2333, 2333,
    0,    0, 2333, 2333, 2333, 2333, 2333, 2333, 2333, 2333,
 2333, 3473,    0,    0,    0,    0, 2333,    0, 2333, 2333,
 2333, 2333, 2333, 2333,    0, 2333,    0,    0,    0,    0,
 1432, 1431, 1433,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2333, 2333,    0, 2333, 2333, 2333, 2333, 2333,
 2333, 2333, 2333, 2333,    0, 2333, 2333, 2333, 2333, 2333,
 2333, 2333, 2333, 2333, 2333, 2333, 2333,    0, 2333, 2333,
 2333,    0, 2333,    0,    0,    0, 2333, 2333, 2333, 2333,
 2333, 2333, 2333, 2333, 2333, 2333, 2333, 2333, 2333, 2337,
 2333, 2333,    0,    0,    0,    0,    0, 2333, 2333, 2333,
 2333, 2333, 2333, 2333, 2333, 2333, 2333, 2333, 2333, 2333,
 2333, 2333, 2333, 2333, 2333,    0,    0, 2333,    0, 2333,
 2333, 2333, 2333, 2333, 2333, 2333, 2333, 2333,    0, 1958,
 2337, 2337, 2337, 2337, 2337, 2337, 2337,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2337, 2337, 2337,
 2337, 2337,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2337,    0, 2337,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1416,    0,    0,    0,    0,    0,    0,    0,
    0, 1417,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1418,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1419,    0,
    0,    0,    0,    0,    0, 1420,    0,    0,    0,    0,
    0,    0,    0, 1421,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1422,    0, 1423,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1424,    0, 1425, 1426, 1427,    0,    0,    0,
    0, 1428,    0,    0,    0,    0, 2337,    0, 2337,    0,
    0, 2337,    0, 2337, 2337, 2337,    0, 2337, 2337,    0,
 2337,    0,    0,    0,    0,    0, 2337,    0, 2337, 2337,
 2337, 2337,    0, 2337,    0,    0, 2337,    0,    0, 2337,
    0,    0, 1429,    0,    0,    0, 2337,    0, 2337, 2337,
    0, 2337, 2337, 2337, 2337, 2337,    0,    0, 2337,    0,
    0, 2337,    0, 2337, 2337,    0,    0, 2337, 2337, 2337,
    0, 2337, 2337, 2337, 2337, 2337, 2337, 2337,    0,    0,
    0, 2337, 2337, 2337, 2337, 2337,    0,    0,    0, 2337,
    0,    0,    0,    0,    0,    0,    0, 2337, 2337, 2337,
 2337, 2337, 2337,    0,    0,    0, 2337, 2337,    0, 2337,
    0, 2337,    0, 2337, 2337, 2337,    0, 2337,    0, 2337,
 2337, 2337,    0, 2337, 2337, 2337, 2337, 2337,    0, 2337,
 2337,    0,    0,    0,    0, 2337,    0, 2337, 2337,    0,
    0, 2337, 2337, 2337,    0,    0, 2337,    0, 2337,    0,
    0, 2337, 2337, 2337, 2337,    0, 2337,    0, 2337,    0,
 2337, 2337, 2337, 2337, 2337,    0,    0, 2337, 2337, 2337,
    0, 2337, 2337,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2337, 2337, 2337,    0, 2337, 2337, 2337,    0,
    0,    0,    0,    0, 2337,    0,    0,    0, 2337,    0,
 2337, 2337, 2337, 2337,    0, 2337,    0, 2337, 2337, 2337,
 2337, 2337, 2337, 2337, 2337,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2337, 2337,    0, 2337, 2337, 2337,
    0,    0, 1430,    0, 2337, 2337, 2337, 2337, 2337,    0,
 2337,    0,    0, 2337, 2337,    0,    0,    0, 2337, 2337,
    0,    0, 2337, 2337, 2337, 2337, 2337, 2337, 2337, 2337,
 2337,    0, 2337,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2337, 2337, 2337, 2337, 2337, 2337, 2337, 2337,
 2337, 2337, 2337, 2337, 2337, 2337, 2337, 2337, 2337, 2337,
 2337, 2337, 2337,    0, 2337, 2337, 2337, 2337, 2337, 2337,
    0, 2337, 2337, 2337, 2337,    0, 2337,    0, 2337, 2337,
 2337, 2337, 2337, 2337, 2337, 2337, 2337, 2337, 2337, 2337,
 2337, 2337, 2337, 2337, 2337, 2337,    0, 2337, 2337, 2337,
 2337,    0, 2337, 2337, 2337, 2337, 2337,    0, 2337, 2337,
 2337, 2337, 2337, 2337, 2337, 2337, 2337, 2337, 2337, 2337,
 2337, 2337, 2337, 2337, 2337, 2337, 2337, 2337, 2337, 2337,
 2337, 2337, 2337, 2337, 2337, 2337, 2337,    0, 2337, 2337,
    0,    0,    0, 2337, 2337, 2337, 2337, 2337, 2337,    0,
    0, 2337, 2337, 2337, 2337, 2337, 2337, 2337, 2337, 2337,
 3480,    0,    0,    0,    0, 2337,    0, 2337, 2337, 2337,
 2337, 2337, 2337,    0, 2337,    0,    0,    0,    0, 1432,
 1431, 1433,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2337, 2337,    0, 2337, 2337, 2337, 2337, 2337, 2337,
 2337, 2337, 2337,    0, 2337, 2337, 2337, 2337, 2337, 2337,
 2337, 2337, 2337, 2337, 2337, 2337,    0, 2337, 2337, 2337,
    0, 2337,    0,    0,    0, 2337, 2337, 2337, 2337, 2337,
 2337, 2337, 2337, 2337, 2337, 2337, 2337, 2337, 2347, 2337,
 2337,    0,    0,    0,    0,    0, 2337, 2337, 2337, 2337,
 2337, 2337, 2337, 2337, 2337, 2337, 2337, 2337, 2337, 2337,
 2337, 2337, 2337, 2337,    0,    0, 2337,    0, 2337, 2337,
 2337, 2337, 2337, 2337, 2337, 2337, 2337,    0, 1956, 2347,
 2347, 2347, 2347, 2347, 2347, 2347,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2347, 2347, 2347, 2347,
 2347,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2347,
    0, 2347,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1416,    0,    0,    0,    0,    0,    0,    0,    0,
 1417,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1418,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1419,    0,    0,
    0,    0,    0,    0, 1420,    0,    0,    0,    0,    0,
    0,    0, 1421,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1422,
    0, 1423,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1424,    0, 1425, 1426, 1427,    0,    0,    0,    0,
 1428,    0,    0,    0,    0, 2347,    0, 2347,    0,    0,
 2347,    0, 2347, 2347, 2347,    0, 2347, 2347,    0, 2347,
    0,    0,    0,    0,    0, 2347,    0, 2347, 2347, 2347,
 2347,    0, 2347,    0,    0, 2347,    0,    0, 2347,    0,
    0, 1429,    0,    0,    0, 2347,    0, 2347, 2347,    0,
 2347, 2347, 2347, 2347, 2347,    0,    0, 2347,    0,    0,
 2347,    0, 2347, 2347,    0,    0, 2347, 2347, 2347,    0,
 2347, 2347, 2347, 2347, 2347, 2347, 2347,    0,    0,    0,
 2347, 2347, 2347, 2347, 2347,    0,    0,    0, 2347,    0,
    0,    0,    0,    0,    0,    0, 2347, 2347, 2347, 2347,
 2347, 2347,    0,    0,    0, 2347, 2347,    0, 2347,    0,
 2347,    0, 2347, 2347, 2347,    0, 2347,    0, 2347, 2347,
 2347,    0, 2347, 2347, 2347, 2347, 2347,    0, 2347, 2347,
    0,    0,    0,    0, 2347,    0, 2347, 2347,    0,    0,
 2347, 2347, 2347,    0,    0, 2347,    0, 2347,    0,    0,
 2347, 2347, 2347, 2347,    0, 2347,    0, 2347,    0, 2347,
 2347, 2347, 2347, 2347,    0,    0, 2347, 2347, 2347,    0,
 2347, 2347,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2347, 2347, 2347,    0, 2347, 2347, 2347,    0,    0,
    0,    0,    0, 2347,    0,    0,    0, 2347,    0, 2347,
 2347, 2347, 2347,    0, 2347,    0, 2347, 2347, 2347, 2347,
 2347, 2347, 2347, 2347,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2347, 2347,    0, 2347, 2347, 2347,    0,
    0, 1430,    0, 2347, 2347, 2347, 2347, 2347,    0, 2347,
    0,    0, 2347, 2347,    0,    0,    0, 2347, 2347,    0,
    0, 2347, 2347, 2347, 2347, 2347, 2347, 2347, 2347, 2347,
    0, 2347,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2347, 2347, 2347, 2347, 2347, 2347, 2347, 2347, 2347,
 2347, 2347, 2347, 2347, 2347, 2347, 2347, 2347, 2347, 2347,
 2347, 2347,    0, 2347, 2347, 2347, 2347, 2347, 2347,    0,
 2347, 2347, 2347, 2347,    0, 2347,    0, 2347, 2347, 2347,
 2347, 2347, 2347, 2347, 2347, 2347, 2347, 2347, 2347, 2347,
 2347, 2347, 2347, 2347, 2347,    0, 2347, 2347, 2347, 2347,
    0, 2347, 2347, 2347, 2347, 2347,    0, 2347, 2347, 2347,
 2347, 2347, 2347, 2347, 2347, 2347, 2347, 2347, 2347, 2347,
 2347, 2347, 2347, 2347, 2347, 2347, 2347, 2347, 2347, 2347,
 2347, 2347, 2347, 2347, 2347, 2347,    0, 2347, 2347,    0,
    0,    0, 2347, 2347, 2347, 2347, 2347, 2347,    0,    0,
 2347, 2347, 2347, 2347, 2347, 2347, 2347, 2347, 2347, 3481,
    0,    0,    0,    0, 2347,    0, 2347, 2347, 2347, 2347,
 2347, 2347,    0, 2347,    0,    0,    0,    0, 1432, 1431,
 1433,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2347, 2347,    0, 2347, 2347, 2347, 2347, 2347, 2347, 2347,
 2347, 2347,    0, 2347, 2347, 2347, 2347, 2347, 2347, 2347,
 2347, 2347, 2347, 2347, 2347,    0, 2347, 2347, 2347,    0,
 2347,    0,    0,    0, 2347, 2347, 2347, 2347, 2347, 2347,
 2347, 2347, 2347, 2347, 2347, 2347, 2347, 2350, 2347, 2347,
    0,    0,    0,    0,    0, 2347, 2347, 2347, 2347, 2347,
 2347, 2347, 2347, 2347, 2347, 2347, 2347, 2347, 2347, 2347,
 2347, 2347, 2347,    0,    0, 2347,    0, 2347, 2347, 2347,
 2347, 2347, 2347, 2347, 2347, 2347,    0, 1979, 2350, 2350,
 2350, 2350, 2350, 2350, 2350,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2350, 2350, 2350, 2350, 2350,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2350,    0,
 2350,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1416,    0,    0,    0,    0,    0,    0,    0,    0, 1417,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1418,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1419,    0,    0,    0,
    0,    0,    0, 1420,    0,    0,    0,    0,    0,    0,
    0, 1421,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1422,    0,
 1423,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1424,    0, 1425, 1426, 1427,    0,    0,    0,    0, 1428,
    0,    0,    0,    0, 2350,    0, 2350,    0,    0, 2350,
    0, 2350, 2350, 2350,    0, 2350, 2350,    0, 2350,    0,
    0,    0,    0,    0, 2350,    0, 2350, 2350, 2350, 2350,
    0, 2350,    0,    0, 2350,    0,    0, 2350,    0,    0,
 1429,    0,    0,    0, 2350,    0, 2350, 2350,    0, 2350,
 2350, 2350, 2350, 2350,    0,    0, 2350,    0,    0, 2350,
    0, 2350, 2350,    0,    0, 2350, 2350, 2350,    0, 2350,
 2350, 2350, 2350, 2350, 2350, 2350,    0,    0,    0, 2350,
 2350, 2350, 2350, 2350,    0,    0,    0, 2350,    0,    0,
    0,    0,    0,    0,    0, 2350, 2350, 2350, 2350, 2350,
 2350,    0,    0,    0, 2350, 2350,    0, 2350,    0, 2350,
    0, 2350, 2350, 2350,    0, 2350,    0, 2350, 2350, 2350,
    0, 2350, 2350, 2350, 2350, 2350,    0, 2350, 2350,    0,
    0,    0,    0, 2350,    0, 2350, 2350,    0,    0, 2350,
 2350, 2350,    0,    0, 2350,    0, 2350,    0,    0, 2350,
 2350, 2350, 2350,    0, 2350,    0, 2350,    0, 2350, 2350,
 2350, 2350, 2350,    0,    0, 2350, 2350, 2350,    0, 2350,
 2350,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2350, 2350, 2350,    0, 2350, 2350, 2350,    0,    0,    0,
    0,    0, 2350,    0,    0,    0, 2350,    0, 2350, 2350,
 2350, 2350,    0, 2350,    0, 2350, 2350, 2350, 2350, 2350,
 2350, 2350, 2350,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2350, 2350,    0, 2350, 2350, 2350,    0,    0,
 1430,    0, 2350, 2350, 2350, 2350, 2350,    0, 2350,    0,
    0, 2350, 2350,    0,    0,    0, 2350, 2350,    0,    0,
 2350, 2350, 2350, 2350, 2350, 2350, 2350, 2350, 2350,    0,
 2350,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2350, 2350, 2350, 2350, 2350, 2350, 2350, 2350, 2350, 2350,
 2350, 2350, 2350, 2350, 2350, 2350, 2350, 2350, 2350, 2350,
 2350,    0, 2350, 2350, 2350, 2350, 2350, 2350,    0, 2350,
 2350, 2350, 2350,    0, 2350,    0, 2350, 2350, 2350, 2350,
 2350, 2350, 2350, 2350, 2350, 2350, 2350, 2350, 2350, 2350,
 2350, 2350, 2350, 2350,    0, 2350, 2350, 2350, 2350,    0,
 2350, 2350, 2350, 2350, 2350,    0, 2350, 2350, 2350, 2350,
 2350, 2350, 2350, 2350, 2350, 2350, 2350, 2350, 2350, 2350,
 2350, 2350, 2350, 2350, 2350, 2350, 2350, 2350, 2350, 2350,
 2350, 2350, 2350, 2350, 2350,    0, 2350, 2350,    0,    0,
    0, 2350, 2350, 2350, 2350, 2350, 2350,    0,    0, 2350,
 2350, 2350, 2350, 2350, 2350, 2350, 2350, 2350, 3584,    0,
    0,    0,    0, 2350,    0, 2350, 2350, 2350, 2350, 2350,
 2350,    0, 2350,    0,    0,    0,    0, 1432, 1431, 1433,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2350,
 2350,    0, 2350, 2350, 2350, 2350, 2350, 2350, 2350, 2350,
 2350,    0, 2350, 2350, 2350, 2350, 2350, 2350, 2350, 2350,
 2350, 2350, 2350, 2350,    0, 2350, 2350, 2350,    0, 2350,
    0,    0,    0, 2350, 2350, 2350, 2350, 2350, 2350, 2350,
 2350, 2350, 2350, 2350, 2350, 2350, 2351, 2350, 2350,    0,
    0,    0,    0,    0, 2350, 2350, 2350, 2350, 2350, 2350,
 2350, 2350, 2350, 2350, 2350, 2350, 2350, 2350, 2350, 2350,
 2350, 2350,    0,    0, 2350,    0, 2350, 2350, 2350, 2350,
 2350, 2350, 2350, 2350, 2350,    0, 1980, 2351, 2351, 2351,
 2351, 2351, 2351, 2351,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2351, 2351, 2351, 2351, 2351,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2351,    0, 2351,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1416,
    0,    0,    0,    0,    0,    0,    0,    0, 1417,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1418,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1419,    0,    0,    0,    0,
    0,    0, 1420,    0,    0,    0,    0,    0,    0,    0,
 1421,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1422,    0, 1423,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1424,
    0, 1425, 1426, 1427,    0,    0,    0,    0, 1428,    0,
    0,    0,    0, 2351,    0, 2351,    0,    0, 2351,    0,
 2351, 2351, 2351,    0, 2351, 2351,    0, 2351,    0,    0,
    0,    0,    0, 2351,    0, 2351, 2351, 2351, 2351,    0,
 2351,    0,    0, 2351,    0,    0, 2351,    0,    0, 1429,
    0,    0,    0, 2351,    0, 2351, 2351,    0, 2351, 2351,
 2351, 2351, 2351,    0,    0, 2351,    0,    0, 2351,    0,
 2351, 2351,    0,    0, 2351, 2351, 2351,    0, 2351, 2351,
 2351, 2351, 2351, 2351, 2351,    0,    0,    0, 2351, 2351,
 2351, 2351, 2351,    0,    0,    0, 2351,    0,    0,    0,
    0,    0,    0,    0, 2351, 2351, 2351, 2351, 2351, 2351,
    0,    0,    0, 2351, 2351,    0, 2351,    0, 2351,    0,
 2351, 2351, 2351,    0, 2351,    0, 2351, 2351, 2351,    0,
 2351, 2351, 2351, 2351, 2351,    0, 2351, 2351,    0,    0,
    0,    0, 2351,    0, 2351, 2351,    0,    0, 2351, 2351,
 2351,    0,    0, 2351,    0, 2351,    0,    0, 2351, 2351,
 2351, 2351,    0, 2351,    0, 2351,    0, 2351, 2351, 2351,
 2351, 2351,    0,    0, 2351, 2351, 2351,    0, 2351, 2351,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2351,
 2351, 2351,    0, 2351, 2351, 2351,    0,    0,    0,    0,
    0, 2351,    0,    0,    0, 2351,    0, 2351, 2351, 2351,
 2351,    0, 2351,    0, 2351, 2351, 2351, 2351, 2351, 2351,
 2351, 2351,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2351, 2351,    0, 2351, 2351, 2351,    0,    0, 1430,
    0, 2351, 2351, 2351, 2351, 2351,    0, 2351,    0,    0,
 2351, 2351,    0,    0,    0, 2351, 2351,    0,    0, 2351,
 2351, 2351, 2351, 2351, 2351, 2351, 2351, 2351,    0, 2351,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2351,
 2351, 2351, 2351, 2351, 2351, 2351, 2351, 2351, 2351, 2351,
 2351, 2351, 2351, 2351, 2351, 2351, 2351, 2351, 2351, 2351,
    0, 2351, 2351, 2351, 2351, 2351, 2351,    0, 2351, 2351,
 2351, 2351,    0, 2351,    0, 2351, 2351, 2351, 2351, 2351,
 2351, 2351, 2351, 2351, 2351, 2351, 2351, 2351, 2351, 2351,
 2351, 2351, 2351,    0, 2351, 2351, 2351, 2351,    0, 2351,
 2351, 2351, 2351, 2351,    0, 2351, 2351, 2351, 2351, 2351,
 2351, 2351, 2351, 2351, 2351, 2351, 2351, 2351, 2351, 2351,
 2351, 2351, 2351, 2351, 2351, 2351, 2351, 2351, 2351, 2351,
 2351, 2351, 2351, 2351,    0, 2351, 2351,    0,    0,    0,
 2351, 2351, 2351, 2351, 2351, 2351,    0,    0, 2351, 2351,
 2351, 2351, 2351, 2351, 2351, 2351, 2351, 3747,    0,    0,
    0,    0, 2351,    0, 2351, 2351, 2351, 2351, 2351, 2351,
    0, 2351,    0,    0,    0,    0, 1432, 1431, 1433,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2351, 2351,
    0, 2351, 2351, 2351, 2351, 2351, 2351, 2351, 2351, 2351,
    0, 2351, 2351, 2351, 2351, 2351, 2351, 2351, 2351, 2351,
 2351, 2351, 2351,    0, 2351, 2351, 2351,    0, 2351,    0,
    0,    0, 2351, 2351, 2351, 2351, 2351, 2351, 2351, 2351,
 2351, 2351, 2351, 2351, 2351, 2352, 2351, 2351,    0,    0,
    0,    0,    0, 2351, 2351, 2351, 2351, 2351, 2351, 2351,
 2351, 2351, 2351, 2351, 2351, 2351, 2351, 2351, 2351, 2351,
 2351,    0,    0, 2351,    0, 2351, 2351, 2351, 2351, 2351,
 2351, 2351, 2351, 2351,    0, 1946, 2352, 2352, 2352, 2352,
 2352, 2352, 2352,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2352, 2352, 2352, 2352, 2352,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2352,    0, 2352,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1416,    0,
    0,    0,    0,    0,    0,    0,    0, 1417,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1418,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1419,    0,    0,    0,    0,    0,
    0, 1420,    0,    0,    0,    0,    0,    0,    0, 1421,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1422,    0, 1423,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1424,    0,
 1425, 1426, 1427,    0,    0,    0,    0, 1428,    0,    0,
    0,    0, 2352,    0, 2352,    0,    0, 2352,    0, 2352,
 2352, 2352,    0, 2352, 2352,    0, 2352,    0,    0,    0,
    0,    0, 2352,    0, 2352, 2352, 2352, 2352,    0, 2352,
    0,    0, 2352,    0,    0, 2352,    0,    0, 1429,    0,
    0,    0, 2352,    0, 2352, 2352,    0, 2352, 2352, 2352,
 2352, 2352,    0,    0, 2352,    0,    0, 2352,    0, 2352,
 2352,    0,    0, 2352, 2352, 2352,    0, 2352, 2352, 2352,
 2352, 2352, 2352, 2352,    0,    0,    0, 2352, 2352, 2352,
 2352, 2352,    0,    0,    0, 2352,    0,    0,    0,    0,
    0,    0,    0, 2352, 2352, 2352, 2352, 2352, 2352,    0,
    0,    0, 2352, 2352,    0, 2352,    0, 2352,    0, 2352,
 2352, 2352,    0, 2352,    0, 2352, 2352, 2352,    0, 2352,
 2352, 2352, 2352, 2352,    0, 2352, 2352,    0,    0,    0,
    0, 2352,    0, 2352, 2352,    0,    0, 2352, 2352, 2352,
    0,    0, 2352,    0, 2352,    0,    0, 2352, 2352, 2352,
 2352,    0, 2352,    0, 2352,    0, 2352, 2352, 2352, 2352,
 2352,    0,    0, 2352, 2352, 2352,    0, 2352, 2352,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2352, 2352,
 2352,    0, 2352, 2352, 2352,    0,    0,    0,    0,    0,
 2352,    0,    0,    0, 2352,    0, 2352, 2352, 2352, 2352,
    0, 2352,    0, 2352, 2352, 2352, 2352, 2352, 2352, 2352,
 2352,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2352, 2352,    0, 2352, 2352, 2352,    0,    0, 1430,    0,
 2352, 2352, 2352, 2352, 2352,    0, 2352,    0,    0, 2352,
 2352,    0,    0,    0, 2352, 2352,    0,    0, 2352, 2352,
 2352, 2352, 2352, 2352, 2352, 2352, 2352,    0, 2352,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2352, 2352,
 2352, 2352, 2352, 2352, 2352, 2352, 2352, 2352, 2352, 2352,
 2352, 2352, 2352, 2352, 2352, 2352, 2352, 2352, 2352,    0,
 2352, 2352, 2352, 2352, 2352, 2352,    0, 2352, 2352, 2352,
 2352,    0, 2352,    0, 2352, 2352, 2352, 2352, 2352, 2352,
 2352, 2352, 2352, 2352, 2352, 2352, 2352, 2352, 2352, 2352,
 2352, 2352,    0, 2352, 2352, 2352, 2352,    0, 2352, 2352,
 2352, 2352, 2352,    0, 2352, 2352, 2352, 2352, 2352, 2352,
 2352, 2352, 2352, 2352, 2352, 2352, 2352, 2352, 2352, 2352,
 2352, 2352, 2352, 2352, 2352, 2352, 2352, 2352, 2352, 2352,
 2352, 2352, 2352,    0, 2352, 2352,    0,    0,    0, 2352,
 2352, 2352, 2352, 2352, 2352,    0,    0, 2352, 2352, 2352,
 2352, 2352, 2352, 2352, 2352, 2352, 3757,    0,    0,    0,
    0, 2352,    0, 2352, 2352, 2352, 2352, 2352, 2352,    0,
 2352,    0,    0,    0,    0, 1432, 1431, 1433,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2352, 2352,    0,
 2352, 2352, 2352, 2352, 2352, 2352, 2352, 2352, 2352,    0,
 2352, 2352, 2352, 2352, 2352, 2352, 2352, 2352, 2352, 2352,
 2352, 2352,    0, 2352, 2352, 2352,    0, 2352,    0,    0,
    0, 2352, 2352, 2352, 2352, 2352, 2352, 2352, 2352, 2352,
 2352, 2352, 2352, 2352, 2353, 2352, 2352,    0,    0,    0,
    0,    0, 2352, 2352, 2352, 2352, 2352, 2352, 2352, 2352,
 2352, 2352, 2352, 2352, 2352, 2352, 2352, 2352, 2352, 2352,
    0,    0, 2352,    0, 2352, 2352, 2352, 2352, 2352, 2352,
 2352, 2352, 2352,    0, 1947, 2353, 2353, 2353, 2353, 2353,
 2353, 2353,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2353, 2353, 2353, 2353, 2353,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2353,    0, 2353,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1416,    0,    0,
    0,    0,    0,    0,    0,    0, 1417,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1418,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1419,    0,    0,    0,    0,    0,    0,
 1420,    0,    0,    0,    0,    0,    0,    0, 1421,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1422,    0, 1423,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1424,    0, 1425,
 1426, 1427,    0,    0,    0,    0, 1428,    0,    0,    0,
    0, 2353,    0, 2353,    0,    0, 2353,    0, 2353, 2353,
 2353,    0, 2353, 2353,    0, 2353,    0,    0,    0,    0,
    0, 2353,    0, 2353, 2353, 2353, 2353,    0, 2353,    0,
    0, 2353,    0,    0, 2353,    0,    0, 1429,    0,    0,
    0, 2353,    0, 2353, 2353,    0, 2353, 2353, 2353, 2353,
 2353,    0,    0, 2353,    0,    0, 2353,    0, 2353, 2353,
    0,    0, 2353, 2353, 2353,    0, 2353, 2353, 2353, 2353,
 2353, 2353, 2353,    0,    0,    0, 2353, 2353, 2353, 2353,
 2353,    0,    0,    0, 2353,    0,    0,    0,    0,    0,
    0,    0, 2353, 2353, 2353, 2353, 2353, 2353,    0,    0,
    0, 2353, 2353,    0, 2353,    0, 2353,    0, 2353, 2353,
 2353,    0, 2353,    0, 2353, 2353, 2353,    0, 2353, 2353,
 2353, 2353, 2353,    0, 2353, 2353,    0,    0,    0,    0,
 2353,    0, 2353, 2353,    0,    0, 2353, 2353, 2353,    0,
    0, 2353,    0, 2353,    0,    0, 2353, 2353, 2353, 2353,
    0, 2353,    0, 2353,    0, 2353, 2353, 2353, 2353, 2353,
    0,    0, 2353, 2353, 2353,    0, 2353, 2353,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2353, 2353, 2353,
    0, 2353, 2353, 2353,    0,    0,    0,    0,    0, 2353,
    0,    0,    0, 2353,    0, 2353, 2353, 2353, 2353,    0,
 2353,    0, 2353, 2353, 2353, 2353, 2353, 2353, 2353, 2353,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2353,
 2353,    0, 2353, 2353, 2353,    0,    0, 1430,    0, 2353,
 2353, 2353, 2353, 2353,    0, 2353,    0,    0, 2353, 2353,
    0,    0,    0, 2353, 2353,    0,    0, 2353, 2353, 2353,
 2353, 2353, 2353, 2353, 2353, 2353,    0, 2353,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2353, 2353, 2353,
 2353, 2353, 2353, 2353, 2353, 2353, 2353, 2353, 2353, 2353,
 2353, 2353, 2353, 2353, 2353, 2353, 2353, 2353,    0, 2353,
 2353, 2353, 2353, 2353, 2353,    0, 2353, 2353, 2353, 2353,
    0, 2353,    0, 2353, 2353, 2353, 2353, 2353, 2353, 2353,
 2353, 2353, 2353, 2353, 2353, 2353, 2353, 2353, 2353, 2353,
 2353,    0, 2353, 2353, 2353, 2353,    0, 2353, 2353, 2353,
 2353, 2353,    0, 2353, 2353, 2353, 2353, 2353, 2353, 2353,
 2353, 2353, 2353, 2353, 2353, 2353, 2353, 2353, 2353, 2353,
 2353, 2353, 2353, 2353, 2353, 2353, 2353, 2353, 2353, 2353,
 2353, 2353,    0, 2353, 2353,    0,    0,    0, 2353, 2353,
 2353, 2353, 2353, 2353,    0,    0, 2353, 2353, 2353, 2353,
 2353, 2353, 2353, 2353, 2353, 3801,    0,    0,    0,    0,
 2353,    0, 2353, 2353, 2353, 2353, 2353, 2353,    0, 2353,
    0,    0,    0,    0, 1432, 1431, 1433,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2353, 2353,    0, 2353,
 2353, 2353, 2353, 2353, 2353, 2353, 2353, 2353,    0, 2353,
 2353, 2353, 2353, 2353, 2353, 2353, 2353, 2353, 2353, 2353,
 2353,    0, 2353, 2353, 2353,    0, 2353,    0,    0,    0,
 2353, 2353, 2353, 2353, 2353, 2353, 2353, 2353, 2353, 2353,
 2353, 2353, 2353, 2363, 2353, 2353,    0,    0,    0,    0,
    0, 2353, 2353, 2353, 2353, 2353, 2353, 2353, 2353, 2353,
 2353, 2353, 2353, 2353, 2353, 2353, 2353, 2353, 2353,    0,
    0, 2353,    0, 2353, 2353, 2353, 2353, 2353, 2353, 2353,
 2353, 2353,    0, 1957, 2363, 2363, 2363, 2363, 2363, 2363,
 2363,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2363, 2363, 2363, 2363, 2363,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2363,    0, 2363,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1416,    0,    0,    0,
    0,    0,    0,    0,    0, 1417,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1418,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1419,    0,    0,    0,    0,    0,    0, 1420,
    0,    0,    0,    0,    0,    0,    0, 1421,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1422,    0, 1423,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1424,    0, 1425, 1426,
 1427,    0,    0,    0,    0, 1428,    0,    0,    0,    0,
 2363,    0, 2363,    0,    0, 2363,    0, 2363, 2363, 2363,
    0, 2363, 2363,    0, 2363,    0,    0,    0,    0,    0,
 2363,    0, 2363, 2363, 2363, 2363,    0, 2363,    0,    0,
 2363,    0,    0, 2363,    0,    0, 1429,    0,    0,    0,
 2363,    0, 2363, 2363,    0, 2363, 2363, 2363, 2363, 2363,
    0,    0, 2363,    0,    0, 2363,    0, 2363, 2363,    0,
    0, 2363, 2363, 2363,    0, 2363, 2363, 2363, 2363, 2363,
 2363, 2363,    0,    0,    0, 2363, 2363, 2363, 2363, 2363,
    0,    0,    0, 2363,    0,    0,    0,    0,    0,    0,
    0, 2363, 2363, 2363, 2363, 2363, 2363,    0,    0,    0,
 2363, 2363,    0, 2363,    0, 2363,    0, 2363, 2363, 2363,
    0, 2363,    0, 2363, 2363, 2363,    0, 2363, 2363, 2363,
 2363, 2363,    0, 2363, 2363,    0,    0,    0,    0, 2363,
    0, 2363, 2363,    0,    0, 2363, 2363, 2363,    0,    0,
 2363,    0, 2363,    0,    0, 2363, 2363, 2363, 2363,    0,
 2363,    0, 2363,    0, 2363, 2363, 2363, 2363, 2363,    0,
    0, 2363, 2363, 2363,    0, 2363, 2363,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2363, 2363, 2363,    0,
 2363, 2363, 2363,    0,    0,    0,    0,    0, 2363,    0,
    0,    0, 2363,    0, 2363, 2363, 2363, 2363,    0, 2363,
    0, 2363, 2363, 2363, 2363, 2363, 2363, 2363, 2363,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2363, 2363,
    0, 2363, 2363, 2363,    0,    0, 1430,    0, 2363, 2363,
 2363, 2363, 2363,    0, 2363,    0,    0, 2363, 2363,    0,
    0,    0, 2363, 2363,    0,    0, 2363, 2363, 2363, 2363,
 2363, 2363, 2363, 2363, 2363,    0, 2363,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2363, 2363, 2363, 2363,
 2363, 2363, 2363, 2363, 2363, 2363, 2363, 2363, 2363, 2363,
 2363, 2363, 2363, 2363, 2363, 2363, 2363,    0, 2363, 2363,
 2363, 2363, 2363, 2363,    0, 2363, 2363, 2363, 2363,    0,
 2363,    0, 2363, 2363, 2363, 2363, 2363, 2363, 2363, 2363,
 2363, 2363, 2363, 2363, 2363, 2363, 2363, 2363, 2363, 2363,
    0, 2363, 2363, 2363, 2363,    0, 2363, 2363, 2363, 2363,
 2363,    0, 2363, 2363, 2363, 2363, 2363, 2363, 2363, 2363,
 2363, 2363, 2363, 2363, 2363, 2363, 2363, 2363, 2363, 2363,
 2363, 2363, 2363, 2363, 2363, 2363, 2363, 2363, 2363, 2363,
 2363,    0, 2363, 2363,    0,    0,    0, 2363, 2363, 2363,
 2363, 2363, 2363,    0,    0, 2363, 2363, 2363, 2363, 2363,
 2363, 2363, 2363, 2363,    0, 1689, 1689, 1687, 1689, 2363,
 1689, 2363, 2363, 2363, 2363, 2363, 2363,    0, 2363,    0,
    0,    0,    0, 1687, 1687, 1687,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2363, 2363,    0, 2363, 2363,
 2363, 2363, 2363, 2363, 2363, 2363, 2363,    0, 2363, 2363,
 2363, 2363, 2363, 2363, 2363, 2363, 2363, 2363, 2363, 2363,
    0, 2363, 2363, 2363,    0, 2363,    0,    0,    0, 2363,
 2363, 2363, 2363, 2363, 2363, 2363, 2363, 2363, 2363, 2363,
 2363, 2363, 2368, 2363, 2363,    0,    0,    0,    0,    0,
 2363, 2363, 2363, 2363, 2363, 2363, 2363, 2363, 2363, 2363,
 2363, 2363, 2363, 2363, 2363, 2363, 2363, 2363,    0,    0,
 2363,    0, 2363, 2363, 2363, 2363, 2363, 2363, 2363, 2363,
 2363,    0, 1914, 2368, 2368, 2368, 2368, 2368, 2368, 2368,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2368, 2368, 2368, 2368, 2368,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2368,    0, 2368,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1687,    0,    0,    0, 1689,
    0,    0,    0,    0, 1687,    0,    0,    0,    0,    0,
 1689,    0,    0,    0, 1689,    0,    0, 1687,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1687,    0,    0,    0,    0,    0,    0, 1687,    0,
    0,    0,    0,    0,    0,    0, 1687,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1687,    0, 1687,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1687,    0, 1687, 1687, 1687,
    0,    0,    0,    0, 1687,    0,    0,    0,    0, 2368,
    0, 2368,    0,    0, 2368,    0, 2368, 2368, 2368,    0,
 2368, 2368,    0, 2368,    0,    0,    0,    0,    0, 2368,
    0, 2368, 2368, 2368, 2368,    0, 2368,    0,    0, 2368,
    0,    0, 2368,    0,    0, 1687,    0,    0,    0, 2368,
    0, 2368, 2368,    0, 2368, 2368, 2368, 2368, 2368,    0,
    0, 2368,    0,    0, 2368,    0, 2368, 2368,    0,    0,
 2368, 2368, 2368,    0, 2368, 2368, 2368, 2368, 2368, 2368,
 2368,    0,    0,    0, 2368, 2368, 2368, 2368, 2368,    0,
    0,    0, 2368,    0,    0,    0,    0,    0,    0,    0,
 2368, 2368, 2368, 2368, 2368, 2368,    0,    0,    0, 2368,
 2368,    0, 2368,    0, 2368,    0, 2368, 2368, 2368,    0,
 2368,    0, 2368, 2368, 2368,    0, 2368, 2368, 2368, 2368,
 2368,    0, 2368, 2368,    0,    0,    0,    0, 2368,    0,
 2368, 2368,    0,    0, 2368, 2368, 2368,    0,    0, 2368,
    0, 2368,    0,    0, 2368, 2368, 2368, 2368,    0, 2368,
    0, 2368,    0, 2368, 2368, 2368, 2368, 2368,    0,    0,
 2368, 2368, 2368,    0, 2368, 2368,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2368, 2368, 2368,    0, 2368,
 2368, 2368,    0,    0,    0,    0,    0, 2368,    0,    0,
    0, 2368,    0, 2368, 2368, 2368, 2368,    0, 2368,    0,
 2368, 2368, 2368, 2368, 2368, 2368, 2368, 2368,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2368, 2368,    0,
 2368, 2368, 2368,    0,    0, 1687,    0, 2368, 2368, 2368,
 2368, 2368,    0, 2368,    0,    0, 2368, 2368,    0,    0,
    0, 2368, 2368,    0,    0, 2368, 2368, 2368, 2368, 2368,
 2368, 2368, 2368, 2368,    0, 2368,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2368, 2368, 2368, 2368, 2368,
 2368, 2368, 2368, 2368, 2368, 2368, 2368, 2368, 2368, 2368,
 2368, 2368, 2368, 2368, 2368, 2368,    0, 2368, 2368, 2368,
 2368, 2368, 2368,    0, 2368, 2368, 2368, 2368,    0, 2368,
    0, 2368, 2368, 2368, 2368, 2368, 2368, 2368, 2368, 2368,
 2368, 2368, 2368, 2368, 2368, 2368, 2368, 2368, 2368,    0,
 2368, 2368, 2368, 2368,    0, 2368, 2368, 2368, 2368, 2368,
    0, 2368, 2368, 2368, 2368, 2368, 2368, 2368, 2368, 2368,
 2368, 2368, 2368, 2368, 2368, 2368, 2368, 2368, 2368, 2368,
 2368, 2368, 2368, 2368, 2368, 2368, 2368, 2368, 2368, 2368,
    0, 2368, 2368,    0,    0,    0, 2368, 2368, 2368, 2368,
 2368, 2368,    0,    0, 2368, 2368, 2368, 2368, 2368, 2368,
 2368, 2368, 2368,    0, 2145,    0,    0,    0, 2368,    0,
 2368, 2368, 2368, 2368, 2368, 2368,    0, 2368,    0,    0,
 1432, 1431, 1433,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2368, 2368,    0, 2368, 2368, 2368,
 2368, 2368, 2368, 2368, 2368, 2368,    0, 2368, 2368, 2368,
 2368, 2368, 2368, 2368, 2368, 2368, 2368, 2368, 2368,    0,
 2368, 2368, 2368,    0, 2368,    0,    0,    0, 2368, 2368,
 2368, 2368, 2368, 2368, 2368, 2368, 2368, 2368, 2368, 2368,
 2368, 2112, 2368, 2368,    0,    0,    0,    0,    0, 2368,
 2368, 2368, 2368, 2368, 2368, 2368, 2368, 2368, 2368, 2368,
 2368, 2368, 2368, 2368, 2368, 2368, 2368,    0,    0, 2368,
    0, 2368, 2368, 2368, 2368, 2368, 2368, 2368, 2368, 2368,
    0,    0, 2112, 2112, 2112, 2112, 2112, 2112, 2112,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2112,
 2112, 2112, 2112, 2112,    0,    0,    0,    0,    0,    0,
    0,    0,    0,   91,    0,    0,    0,    0,    0,    0,
    0,    0,    0,   92,    0,    0,    0,    0,    0,   93,
    0,    0, 2112,    0, 2112,    0,    0,    0,    0,   94,
    0,    0,   95,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1416,    0,    0,    0,    0,    0,    0,    0,
    0, 1417,    0,    0,   96,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1418,    0,    0,    0,    0,    0,
   97,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   98,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1419,    0,
   99,    0,    0,    0,  100, 1420,    0,  101,    0,  102,
    0,    0,    0, 1421,    0,  103,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1422,    0, 1423,    0,    0,    0,    0,  104,    0,    0,
    0,    0, 1424,    0, 1425, 1426, 1427,    0,    0,    0,
    0, 1428,    0,    0,    0,    0,    0,    0, 2112,    0,
 2112,    0,    0, 2112,    0, 2112, 2112, 2112,    0, 2112,
 2112,    0, 2112,    0,    0,    0,    0,    0, 2112,    0,
 2112, 2112, 2112, 2112,    0, 2112,    0,    0, 2112,    0,
    0, 2112, 1429,  105,    0,    0,  106,    0, 2112,    0,
 2112, 2112,    0, 2112, 2112, 2112, 2112, 2112,    0,    0,
 2112,    0,    0, 2112,    0, 2112, 2112,    0,    0, 2112,
 2112, 2112,    0, 2112, 2112, 2112, 2112, 2112, 2112, 2112,
    0,    0,    0, 2112, 2112, 2112, 2112, 2112,    0,  107,
    0, 2112,    0,    0,    0,    0,    0,    0,    0, 2112,
 2112, 2112, 2112, 2112, 2112,    0,    0,    0, 2112, 2112,
    0, 2112,    0, 2112,    0, 2112, 2112, 2112,    0, 2112,
    0, 2112, 2112, 2112,    0, 2112, 2112, 2112, 2112, 2112,
    0, 2112, 2112,  108,    0,    0,    0, 2112,    0, 2112,
 2112,    0,    0, 2112, 2112, 2112,    0,    0, 2112,    0,
 2112,    0,  109, 2112, 2112, 2112, 2112,    0, 2112,    0,
 2112,    0, 2112, 2112, 2112, 2112, 2112,    0,    0, 2112,
 2112, 2112,    0, 2112, 2112,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2112, 2112, 2112,    0, 2112, 2112,
 2112,    0,    0,    0,    0,    0, 2112,    0,    0,    0,
 2112,    0, 2112, 2112, 2112, 2112,    0, 2112,    0, 2112,
 2112, 2112, 2112, 2112, 2112, 2112, 2112,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2112, 2112,    0, 2112,
 2112, 2112, 1430,    0,    0,    0, 2112, 2112, 2112, 2112,
 2112,    0, 2112,    0,    0, 2112, 2112,    0,    0,    0,
 2112, 2112,    0,    0, 2112, 2112, 2112, 2112, 2112, 2112,
 2112, 2112, 2112,    0, 2112,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2112, 2112, 2112, 2112, 2112, 2112,
 2112, 2112, 2112, 2112, 2112, 2112, 2112, 2112, 2112, 2112,
 2112, 2112, 2112, 2112, 2112,    0, 2112, 2112, 2112, 2112,
 2112, 2112,    0, 2112, 2112, 2112, 2112,    0, 2112,    0,
 2112, 2112, 2112, 2112, 2112, 2112, 2112, 2112, 2112, 2112,
 2112, 2112, 2112, 2112, 2112, 2112, 2112, 2112,    0, 2112,
 2112, 2112, 2112,    0, 2112, 2112, 2112, 2112, 2112,    0,
 2112, 2112, 2112, 2112, 2112, 2112, 2112, 2112, 2112, 2112,
 2112, 2112, 2112, 2112, 2112, 2112, 2112, 2112, 2112, 2112,
 2112, 2112, 2112, 2112, 2112, 2112, 2112, 2112, 2112,    0,
 2112, 2112,    0,    0,    0, 2112, 2112, 2112, 2112, 2112,
 2112,    0,    0, 2112, 2112, 2112, 2112, 2112, 2112, 2112,
 2112, 2112,    0, 2146,    0,    0,    0, 2112,    0, 2112,
 2112, 2112, 2112, 2112, 2112,    0, 2112,    0,    0, 1432,
 1431, 1433,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2112, 2112,    0, 2112, 2112, 2112, 2112,
 2112, 2112, 2112, 2112, 2112,    0, 2112, 2112, 2112, 2112,
 2112, 2112, 2112, 2112, 2112, 2112, 2112, 2112,    0, 2112,
 2112, 2112,    0, 2112,    0,    0,    0, 2112, 2112, 2112,
 2112, 2112, 2112, 2112, 2112, 2112, 2112, 2112, 2112, 2112,
 2157, 2112, 2112,    0,    0,    0,    0,    0, 2112, 2112,
 2112, 2112, 2112, 2112, 2112, 2112, 2112, 2112, 2112, 2112,
 2112, 2112, 2112, 2112, 2112, 2112,    0,    0, 2112,    0,
 2112, 2112, 2112, 2112, 2112, 2112, 2112, 2112, 2112,    0,
    0, 2157, 2157, 2157, 2157, 2157, 2157, 2157,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2157, 2157,
 2157, 2157, 2157,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2157,    0, 2157,    0,    0,    0,    0,  116,    0,
    0,    0,    0,    0,  117,    0,    0,    0,  118,  119,
    0,    0,    0,    0,  120,    0,    0,  121,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  122,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1416,    0,    0,    0,    0,    0,    0,    0,    0,
 1417,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1418,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  123,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1419,    0,    0,
  124,    0,    0,    0, 1420,    0,    0,    0,    0,    0,
    0,    0, 1421,    0,    0,  125,    0,    0,    0,  126,
    0,    0,    0,    0,  127,    0,    0,    0,    0, 1422,
  128, 1423,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1424,    0, 1425, 1426, 1427,    0,    0,    0,    0,
 1428,    0,  129,    0,    0,    0,    0, 2157,    0, 2157,
    0,    0, 2157,    0, 2157, 2157, 2157,    0, 2157, 2157,
    0, 2157,    0,    0,    0,    0,    0, 2157,    0, 2157,
 2157, 2157, 2157,    0, 2157,    0,    0, 2157,    0,    0,
 2157, 1429,    0,    0,    0,    0,    0, 2157,    0, 2157,
 2157,    0, 2157, 2157, 2157, 2157, 2157,    0,  130, 2157,
    0,  131, 2157,    0, 2157, 2157,    0,    0, 2157, 2157,
 2157,    0, 2157, 2157, 2157, 2157, 2157, 2157, 2157,    0,
    0,    0, 2157, 2157, 2157, 2157, 2157,    0,    0,    0,
 2157,    0,    0,    0,    0,    0,    0,    0, 2157, 2157,
 2157, 2157, 2157, 2157,  132,    0,    0, 2157, 2157,    0,
 2157,    0, 2157,    0, 2157, 2157, 2157,    0, 2157,    0,
 2157, 2157, 2157,    0, 2157, 2157, 2157, 2157, 2157,    0,
 2157, 2157,    0,    0,    0,    0, 2157,    0, 2157, 2157,
    0,    0, 2157, 2157, 2157,    0,    0, 2157,  133, 2157,
    0,    0, 2157, 2157, 2157, 2157,    0, 2157,    0, 2157,
    0, 2157, 2157, 2157, 2157, 2157,    0,  134, 2157, 2157,
 2157,    0, 2157, 2157,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2157, 2157, 2157,    0, 2157, 2157, 2157,
    0,    0,    0,    0,    0, 2157,    0,    0,    0, 2157,
    0, 2157, 2157, 2157, 2157,    0, 2157,    0, 2157, 2157,
 2157, 2157, 2157, 2157, 2157, 2157,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2157, 2157,    0, 2157, 2157,
 2157, 1430,    0,    0,    0, 2157, 2157, 2157, 2157, 2157,
    0, 2157,    0,    0, 2157, 2157,    0,    0,    0, 2157,
 2157,    0,    0, 2157, 2157, 2157, 2157, 2157, 2157, 2157,
 2157, 2157,    0, 2157,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2157, 2157, 2157, 2157, 2157, 2157, 2157,
 2157, 2157, 2157, 2157, 2157, 2157, 2157, 2157, 2157, 2157,
 2157, 2157, 2157, 2157,    0, 2157, 2157, 2157, 2157, 2157,
 2157,    0, 2157, 2157, 2157, 2157,    0, 2157,    0, 2157,
 2157, 2157, 2157, 2157, 2157, 2157, 2157, 2157, 2157, 2157,
 2157, 2157, 2157, 2157, 2157, 2157, 2157,    0, 2157, 2157,
 2157, 2157,    0, 2157, 2157, 2157, 2157, 2157,    0, 2157,
 2157, 2157, 2157, 2157, 2157, 2157, 2157, 2157, 2157, 2157,
 2157, 2157, 2157, 2157, 2157, 2157, 2157, 2157, 2157, 2157,
 2157, 2157, 2157, 2157, 2157, 2157, 2157, 2157,    0, 2157,
 2157,    0,    0,    0, 2157, 2157, 2157, 2157, 2157, 2157,
    0,    0, 2157, 2157, 2157, 2157, 2157, 2157, 2157, 2157,
 2157,    0, 2162,    0,    0,    0, 2157,    0, 2157, 2157,
 2157, 2157, 2157, 2157,    0, 2157,    0,    0, 1432, 1431,
 1433,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2157, 2157,    0, 2157, 2157, 2157, 2157, 2157,
 2157, 2157, 2157, 2157,    0, 2157, 2157, 2157, 2157, 2157,
 2157, 2157, 2157, 2157, 2157, 2157, 2157,    0, 2157, 2157,
 2157,    0, 2157,    0,    0,    0, 2157, 2157, 2157, 2157,
 2157, 2157, 2157, 2157, 2157, 2157, 2157, 2157, 2157, 2158,
 2157, 2157,    0,    0,    0,    0,    0, 2157, 2157, 2157,
 2157, 2157, 2157, 2157, 2157, 2157, 2157, 2157, 2157, 2157,
 2157, 2157, 2157, 2157, 2157,    0,    0, 2157,    0, 2157,
 2157, 2157, 2157, 2157, 2157, 2157, 2157, 2157,    0,    0,
 2158, 2158, 2158, 2158, 2158, 2158, 2158,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2158, 2158, 2158,
 2158, 2158,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2158,    0, 2158,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1416,    0,    0,    0,    0,    0,    0,    0,    0, 1417,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1418,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1419,    0,    0,    0,
    0,    0,    0, 1420,    0,    0,    0,    0,    0,    0,
    0, 1421,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1422,    0,
 1423,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1424,    0, 1425, 1426, 1427,    0,    0,    0,    0, 1428,
    0,    0,    0,    0,    0,    0, 2158,    0, 2158,    0,
    0, 2158,    0, 2158, 2158, 2158,    0, 2158, 2158,    0,
 2158,    0,    0,    0,    0,    0, 2158,    0, 2158, 2158,
 2158, 2158,    0, 2158,    0,    0, 2158,    0,    0, 2158,
 1429,    0,    0,    0,    0,    0, 2158,    0, 2158, 2158,
    0, 2158, 2158, 2158, 2158, 2158,    0,    0, 2158,    0,
    0, 2158,    0, 2158, 2158,    0,    0, 2158, 2158, 2158,
    0, 2158, 2158, 2158, 2158, 2158, 2158, 2158,    0,    0,
    0, 2158, 2158, 2158, 2158, 2158,    0,    0,    0, 2158,
    0,    0,    0,    0,    0,    0,    0, 2158, 2158, 2158,
 2158, 2158, 2158,    0,    0,    0, 2158, 2158,    0, 2158,
    0, 2158,    0, 2158, 2158, 2158,    0, 2158,    0, 2158,
 2158, 2158,    0, 2158, 2158, 2158, 2158, 2158,    0, 2158,
 2158,    0,    0,    0,    0, 2158,    0, 2158, 2158,    0,
    0, 2158, 2158, 2158,    0,    0, 2158,    0, 2158,    0,
    0, 2158, 2158, 2158, 2158,    0, 2158,    0, 2158,    0,
 2158, 2158, 2158, 2158, 2158,    0,    0, 2158, 2158, 2158,
    0, 2158, 2158,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2158, 2158, 2158,    0, 2158, 2158, 2158,    0,
    0,    0,    0,    0, 2158,    0,    0,    0, 2158,    0,
 2158, 2158, 2158, 2158,    0, 2158,    0, 2158, 2158, 2158,
 2158, 2158, 2158, 2158, 2158,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2158, 2158,    0, 2158, 2158, 2158,
 1430,    0,    0,    0, 2158, 2158, 2158, 2158, 2158,    0,
 2158,    0,    0, 2158, 2158,    0,    0,    0, 2158, 2158,
    0,    0, 2158, 2158, 2158, 2158, 2158, 2158, 2158, 2158,
 2158,    0, 2158,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2158, 2158, 2158, 2158, 2158, 2158, 2158, 2158,
 2158, 2158, 2158, 2158, 2158, 2158, 2158, 2158, 2158, 2158,
 2158, 2158, 2158,    0, 2158, 2158, 2158, 2158, 2158, 2158,
    0, 2158, 2158, 2158, 2158,    0, 2158,    0, 2158, 2158,
 2158, 2158, 2158, 2158, 2158, 2158, 2158, 2158, 2158, 2158,
 2158, 2158, 2158, 2158, 2158, 2158,    0, 2158, 2158, 2158,
 2158,    0, 2158, 2158, 2158, 2158, 2158,    0, 2158, 2158,
 2158, 2158, 2158, 2158, 2158, 2158, 2158, 2158, 2158, 2158,
 2158, 2158, 2158, 2158, 2158, 2158, 2158, 2158, 2158, 2158,
 2158, 2158, 2158, 2158, 2158, 2158, 2158,    0, 2158, 2158,
    0,    0,    0, 2158, 2158, 2158, 2158, 2158, 2158,    0,
    0, 2158, 2158, 2158, 2158, 2158, 2158, 2158, 2158, 2158,
    0, 2168,    0,    0,    0, 2158,    0, 2158, 2158, 2158,
 2158, 2158, 2158,    0, 2158,    0,    0, 1432, 1431, 1433,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2158, 2158,    0, 2158, 2158, 2158, 2158, 2158, 2158,
 2158, 2158, 2158,    0, 2158, 2158, 2158, 2158, 2158, 2158,
 2158, 2158, 2158, 2158, 2158, 2158,    0, 2158, 2158, 2158,
    0, 2158,    0,    0,    0, 2158, 2158, 2158, 2158, 2158,
 2158, 2158, 2158, 2158, 2158, 2158, 2158, 2158, 2164, 2158,
 2158,    0,    0,    0,    0,    0, 2158, 2158, 2158, 2158,
 2158, 2158, 2158, 2158, 2158, 2158, 2158, 2158, 2158, 2158,
 2158, 2158, 2158, 2158,    0,    0, 2158,    0, 2158, 2158,
 2158, 2158, 2158, 2158, 2158, 2158, 2158,    0,    0, 2164,
 2164, 2164, 2164, 2164, 2164, 2164,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2164, 2164, 2164, 2164,
 2164,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2164,
    0, 2164,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1416,
    0,    0,    0,    0,    0,    0,    0,    0, 1417,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1418,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1419,    0,    0,    0,    0,
    0,    0, 1420,    0,    0,    0,    0,    0,    0,    0,
 1421,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1422,    0, 1423,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1424,
    0, 1425, 1426, 1427,    0,    0,    0,    0, 1428,    0,
    0,    0,    0,    0,    0, 2164,    0, 2164,    0,    0,
 2164,    0, 2164, 2164, 2164,    0, 2164, 2164,    0, 2164,
    0,    0,    0,    0,    0, 2164,    0, 2164, 2164, 2164,
 2164,    0, 2164,    0,    0, 2164,    0,    0, 2164, 1429,
    0,    0,    0,    0,    0, 2164,    0, 2164, 2164,    0,
 2164, 2164, 2164, 2164, 2164,    0,    0, 2164,    0,    0,
 2164,    0, 2164, 2164,    0,    0, 2164, 2164, 2164,    0,
 2164, 2164, 2164, 2164, 2164, 2164, 2164,    0,    0,    0,
 2164, 2164, 2164, 2164, 2164,    0,    0,    0, 2164,    0,
    0,    0,    0,    0,    0,    0, 2164, 2164, 2164, 2164,
 2164, 2164,    0,    0,    0, 2164, 2164,    0, 2164,    0,
 2164,    0, 2164, 2164, 2164,    0, 2164,    0, 2164, 2164,
 2164,    0, 2164, 2164, 2164, 2164, 2164,    0, 2164, 2164,
    0,    0,    0,    0, 2164,    0, 2164, 2164,    0,    0,
 2164, 2164, 2164,    0,    0, 2164,    0, 2164,    0,    0,
 2164, 2164, 2164, 2164,    0, 2164,    0, 2164,    0, 2164,
 2164, 2164, 2164, 2164,    0,    0, 2164, 2164, 2164,    0,
 2164, 2164,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2164, 2164, 2164,    0, 2164, 2164, 2164,    0,    0,
    0,    0,    0, 2164,    0,    0,    0, 2164,    0, 2164,
 2164, 2164, 2164,    0, 2164,    0, 2164, 2164, 2164, 2164,
 2164, 2164, 2164, 2164,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2164, 2164,    0, 2164, 2164, 2164, 1430,
    0,    0,    0, 2164, 2164, 2164, 2164, 2164,    0, 2164,
    0,    0, 2164, 2164,    0,    0,    0, 2164, 2164,    0,
    0, 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164,
    0, 2164,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164,
 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164,
 2164, 2164,    0, 2164, 2164, 2164, 2164, 2164, 2164,    0,
 2164, 2164, 2164, 2164,    0, 2164,    0, 2164, 2164, 2164,
 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164,
 2164, 2164, 2164, 2164, 2164,    0, 2164, 2164, 2164, 2164,
    0, 2164, 2164, 2164, 2164, 2164,    0, 2164, 2164, 2164,
 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164,
 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164,
 2164, 2164, 2164, 2164, 2164, 2164,    0, 2164, 2164,    0,
    0,    0, 2164, 2164, 2164, 2164, 2164, 2164,    0,    0,
 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164,    0,
 2178,    0,    0,    0, 2164,    0, 2164, 2164, 2164, 2164,
 2164, 2164,    0, 2164,    0,    0, 1432, 1431, 1433,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2164, 2164,    0, 2164, 2164, 2164, 2164, 2164, 2164, 2164,
 2164, 2164,    0, 2164, 2164, 2164, 2164, 2164, 2164, 2164,
 2164, 2164, 2164, 2164, 2164,    0, 2164, 2164, 2164,    0,
 2164,    0,    0,    0, 2164, 2164, 2164, 2164, 2164, 2164,
 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2176, 2164, 2164,
    0,    0,    0,    0,    0, 2164, 2164, 2164, 2164, 2164,
 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164,
 2164, 2164, 2164,    0,    0, 2164,    0, 2164, 2164, 2164,
 2164, 2164, 2164, 2164, 2164, 2164,    0,    0, 2176, 2176,
 2176, 2176, 2176, 2176, 2176,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2176, 2176, 2176, 2176, 2176,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2176,    0,
 2176,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1416,    0,
    0,    0,    0,    0,    0,    0,    0, 1417,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1418,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1419,    0,    0,    0,    0,    0,
    0, 1420,    0,    0,    0,    0,    0,    0,    0, 1421,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1422,    0, 1423,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1424,    0,
 1425, 1426, 1427,    0,    0,    0,    0, 1428,    0,    0,
    0,    0,    0,    0, 2176,    0, 2176,    0,    0, 2176,
    0, 2176, 2176, 2176,    0, 2176, 2176,    0, 2176,    0,
    0,    0,    0,    0, 2176,    0, 2176, 2176, 2176, 2176,
    0, 2176,    0,    0, 2176,    0,    0, 2176, 1429,    0,
    0,    0,    0,    0, 2176,    0, 2176, 2176,    0, 2176,
 2176, 2176, 2176, 2176,    0,    0, 2176,    0,    0, 2176,
    0, 2176, 2176,    0,    0, 2176, 2176, 2176,    0, 2176,
 2176, 2176, 2176, 2176, 2176, 2176,    0,    0,    0, 2176,
 2176, 2176, 2176, 2176,    0,    0,    0, 2176,    0,    0,
    0,    0,    0,    0,    0, 2176, 2176, 2176, 2176, 2176,
 2176,    0,    0,    0, 2176, 2176,    0, 2176,    0, 2176,
    0, 2176, 2176, 2176,    0, 2176,    0, 2176, 2176, 2176,
    0, 2176, 2176, 2176, 2176, 2176,    0, 2176, 2176,    0,
    0,    0,    0, 2176,    0, 2176, 2176,    0,    0, 2176,
 2176, 2176,    0,    0, 2176,    0, 2176,    0,    0, 2176,
 2176, 2176, 2176,    0, 2176,    0, 2176,    0, 2176, 2176,
 2176, 2176, 2176,    0,    0, 2176, 2176, 2176,    0, 2176,
 2176,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2176, 2176, 2176,    0, 2176, 2176, 2176,    0,    0,    0,
    0,    0, 2176,    0,    0,    0, 2176,    0, 2176, 2176,
 2176, 2176,    0, 2176,    0, 2176, 2176, 2176, 2176, 2176,
 2176, 2176, 2176,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2176, 2176,    0, 2176, 2176, 2176, 1430,    0,
    0,    0, 2176, 2176, 2176, 2176, 2176,    0, 2176,    0,
    0, 2176, 2176,    0,    0,    0, 2176, 2176,    0,    0,
 2176, 2176, 2176, 2176, 2176, 2176, 2176, 2176, 2176,    0,
 2176,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2176, 2176, 2176, 2176, 2176, 2176, 2176, 2176, 2176, 2176,
 2176, 2176, 2176, 2176, 2176, 2176, 2176, 2176, 2176, 2176,
 2176,    0, 2176, 2176, 2176, 2176, 2176, 2176,    0, 2176,
 2176, 2176, 2176,    0, 2176,    0, 2176, 2176, 2176, 2176,
 2176, 2176, 2176, 2176, 2176, 2176, 2176, 2176, 2176, 2176,
 2176, 2176, 2176, 2176,    0, 2176, 2176, 2176, 2176,    0,
 2176, 2176, 2176, 2176, 2176,    0, 2176, 2176, 2176, 2176,
 2176, 2176, 2176, 2176, 2176, 2176, 2176, 2176, 2176, 2176,
 2176, 2176, 2176, 2176, 2176, 2176, 2176, 2176, 2176, 2176,
 2176, 2176, 2176, 2176, 2176,    0, 2176, 2176,    0,    0,
    0, 2176, 2176, 2176, 2176, 2176, 2176,    0,    0, 2176,
 2176, 2176, 2176, 2176, 2176, 2176, 2176, 2176,    0, 2179,
    0,    0,    0, 2176,    0, 2176, 2176, 2176, 2176, 2176,
 2176,    0, 2176,    0,    0, 1432, 1431, 1433,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2176,
 2176,    0, 2176, 2176, 2176, 2176, 2176, 2176, 2176, 2176,
 2176,    0, 2176, 2176, 2176, 2176, 2176, 2176, 2176, 2176,
 2176, 2176, 2176, 2176,    0, 2176, 2176, 2176,    0, 2176,
    0,    0,    0, 2176, 2176, 2176, 2176, 2176, 2176, 2176,
 2176, 2176, 2176, 2176, 2176, 2176, 2321, 2176, 2176,    0,
    0,    0,    0,    0, 2176, 2176, 2176, 2176, 2176, 2176,
 2176, 2176, 2176, 2176, 2176, 2176, 2176, 2176, 2176, 2176,
 2176, 2176,    0,    0, 2176,    0, 2176, 2176, 2176, 2176,
 2176, 2176, 2176, 2176, 2176,    0,    0, 2321, 2321, 2321,
 2321, 2321, 2321, 2321,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2321, 2321, 2321, 2321, 2321,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2321,    0, 2321,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1416,    0,    0,
    0,    0,    0,    0,    0,    0, 1417,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1418,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1419,    0,    0,    0,    0,    0,    0,
 1420,    0,    0,    0,    0,    0,    0,    0, 1421,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1422,    0, 1423,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1424,    0, 1425,
 1426, 1427,    0,    0,    0,    0, 1428,    0,    0,    0,
    0,    0,    0, 2321,    0, 2321,    0,    0, 2321,    0,
 2321, 2321, 2321,    0, 2321, 2321,    0, 2321,    0,    0,
    0,    0,    0, 2321,    0, 2321, 2321, 2321, 2321,    0,
 2321,    0,    0, 2321,    0,    0, 2321, 1429,    0,    0,
    0,    0,    0, 2321,    0, 2321, 2321,    0, 2321, 2321,
 2321, 2321, 2321,    0,    0, 2321,    0,    0, 2321,    0,
 2321, 2321,    0,    0, 2321, 2321, 2321,    0, 2321, 2321,
 2321, 2321, 2321, 2321, 2321,    0,    0,    0, 2321, 2321,
 2321, 2321, 2321,    0,    0,    0, 2321,    0,    0,    0,
    0,    0,    0,    0, 2321, 2321, 2321, 2321, 2321, 2321,
    0,    0,    0, 2321, 2321,    0, 2321,    0, 2321,    0,
 2321, 2321, 2321,    0, 2321,    0, 2321, 2321, 2321,    0,
 2321, 2321, 2321, 2321, 2321,    0, 2321, 2321,    0,    0,
    0,    0, 2321,    0, 2321, 2321,    0,    0, 2321, 2321,
 2321,    0,    0, 2321,    0, 2321,    0,    0, 2321, 2321,
 2321, 2321,    0, 2321,    0, 2321,    0, 2321, 2321, 2321,
 2321, 2321,    0,    0, 2321, 2321, 2321,    0, 2321, 2321,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2321,
 2321, 2321,    0, 2321, 2321, 2321,    0,    0,    0,    0,
    0, 2321,    0,    0,    0, 2321,    0, 2321, 2321, 2321,
 2321,    0, 2321,    0, 2321, 2321, 2321, 2321, 2321, 2321,
 2321, 2321,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2321, 2321,    0, 2321, 2321, 2321, 1430,    0,    0,
    0, 2321, 2321, 2321, 2321, 2321,    0, 2321,    0,    0,
 2321, 2321,    0,    0,    0, 2321, 2321,    0,    0, 2321,
 2321, 2321, 2321, 2321, 2321, 2321, 2321, 2321,    0, 2321,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2321,
 2321, 2321, 2321, 2321, 2321, 2321, 2321, 2321, 2321, 2321,
 2321, 2321, 2321, 2321, 2321, 2321, 2321, 2321, 2321, 2321,
    0, 2321, 2321, 2321, 2321, 2321, 2321,    0, 2321, 2321,
 2321, 2321,    0, 2321,    0, 2321, 2321, 2321, 2321, 2321,
 2321, 2321, 2321, 2321, 2321, 2321, 2321, 2321, 2321, 2321,
 2321, 2321, 2321,    0, 2321, 2321, 2321, 2321,    0, 2321,
 2321, 2321, 2321, 2321,    0, 2321, 2321, 2321, 2321, 2321,
 2321, 2321, 2321, 2321, 2321, 2321, 2321, 2321, 2321, 2321,
 2321, 2321, 2321, 2321, 2321, 2321, 2321, 2321, 2321, 2321,
 2321, 2321, 2321, 2321,    0, 2321, 2321,    0,    0,    0,
 2321, 2321, 2321, 2321, 2321, 2321,    0,    0, 2321, 2321,
 2321, 2321, 2321, 2321, 2321, 2321, 2321,    0, 2180,    0,
    0,    0, 2321,    0, 2321, 2321, 2321, 2321, 2321, 2321,
    0, 2321,    0,    0, 1432, 1431, 1433,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2321, 2321,
    0, 2321, 2321, 2321, 2321, 2321, 2321, 2321, 2321, 2321,
    0, 2321, 2321, 2321, 2321, 2321, 2321, 2321, 2321, 2321,
 2321, 2321, 2321,    0, 2321, 2321, 2321,    0, 2321,    0,
    0,    0, 2321, 2321, 2321, 2321, 2321, 2321, 2321, 2321,
 2321, 2321, 2321, 2321, 2321, 2329, 2321, 2321,    0,    0,
    0,    0,    0, 2321, 2321, 2321, 2321, 2321, 2321, 2321,
 2321, 2321, 2321, 2321, 2321, 2321, 2321, 2321, 2321, 2321,
 2321,    0,    0, 2321,    0, 2321, 2321, 2321, 2321, 2321,
 2321, 2321, 2321, 2321,    0,    0, 2329, 2329, 2329, 2329,
 2329, 2329, 2329,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2329, 2329, 2329, 2329, 2329,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2329,    0, 2329,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1416,    0,    0,    0,
    0,    0,    0,    0,    0, 1417,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1418,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1419,    0,    0,    0,    0,    0,    0, 1420,
    0,    0,    0,    0,    0,    0,    0, 1421,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1422,    0, 1423,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1424,    0, 1425, 1426,
 1427,    0,    0,    0,    0, 1428,    0,    0,    0,    0,
    0,    0, 2329,    0, 2329,    0,    0, 2329,    0, 2329,
 2329, 2329,    0, 2329, 2329,    0, 2329,    0,    0,    0,
    0,    0, 2329,    0, 2329, 2329, 2329, 2329,    0, 2329,
    0,    0, 2329,    0,    0, 2329, 1429,    0,    0,    0,
    0,    0, 2329,    0, 2329, 2329,    0, 2329, 2329, 2329,
 2329, 2329,    0,    0, 2329,    0,    0, 2329,    0, 2329,
 2329,    0,    0, 2329, 2329, 2329,    0, 2329, 2329, 2329,
 2329, 2329, 2329, 2329,    0,    0,    0, 2329, 2329, 2329,
 2329, 2329,    0,    0,    0, 2329,    0,    0,    0,    0,
    0,    0,    0, 2329, 2329, 2329, 2329, 2329, 2329,    0,
    0,    0, 2329, 2329,    0, 2329,    0, 2329,    0, 2329,
 2329, 2329,    0, 2329,    0, 2329, 2329, 2329,    0, 2329,
 2329, 2329, 2329, 2329,    0, 2329, 2329,    0,    0,    0,
    0, 2329,    0, 2329, 2329,    0,    0, 2329, 2329, 2329,
    0,    0, 2329,    0, 2329,    0,    0, 2329, 2329, 2329,
 2329,    0, 2329,    0, 2329,    0, 2329, 2329, 2329, 2329,
 2329,    0,    0, 2329, 2329, 2329,    0, 2329, 2329,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2329, 2329,
 2329,    0, 2329, 2329, 2329,    0,    0,    0,    0,    0,
 2329,    0,    0,    0, 2329,    0, 2329, 2329, 2329, 2329,
    0, 2329,    0, 2329, 2329, 2329, 2329, 2329, 2329, 2329,
 2329,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2329, 2329,    0, 2329, 2329, 2329, 1430,    0,    0,    0,
 2329, 2329, 2329, 2329, 2329,    0, 2329,    0,    0, 2329,
 2329,    0,    0,    0, 2329, 2329,    0,    0, 2329, 2329,
 2329, 2329, 2329, 2329, 2329, 2329, 2329,    0, 2329,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2329, 2329,
 2329, 2329, 2329, 2329, 2329, 2329, 2329, 2329, 2329, 2329,
 2329, 2329, 2329, 2329, 2329, 2329, 2329, 2329, 2329,    0,
 2329, 2329, 2329, 2329, 2329, 2329,    0, 2329, 2329, 2329,
 2329,    0, 2329,    0, 2329, 2329, 2329, 2329, 2329, 2329,
 2329, 2329, 2329, 2329, 2329, 2329, 2329, 2329, 2329, 2329,
 2329, 2329,    0, 2329, 2329, 2329, 2329,    0, 2329, 2329,
 2329, 2329, 2329,    0, 2329, 2329, 2329, 2329, 2329, 2329,
 2329, 2329, 2329, 2329, 2329, 2329, 2329, 2329, 2329, 2329,
 2329, 2329, 2329, 2329, 2329, 2329, 2329, 2329, 2329, 2329,
 2329, 2329, 2329,    0, 2329, 2329,    0,    0,    0, 2329,
 2329, 2329, 2329, 2329, 2329,    0,    0, 2329, 2329, 2329,
 2329, 2329, 2329, 2329, 2329, 2329,    0, 2181,    0,    0,
    0, 2329,    0, 2329, 2329, 2329, 2329, 2329, 2329,    0,
 2329,    0,    0, 1432, 1431, 1433,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2329, 2329,    0,
 2329, 2329, 2329, 2329, 2329, 2329, 2329, 2329, 2329,    0,
 2329, 2329, 2329, 2329, 2329, 2329, 2329, 2329, 2329, 2329,
 2329, 2329,    0, 2329, 2329, 2329,    0, 2329,    0,    0,
    0, 2329, 2329, 2329, 2329, 2329, 2329, 2329, 2329, 2329,
 2329, 2329, 2329, 2329, 2354, 2329, 2329,    0,    0,    0,
    0,    0, 2329, 2329, 2329, 2329, 2329, 2329, 2329, 2329,
 2329, 2329, 2329, 2329, 2329, 2329, 2329, 2329, 2329, 2329,
    0,    0, 2329,    0, 2329, 2329, 2329, 2329, 2329, 2329,
 2329, 2329, 2329,    0,    0, 2354, 2354, 2354, 2354, 2354,
 2354, 2354,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2354, 2354, 2354, 2354, 2354,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2354,    0, 2354,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1416,    0,    0,    0,    0,
    0,    0,    0,    0, 1417,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1418,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1419,    0,    0,    0,    0,    0,    0, 1420,    0,
    0,    0,    0,    0,    0,    0, 1421,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1422,    0, 1423,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1424,    0, 1425, 1426, 1427,
    0,    0,    0,    0, 1428,    0,    0,    0,    0,    0,
    0, 2354,    0, 2354,    0,    0, 2354,    0, 2354, 2354,
 2354,    0, 2354, 2354,    0, 2354,    0,    0,    0,    0,
    0, 2354,    0, 2354, 2354, 2354, 2354,    0, 2354,    0,
    0, 2354,    0,    0, 2354, 1429,    0,    0,    0,    0,
    0, 2354,    0, 2354, 2354,    0, 2354, 2354, 2354, 2354,
 2354,    0,    0, 2354,    0,    0, 2354,    0, 2354, 2354,
    0,    0, 2354, 2354, 2354,    0, 2354, 2354, 2354, 2354,
 2354, 2354, 2354,    0,    0,    0, 2354, 2354, 2354, 2354,
 2354,    0,    0,    0, 2354,    0,    0,    0,    0,    0,
    0,    0, 2354, 2354, 2354, 2354, 2354, 2354,    0,    0,
    0, 2354, 2354,    0, 2354,    0, 2354,    0, 2354, 2354,
 2354,    0, 2354,    0, 2354, 2354, 2354,    0, 2354, 2354,
 2354, 2354, 2354,    0, 2354, 2354,    0,    0,    0,    0,
 2354,    0, 2354, 2354,    0,    0, 2354, 2354, 2354,    0,
    0, 2354,    0, 2354,    0,    0, 2354, 2354, 2354, 2354,
    0, 2354,    0, 2354,    0, 2354, 2354, 2354, 2354, 2354,
    0,    0, 2354, 2354, 2354,    0, 2354, 2354,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2354, 2354, 2354,
    0, 2354, 2354, 2354,    0,    0,    0,    0,    0, 2354,
    0,    0,    0, 2354,    0, 2354, 2354, 2354, 2354,    0,
 2354,    0, 2354, 2354, 2354, 2354, 2354, 2354, 2354, 2354,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2354,
 2354,    0, 2354, 2354, 2354, 1430,    0,    0,    0, 2354,
 2354, 2354, 2354, 2354,    0, 2354,    0,    0, 2354, 2354,
    0,    0,    0, 2354, 2354,    0,    0, 2354, 2354, 2354,
 2354, 2354, 2354, 2354, 2354, 2354,    0, 2354,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2354, 2354, 2354,
 2354, 2354, 2354, 2354, 2354, 2354, 2354, 2354, 2354, 2354,
 2354, 2354, 2354, 2354, 2354, 2354, 2354, 2354,    0, 2354,
 2354, 2354, 2354, 2354, 2354,    0, 2354, 2354, 2354, 2354,
    0, 2354,    0, 2354, 2354, 2354, 2354, 2354, 2354, 2354,
 2354, 2354, 2354, 2354, 2354, 2354, 2354, 2354, 2354, 2354,
 2354,    0, 2354, 2354, 2354, 2354,    0, 2354, 2354, 2354,
 2354, 2354,    0, 2354, 2354, 2354, 2354, 2354, 2354, 2354,
 2354, 2354, 2354, 2354, 2354, 2354, 2354, 2354, 2354, 2354,
 2354, 2354, 2354, 2354, 2354, 2354, 2354, 2354, 2354, 2354,
 2354, 2354,    0, 2354, 2354,    0,    0,    0, 2354, 2354,
 2354, 2354, 2354, 2354,    0,    0, 2354, 2354, 2354, 2354,
 2354, 2354, 2354, 2354, 2354,    0, 2182,    0,    0,    0,
 2354,    0, 2354, 2354, 2354, 2354, 2354, 2354,    0, 2354,
    0,    0, 1432, 1431, 1433,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2354, 2354,    0, 2354,
 2354, 2354, 2354, 2354, 2354, 2354, 2354, 2354,    0, 2354,
 2354, 2354, 2354, 2354, 2354, 2354, 2354, 2354, 2354, 2354,
 2354,    0, 2354, 2354, 2354,    0, 2354,    0,    0,    0,
 2354, 2354, 2354, 2354, 2354, 2354, 2354, 2354, 2354, 2354,
 2354, 2354, 2354, 2355, 2354, 2354,    0,    0,    0,    0,
    0, 2354, 2354, 2354, 2354, 2354, 2354, 2354, 2354, 2354,
 2354, 2354, 2354, 2354, 2354, 2354, 2354, 2354, 2354,    0,
    0, 2354,    0, 2354, 2354, 2354, 2354, 2354, 2354, 2354,
 2354, 2354,    0,    0, 2355, 2355, 2355, 2355, 2355, 2355,
 2355,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2355, 2355, 2355, 2355, 2355,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2355,    0, 2355,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1416,    0,    0,    0,    0,    0,
    0,    0,    0, 1417,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1418,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1419,    0,    0,    0,    0,    0,    0, 1420,    0,    0,
    0,    0,    0,    0,    0, 1421,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1422,    0, 1423,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1424,    0, 1425, 1426, 1427,    0,
    0,    0,    0, 1428,    0,    0,    0,    0,    0,    0,
 2355,    0, 2355,    0,    0, 2355,    0, 2355, 2355, 2355,
    0, 2355, 2355,    0, 2355,    0,    0,    0,    0,    0,
 2355,    0, 2355, 2355, 2355, 2355,    0, 2355,    0,    0,
 2355,    0,    0, 2355, 1429,    0,    0,    0,    0,    0,
 2355,    0, 2355, 2355,    0, 2355, 2355, 2355, 2355, 2355,
    0,    0, 2355,    0,    0, 2355,    0, 2355, 2355,    0,
    0, 2355, 2355, 2355,    0, 2355, 2355, 2355, 2355, 2355,
 2355, 2355,    0,    0,    0, 2355, 2355, 2355, 2355, 2355,
    0,    0,    0, 2355,    0,    0,    0,    0,    0,    0,
    0, 2355, 2355, 2355, 2355, 2355, 2355,    0,    0,    0,
 2355, 2355,    0, 2355,    0, 2355,    0, 2355, 2355, 2355,
    0, 2355,    0, 2355, 2355, 2355,    0, 2355, 2355, 2355,
 2355, 2355,    0, 2355, 2355,    0,    0,    0,    0, 2355,
    0, 2355, 2355,    0,    0, 2355, 2355, 2355,    0,    0,
 2355,    0, 2355,    0,    0, 2355, 2355, 2355, 2355,    0,
 2355,    0, 2355,    0, 2355, 2355, 2355, 2355, 2355,    0,
    0, 2355, 2355, 2355,    0, 2355, 2355,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2355, 2355, 2355,    0,
 2355, 2355, 2355,    0,    0,    0,    0,    0, 2355,    0,
    0,    0, 2355,    0, 2355, 2355, 2355, 2355,    0, 2355,
    0, 2355, 2355, 2355, 2355, 2355, 2355, 2355, 2355,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2355, 2355,
    0, 2355, 2355, 2355, 1430,    0,    0,    0, 2355, 2355,
 2355, 2355, 2355,    0, 2355,    0,    0, 2355, 2355,    0,
    0,    0, 2355, 2355,    0,    0, 2355, 2355, 2355, 2355,
 2355, 2355, 2355, 2355, 2355,    0, 2355,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2355, 2355, 2355, 2355,
 2355, 2355, 2355, 2355, 2355, 2355, 2355, 2355, 2355, 2355,
 2355, 2355, 2355, 2355, 2355, 2355, 2355,    0, 2355, 2355,
 2355, 2355, 2355, 2355,    0, 2355, 2355, 2355, 2355,    0,
 2355,    0, 2355, 2355, 2355, 2355, 2355, 2355, 2355, 2355,
 2355, 2355, 2355, 2355, 2355, 2355, 2355, 2355, 2355, 2355,
    0, 2355, 2355, 2355, 2355,    0, 2355, 2355, 2355, 2355,
 2355,    0, 2355, 2355, 2355, 2355, 2355, 2355, 2355, 2355,
 2355, 2355, 2355, 2355, 2355, 2355, 2355, 2355, 2355, 2355,
 2355, 2355, 2355, 2355, 2355, 2355, 2355, 2355, 2355, 2355,
 2355,    0, 2355, 2355,    0,    0,    0, 2355, 2355, 2355,
 2355, 2355, 2355,    0,    0, 2355, 2355, 2355, 2355, 2355,
 2355, 2355, 2355, 2355,    0, 2183,    0,    0,    0, 2355,
    0, 2355, 2355, 2355, 2355, 2355, 2355,    0, 2355,    0,
    0, 1432, 1431, 1433,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2355, 2355,    0, 2355, 2355,
 2355, 2355, 2355, 2355, 2355, 2355, 2355,    0, 2355, 2355,
 2355, 2355, 2355, 2355, 2355, 2355, 2355, 2355, 2355, 2355,
    0, 2355, 2355, 2355,    0, 2355,    0,    0,    0, 2355,
 2355, 2355, 2355, 2355, 2355, 2355, 2355, 2355, 2355, 2355,
 2355, 2355, 2230, 2355, 2355,    0,    0,    0,    0,    0,
 2355, 2355, 2355, 2355, 2355, 2355, 2355, 2355, 2355, 2355,
 2355, 2355, 2355, 2355, 2355, 2355, 2355, 2355,    0,    0,
 2355,    0, 2355, 2355, 2355, 2355, 2355, 2355, 2355, 2355,
 2355,    0,    0, 2230, 2230, 2230, 2230, 2230, 2230, 2230,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2230, 2230, 2230, 2230,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2230,    0, 2230,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1416,    0,    0,    0,    0,    0,    0,
    0,    0, 1417,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1418,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1419,
    0,    0,    0,    0,    0,    0, 1420,    0,    0,    0,
    0,    0,    0,    0, 1421,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1422,    0, 1423,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1424,    0, 1425, 1426, 1427,    0,    0,
    0,    0, 1428,    0,    0,    0,    0,    0,    0, 2230,
    0, 2230,    0,    0, 2230,    0, 2230, 2230, 2230,    0,
 2230, 2230,    0, 2230,    0,    0,    0,    0,    0, 2230,
    0, 2230, 2230, 2230, 2230,    0, 2230,    0,    0, 2230,
    0,    0, 2230, 1429,    0,    0,    0,    0,    0, 2230,
    0, 2230, 2230,    0, 2230, 2230, 2230, 2230, 2230,    0,
    0, 2230,    0,    0, 2230,    0, 2230, 2230,    0,    0,
 2230, 2230, 2230,    0, 2230, 2230, 2230, 2230, 2230, 2230,
 2230,    0,    0,    0, 2230, 2230, 2230, 2230, 2230,    0,
    0,    0, 2230,    0,    0,    0,    0,    0,    0,    0,
 2230, 2230, 2230, 2230, 2230, 2230,    0,    0,    0, 2230,
 2230,    0, 2230,    0, 2230,    0, 2230, 2230, 2230,    0,
 2230,    0, 2230, 2230, 2230,    0, 2230, 2230, 2230, 2230,
 2230,    0, 2230, 2230,    0,    0,    0,    0, 2230,    0,
 2230, 2230,    0,    0, 2230, 2230, 2230,    0,    0, 2230,
    0, 2230,    0,    0, 2230, 2230, 2230, 2230,    0, 2230,
    0, 2230,    0, 2230, 2230, 2230, 2230, 2230,    0,    0,
 2230, 2230, 2230,    0, 2230, 2230,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2230, 2230, 2230,    0, 2230,
 2230, 2230,    0,    0,    0,    0,    0, 2230,    0,    0,
    0, 2230,    0, 2230, 2230, 2230, 2230,    0, 2230,    0,
 2230, 2230, 2230, 2230, 2230, 2230, 2230, 2230,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2230, 2230,    0,
 2230, 2230, 2230, 1430,    0,    0,    0, 2230, 2230, 2230,
 2230, 2230,    0, 2230,    0,    0, 2230, 2230,    0,    0,
    0, 2230, 2230,    0,    0, 2230, 2230, 2230, 2230, 2230,
 2230, 2230, 2230, 2230,    0, 2230,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2230, 2230, 2230, 2230, 2230,
 2230, 2230, 2230, 2230, 2230, 2230, 2230, 2230, 2230, 2230,
 2230, 2230, 2230, 2230, 2230, 2230,    0, 2230, 2230, 2230,
 2230, 2230, 2230,    0, 2230, 2230, 2230, 2230,    0, 2230,
    0, 2230, 2230, 2230, 2230, 2230, 2230, 2230, 2230, 2230,
 2230, 2230, 2230, 2230, 2230, 2230, 2230, 2230, 2230,    0,
 2230, 2230, 2230, 2230,    0, 2230, 2230, 2230, 2230, 2230,
    0, 2230, 2230, 2230, 2230, 2230, 2230, 2230, 2230, 2230,
 2230, 2230, 2230, 2230, 2230, 2230, 2230, 2230, 2230, 2230,
 2230, 2230, 2230, 2230, 2230, 2230, 2230, 2230, 2230, 2230,
    0, 2230, 2230,    0,    0,    0, 2230, 2230, 2230, 2230,
 2230, 2230,    0,    0, 2230, 2230, 2230, 2230, 2230, 2230,
 2230, 2230, 2230,    0, 2184,    0,    0,    0, 2230,    0,
 2230, 2230, 2230, 2230, 2230, 2230,    0, 2230,    0,    0,
 1432, 1431, 1433,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2230, 2230,    0, 2230, 2230, 2230,
 2230, 2230, 2230, 2230, 2230, 2230,    0, 2230, 2230, 2230,
 2230, 2230, 2230, 2230, 2230, 2230, 2230, 2230, 2230,    0,
 2230, 2230, 2230,    0, 2230,    0,    0,    0, 2230, 2230,
 2230, 2230, 2230, 2230, 2230, 2230, 2230, 2230, 2230, 2230,
 2230, 2256, 2230, 2230,    0,    0,    0,    0,    0, 2230,
 2230, 2230, 2230, 2230, 2230, 2230, 2230, 2230, 2230, 2230,
 2230, 2230, 2230, 2230, 2230, 2230, 2230,    0,    0, 2230,
    0, 2230, 2230, 2230, 2230, 2230, 2230, 2230, 2230, 2230,
    0,    0, 2256, 2256, 2256, 2256, 2256, 2256, 2256,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2256, 2256, 2256, 2256,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2256,    0, 2256,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1416,    0,    0,    0,    0,    0,    0,    0,
    0, 1417,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1418,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1419,    0,
    0,    0,    0,    0,    0, 1420,    0,    0,    0,    0,
    0,    0,    0, 1421,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1422,    0, 1423,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1424,    0, 1425, 1426, 1427,    0,    0,    0,
    0, 1428,    0,    0,    0,    0,    0,    0, 2256,    0,
 2256,    0,    0, 2256,    0, 2256, 2256, 2256,    0, 2256,
 2256,    0, 2256,    0,    0,    0,    0,    0, 2256,    0,
 2256, 2256, 2256, 2256,    0, 2256,    0,    0, 2256,    0,
    0, 2256, 1429,    0,    0,    0,    0,    0, 2256,    0,
 2256, 2256,    0, 2256, 2256, 2256, 2256, 2256,    0,    0,
 2256,    0,    0, 2256,    0, 2256, 2256,    0,    0, 2256,
 2256, 2256,    0, 2256, 2256, 2256, 2256, 2256, 2256, 2256,
    0,    0,    0, 2256, 2256, 2256, 2256, 2256,    0,    0,
    0, 2256,    0,    0,    0,    0,    0,    0,    0, 2256,
 2256, 2256, 2256, 2256, 2256,    0,    0,    0, 2256, 2256,
    0, 2256,    0, 2256,    0, 2256, 2256, 2256,    0, 2256,
    0, 2256, 2256, 2256,    0, 2256, 2256, 2256, 2256, 2256,
    0, 2256, 2256,    0,    0,    0,    0, 2256,    0, 2256,
 2256,    0,    0, 2256, 2256, 2256,    0,    0, 2256,    0,
 2256,    0,    0, 2256, 2256, 2256, 2256,    0, 2256,    0,
 2256,    0, 2256, 2256, 2256, 2256, 2256,    0,    0, 2256,
 2256, 2256,    0, 2256, 2256,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2256, 2256, 2256,    0, 2256, 2256,
 2256,    0,    0,    0,    0,    0, 2256,    0,    0,    0,
 2256,    0, 2256, 2256, 2256, 2256,    0, 2256,    0, 2256,
 2256, 2256, 2256, 2256, 2256, 2256, 2256,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2256, 2256,    0, 2256,
 2256, 2256, 1430,    0,    0,    0, 2256, 2256, 2256, 2256,
 2256,    0, 2256,    0,    0, 2256, 2256,    0,    0,    0,
 2256, 2256,    0,    0, 2256, 2256, 2256, 2256, 2256, 2256,
 2256, 2256, 2256,    0, 2256,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2256, 2256, 2256, 2256, 2256, 2256,
 2256, 2256, 2256, 2256, 2256, 2256, 2256, 2256, 2256, 2256,
 2256, 2256, 2256, 2256, 2256,    0, 2256, 2256, 2256, 2256,
 2256, 2256,    0, 2256, 2256, 2256, 2256,    0, 2256,    0,
 2256, 2256, 2256, 2256, 2256, 2256, 2256, 2256, 2256, 2256,
 2256, 2256, 2256, 2256, 2256, 2256, 2256, 2256,    0, 2256,
 2256, 2256, 2256,    0, 2256, 2256, 2256, 2256, 2256,    0,
 2256, 2256, 2256, 2256, 2256, 2256, 2256, 2256, 2256, 2256,
 2256, 2256, 2256, 2256, 2256, 2256, 2256, 2256, 2256, 2256,
 2256, 2256, 2256, 2256, 2256, 2256, 2256, 2256, 2256,    0,
 2256, 2256,    0,    0,    0, 2256, 2256, 2256, 2256, 2256,
 2256,    0,    0, 2256, 2256, 2256, 2256, 2256, 2256, 2256,
 2256, 2256,    0, 2185,    0,    0,    0, 2256,    0, 2256,
 2256, 2256, 2256, 2256, 2256,    0, 2256,    0,    0, 1432,
 1431, 1433,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2256, 2256,    0, 2256, 2256, 2256, 2256,
 2256, 2256, 2256, 2256, 2256,    0, 2256, 2256, 2256, 2256,
 2256, 2256, 2256, 2256, 2256, 2256, 2256, 2256,    0, 2256,
 2256, 2256,    0, 2256,    0,    0,    0, 2256, 2256, 2256,
 2256, 2256, 2256, 2256, 2256, 2256, 2256, 2256, 2256, 2256,
 2117, 2256, 2256,    0,    0,    0,    0,    0, 2256, 2256,
 2256, 2256, 2256, 2256, 2256, 2256, 2256, 2256, 2256, 2256,
 2256, 2256, 2256, 2256, 2256, 2256,    0,    0, 2256,    0,
 2256, 2256, 2256, 2256, 2256, 2256, 2256, 2256, 2256,    0,
    0, 2117, 2117, 2117, 2117, 2117, 2117, 2117,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2117,
 2117, 2117, 2117,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2117,    0, 2117,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1416,    0,    0,    0,    0,    0,    0,    0,    0,
 1417,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1418,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1419,    0,    0,
    0,    0,    0,    0, 1420,    0,    0,    0,    0,    0,
    0,    0, 1421,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1422,
    0, 1423,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1424,    0, 1425, 1426, 1427,    0,    0,    0,    0,
 1428,    0,    0,    0,    0,    0,    0, 2117,    0, 2117,
    0,    0, 2117,    0, 2117, 2117, 2117,    0, 2117, 2117,
    0, 2117,    0,    0,    0,    0,    0, 2117,    0, 2117,
 2117, 2117, 2117,    0, 2117,    0,    0, 2117,    0,    0,
 2117, 1429,    0,    0,    0,    0,    0, 2117,    0, 2117,
 2117,    0, 2117, 2117, 2117, 2117, 2117,    0,    0, 2117,
    0,    0, 2117,    0, 2117, 2117,    0,    0, 2117, 2117,
 2117,    0, 2117, 2117, 2117, 2117, 2117, 2117, 2117,    0,
    0,    0, 2117, 2117, 2117, 2117, 2117,    0,    0,    0,
 2117,    0,    0,    0,    0,    0,    0,    0, 2117, 2117,
 2117, 2117, 2117, 2117,    0,    0,    0, 2117, 2117,    0,
 2117,    0, 2117,    0, 2117, 2117, 2117,    0, 2117,    0,
 2117, 2117, 2117,    0, 2117, 2117, 2117, 2117, 2117,    0,
 2117, 2117,    0,    0,    0,    0, 2117,    0, 2117, 2117,
    0,    0, 2117, 2117, 2117,    0,    0, 2117,    0, 2117,
    0,    0, 2117, 2117, 2117, 2117,    0, 2117,    0, 2117,
    0, 2117, 2117, 2117, 2117, 2117,    0,    0, 2117, 2117,
 2117,    0, 2117, 2117,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2117, 2117, 2117,    0, 2117, 2117, 2117,
    0,    0,    0,    0,    0, 2117,    0,    0,    0, 2117,
    0, 2117, 2117, 2117, 2117,    0, 2117,    0, 2117, 2117,
 2117, 2117, 2117, 2117, 2117, 2117,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2117, 2117,    0, 2117, 2117,
 2117, 1430,    0,    0,    0, 2117, 2117, 2117, 2117, 2117,
    0, 2117,    0,    0, 2117, 2117,    0,    0,    0, 2117,
 2117,    0,    0, 2117, 2117, 2117, 2117, 2117, 2117, 2117,
 2117, 2117,    0, 2117,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2117, 2117, 2117, 2117, 2117, 2117, 2117,
 2117, 2117, 2117, 2117, 2117, 2117, 2117, 2117, 2117, 2117,
 2117, 2117, 2117, 2117,    0, 2117, 2117, 2117, 2117, 2117,
 2117,    0, 2117, 2117, 2117, 2117,    0, 2117,    0, 2117,
 2117, 2117, 2117, 2117, 2117, 2117, 2117, 2117, 2117, 2117,
 2117, 2117, 2117, 2117, 2117, 2117, 2117,    0, 2117, 2117,
 2117, 2117,    0, 2117, 2117, 2117, 2117, 2117,    0, 2117,
 2117, 2117, 2117, 2117, 2117, 2117, 2117, 2117, 2117, 2117,
 2117, 2117, 2117, 2117, 2117, 2117, 2117, 2117, 2117, 2117,
 2117, 2117, 2117, 2117, 2117, 2117, 2117, 2117,    0, 2117,
 2117,    0,    0,    0, 2117, 2117, 2117, 2117, 2117, 2117,
    0,    0, 2117, 2117, 2117, 2117, 2117, 2117, 2117, 2117,
 2117,    0, 2186,    0,    0,    0, 2117,    0, 2117, 2117,
 2117, 2117, 2117, 2117,    0, 2117,    0,    0, 1432, 1431,
 1433,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2117, 2117,    0, 2117, 2117, 2117, 2117, 2117,
 2117, 2117, 2117, 2117,    0, 2117, 2117, 2117, 2117, 2117,
 2117, 2117, 2117, 2117, 2117, 2117, 2117,    0, 2117, 2117,
 2117,    0, 2117,    0,    0,    0, 2117, 2117, 2117, 2117,
 2117, 2117, 2117, 2117, 2117, 2117, 2117, 2117, 2117, 2113,
 2117, 2117,    0,    0,    0,    0,    0, 2117, 2117, 2117,
 2117, 2117, 2117, 2117, 2117, 2117, 2117, 2117, 2117, 2117,
 2117, 2117, 2117, 2117, 2117,    0,    0, 2117,    0, 2117,
 2117, 2117, 2117, 2117, 2117, 2117, 2117, 2117,    0,    0,
 2113, 2113, 2113, 2113, 2113, 2113, 2113,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2113, 2113,
 2113, 2113,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2113,    0, 2113,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1416,    0,    0,    0,    0,    0,    0,    0,    0, 1417,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1418,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1419,    0,    0,    0,
    0,    0,    0, 1420,    0,    0,    0,    0,    0,    0,
    0, 1421,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1422,    0,
 1423,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1424,    0, 1425, 1426, 1427,    0,    0,    0,    0, 1428,
    0,    0,    0,    0,    0,    0, 2113,    0, 2113,    0,
    0, 2113,    0, 2113, 2113, 2113,    0, 2113, 2113,    0,
 2113,    0,    0,    0,    0,    0, 2113,    0, 2113, 2113,
 2113, 2113,    0, 2113,    0,    0, 2113,    0,    0, 2113,
 1429,    0,    0,    0,    0,    0, 2113,    0, 2113, 2113,
    0, 2113, 2113, 2113, 2113, 2113,    0,    0, 2113,    0,
    0, 2113,    0, 2113, 2113,    0,    0, 2113, 2113, 2113,
    0, 2113, 2113, 2113, 2113, 2113, 2113, 2113,    0,    0,
    0, 2113, 2113, 2113, 2113, 2113,    0,    0,    0, 2113,
    0,    0,    0,    0,    0,    0,    0, 2113, 2113, 2113,
 2113, 2113, 2113,    0,    0,    0, 2113, 2113,    0, 2113,
    0, 2113,    0, 2113, 2113, 2113,    0, 2113,    0, 2113,
 2113, 2113,    0, 2113, 2113, 2113, 2113, 2113,    0, 2113,
 2113,    0,    0,    0,    0, 2113,    0, 2113, 2113,    0,
    0, 2113, 2113, 2113,    0,    0, 2113,    0, 2113,    0,
    0, 2113, 2113, 2113, 2113,    0, 2113,    0, 2113,    0,
 2113, 2113, 2113, 2113, 2113,    0,    0, 2113, 2113, 2113,
    0, 2113, 2113,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2113, 2113, 2113,    0, 2113, 2113, 2113,    0,
    0,    0,    0,    0, 2113,    0,    0,    0, 2113,    0,
 2113, 2113, 2113, 2113,    0, 2113,    0, 2113, 2113, 2113,
 2113, 2113, 2113, 2113, 2113,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2113, 2113,    0, 2113, 2113, 2113,
 1430,    0,    0,    0, 2113, 2113, 2113, 2113, 2113,    0,
 2113,    0,    0, 2113, 2113,    0,    0,    0, 2113, 2113,
    0,    0, 2113, 2113, 2113, 2113, 2113, 2113, 2113, 2113,
 2113,    0, 2113,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2113, 2113, 2113, 2113, 2113, 2113, 2113, 2113,
 2113, 2113, 2113, 2113, 2113, 2113, 2113, 2113, 2113, 2113,
 2113, 2113, 2113,    0, 2113, 2113, 2113, 2113, 2113, 2113,
    0, 2113, 2113, 2113, 2113,    0, 2113,    0, 2113, 2113,
 2113, 2113, 2113, 2113, 2113, 2113, 2113, 2113, 2113, 2113,
 2113, 2113, 2113, 2113, 2113, 2113,    0, 2113, 2113, 2113,
 2113,    0, 2113, 2113, 2113, 2113, 2113,    0, 2113, 2113,
 2113, 2113, 2113, 2113, 2113, 2113, 2113, 2113, 2113, 2113,
 2113, 2113, 2113, 2113, 2113, 2113, 2113, 2113, 2113, 2113,
 2113, 2113, 2113, 2113, 2113, 2113, 2113,    0, 2113, 2113,
    0,    0,    0, 2113, 2113, 2113, 2113, 2113, 2113,    0,
    0, 2113, 2113, 2113, 2113, 2113, 2113, 2113, 2113, 2113,
    0, 2187,    0,    0,    0, 2113,    0, 2113, 2113, 2113,
 2113, 2113, 2113,    0, 2113,    0,    0, 1432, 1431, 1433,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2113, 2113,    0, 2113, 2113, 2113, 2113, 2113, 2113,
 2113, 2113, 2113,    0, 2113, 2113, 2113, 2113, 2113, 2113,
 2113, 2113, 2113, 2113, 2113, 2113,    0, 2113, 2113, 2113,
    0, 2113,    0,    0,    0, 2113, 2113, 2113, 2113, 2113,
 2113, 2113, 2113, 2113, 2113, 2113, 2113, 2113, 2125, 2113,
 2113,    0,    0,    0,    0,    0, 2113, 2113, 2113, 2113,
 2113, 2113, 2113, 2113, 2113, 2113, 2113, 2113, 2113, 2113,
 2113, 2113, 2113, 2113,    0,    0, 2113,    0, 2113, 2113,
 2113, 2113, 2113, 2113, 2113, 2113, 2113,    0,    0, 2125,
 2125, 2125, 2125, 2125, 2125, 2125,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2125, 2125, 2125,
 2125,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2125,
    0, 2125,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1416,
    0,    0,    0,    0,    0,    0,    0,    0, 1417,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1418,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1419,    0,    0,    0,    0,
    0,    0, 1420,    0,    0,    0,    0,    0,    0,    0,
 1421,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1422,    0, 1423,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1424,
    0, 1425, 1426, 1427,    0,    0,    0,    0, 1428,    0,
    0,    0,    0,    0,    0, 2125,    0, 2125,    0,    0,
 2125,    0, 2125, 2125, 2125,    0, 2125, 2125,    0, 2125,
    0,    0,    0,    0,    0, 2125,    0, 2125, 2125, 2125,
 2125,    0, 2125,    0,    0, 2125,    0,    0, 2125, 1429,
    0,    0,    0,    0,    0, 2125,    0, 2125, 2125,    0,
 2125, 2125, 2125, 2125, 2125,    0,    0, 2125,    0,    0,
 2125,    0, 2125, 2125,    0,    0, 2125, 2125, 2125,    0,
 2125, 2125, 2125, 2125, 2125, 2125, 2125,    0,    0,    0,
 2125, 2125, 2125, 2125, 2125,    0,    0,    0, 2125,    0,
    0,    0,    0,    0,    0,    0, 2125, 2125, 2125, 2125,
 2125, 2125,    0,    0,    0, 2125, 2125,    0, 2125,    0,
 2125,    0, 2125, 2125, 2125,    0, 2125,    0, 2125, 2125,
 2125,    0, 2125, 2125, 2125, 2125, 2125,    0, 2125, 2125,
    0,    0,    0,    0, 2125,    0, 2125, 2125,    0,    0,
 2125, 2125, 2125,    0,    0, 2125,    0, 2125,    0,    0,
 2125, 2125, 2125, 2125,    0, 2125,    0, 2125,    0, 2125,
 2125, 2125, 2125, 2125,    0,    0, 2125, 2125, 2125,    0,
 2125, 2125,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2125, 2125, 2125,    0, 2125, 2125, 2125,    0,    0,
    0,    0,    0, 2125,    0,    0,    0, 2125,    0, 2125,
 2125, 2125, 2125,    0, 2125,    0, 2125, 2125, 2125, 2125,
 2125, 2125, 2125, 2125,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2125, 2125,    0, 2125, 2125, 2125, 1430,
    0,    0,    0, 2125, 2125, 2125, 2125, 2125,    0, 2125,
    0,    0, 2125, 2125,    0,    0,    0, 2125, 2125,    0,
    0, 2125, 2125, 2125, 2125, 2125, 2125, 2125, 2125, 2125,
    0, 2125,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2125, 2125, 2125, 2125, 2125, 2125, 2125, 2125, 2125,
 2125, 2125, 2125, 2125, 2125, 2125, 2125, 2125, 2125, 2125,
 2125, 2125,    0, 2125, 2125, 2125, 2125, 2125, 2125,    0,
 2125, 2125, 2125, 2125,    0, 2125,    0, 2125, 2125, 2125,
 2125, 2125, 2125, 2125, 2125, 2125, 2125, 2125, 2125, 2125,
 2125, 2125, 2125, 2125, 2125,    0, 2125, 2125, 2125, 2125,
    0, 2125, 2125, 2125, 2125, 2125,    0, 2125, 2125, 2125,
 2125, 2125, 2125, 2125, 2125, 2125, 2125, 2125, 2125, 2125,
 2125, 2125, 2125, 2125, 2125, 2125, 2125, 2125, 2125, 2125,
 2125, 2125, 2125, 2125, 2125, 2125,    0, 2125, 2125,    0,
    0,    0, 2125, 2125, 2125, 2125, 2125, 2125,    0,    0,
 2125, 2125, 2125, 2125, 2125, 2125, 2125, 2125, 2125,    0,
 2188,    0,    0,    0, 2125,    0, 2125, 2125, 2125, 2125,
 2125, 2125,    0, 2125,    0,    0, 1432, 1431, 1433,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2125, 2125,    0, 2125, 2125, 2125, 2125, 2125, 2125, 2125,
 2125, 2125,    0, 2125, 2125, 2125, 2125, 2125, 2125, 2125,
 2125, 2125, 2125, 2125, 2125,    0, 2125, 2125, 2125,    0,
 2125,    0,    0,    0, 2125, 2125, 2125, 2125, 2125, 2125,
 2125, 2125, 2125, 2125, 2125, 2125, 2125, 2130, 2125, 2125,
    0,    0,    0,    0,    0, 2125, 2125, 2125, 2125, 2125,
 2125, 2125, 2125, 2125, 2125, 2125, 2125, 2125, 2125, 2125,
 2125, 2125, 2125,    0,    0, 2125,    0, 2125, 2125, 2125,
 2125, 2125, 2125, 2125, 2125, 2125,    0,    0, 2130, 2130,
 2130, 2130, 2130, 2130, 2130,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2130, 2130, 2130, 2130,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2130,    0,
 2130,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1416,    0,
    0,    0,    0,    0,    0,    0,    0, 1417,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1418,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1419,    0,    0,    0,    0,    0,
    0, 1420,    0,    0,    0,    0,    0,    0,    0, 1421,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1422,    0, 1423,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1424,    0,
 1425, 1426, 1427,    0,    0,    0,    0, 1428,    0,    0,
    0,    0,    0,    0, 2130,    0, 2130,    0,    0, 2130,
    0, 2130, 2130, 2130,    0, 2130, 2130,    0, 2130,    0,
    0,    0,    0,    0, 2130,    0, 2130, 2130, 2130, 2130,
    0, 2130,    0,    0, 2130,    0,    0, 2130, 1429,    0,
    0,    0,    0,    0, 2130,    0, 2130, 2130,    0, 2130,
 2130, 2130, 2130, 2130,    0,    0, 2130,    0,    0, 2130,
    0, 2130, 2130,    0,    0, 2130, 2130, 2130,    0, 2130,
 2130, 2130, 2130, 2130, 2130, 2130,    0,    0,    0, 2130,
 2130, 2130, 2130, 2130,    0,    0,    0, 2130,    0,    0,
    0,    0,    0,    0,    0, 2130, 2130, 2130, 2130, 2130,
 2130,    0,    0,    0, 2130, 2130,    0, 2130,    0, 2130,
    0, 2130, 2130, 2130,    0, 2130,    0, 2130, 2130, 2130,
    0, 2130, 2130, 2130, 2130, 2130,    0, 2130, 2130,    0,
    0,    0,    0, 2130,    0, 2130, 2130,    0,    0, 2130,
 2130, 2130,    0,    0, 2130,    0, 2130,    0,    0, 2130,
 2130, 2130, 2130,    0, 2130,    0, 2130,    0, 2130, 2130,
 2130, 2130, 2130,    0,    0, 2130, 2130, 2130,    0, 2130,
 2130,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2130, 2130, 2130,    0, 2130, 2130, 2130,    0,    0,    0,
    0,    0, 2130,    0,    0,    0, 2130,    0, 2130, 2130,
 2130, 2130,    0, 2130,    0, 2130, 2130, 2130, 2130, 2130,
 2130, 2130, 2130,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2130, 2130,    0, 2130, 2130, 2130, 1430,    0,
    0,    0, 2130, 2130, 2130, 2130, 2130,    0, 2130,    0,
    0, 2130, 2130,    0,    0,    0, 2130, 2130,    0,    0,
 2130, 2130, 2130, 2130, 2130, 2130, 2130, 2130, 2130,    0,
 2130,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2130, 2130, 2130, 2130, 2130, 2130, 2130, 2130, 2130, 2130,
 2130, 2130, 2130, 2130, 2130, 2130, 2130, 2130, 2130, 2130,
 2130,    0, 2130, 2130, 2130, 2130, 2130, 2130,    0, 2130,
 2130, 2130, 2130,    0, 2130,    0, 2130, 2130, 2130, 2130,
 2130, 2130, 2130, 2130, 2130, 2130, 2130, 2130, 2130, 2130,
 2130, 2130, 2130, 2130,    0, 2130, 2130, 2130, 2130,    0,
 2130, 2130, 2130, 2130, 2130,    0, 2130, 2130, 2130, 2130,
 2130, 2130, 2130, 2130, 2130, 2130, 2130, 2130, 2130, 2130,
 2130, 2130, 2130, 2130, 2130, 2130, 2130, 2130, 2130, 2130,
 2130, 2130, 2130, 2130, 2130,    0, 2130, 2130,    0,    0,
    0, 2130, 2130, 2130, 2130, 2130, 2130,    0,    0, 2130,
 2130, 2130, 2130, 2130, 2130, 2130, 2130, 2130,    0, 2189,
    0,    0,    0, 2130,    0, 2130, 2130, 2130, 2130, 2130,
 2130,    0, 2130,    0,    0, 1432, 1431, 1433,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2130,
 2130,    0, 2130, 2130, 2130, 2130, 2130, 2130, 2130, 2130,
 2130,    0, 2130, 2130, 2130, 2130, 2130, 2130, 2130, 2130,
 2130, 2130, 2130, 2130,    0, 2130, 2130, 2130,    0, 2130,
    0,    0,    0, 2130, 2130, 2130, 2130, 2130, 2130, 2130,
 2130, 2130, 2130, 2130, 2130, 2130, 2159, 2130, 2130,    0,
    0,    0,    0,    0, 2130, 2130, 2130, 2130, 2130, 2130,
 2130, 2130, 2130, 2130, 2130, 2130, 2130, 2130, 2130, 2130,
 2130, 2130,    0,    0, 2130,    0, 2130, 2130, 2130, 2130,
 2130, 2130, 2130, 2130, 2130,    0,    0, 2159, 2159, 2159,
 2159, 2159, 2159, 2159,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2159, 2159, 2159, 2159,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2159,    0, 2159,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1416,    0,    0,
    0,    0,    0,    0,    0,    0, 1417,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1418,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1419,    0,    0,    0,    0,    0,    0,
 1420,    0,    0,    0,    0,    0,    0,    0, 1421,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1422,    0, 1423,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1424,    0, 1425,
 1426, 1427,    0,    0,    0,    0, 1428,    0,    0,    0,
    0,    0,    0, 2159,    0, 2159,    0,    0, 2159,    0,
 2159, 2159, 2159,    0, 2159, 2159,    0, 2159,    0,    0,
    0,    0,    0, 2159,    0, 2159, 2159, 2159, 2159,    0,
 2159,    0,    0, 2159,    0,    0, 2159, 1429,    0,    0,
    0,    0,    0, 2159,    0, 2159, 2159,    0, 2159, 2159,
 2159, 2159, 2159,    0,    0, 2159,    0,    0, 2159,    0,
 2159, 2159,    0,    0, 2159, 2159, 2159,    0, 2159, 2159,
 2159, 2159, 2159, 2159, 2159,    0,    0,    0, 2159, 2159,
 2159, 2159, 2159,    0,    0,    0, 2159,    0,    0,    0,
    0,    0,    0,    0, 2159, 2159, 2159, 2159, 2159, 2159,
    0,    0,    0, 2159, 2159,    0, 2159,    0, 2159,    0,
 2159, 2159, 2159,    0, 2159,    0, 2159, 2159, 2159,    0,
 2159, 2159, 2159, 2159, 2159,    0, 2159, 2159,    0,    0,
    0,    0, 2159,    0, 2159, 2159,    0,    0, 2159, 2159,
 2159,    0,    0, 2159,    0, 2159,    0,    0, 2159, 2159,
 2159, 2159,    0, 2159,    0, 2159,    0, 2159, 2159, 2159,
 2159, 2159,    0,    0, 2159, 2159, 2159,    0, 2159, 2159,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2159,
 2159, 2159,    0, 2159, 2159, 2159,    0,    0,    0,    0,
    0, 2159,    0,    0,    0, 2159,    0, 2159, 2159, 2159,
 2159,    0, 2159,    0, 2159, 2159, 2159, 2159, 2159, 2159,
 2159, 2159,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2159, 2159,    0, 2159, 2159, 2159, 1430,    0,    0,
    0, 2159, 2159, 2159, 2159, 2159,    0, 2159,    0,    0,
 2159, 2159,    0,    0,    0, 2159, 2159,    0,    0, 2159,
 2159, 2159, 2159, 2159, 2159, 2159, 2159, 2159,    0, 2159,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2159,
 2159, 2159, 2159, 2159, 2159, 2159, 2159, 2159, 2159, 2159,
 2159, 2159, 2159, 2159, 2159, 2159, 2159, 2159, 2159, 2159,
    0, 2159, 2159, 2159, 2159, 2159, 2159,    0, 2159, 2159,
 2159, 2159,    0, 2159,    0, 2159, 2159, 2159, 2159, 2159,
 2159, 2159, 2159, 2159, 2159, 2159, 2159, 2159, 2159, 2159,
 2159, 2159, 2159,    0, 2159, 2159, 2159, 2159,    0, 2159,
 2159, 2159, 2159, 2159,    0, 2159, 2159, 2159, 2159, 2159,
 2159, 2159, 2159, 2159, 2159, 2159, 2159, 2159, 2159, 2159,
 2159, 2159, 2159, 2159, 2159, 2159, 2159, 2159, 2159, 2159,
 2159, 2159, 2159, 2159,    0, 2159, 2159,    0,    0,    0,
 2159, 2159, 2159, 2159, 2159, 2159,    0,    0, 2159, 2159,
 2159, 2159, 2159, 2159, 2159, 2159, 2159,    0, 2594,    0,
    0,    0, 2159,    0, 2159, 2159, 2159, 2159, 2159, 2159,
    0, 2159,    0,    0, 1432, 1431, 1433,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2159, 2159,
    0, 2159, 2159, 2159, 2159, 2159, 2159, 2159, 2159, 2159,
    0, 2159, 2159, 2159, 2159, 2159, 2159, 2159, 2159, 2159,
 2159, 2159, 2159,    0, 2159, 2159, 2159,    0, 2159,    0,
    0,    0, 2159, 2159, 2159, 2159, 2159, 2159, 2159, 2159,
 2159, 2159, 2159, 2159, 2159, 2165, 2159, 2159,    0,    0,
    0,    0,    0, 2159, 2159, 2159, 2159, 2159, 2159, 2159,
 2159, 2159, 2159, 2159, 2159, 2159, 2159, 2159, 2159, 2159,
 2159,    0,    0, 2159,    0, 2159, 2159, 2159, 2159, 2159,
 2159, 2159, 2159, 2159,    0,    0, 2165, 2165, 2165, 2165,
 2165, 2165, 2165,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2165, 2165, 2165, 2165,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2165,    0, 2165,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1416,    0,    0,    0,
    0,    0,    0,    0,    0, 1417,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1418,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1419,    0,    0,    0,    0,    0,    0, 1420,
    0,    0,    0,    0,    0,    0,    0, 1421,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1422,    0, 1423,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1424,    0, 1425, 1426,
 1427,    0,    0,    0,    0, 1428,    0,    0,    0,    0,
    0,    0, 2165,    0, 2165,    0,    0, 2165,    0, 2165,
 2165, 2165,    0, 2165, 2165,    0, 2165,    0,    0,    0,
    0,    0, 2165,    0, 2165, 2165, 2165, 2165,    0, 2165,
    0,    0, 2165,    0,    0, 2165, 1429,    0,    0,    0,
    0,    0, 2165,    0, 2165, 2165,    0, 2165, 2165, 2165,
 2165, 2165,    0,    0, 2165,    0,    0, 2165,    0, 2165,
 2165,    0,    0, 2165, 2165, 2165,    0, 2165, 2165, 2165,
 2165, 2165, 2165, 2165,    0,    0,    0, 2165, 2165, 2165,
 2165, 2165,    0,    0,    0, 2165,    0,    0,    0,    0,
    0,    0,    0, 2165, 2165, 2165, 2165, 2165, 2165,    0,
    0,    0, 2165, 2165,    0, 2165,    0, 2165,    0, 2165,
 2165, 2165,    0, 2165,    0, 2165, 2165, 2165,    0, 2165,
 2165, 2165, 2165, 2165,    0, 2165, 2165,    0,    0,    0,
    0, 2165,    0, 2165, 2165,    0,    0, 2165, 2165, 2165,
    0,    0, 2165,    0, 2165,    0,    0, 2165, 2165, 2165,
 2165,    0, 2165,    0, 2165,    0, 2165, 2165, 2165, 2165,
 2165,    0,    0, 2165, 2165, 2165,    0, 2165, 2165,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2165, 2165,
 2165,    0, 2165, 2165, 2165,    0,    0,    0,    0,    0,
 2165,    0,    0,    0, 2165,    0, 2165, 2165, 2165, 2165,
    0, 2165,    0, 2165, 2165, 2165, 2165, 2165, 2165, 2165,
 2165,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2165, 2165,    0, 2165, 2165, 2165, 1430,    0,    0,    0,
 2165, 2165, 2165, 2165, 2165,    0, 2165,    0,    0, 2165,
 2165,    0,    0,    0, 2165, 2165,    0,    0, 2165, 2165,
 2165, 2165, 2165, 2165, 2165, 2165, 2165,    0, 2165,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2165, 2165,
 2165, 2165, 2165, 2165, 2165, 2165, 2165, 2165, 2165, 2165,
 2165, 2165, 2165, 2165, 2165, 2165, 2165, 2165, 2165,    0,
 2165, 2165, 2165, 2165, 2165, 2165,    0, 2165, 2165, 2165,
 2165,    0, 2165,    0, 2165, 2165, 2165, 2165, 2165, 2165,
 2165, 2165, 2165, 2165, 2165, 2165, 2165, 2165, 2165, 2165,
 2165, 2165,    0, 2165, 2165, 2165, 2165,    0, 2165, 2165,
 2165, 2165, 2165,    0, 2165, 2165, 2165, 2165, 2165, 2165,
 2165, 2165, 2165, 2165, 2165, 2165, 2165, 2165, 2165, 2165,
 2165, 2165, 2165, 2165, 2165, 2165, 2165, 2165, 2165, 2165,
 2165, 2165, 2165,    0, 2165, 2165,    0,    0,    0, 2165,
 2165, 2165, 2165, 2165, 2165,    0,    0, 2165, 2165, 2165,
 2165, 2165, 2165, 2165, 2165, 2165,    0, 2928,    0,    0,
    0, 2165,    0, 2165, 2165, 2165, 2165, 2165, 2165,    0,
 2165,    0,    0, 1432, 1431, 1433,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2165, 2165,    0,
 2165, 2165, 2165, 2165, 2165, 2165, 2165, 2165, 2165,    0,
 2165, 2165, 2165, 2165, 2165, 2165, 2165, 2165, 2165, 2165,
 2165, 2165,    0, 2165, 2165, 2165,    0, 2165,    0,    0,
    0, 2165, 2165, 2165, 2165, 2165, 2165, 2165, 2165, 2165,
 2165, 2165, 2165, 2165, 2287, 2165, 2165,    0,    0,    0,
    0,    0, 2165, 2165, 2165, 2165, 2165, 2165, 2165, 2165,
 2165, 2165, 2165, 2165, 2165, 2165, 2165, 2165, 2165, 2165,
    0,    0, 2165,    0, 2165, 2165, 2165, 2165, 2165, 2165,
 2165, 2165, 2165,    0,    0, 2287, 2287, 2287, 2287, 2287,
 2287, 2287,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2287, 2287, 2287, 2287,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2287,    0, 2287,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1416,    0,    0,    0,    0,
    0,    0,    0,    0, 1417,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1418,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1419,    0,    0,    0,    0,    0,    0, 1420,    0,
    0,    0,    0,    0,    0,    0, 1421,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1422,    0, 1423,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1424,    0, 1425, 1426, 1427,
    0,    0,    0,    0, 1428,    0,    0,    0,    0,    0,
    0, 2287,    0, 2287,    0,    0, 2287,    0, 2287, 2287,
 2287,    0, 2287, 2287,    0, 2287,    0,    0,    0,    0,
    0, 2287,    0, 2287, 2287, 2287, 2287,    0, 2287,    0,
    0, 2287,    0,    0, 2287, 1429,    0,    0,    0,    0,
    0, 2287,    0, 2287, 2287,    0, 2287, 2287, 2287, 2287,
 2287,    0,    0, 2287,    0,    0, 2287,    0, 2287, 2287,
    0,    0, 2287, 2287, 2287,    0, 2287, 2287, 2287, 2287,
 2287, 2287, 2287,    0,    0,    0, 2287, 2287, 2287, 2287,
 2287,    0,    0,    0, 2287,    0,    0,    0,    0,    0,
    0,    0, 2287, 2287, 2287, 2287, 2287, 2287,    0,    0,
    0, 2287, 2287,    0, 2287,    0, 2287,    0, 2287, 2287,
 2287,    0, 2287,    0, 2287, 2287, 2287,    0, 2287, 2287,
 2287, 2287, 2287,    0, 2287, 2287,    0,    0,    0,    0,
 2287,    0, 2287, 2287,    0,    0, 2287, 2287, 2287,    0,
    0, 2287,    0, 2287,    0,    0, 2287, 2287, 2287, 2287,
    0, 2287,    0, 2287,    0, 2287, 2287, 2287, 2287, 2287,
    0,    0, 2287, 2287, 2287,    0, 2287, 2287,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2287, 2287, 2287,
    0, 2287, 2287, 2287,    0,    0,    0,    0,    0, 2287,
    0,    0,    0, 2287,    0, 2287, 2287, 2287, 2287,    0,
 2287,    0, 2287, 2287, 2287, 2287, 2287, 2287, 2287, 2287,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2287,
 2287,    0, 2287, 2287, 2287, 1430,    0,    0,    0, 2287,
 2287, 2287, 2287, 2287,    0, 2287,    0,    0, 2287, 2287,
    0,    0,    0, 2287, 2287,    0,    0, 2287, 2287, 2287,
 2287, 2287, 2287, 2287, 2287, 2287,    0, 2287,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2287, 2287, 2287,
 2287, 2287, 2287, 2287, 2287, 2287, 2287, 2287, 2287, 2287,
 2287, 2287, 2287, 2287, 2287, 2287, 2287, 2287,    0, 2287,
 2287, 2287, 2287, 2287, 2287,    0, 2287, 2287, 2287, 2287,
    0, 2287,    0, 2287, 2287, 2287, 2287, 2287, 2287, 2287,
 2287, 2287, 2287, 2287, 2287, 2287, 2287, 2287, 2287, 2287,
 2287,    0, 2287, 2287, 2287, 2287,    0, 2287, 2287, 2287,
 2287, 2287,    0, 2287, 2287, 2287, 2287, 2287, 2287, 2287,
 2287, 2287, 2287, 2287, 2287, 2287, 2287, 2287, 2287, 2287,
 2287, 2287, 2287, 2287, 2287, 2287, 2287, 2287, 2287, 2287,
 2287, 2287,    0, 2287, 2287,    0,    0,    0, 2287, 2287,
 2287, 2287, 2287, 2287,    0,    0, 2287, 2287, 2287, 2287,
 2287, 2287, 2287, 2287, 2287,    0, 2933,    0,    0,    0,
 2287,    0, 2287, 2287, 2287, 2287, 2287, 2287,    0, 2287,
    0,    0, 1432, 1431, 1433,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2287, 2287,    0, 2287,
 2287, 2287, 2287, 2287, 2287, 2287, 2287, 2287,    0, 2287,
 2287, 2287, 2287, 2287, 2287, 2287, 2287, 2287, 2287, 2287,
 2287,    0, 2287, 2287, 2287,    0, 2287,    0,    0,    0,
 2287, 2287, 2287, 2287, 2287, 2287, 2287, 2287, 2287, 2287,
 2287, 2287, 2287, 2288, 2287, 2287,    0,    0,    0,    0,
    0, 2287, 2287, 2287, 2287, 2287, 2287, 2287, 2287, 2287,
 2287, 2287, 2287, 2287, 2287, 2287, 2287, 2287, 2287,    0,
    0, 2287,    0, 2287, 2287, 2287, 2287, 2287, 2287, 2287,
 2287, 2287,    0,    0, 2288, 2288, 2288, 2288, 2288, 2288,
 2288,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2288, 2288, 2288, 2288,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2288,    0, 2288,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1416,    0,    0,    0,    0,    0,
    0,    0,    0, 1417,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1418,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1419,    0,    0,    0,    0,    0,    0, 1420,    0,    0,
    0,    0,    0,    0,    0, 1421,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1422,    0, 1423,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1424,    0, 1425, 1426, 1427,    0,
    0,    0,    0, 1428,    0,    0,    0,    0,    0,    0,
 2288,    0, 2288,    0,    0, 2288,    0, 2288, 2288, 2288,
    0, 2288, 2288,    0, 2288,    0,    0,    0,    0,    0,
 2288,    0, 2288, 2288, 2288, 2288,    0, 2288,    0,    0,
 2288,    0,    0, 2288, 1429,    0,    0,    0,    0,    0,
 2288,    0, 2288, 2288,    0, 2288, 2288, 2288, 2288, 2288,
    0,    0, 2288,    0,    0, 2288,    0, 2288, 2288,    0,
    0, 2288, 2288, 2288,    0, 2288, 2288, 2288, 2288, 2288,
 2288, 2288,    0,    0,    0, 2288, 2288, 2288, 2288, 2288,
    0,    0,    0, 2288,    0,    0,    0,    0,    0,    0,
    0, 2288, 2288, 2288, 2288, 2288, 2288,    0,    0,    0,
 2288, 2288,    0, 2288,    0, 2288,    0, 2288, 2288, 2288,
    0, 2288,    0, 2288, 2288, 2288,    0, 2288, 2288, 2288,
 2288, 2288,    0, 2288, 2288,    0,    0,    0,    0, 2288,
    0, 2288, 2288,    0,    0, 2288, 2288, 2288,    0,    0,
 2288,    0, 2288,    0,    0, 2288, 2288, 2288, 2288,    0,
 2288,    0, 2288,    0, 2288, 2288, 2288, 2288, 2288,    0,
    0, 2288, 2288, 2288,    0, 2288, 2288,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2288, 2288, 2288,    0,
 2288, 2288, 2288,    0,    0,    0,    0,    0, 2288,    0,
    0,    0, 2288,    0, 2288, 2288, 2288, 2288,    0, 2288,
    0, 2288, 2288, 2288, 2288, 2288, 2288, 2288, 2288,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2288, 2288,
    0, 2288, 2288, 2288, 1430,    0,    0,    0, 2288, 2288,
 2288, 2288, 2288,    0, 2288,    0,    0, 2288, 2288,    0,
    0,    0, 2288, 2288,    0,    0, 2288, 2288, 2288, 2288,
 2288, 2288, 2288, 2288, 2288,    0, 2288,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2288, 2288, 2288, 2288,
 2288, 2288, 2288, 2288, 2288, 2288, 2288, 2288, 2288, 2288,
 2288, 2288, 2288, 2288, 2288, 2288, 2288,    0, 2288, 2288,
 2288, 2288, 2288, 2288,    0, 2288, 2288, 2288, 2288,    0,
 2288,    0, 2288, 2288, 2288, 2288, 2288, 2288, 2288, 2288,
 2288, 2288, 2288, 2288, 2288, 2288, 2288, 2288, 2288, 2288,
    0, 2288, 2288, 2288, 2288,    0, 2288, 2288, 2288, 2288,
 2288,    0, 2288, 2288, 2288, 2288, 2288, 2288, 2288, 2288,
 2288, 2288, 2288, 2288, 2288, 2288, 2288, 2288, 2288, 2288,
 2288, 2288, 2288, 2288, 2288, 2288, 2288, 2288, 2288, 2288,
 2288,    0, 2288, 2288,    0,    0,    0, 2288, 2288, 2288,
 2288, 2288, 2288,    0,    0, 2288, 2288, 2288, 2288, 2288,
 2288, 2288, 2288, 2288,    0, 2935,    0,    0,    0, 2288,
    0, 2288, 2288, 2288, 2288, 2288, 2288,    0, 2288,    0,
    0, 1432, 1431, 1433,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2288, 2288,    0, 2288, 2288,
 2288, 2288, 2288, 2288, 2288, 2288, 2288,    0, 2288, 2288,
 2288, 2288, 2288, 2288, 2288, 2288, 2288, 2288, 2288, 2288,
    0, 2288, 2288, 2288,    0, 2288,    0,    0,    0, 2288,
 2288, 2288, 2288, 2288, 2288, 2288, 2288, 2288, 2288, 2288,
 2288, 2288, 2289, 2288, 2288,    0,    0,    0,    0,    0,
 2288, 2288, 2288, 2288, 2288, 2288, 2288, 2288, 2288, 2288,
 2288, 2288, 2288, 2288, 2288, 2288, 2288, 2288,    0,    0,
 2288,    0, 2288, 2288, 2288, 2288, 2288, 2288, 2288, 2288,
 2288,    0,    0, 2289, 2289, 2289, 2289, 2289, 2289, 2289,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2289, 2289, 2289, 2289,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2289,    0, 2289,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1416,    0,    0,    0,    0,    0,    0,
    0,    0, 1417,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1418,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1419,
    0,    0,    0,    0,    0,    0, 1420,    0,    0,    0,
    0,    0,    0,    0, 1421,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1422,    0, 1423,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1424,    0, 1425, 1426, 1427,    0,    0,
    0,    0, 1428,    0,    0,    0,    0,    0,    0, 2289,
    0, 2289,    0,    0, 2289,    0, 2289, 2289, 2289,    0,
 2289, 2289,    0, 2289,    0,    0,    0,    0,    0, 2289,
    0, 2289, 2289, 2289, 2289,    0, 2289,    0,    0, 2289,
    0,    0, 2289, 1429,    0,    0,    0,    0,    0, 2289,
    0, 2289, 2289,    0, 2289, 2289, 2289, 2289, 2289,    0,
    0, 2289,    0,    0, 2289,    0, 2289, 2289,    0,    0,
 2289, 2289, 2289,    0, 2289, 2289, 2289, 2289, 2289, 2289,
 2289,    0,    0,    0, 2289, 2289, 2289, 2289, 2289,    0,
    0,    0, 2289,    0,    0,    0,    0,    0,    0,    0,
 2289, 2289, 2289, 2289, 2289, 2289,    0,    0,    0, 2289,
 2289,    0, 2289,    0, 2289,    0, 2289, 2289, 2289,    0,
 2289,    0, 2289, 2289, 2289,    0, 2289, 2289, 2289, 2289,
 2289,    0, 2289, 2289,    0,    0,    0,    0, 2289,    0,
 2289, 2289,    0,    0, 2289, 2289, 2289,    0,    0, 2289,
    0, 2289,    0,    0, 2289, 2289, 2289, 2289,    0, 2289,
    0, 2289,    0, 2289, 2289, 2289, 2289, 2289,    0,    0,
 2289, 2289, 2289,    0, 2289, 2289,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2289, 2289, 2289,    0, 2289,
 2289, 2289,    0,    0,    0,    0,    0, 2289,    0,    0,
    0, 2289,    0, 2289, 2289, 2289, 2289,    0, 2289,    0,
 2289, 2289, 2289, 2289, 2289, 2289, 2289, 2289,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2289, 2289,    0,
 2289, 2289, 2289, 1430,    0,    0,    0, 2289, 2289, 2289,
 2289, 2289,    0, 2289,    0,    0, 2289, 2289,    0,    0,
    0, 2289, 2289,    0,    0, 2289, 2289, 2289, 2289, 2289,
 2289, 2289, 2289, 2289,    0, 2289,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2289, 2289, 2289, 2289, 2289,
 2289, 2289, 2289, 2289, 2289, 2289, 2289, 2289, 2289, 2289,
 2289, 2289, 2289, 2289, 2289, 2289,    0, 2289, 2289, 2289,
 2289, 2289, 2289,    0, 2289, 2289, 2289, 2289,    0, 2289,
    0, 2289, 2289, 2289, 2289, 2289, 2289, 2289, 2289, 2289,
 2289, 2289, 2289, 2289, 2289, 2289, 2289, 2289, 2289,    0,
 2289, 2289, 2289, 2289,    0, 2289, 2289, 2289, 2289, 2289,
    0, 2289, 2289, 2289, 2289, 2289, 2289, 2289, 2289, 2289,
 2289, 2289, 2289, 2289, 2289, 2289, 2289, 2289, 2289, 2289,
 2289, 2289, 2289, 2289, 2289, 2289, 2289, 2289, 2289, 2289,
    0, 2289, 2289,    0,    0,    0, 2289, 2289, 2289, 2289,
 2289, 2289,    0,    0, 2289, 2289, 2289, 2289, 2289, 2289,
 2289, 2289, 2289,    0, 2936,    0,    0,    0, 2289,    0,
 2289, 2289, 2289, 2289, 2289, 2289,    0, 2289,    0,    0,
 1432, 1431, 1433,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2289, 2289,    0, 2289, 2289, 2289,
 2289, 2289, 2289, 2289, 2289, 2289,    0, 2289, 2289, 2289,
 2289, 2289, 2289, 2289, 2289, 2289, 2289, 2289, 2289,    0,
 2289, 2289, 2289,    0, 2289,    0,    0,    0, 2289, 2289,
 2289, 2289, 2289, 2289, 2289, 2289, 2289, 2289, 2289, 2289,
 2289, 2290, 2289, 2289,    0,    0,    0,    0,    0, 2289,
 2289, 2289, 2289, 2289, 2289, 2289, 2289, 2289, 2289, 2289,
 2289, 2289, 2289, 2289, 2289, 2289, 2289,    0,    0, 2289,
    0, 2289, 2289, 2289, 2289, 2289, 2289, 2289, 2289, 2289,
    0,    0, 2290, 2290, 2290, 2290, 2290, 2290, 2290,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2290, 2290, 2290, 2290,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2290,    0, 2290,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1416,    0,    0,    0,    0,    0,    0,    0,
    0, 1417,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1418,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1419,    0,
    0,    0,    0,    0,    0, 1420,    0,    0,    0,    0,
    0,    0,    0, 1421,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1422,    0, 1423,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1424,    0, 1425, 1426, 1427,    0,    0,    0,
    0, 1428,    0,    0,    0,    0,    0,    0, 2290,    0,
 2290,    0,    0, 2290,    0, 2290, 2290, 2290,    0, 2290,
 2290,    0, 2290,    0,    0,    0,    0,    0, 2290,    0,
 2290, 2290, 2290, 2290,    0, 2290,    0,    0, 2290,    0,
    0, 2290, 1429,    0,    0,    0,    0,    0, 2290,    0,
 2290, 2290,    0, 2290, 2290, 2290, 2290, 2290,    0,    0,
 2290,    0,    0, 2290,    0, 2290, 2290,    0,    0, 2290,
 2290, 2290,    0, 2290, 2290, 2290, 2290, 2290, 2290, 2290,
    0,    0,    0, 2290, 2290, 2290, 2290, 2290,    0,    0,
    0, 2290,    0,    0,    0,    0,    0,    0,    0, 2290,
 2290, 2290, 2290, 2290, 2290,    0,    0,    0, 2290, 2290,
    0, 2290,    0, 2290,    0, 2290, 2290, 2290,    0, 2290,
    0, 2290, 2290, 2290,    0, 2290, 2290, 2290, 2290, 2290,
    0, 2290, 2290,    0,    0,    0,    0, 2290,    0, 2290,
 2290,    0,    0, 2290, 2290, 2290,    0,    0, 2290,    0,
 2290,    0,    0, 2290, 2290, 2290, 2290,    0, 2290,    0,
 2290,    0, 2290, 2290, 2290, 2290, 2290,    0,    0, 2290,
 2290, 2290,    0, 2290, 2290,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2290, 2290, 2290,    0, 2290, 2290,
 2290,    0,    0,    0,    0,    0, 2290,    0,    0,    0,
 2290,    0, 2290, 2290, 2290, 2290,    0, 2290,    0, 2290,
 2290, 2290, 2290, 2290, 2290, 2290, 2290,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2290, 2290,    0, 2290,
 2290, 2290, 1430,    0,    0,    0, 2290, 2290, 2290, 2290,
 2290,    0, 2290,    0,    0, 2290, 2290,    0,    0,    0,
 2290, 2290,    0,    0, 2290, 2290, 2290, 2290, 2290, 2290,
 2290, 2290, 2290,    0, 2290,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2290, 2290, 2290, 2290, 2290, 2290,
 2290, 2290, 2290, 2290, 2290, 2290, 2290, 2290, 2290, 2290,
 2290, 2290, 2290, 2290, 2290,    0, 2290, 2290, 2290, 2290,
 2290, 2290,    0, 2290, 2290, 2290, 2290,    0, 2290,    0,
 2290, 2290, 2290, 2290, 2290, 2290, 2290, 2290, 2290, 2290,
 2290, 2290, 2290, 2290, 2290, 2290, 2290, 2290,    0, 2290,
 2290, 2290, 2290,    0, 2290, 2290, 2290, 2290, 2290,    0,
 2290, 2290, 2290, 2290, 2290, 2290, 2290, 2290, 2290, 2290,
 2290, 2290, 2290, 2290, 2290, 2290, 2290, 2290, 2290, 2290,
 2290, 2290, 2290, 2290, 2290, 2290, 2290, 2290, 2290,    0,
 2290, 2290,    0,    0,    0, 2290, 2290, 2290, 2290, 2290,
 2290,    0,    0, 2290, 2290, 2290, 2290, 2290, 2290, 2290,
 2290, 2290,    0, 1688,    0,    0,    0, 2290,    0, 2290,
 2290, 2290, 2290, 2290, 2290,    0, 2290,    0,    0, 1688,
 1688, 1688,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2290, 2290,    0, 2290, 2290, 2290, 2290,
 2290, 2290, 2290, 2290, 2290,    0, 2290, 2290, 2290, 2290,
 2290, 2290, 2290, 2290, 2290, 2290, 2290, 2290,    0, 2290,
 2290, 2290,    0, 2290,    0,    0,    0, 2290, 2290, 2290,
 2290, 2290, 2290, 2290, 2290, 2290, 2290, 2290, 2290, 2290,
 2291, 2290, 2290,    0,    0,    0,    0,    0, 2290, 2290,
 2290, 2290, 2290, 2290, 2290, 2290, 2290, 2290, 2290, 2290,
 2290, 2290, 2290, 2290, 2290, 2290,    0,    0, 2290,    0,
 2290, 2290, 2290, 2290, 2290, 2290, 2290, 2290, 2290,    0,
    0, 2291, 2291, 2291, 2291, 2291, 2291, 2291,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2291,
 2291, 2291, 2291,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2291,    0, 2291,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1688,    0,    0,    0,    0,    0,    0,    0,    0,
 1688,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1688,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1688,    0,    0,
    0,    0,    0,    0, 1688,    0,    0,    0,    0,    0,
    0,    0, 1688,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1688,
    0, 1688,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1688,    0, 1688, 1688, 1688,    0,    0,    0,    0,
 1688,    0,    0,    0,    0,    0,    0, 2291,    0, 2291,
    0,    0, 2291,    0, 2291, 2291, 2291,    0, 2291, 2291,
    0, 2291,    0,    0,    0,    0,    0, 2291,    0, 2291,
 2291, 2291, 2291,    0, 2291,    0,    0, 2291,    0,    0,
 2291, 1688,    0,    0,    0,    0,    0, 2291,    0, 2291,
 2291,    0, 2291, 2291, 2291, 2291, 2291,    0,    0, 2291,
    0,    0, 2291,    0, 2291, 2291,    0,    0, 2291, 2291,
 2291,    0, 2291, 2291, 2291, 2291, 2291, 2291, 2291,    0,
    0,    0, 2291, 2291, 2291, 2291, 2291,    0,    0,    0,
 2291,    0,    0,    0,    0,    0,    0,    0, 2291, 2291,
 2291, 2291, 2291, 2291,    0,    0,    0, 2291, 2291,    0,
 2291,    0, 2291,    0, 2291, 2291, 2291,    0, 2291,    0,
 2291, 2291, 2291,    0, 2291, 2291, 2291, 2291, 2291,    0,
 2291, 2291,    0,    0,  503,    0, 2291,    0, 2291, 2291,
    0,    0, 2291, 2291, 2291,    0,    0, 2291,    0, 2291,
    0,    0, 2291, 2291, 2291, 2291,    0, 2291,    0, 2291,
    0, 2291, 2291, 2291, 2291, 2291,    0,    0, 2291, 2291,
 2291,    0, 2291, 2291,    0,  503,    0,    0,  503,    0,
    0,    0,    0, 2291, 2291, 2291,    0, 2291, 2291, 2291,
    0,    0,    0,  503,    0, 2291,    0,    0,    0, 2291,
    0, 2291, 2291, 2291, 2291,    0, 2291,    0, 2291, 2291,
 2291, 2291, 2291, 2291, 2291, 2291,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2291, 2291,    0, 2291, 2291,
 2291, 1688,    0,    0,    0, 2291, 2291, 2291, 2291, 2291,
    0, 2291,    0,    0, 2291, 2291,    0,    0,    0, 2291,
 2291,    0,    0, 2291, 2291, 2291, 2291, 2291, 2291, 2291,
 2291, 2291,    0, 2291,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2291, 2291, 2291, 2291, 2291, 2291, 2291,
 2291, 2291, 2291, 2291, 2291, 2291, 2291, 2291, 2291, 2291,
 2291, 2291, 2291, 2291,    0, 2291, 2291, 2291, 2291, 2291,
 2291,    0, 2291, 2291, 2291, 2291,    0, 2291,    0, 2291,
 2291, 2291, 2291, 2291, 2291, 2291, 2291, 2291, 2291, 2291,
 2291, 2291, 2291, 2291, 2291, 2291, 2291,    0, 2291, 2291,
 2291, 2291,    0, 2291, 2291, 2291, 2291, 2291,    0, 2291,
 2291, 2291, 2291, 2291, 2291, 2291, 2291, 2291, 2291, 2291,
 2291, 2291, 2291, 2291, 2291, 2291, 2291, 2291, 2291, 2291,
 2291, 2291, 2291, 2291, 2291, 2291, 2291, 2291,    0, 2291,
 2291, 1432, 1431, 1433, 2291, 2291, 2291, 2291, 2291, 2291,
    0,    0, 2291, 2291, 2291, 2291, 2291, 2291, 2291, 2291,
 2291,    0,    0,    0,    0,    0, 2291,    0, 2291, 2291,
 2291, 2291, 2291, 2291,    0, 2291,    0,    0,    0,    0,
  503,  503,    0,    0,    0,    0,    0,  503,    0,    0,
    0,    0, 2291, 2291,    0, 2291, 2291, 2291, 2291, 2291,
 2291, 2291, 2291, 2291,    0, 2291, 2291, 2291, 2291, 2291,
 2291, 2291, 2291, 2291, 2291, 2291, 2291,    0, 2291, 2291,
 2291,    0, 2291,    0,    0,    0, 2291, 2291, 2291, 2291,
 2291, 2291, 2291, 2291, 2291, 2291, 2291, 2291, 2291, 2292,
 2291, 2291,    0,    0,    0,    0,    0, 2291, 2291, 2291,
 2291, 2291, 2291, 2291, 2291, 2291, 2291, 2291, 2291, 2291,
 2291, 2291, 2291, 2291, 2291,    0,    0, 2291,  503, 2291,
 2291, 2291, 2291, 2291, 2291, 2291, 2291, 2291,    0,    0,
 2292, 2292, 2292, 2292, 2292, 2292, 2292,    0,    0,  503,
    0,    0,    0,    0,    0,  503,    0,    0, 2292, 2292,
 2292, 2292,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  503,    0,
 2292,    0, 2292,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1416,    0,    0,  645,    0,    0,    0,
    0,    0, 1417,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1418,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  646,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  503,    0,    0,    0,    0,    0,    0,    0, 1419,
    0,    0,    0,    0,    0,    0, 1420,    0,    0,    0,
    0,    0,    0,    0, 1421,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1422,    0, 1423,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1424,    0, 1425, 1426, 1427,    0,    0,
    0,    0, 1428,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1429,    0,    0, 2292,    0, 2292,    0,
    0, 2292,    0, 2292, 2292, 2292,    0, 2292, 2292,    0,
 2292,    0,    0,    0,    0,    0, 2292,    0, 2292, 2292,
 2292, 2292,    0, 2292,    0,    0, 2292,    0,    0, 2292,
    0,    0,    0,    0,    0,    0, 2292,    0, 2292, 2292,
    0, 2292, 2292, 2292, 2292, 2292,    0,    0, 2292,    0,
    0, 2292,    0, 2292, 2292,    0,    0, 2292, 2292, 2292,
    0, 2292, 2292, 2292, 2292, 2292, 2292, 2292,    0,    0,
    0, 2292, 2292, 2292, 2292, 2292,    0,    0,    0, 2292,
    0,    0,    0,    0,    0,    0,    0, 2292, 2292, 2292,
 2292, 2292, 2292,    0,    0,    0, 2292, 2292,    0, 2292,
    0, 2292,    0, 2292, 2292, 2292,    0, 2292,    0, 2292,
 2292, 2292,    0, 2292, 2292, 2292, 2292, 2292,    0, 2292,
 2292,    0,    0,    0,    0, 2292,    0, 2292, 2292,    0,
    0, 2292, 2292, 2292,    0,    0, 2292,    0, 2292,    0,
    0, 2292, 2292, 2292, 2292,    0, 2292,    0, 2292,    0,
 2292, 2292, 2292, 2292, 2292,    0,    0, 2292, 2292, 2292,
    0, 2292, 2292,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2292, 2292, 2292,    0, 2292, 2292, 2292,    0,
    0,    0,    0, 1430, 2292,    0,    0,    0, 2292,    0,
 2292, 2292, 2292, 2292,    0, 2292,    0, 2292, 2292, 2292,
 2292, 2292, 2292, 2292, 2292,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2292, 2292,    0, 2292, 2292, 2292,
    0,    0,    0,    0, 2292, 2292, 2292, 2292, 2292,    0,
 2292,    0,    0, 2292, 2292,    0,    0,    0, 2292, 2292,
    0,    0, 2292, 2292, 2292, 2292, 2292, 2292, 2292, 2292,
 2292,    0, 2292,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2292, 2292, 2292, 2292, 2292, 2292, 2292, 2292,
 2292, 2292, 2292, 2292, 2292, 2292, 2292, 2292, 2292, 2292,
 2292, 2292, 2292,    0, 2292, 2292, 2292, 2292, 2292, 2292,
    0, 2292, 2292, 2292, 2292,    0, 2292,    0, 2292, 2292,
 2292, 2292, 2292, 2292, 2292, 2292, 2292, 2292, 2292, 2292,
 2292, 2292, 2292, 2292, 2292, 2292,    0, 2292, 2292, 2292,
 2292,    0, 2292, 2292, 2292, 2292, 2292,    0, 2292, 2292,
 2292, 2292, 2292, 2292, 2292, 2292, 2292, 2292, 2292, 2292,
 2292, 2292, 2292, 2292, 2292, 2292, 2292, 2292, 2292, 2292,
 2292, 2292, 2292, 2292, 2292, 2292, 2292,    0, 2292, 2292,
 1432, 1431, 1433, 2292, 2292, 2292, 2292, 2292, 2292,    0,
    0, 2292, 2292, 2292, 2292, 2292, 2292, 2292, 2292, 2292,
    0,    0,    0,    0,    0, 2292,    0, 2292, 2292, 2292,
 2292, 2292, 2292,    0, 2292,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2292, 2292,    0, 2292, 2292, 2292, 2292, 2292, 2292,
 2292, 2292, 2292,    0, 2292, 2292, 2292, 2292, 2292, 2292,
 2292, 2292, 2292, 2292, 2292, 2292,    0, 2292, 2292, 2292,
    0, 2292,    0,    0,    0, 2292, 2292, 2292, 2292, 2292,
 2292, 2292, 2292, 2292, 2292, 2292, 2292, 2292, 2293, 2292,
 2292,    0,    0,    0,    0,    0, 2292, 2292, 2292, 2292,
 2292, 2292, 2292, 2292, 2292, 2292, 2292, 2292, 2292, 2292,
 2292, 2292, 2292, 2292,    0,    0, 2292,    0, 2292, 2292,
 2292, 2292, 2292, 2292, 2292, 2292, 2292,    0,    0, 2293,
 2293, 2293, 2293, 2293, 2293, 2293,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2293, 2293, 2293,
 2293,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2293,
    0, 2293,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1416,    0,    0,    0,    0,    0,    0,    0,
    0, 1417,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1418,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1419,    0,
    0,    0,    0,    0,    0, 1420,    0,    0,    0,    0,
    0,    0,    0, 1421,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1422,    0, 1423,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1424,    0, 1425, 1426, 1427,    0,    0,    0,
    0, 1428,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1429,    0,    0, 2293,    0, 2293,    0, 1972,
 2293,    0, 2293, 2293, 2293,    0, 2293, 2293,    0, 2293,
    0,    0,    0,    0,    0, 2293,    0, 2293, 2293, 2293,
 2293,    0, 2293,    0,    0, 2293,    0,    0, 2293,    0,
    0,    0,    0,    0,    0, 2293,    0, 2293, 2293,    0,
 2293, 2293, 2293, 2293, 2293,    0,    0, 2293,    0,    0,
 2293,    0, 2293, 2293,    0,    0, 2293, 2293, 2293,    0,
 2293, 2293, 2293, 2293, 2293, 2293, 2293,    0,    0,    0,
 2293, 2293, 2293, 2293, 2293,    0,    0,    0, 2293,    0,
    0,    0,    0,    0,    0,    0, 2293, 2293, 2293, 2293,
 2293, 2293,    0,    0,    0, 2293, 2293,    0, 2293,    0,
 2293,    0, 2293, 2293, 2293,    0, 2293,    0, 2293, 2293,
 2293,    0, 2293, 2293, 2293, 2293, 2293,    0, 2293, 2293,
    0,    0,    0,    0, 2293,    0, 2293, 2293,    0,    0,
 2293, 2293, 2293,    0,    0, 2293,    0, 2293,    0,    0,
 2293, 2293, 2293, 2293,    0, 2293,    0, 2293,    0, 2293,
 2293, 2293, 2293, 2293,    0,    0, 2293, 2293, 2293,    0,
 2293, 2293,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2293, 2293, 2293,    0, 2293, 2293, 2293,    0,    0,
    0,    0, 1430, 2293,    0,    0,    0, 2293,    0, 2293,
 2293, 2293, 2293,    0, 2293,    0, 2293, 2293, 2293, 2293,
 2293, 2293, 2293, 2293,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2293, 2293,    0, 2293, 2293, 2293,    0,
    0,    0,    0, 2293, 2293, 2293, 2293, 2293,    0, 2293,
    0,    0, 2293, 2293,    0,    0,    0, 2293, 2293,    0,
    0, 2293, 2293, 2293, 2293, 2293, 2293, 2293, 2293, 2293,
    0, 2293,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2293, 2293, 2293, 2293, 2293, 2293, 2293, 2293, 2293,
 2293, 2293, 2293, 2293, 2293, 2293, 2293, 2293, 2293, 2293,
 2293, 2293,    0, 2293, 2293, 2293, 2293, 2293, 2293,    0,
 2293, 2293, 2293, 2293,    0, 2293,    0, 2293, 2293, 2293,
 2293, 2293, 2293, 2293, 2293, 2293, 2293, 2293, 2293, 2293,
 2293, 2293, 2293, 2293, 2293,    0, 2293, 2293, 2293, 2293,
    0, 2293, 2293, 2293, 2293, 2293,    0, 2293, 2293, 2293,
 2293, 2293, 2293, 2293, 2293, 2293, 2293, 2293, 2293, 2293,
 2293, 2293, 2293, 2293, 2293, 2293, 2293, 2293, 2293, 2293,
 2293, 2293, 2293, 2293, 2293, 2293,    0, 2293, 2293, 1432,
 1431, 1433, 2293, 2293, 2293, 2293, 2293, 2293,    0,    0,
 2293, 2293, 2293, 2293, 2293, 2293, 2293, 2293, 2293,    0,
    0,    0,    0,    0, 2293,    0, 2293, 2293, 2293, 2293,
 2293, 2293,    0, 2293,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2293, 2293,    0, 2293, 2293, 2293, 2293, 2293, 2293, 2293,
 2293, 2293,    0, 2293, 2293, 2293, 2293, 2293, 2293, 2293,
 2293, 2293, 2293, 2293, 2293,    0, 2293, 2293, 2293,    0,
 2293,    0,    0,    0, 2293, 2293, 2293, 2293, 2293, 2293,
 2293, 2293, 2293, 2293, 2293, 2293, 2293, 2294, 2293, 2293,
    0,    0,    0,    0,    0, 2293, 2293, 2293, 2293, 2293,
 2293, 2293, 2293, 2293, 2293, 2293, 2293, 2293, 2293, 2293,
 2293, 2293, 2293,    0,    0, 2293,    0, 2293, 2293, 2293,
 2293, 2293, 2293, 2293, 2293, 2293,    0,    0, 2294, 2294,
 2294, 2294, 2294, 2294, 2294,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2294, 2294, 2294, 2294,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2294,    0,
 2294,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1416,    0, 2119,    0,    0,    0,    0,    0,    0,
 1417,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1418,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1419,    0,    0,
    0,    0,    0,    0, 1420,    0,    0,    0,    0,    0,
    0,    0, 1421,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1422,
    0, 1423,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1424,    0, 1425, 1426, 1427,    0,    0,    0,    0,
 1428,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1429,    0,    0, 2294,    0, 2294,    0,    0, 2294,
    0, 2294, 2294, 2294,    0, 2294, 2294,    0, 2294,    0,
    0,    0,    0,    0, 2294,    0, 2294, 2294, 2294, 2294,
    0, 2294,    0,    0, 2294,    0,    0, 2294,    0,    0,
    0,    0,    0,    0, 2294,    0, 2294, 2294,    0, 2294,
 2294, 2294, 2294, 2294,    0,    0, 2294,    0,    0, 2294,
    0, 2294, 2294,    0,    0, 2294, 2294, 2294,    0, 2294,
 2294, 2294, 2294, 2294, 2294, 2294,    0,    0,    0, 2294,
 2294, 2294, 2294, 2294,    0,    0,    0, 2294,    0,    0,
    0,    0,    0,    0,    0, 2294, 2294, 2294, 2294, 2294,
 2294,    0,    0,    0, 2294, 2294,    0, 2294,    0, 2294,
    0, 2294, 2294, 2294,    0, 2294,    0, 2294, 2294, 2294,
    0, 2294, 2294, 2294, 2294, 2294,    0, 2294, 2294,    0,
    0,    0,    0, 2294,    0, 2294, 2294,    0,    0, 2294,
 2294, 2294,    0,    0, 2294,    0, 2294,    0,    0, 2294,
 2294, 2294, 2294,    0, 2294,    0, 2294,    0, 2294, 2294,
 2294, 2294, 2294,    0,    0, 2294, 2294, 2294,    0, 2294,
 2294,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2294, 2294, 2294,    0, 2294, 2294, 2294,    0,    0,    0,
    0, 1430, 2294,    0,    0,    0, 2294,    0, 2294, 2294,
 2294, 2294,    0, 2294,    0, 2294, 2294, 2294, 2294, 2294,
 2294, 2294, 2294,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2294, 2294,    0, 2294, 2294, 2294,    0,    0,
    0,    0, 2294, 2294, 2294, 2294, 2294,    0, 2294,    0,
    0, 2294, 2294,    0,    0,    0, 2294, 2294,    0,    0,
 2294, 2294, 2294, 2294, 2294, 2294, 2294, 2294, 2294,    0,
 2294,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2294, 2294, 2294, 2294, 2294, 2294, 2294, 2294, 2294, 2294,
 2294, 2294, 2294, 2294, 2294, 2294, 2294, 2294, 2294, 2294,
 2294,    0, 2294, 2294, 2294, 2294, 2294, 2294,    0, 2294,
 2294, 2294, 2294,    0, 2294,    0, 2294, 2294, 2294, 2294,
 2294, 2294, 2294, 2294, 2294, 2294, 2294, 2294, 2294, 2294,
 2294, 2294, 2294, 2294,    0, 2294, 2294, 2294, 2294,    0,
 2294, 2294, 2294, 2294, 2294,    0, 2294, 2294, 2294, 2294,
 2294, 2294, 2294, 2294, 2294, 2294, 2294, 2294, 2294, 2294,
 2294, 2294, 2294, 2294, 2294, 2294, 2294, 2294, 2294, 2294,
 2294, 2294, 2294, 2294, 2294,    0, 2294, 2294, 1432, 1431,
 1433, 2294, 2294, 2294, 2294, 2294, 2294,    0,    0, 2294,
 2294, 2294, 2294, 2294, 2294, 2294, 2294, 2294,    0,    0,
    0,    0,    0, 2294,    0, 2294, 2294, 2294, 2294, 2294,
 2294,    0, 2294,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2294,
 2294,    0, 2294, 2294, 2294, 2294, 2294, 2294, 2294, 2294,
 2294,    0, 2294, 2294, 2294, 2294, 2294, 2294, 2294, 2294,
 2294, 2294, 2294, 2294,    0, 2294, 2294, 2294,    0, 2294,
    0,    0,    0, 2294, 2294, 2294, 2294, 2294, 2294, 2294,
 2294, 2294, 2294, 2294, 2294, 2294, 2314, 2294, 2294,    0,
    0,    0,    0,    0, 2294, 2294, 2294, 2294, 2294, 2294,
 2294, 2294, 2294, 2294, 2294, 2294, 2294, 2294, 2294, 2294,
 2294, 2294,    0,    0, 2294,    0, 2294, 2294, 2294, 2294,
 2294, 2294, 2294, 2294, 2294,    0,    0, 2314, 2314, 2314,
 2314, 2314, 2314, 2314,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2314, 2314, 2314, 2314,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2314,    0, 2314,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1416,    0,    0,    0,    0,    0,    0,    0,    0, 1417,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1418,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2138,    0,    0,    0, 1419,    0,    0,    0,
    0,    0,    0, 1420,    0,    0,    0,    0,    0,    0,
    0, 1421,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1422,    0,
 1423,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1424,    0, 1425, 1426, 1427,    0,    0,    0,    0, 1428,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1429,    0,    0, 2314,    0, 2314,    0,    0, 2314,    0,
 2314, 2314, 2314,    0, 2314, 2314,    0, 2314,    0,    0,
    0,    0,    0, 2314,    0, 2314, 2314, 2314, 2314,    0,
 2314,    0,    0, 2314,    0,    0, 2314,    0,    0,    0,
    0,    0,    0, 2314,    0, 2314, 2314,    0, 2314, 2314,
 2314, 2314, 2314,    0,    0, 2314,    0,    0, 2314,    0,
 2314, 2314,    0,    0, 2314, 2314, 2314,    0, 2314, 2314,
 2314, 2314, 2314, 2314, 2314,    0,    0,    0, 2314, 2314,
 2314, 2314, 2314,    0,    0,    0, 2314,    0,    0,    0,
    0,    0,    0,    0, 2314, 2314, 2314, 2314, 2314, 2314,
    0,    0,    0, 2314, 2314,    0, 2314,    0, 2314,    0,
 2314, 2314, 2314,    0, 2314,    0, 2314, 2314, 2314,    0,
 2314, 2314, 2314, 2314, 2314,    0, 2314, 2314,    0,    0,
    0,    0, 2314,    0, 2314, 2314,    0,    0, 2314, 2314,
 2314,    0,    0, 2314,    0, 2314,    0,    0, 2314, 2314,
 2314, 2314,    0, 2314,    0, 2314,    0, 2314, 2314, 2314,
 2314, 2314,    0,    0, 2314, 2314, 2314,    0, 2314, 2314,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2314,
 2314, 2314,    0, 2314, 2314, 2314,    0,    0,    0,    0,
 2139, 2314,    0,    0,    0, 2314,    0, 2314, 2314, 2314,
 2314,    0, 2314,    0, 2314, 2314, 2314, 2314, 2314, 2314,
 2314, 2314,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2314, 2314,    0, 2314, 2314, 2314,    0,    0,    0,
    0, 2314, 2314, 2314, 2314, 2314,    0, 2314,    0,    0,
 2314, 2314,    0,    0,    0, 2314, 2314,    0,    0, 2314,
 2314, 2314, 2314, 2314, 2314, 2314, 2314, 2314,    0, 2314,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2314,
 2314, 2314, 2314, 2314, 2314, 2314, 2314, 2314, 2314, 2314,
 2314, 2314, 2314, 2314, 2314, 2314, 2314, 2314, 2314, 2314,
    0, 2314, 2314, 2314, 2314, 2314, 2314,    0, 2314, 2314,
 2314, 2314,    0, 2314,    0, 2314, 2314, 2314, 2314, 2314,
 2314, 2314, 2314, 2314, 2314, 2314, 2314, 2314, 2314, 2314,
 2314, 2314, 2314,    0, 2314, 2314, 2314, 2314,    0, 2314,
 2314, 2314, 2314, 2314,    0, 2314, 2314, 2314, 2314, 2314,
 2314, 2314, 2314, 2314, 2314, 2314, 2314, 2314, 2314, 2314,
 2314, 2314, 2314, 2314, 2314, 2314, 2314, 2314, 2314, 2314,
 2314, 2314, 2314, 2314,    0, 2314, 2314,    0,    0,    0,
 2314, 2314, 2314, 2314, 2314, 2314,    0,    0, 2314, 2314,
 2314, 2314, 2314, 2314, 2314, 2314, 2314,    0,    0, 1432,
 1431, 1433, 2314,    0, 2314, 2314, 2314, 2314, 2314, 2314,
    0, 2314,    0,    0,    0,    0,    0, 1432, 1431, 1433,
    0,    0,    0,    0,    0,    0,    0,    0, 2314, 2314,
    0, 2314, 2314, 2314, 2314, 2314, 2314, 2314, 2314, 2314,
    0, 2314, 2314, 2314, 2314, 2314, 2314, 2314, 2314, 2314,
 2314, 2314, 2314,    0, 2314, 2314, 2314,    0, 2314,    0,
    0,    0, 2314, 2314, 2314, 2314, 2314, 2314, 2314, 2314,
 2314, 2314, 2314, 2314, 2314, 2338, 2314, 2314,    0,    0,
    0,    0,    0, 2314, 2314, 2314, 2314, 2314, 2314, 2314,
 2314, 2314, 2314, 2314, 2314, 2314, 2314, 2314, 2314, 2314,
 2314,    0,    0, 2314,    0, 2314, 2314, 2314, 2314, 2314,
 2314, 2314, 2314, 2314,    0,    0, 2338, 2338, 2338, 2338,
 2338, 2338, 2338,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2338, 2338, 2338, 2338,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2338,    0, 2338,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1416,    0,    0,    0,    0,    0,    0,    0,    0,
 1417,    0,    0,    0,    0,    0,    0,    0,    0, 1416,
    0,    0,    0, 1418,    0,    0,    0,    0, 1417,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1418,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2587,    0,    0,    0, 1419,    0,    0,
    0,    0,    0,    0, 1420,    0,    0,    0,    0,    0,
    0,    0, 1421,    0,    0, 1419,    0,    0,    0,    0,
    0,    0, 1420,    0,    0,    0,    0,    0,    0, 1422,
 1421, 1423,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1424,    0, 1425, 1426, 1427,    0, 1422,    0, 1423,
 1428,    0,    0,    0,    0,    0,    0,    0,    0, 1424,
    0, 1425, 1426, 1427,    0,    0,    0,    0, 1428,    0,
    0,    0, 2338,    0, 2338,    0,    0, 2338,    0, 2338,
 2338, 2338,    0, 2338, 2338,    0, 2338,    0,    0,    0,
    0, 1429, 2338,    0, 2338, 2338, 2338, 2338,    0, 2338,
    0,    0, 2338,    0,    0, 2338,    0,    0,    0, 1429,
    0,    0, 2338,    0, 2338, 2338,    0, 2338, 2338, 2338,
 2338, 2338,    0,    0, 2338,    0,    0, 2338,    0, 2338,
 2338,    0,    0, 2338, 2338, 2338,    0, 2338, 2338, 2338,
 2338, 2338, 2338, 2338,    0,    0,    0, 2338, 2338, 2338,
 2338, 2338,    0,    0,    0, 2338,    0,    0,    0,    0,
    0,    0,    0, 2338, 2338, 2338, 2338, 2338, 2338,    0,
    0,    0, 2338, 2338,    0, 2338,    0, 2338,    0, 2338,
 2338, 2338,    0, 2338,    0, 2338, 2338, 2338,    0, 2338,
 2338, 2338, 2338, 2338,    0, 2338, 2338,    0,    0,    0,
    0, 2338,    0, 2338, 2338,    0,    0, 2338, 2338, 2338,
    0,    0, 2338,    0, 2338,    0,    0, 2338, 2338, 2338,
 2338,    0, 2338,    0, 2338,    0, 2338, 2338, 2338, 2338,
 2338,    0,    0, 2338, 2338, 2338,    0, 2338, 2338,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2338, 2338,
 2338,    0, 2338, 2338, 2338,    0,    0,    0,    0,    0,
 2338,    0,    0,    0, 2338,    0, 2338, 2338, 2338, 2338,
 2166, 2338,    0, 2338, 2338, 2338, 2338, 2338, 2338, 2338,
 2338, 1430,    0,    0,    0,    0,    0,    0,    0,    0,
 2338, 2338,    0, 2338, 2338, 2338,    0,    0,    0, 1430,
 2338, 2338, 2338, 2338, 2338,    0, 2338,    0,    0, 2338,
 2338,    0,    0,    0, 2338, 2338,    0,    0, 2338, 2338,
 2338, 2338, 2338, 2338, 2338, 2338, 2338,    0, 2338,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2338, 2338,
 2338, 2338, 2338, 2338, 2338, 2338, 2338, 2338, 2338, 2338,
 2338, 2338, 2338, 2338, 2338, 2338, 2338, 2338, 2338,    0,
 2338, 2338, 2338, 2338, 2338, 2338,    0, 2338, 2338, 2338,
 2338,    0, 2338,    0, 2338, 2338, 2338, 2338, 2338, 2338,
 2338, 2338, 2338, 2338, 2338, 2338, 2338, 2338, 2338, 2338,
 2338, 2338,    0, 2338, 2338, 2338, 2338,    0, 2338, 2338,
 2338, 2338, 2338,    0, 2338, 2338, 2338, 2338, 2338, 2338,
 2338, 2338, 2338, 2338, 2338, 2338, 2338, 2338, 2338, 2338,
 2338, 2338, 2338, 2338, 2338, 2338, 2338, 2338, 2338, 2338,
 2338, 2338, 2338,    0, 2338, 2338, 1432, 1431, 1433, 2338,
 2338, 2338, 2338, 2338, 2338,    0,    0, 2338, 2338, 2338,
 2338, 2338, 2338, 2338, 2338, 2338,    0,    0,    0,    0,
    0, 2338,    0, 2338, 2338, 2338, 2338, 2338, 2338,    0,
 2338,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2338, 2338,    0,
 2338, 2338, 2338, 2338, 2338, 2338, 2338, 2338, 2338,    0,
 2338, 2338, 2338, 2338, 2338, 2338, 2338, 2338, 2338, 2338,
 2338, 2338,    0, 2338, 2338, 2338,    0, 2338,    0,    0,
    0, 2338, 2338, 2338, 2338, 2338, 2338, 2338, 2338, 2338,
 2338, 2338, 2338, 2338, 2343, 2338, 2338,    0,    0,    0,
    0,    0, 2338, 2338, 2338, 2338, 2338, 2338, 2338, 2338,
 2338, 2338, 2338, 2338, 2338, 2338, 2338, 2338, 2338, 2338,
    0,    0, 2338,    0, 2338, 2338, 2338, 2338, 2338, 2338,
 2338, 2338, 2338,    0,    0, 2343, 2343, 2343, 2343, 2343,
 2343, 2343,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2343, 2343, 2343, 2343,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2343,    0, 2343,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1416,    0,
    0,    0,    0,    0,    0,    0,    0, 1417,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1418,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1419,    0,    0,    0,    0,    0,
    0, 1420,    0,    0,    0,    0,    0,    0,    0, 1421,
    0,    0, 2198,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1422,    0, 1423,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1424,    0,
 1425, 1426, 1427,    0,    0,    0,    0, 1428,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1429,    0,
    0, 2343,    0, 2343,    0,    0, 2343,    0, 2343, 2343,
 2343,    0, 2343, 2343,    0, 2343,    0,    0,    0,    0,
    0, 2343,    0, 2343, 2343, 2343, 2343,    0, 2343,    0,
    0, 2343,    0,    0, 2343,    0,    0,    0,    0,    0,
    0, 2343,    0, 2343, 2343,    0, 2343, 2343, 2343, 2343,
 2343,    0,    0, 2343,    0,    0, 2343,    0, 2343, 2343,
    0,    0, 2343, 2343, 2343,    0, 2343, 2343, 2343, 2343,
 2343, 2343, 2343,    0,    0,    0, 2343, 2343, 2343, 2343,
 2343,    0,    0,    0, 2343,    0,    0,    0,    0,    0,
    0,    0, 2343, 2343, 2343, 2343, 2343, 2343,    0,    0,
    0, 2343, 2343,    0, 2343,    0, 2343,    0, 2343, 2343,
 2343,    0, 2343,    0, 2343, 2343, 2343,    0, 2343, 2343,
 2343, 2343, 2343,    0, 2343, 2343,    0,    0,    0,    0,
 2343,    0, 2343, 2343,    0,    0, 2343, 2343, 2343,    0,
    0, 2343,    0, 2343,    0,    0, 2343, 2343, 2343, 2343,
    0, 2343,    0, 2343,    0, 2343, 2343, 2343, 2343, 2343,
    0,    0, 2343, 2343, 2343,    0, 2343, 2343,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2343, 2343, 2343,
    0, 2343, 2343, 2343,    0,    0,    0,    0, 1430, 2343,
    0,    0,    0, 2343,    0, 2343, 2343, 2343, 2343,    0,
 2343,    0, 2343, 2343, 2343, 2343, 2343, 2343, 2343, 2343,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2343,
 2343,    0, 2343, 2343, 2343,    0,    0,    0,    0, 2343,
 2343, 2343, 2343, 2343,    0, 2343,    0,    0, 2343, 2343,
    0,    0,    0, 2343, 2343,    0,    0, 2343, 2343, 2343,
 2343, 2343, 2343, 2343, 2343, 2343,    0, 2343,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2343, 2343, 2343,
 2343, 2343, 2343, 2343, 2343, 2343, 2343, 2343, 2343, 2343,
 2343, 2343, 2343, 2343, 2343, 2343, 2343, 2343,    0, 2343,
 2343, 2343, 2343, 2343, 2343,    0, 2343, 2343, 2343, 2343,
    0, 2343,    0, 2343, 2343, 2343, 2343, 2343, 2343, 2343,
 2343, 2343, 2343, 2343, 2343, 2343, 2343, 2343, 2343, 2343,
 2343,    0, 2343, 2343, 2343, 2343,    0, 2343, 2343, 2343,
 2343, 2343,    0, 2343, 2343, 2343, 2343, 2343, 2343, 2343,
 2343, 2343, 2343, 2343, 2343, 2343, 2343, 2343, 2343, 2343,
 2343, 2343, 2343, 2343, 2343, 2343, 2343, 2343, 2343, 2343,
 2343, 2343,    0, 2343, 2343, 1432, 1431, 1433, 2343, 2343,
 2343, 2343, 2343, 2343,    0,    0, 2343, 2343, 2343, 2343,
 2343, 2343, 2343, 2343, 2343,    0,    0,    0,    0,    0,
 2343,    0, 2343, 2343, 2343, 2343, 2343, 2343,    0, 2343,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2343, 2343,    0, 2343,
 2343, 2343, 2343, 2343, 2343, 2343, 2343, 2343,    0, 2343,
 2343, 2343, 2343, 2343, 2343, 2343, 2343, 2343, 2343, 2343,
 2343,    0, 2343, 2343, 2343,    0, 2343,    0,    0,    0,
 2343, 2343, 2343, 2343, 2343, 2343, 2343, 2343, 2343, 2343,
 2343, 2343, 2343, 1793, 2343, 2343,    0,    0,    0,    0,
    0, 2343, 2343, 2343, 2343, 2343, 2343, 2343, 2343, 2343,
 2343, 2343, 2343, 2343, 2343, 2343, 2343, 2343, 2343,    0,
    0, 2343,    0, 2343, 2343, 2343, 2343, 2343, 2343, 2343,
 2343, 2343,    0,    0, 1793, 1793, 1793, 1793, 1793,    0,
 1793,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1793, 1793, 1793, 1793,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1793,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1416,    0,    0,
    0,    0,    0,    0,    0,    0, 1417,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1418,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1419,    0,    0,    0,    0,    0,    0,
 1420,    0,    0,    0,    0,    0,    0,    0, 1421,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1422,    0, 1423,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1424,    0, 1425,
 1426, 1427,    0,    0,    0,    0, 1428,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1429,    0,    0,
 1793,    0, 1793,    0,    0, 1793,    0, 1793, 1793, 1793,
    0, 1793, 1793,    0, 1793,    0,    0,    0,    0,    0,
 1793,    0, 1793, 1793, 1793, 1793,    0, 1793,    0,    0,
 1793,    0,    0, 1793,    0,    0,    0,    0,    0,    0,
 1793,    0, 1793, 1793,    0, 1793, 1793, 1793, 1793, 1793,
    0,    0, 1793,    0,    0, 1793,    0, 1793, 1793,    0,
    0, 1793, 1793, 1793,    0, 1793, 1793, 1793, 1793, 1793,
 1793, 1793, 2228,    0,    0, 1793, 1793, 1793, 1793, 1793,
    0,    0,    0, 1793,    0,    0,    0,    0,    0,    0,
    0, 1793, 1793, 1793, 1793, 1793, 1793,    0,    0,    0,
 1793, 1793,    0, 1793,    0, 1793,    0, 1793, 1793, 1793,
    0, 1793,    0, 1793, 1793, 1793,    0, 1793, 1793, 1793,
 1793, 1793,    0, 1793, 1793,    0,    0,    0,    0, 1793,
    0, 1793, 1793,    0,    0, 1793, 1793, 1793,    0,    0,
 1793,    0, 1793,    0,    0, 1793, 1793, 1793, 1793,    0,
 1793,    0, 1793,    0, 1793, 1793, 1793, 1793, 1793,    0,
    0, 1793, 1793, 1793,    0, 1793, 1793,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1793, 1793, 1793,    0,
 1793, 1793, 1793,    0,    0,    0,    0, 1430, 1793,    0,
    0,    0, 1793,    0, 1793, 1793, 1793, 1793,    0, 1793,
    0, 1793, 1793, 1793, 1793, 1793, 1793, 1793, 1793,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1793, 1793,
    0, 1793, 1793, 1793,    0,    0,    0,    0, 1793, 1793,
 1793, 1793, 1793,    0, 1793,    0,    0, 1793, 1793,    0,
    0,    0, 1793, 1793,    0,    0, 1793, 1793, 1793, 1793,
 1793, 1793, 1793, 1793, 1793,    0, 1793,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1793, 1793, 1793, 1793,
 1793, 1793, 1793, 1793, 1793, 1793, 1793, 1793, 1793, 1793,
 1793, 1793, 1793, 1793, 1793, 1793, 1793,    0, 1793, 1793,
 1793, 1793, 1793, 1793,    0, 1793, 1793, 1793, 1793,    0,
 1793,    0, 1793, 1793, 1793, 1793, 1793, 1793, 1793, 1793,
 1793, 1793, 1793, 1793, 1793, 1793, 1793, 1793, 1793, 1793,
    0, 1793, 1793, 1793, 1793,    0, 1793, 1793, 1793, 1793,
 1793,    0, 1793, 1793, 1793, 1793, 1793, 1793, 1793, 1793,
 1793, 1793, 1793, 1793, 1793, 1793, 1793, 1793, 1793, 1793,
 1793, 1793,    0, 1793, 1793, 1793, 1793, 1793, 1793, 1793,
 1793, 1851, 1793, 1793, 1432, 1431, 1433, 1793, 1793, 1793,
 1793, 1793, 1793,    0,    0, 1793, 1793, 1793, 1793, 1793,
 1793, 1793, 1793, 1793,    0,    0,    0,    0,    0, 1793,
    0, 1793, 1793, 1793, 1793, 1793, 1793,    0, 1793,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1793, 1793,    0, 1793, 1793,
 1793, 1793, 1793, 1793, 1793, 1793, 1793,    0, 1793, 1793,
 1793, 1793, 1793, 1793, 1793, 1793, 1793, 1793, 1793, 1793,
    0, 1793, 1793, 1793,    0, 1793,    0,    0,    0, 1793,
 1793, 1793, 1793, 1793, 1793, 1793, 1793, 1793, 1793, 1793,
 1793, 1793, 1799, 1793, 1793,    0,    0,    0,    0,    0,
 1793, 1793, 1793, 1793, 1793, 1793, 1793, 1793, 1793, 1793,
 1793, 1793, 1793, 1793, 1793, 1793, 1793, 1793,    0,    0,
 1793,    0, 1793, 1793, 1793, 1793, 1793, 1793, 1793, 1793,
 1793,    0,    0, 1799, 1799, 1799, 1799, 1799,    0, 1799,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1799, 1799, 1799, 1799,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1799,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1416,    0,    0,    0,
    0,    0,    0,    0,    0, 1417,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1418,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1419,    0,    0,    0,    0,    0,    0, 1420,
    0,    0,    0,    0,    0,    0,    0, 1421,    0,    0,
 2229,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1422,    0, 1423,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1424,    0, 1425, 1426,
 1427,    0,    0,    0,    0, 1428,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1429,    0,    0, 1799,
    0, 1799,    0,    0, 1799,    0, 1799, 1799, 1799,    0,
 1799, 1799,    0, 1799,    0,    0,    0,    0,    0, 1799,
    0, 1799, 1799, 1799, 1799,    0, 1799,    0,    0, 1799,
    0,    0, 1799,    0,    0,    0,    0,    0,    0, 1799,
    0, 1799, 1799,    0, 1799, 1799, 1799, 1799, 1799,    0,
    0, 1799,    0,    0, 1799,    0, 1799, 1799,    0,    0,
 1799, 1799, 1799,    0, 1799, 1799, 1799, 1799, 1799, 1799,
 1799,    0,    0,    0, 1799, 1799, 1799, 1799, 1799,    0,
    0,    0, 1799,    0,    0,    0,    0,    0,    0,    0,
 1799, 1799, 1799, 1799, 1799, 1799,    0,    0,    0, 1799,
 1799,    0, 1799,    0, 1799,    0, 1799, 1799, 1799,    0,
 1799,    0, 1799, 1799, 1799,    0, 1799, 1799, 1799, 1799,
 1799,    0, 1799, 1799,    0,    0,    0,    0, 1799,    0,
 1799, 1799,    0,    0, 1799, 1799, 1799,    0,    0, 1799,
    0, 1799,    0,    0, 1799, 1799, 1799, 1799,    0, 1799,
    0, 1799,    0, 1799, 1799, 1799, 1799, 1799,    0,    0,
 1799, 1799, 1799,    0, 1799, 1799,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1799, 1799, 1799,    0, 1799,
 1799, 1799,    0,    0,    0,    0, 1430, 1799,    0,    0,
    0, 1799,    0, 1799, 1799, 1799, 1799,    0, 1799,    0,
 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1799, 1799,    0,
 1799, 1799, 1799,    0,    0,    0,    0, 1799, 1799, 1799,
 1799, 1799,    0, 1799,    0,    0, 1799, 1799,    0,    0,
    0, 1799, 1799,    0,    0, 1799, 1799, 1799, 1799, 1799,
 1799, 1799, 1799, 1799,    0, 1799,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1799, 1799, 1799, 1799, 1799,
 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799,
 1799, 1799, 1799, 1799, 1799, 1799,    0, 1799, 1799, 1799,
 1799, 1799, 1799,    0, 1799, 1799, 1799, 1799,    0, 1799,
    0, 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799,
 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799,    0,
 1799, 1799, 1799, 1799,    0, 1799, 1799, 1799, 1799, 1799,
    0, 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799,
 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799,
 1799,    0, 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799,
 1799, 1799, 1799, 1432, 1431, 1433, 1799, 1799, 1799, 1799,
 1799, 1799,    0,    0, 1799, 1799, 1799, 1799, 1799, 1799,
 1799, 1799, 1799,    0,    0,    0,    0,    0, 1799,    0,
 1799, 1799, 1799, 1799, 1799, 1799,    0, 1799,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1799, 1799,    0, 1799, 1799, 1799,
 1799, 1799, 1799, 1799, 1799, 1799,    0, 1799, 1799, 1799,
 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799,    0,
 1799, 1799, 1799,    0, 1799,    0,    0,    0, 1799, 1799,
 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799,
 1799, 2079, 1799, 1799,    0,    0,    0,    0,    0, 1799,
 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799,
 1799, 1799, 1799, 1799, 1799, 1799, 1799,    0,    0, 1799,
    0, 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799, 1799,
    0,    0, 2079, 2079, 2079, 2079, 2079,    0, 2079,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2079, 2079, 2079, 2079,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2079,    0, 2079,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1416,    0,    0,    0,    0,
    0,    0,    0,    0, 1417,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1418,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1419,    0,    0,    0,    0,    0,    0, 1420,    0,
    0,    0,    0,    0,    0,    0, 1421,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1422,    0, 1423,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1424,    0, 1425, 1426, 1427,
    0,    0,    0,    0, 1428,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1429,    0,    0, 2079,    0,
 2079,    0,    0, 2079,    0, 2079, 2079, 2079,    0, 2079,
 2079,    0, 2079,    0,    0,    0,    0,    0, 2079,    0,
 2079, 2079, 2079, 2079,    0, 2079,    0,    0, 2079,    0,
    0, 2079,    0,    0,    0,    0,    0,    0, 2079,    0,
 2079, 2079,    0, 2079, 2079, 2079, 2079, 2079,    0,    0,
 2079,    0,    0, 2079,    0, 2079, 2079,    0,    0, 2079,
 2079, 2079,    0, 2079, 2079, 2079, 2079, 2079, 2079, 2079,
 2230,    0,    0, 2079, 2079, 2079, 2079, 2079,    0,    0,
    0, 2079,    0,    0,    0,    0,    0,    0,    0, 2079,
 2079, 2079, 2079, 2079, 2079,    0,    0,    0, 2079, 2079,
    0, 2079,    0, 2079,    0, 2079, 2079, 2079,    0, 2079,
    0, 2079, 2079, 2079,    0, 2079, 2079, 2079, 2079, 2079,
    0, 2079, 2079,    0,    0,    0,    0, 2079,    0, 2079,
 2079,    0,    0, 2079, 2079, 2079,    0,    0, 2079,    0,
 2079,    0,    0, 2079, 2079, 2079, 2079,    0, 2079,    0,
 2079,    0, 2079, 2079, 2079, 2079, 2079,    0,    0, 2079,
 2079, 2079,    0, 2079, 2079,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2079, 2079, 2079,    0, 2079, 2079,
 2079,    0,    0,    0,    0, 1430, 2079,    0,    0,    0,
 2079,    0, 2079, 2079, 2079, 2079,    0, 2079,    0, 2079,
 2079, 2079, 2079, 2079, 2079, 2079, 2079,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2079, 2079,    0, 2079,
 2079, 2079,    0,    0,    0,    0, 2079, 2079, 2079, 2079,
 2079,    0, 2079,    0,    0, 2079, 2079,    0,    0,    0,
 2079, 2079,    0,    0, 2079, 2079, 2079, 2079, 2079, 2079,
 2079, 2079, 2079,    0, 2079,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2079, 2079, 2079, 2079, 2079, 2079,
 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079,
 2079, 2079, 2079, 2079, 2079,    0, 2079, 2079, 2079, 2079,
 2079, 2079,    0, 2079, 2079, 2079, 2079,    0, 2079,    0,
 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079,
 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079,    0, 2079,
 2079, 2079, 2079,    0, 2079, 2079, 2079, 2079, 2079,    0,
 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079,
 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079,
    0, 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079,    0,
 2079, 2079, 1432, 1431, 1433, 2079, 2079, 2079, 2079, 2079,
 2079,    0,    0, 2079, 2079, 2079, 2079, 2079, 2079, 2079,
 2079, 2079,    0,    0,    0,    0,    0, 2079,    0, 2079,
 2079, 2079, 2079, 2079, 2079,    0, 2079,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2079, 2079,    0, 2079, 2079, 2079, 2079,
 2079, 2079, 2079, 2079, 2079,    0, 2079, 2079, 2079, 2079,
 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079,    0, 2079,
 2079, 2079,    0, 2079,    0,    0,    0, 2079, 2079, 2079,
 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079,
 2097, 2079, 2079,    0,    0,    0,    0,    0, 2079, 2079,
 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079,
 2079, 2079, 2079, 2079, 2079, 2079,    0,    0, 2079,    0,
 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079,    0,
    0, 2097, 2097, 2097, 2097, 2097, 2093, 2097,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2097,
 2097, 2097, 2097,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2097,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1416,    0,    0,    0,    0,    0,
    0,    0,    0, 1417,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1418,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2920,    0,    0,    0,    0,    0,
 1419,    0,    0,    0,    0,    0,    0, 1420,    0,    0,
    0,    0,    0,    0,    0, 1421,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1422,    0, 1423,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1424,    0, 1425, 1426, 1427,    0,
    0,    0,    0, 1428,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1429,    0,    0, 2097,    0, 2097,
    0,    0, 2097,    0, 2097, 2097, 2097,    0, 2097, 2097,
    0, 2097,    0,    0,    0,    0,    0, 2097,    0, 2097,
 2097, 2097, 2097,    0, 2097,    0,    0, 2097,    0,    0,
 2097,    0,    0,    0,    0,    0,    0, 2097,    0, 2097,
 2097,    0, 2097, 2097, 2097, 2097, 2097,    0,    0, 2097,
    0,    0, 2097,    0, 2097, 2097,    0,    0, 2097, 2097,
 2097,    0, 2097, 2097, 2097, 2097, 2097, 2097, 2097,    0,
    0,    0, 2097, 2097, 2097, 2097, 2097,    0,    0,    0,
 2097,    0,    0,    0,    0,    0,    0,    0, 2097, 2097,
 2097, 2097, 2097, 2097,    0,    0,    0, 2097, 2097,    0,
 2097,    0, 2097,    0, 2097, 2097, 2097,    0, 2097,    0,
 2097, 2097, 2097,    0, 2097, 2097, 2097, 2097, 2097,    0,
 2097, 2097,    0,    0,    0,    0, 2097,    0, 2097, 2097,
    0,    0, 2097, 2097, 2097,    0,    0, 2097,    0, 2097,
    0,    0, 2097, 2097, 2097, 2097,    0, 2097,    0, 2097,
    0, 2097, 2097, 2097, 2097, 2097,    0,    0, 2097, 2097,
 2097,    0, 2097, 2097,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2097, 2097, 2097,    0, 2097, 2097, 2097,
    0,    0,    0,    0, 1430, 2097,    0,    0,    0, 2097,
    0, 2097, 2097, 2097, 2097,    0, 2097,    0, 2097, 2097,
 2097, 2097, 2097, 2097, 2097, 2097,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2097, 2097,    0, 2097, 2097,
 2097,    0,    0,    0,    0, 2097, 2097, 2097, 2097, 2097,
    0, 2097,    0,    0, 2097, 2097,    0,    0,    0, 2097,
 2097,    0,    0, 2097, 2097, 2097, 2097, 2097, 2097, 2097,
 2097, 2097,    0, 2097,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2097, 2097, 2097, 2097, 2097, 2097, 2097,
 2097, 2097, 2097, 2097, 2097, 2097, 2097, 2097, 2097, 2097,
 2097, 2097, 2097, 2097,    0, 2097, 2097, 2097, 2097, 2097,
 2097,    0, 2097, 2097, 2097, 2097,    0, 2097,    0, 2097,
 2097, 2097, 2097, 2097, 2097, 2097, 2097, 2097, 2097, 2097,
 2097, 2097, 2097, 2097, 2097, 2097, 2097,    0, 2097, 2097,
 2097, 2097,    0, 2097, 2097, 2097, 2097, 2097,    0, 2097,
 2097, 2097, 2097, 2097, 2097, 2097, 2097, 2097, 2097, 2097,
 2097, 2097, 2097, 2097, 2097, 2097, 2097, 2097, 2097,    0,
 2097, 2097, 2097, 2097, 2097, 2097, 2097, 2097,    0, 2097,
 2097, 1432, 1431, 1433, 2097, 2097, 2097, 2097, 2097, 2097,
    0,    0, 2097, 2097, 2097, 2097, 2097, 2097, 2097, 2097,
 2097,    0,    0,    0,    0,    0, 2097,    0, 2097, 2097,
 2097, 2097, 2097, 2097,    0, 2097,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2097, 2097,    0, 2097, 2097, 2097, 2097, 2097,
 2097, 2097, 2097, 2097,    0, 2097, 2097, 2097, 2097, 2097,
 2097, 2097, 2097, 2097, 2097, 2097, 2097,    0, 2097, 2097,
 2097,    0, 2097,    0,    0,    0, 2097, 2097, 2097, 2097,
 2097, 2097, 2097, 2097, 2097, 2097, 2097, 2097, 2097, 1696,
 2097, 2097,    0,    0,    0,    0,    0, 2097, 2097, 2097,
 2097, 2097, 2097, 2097, 2097, 2097, 2097, 2097, 2097, 2097,
 2097, 2097, 2097, 2097, 2097,    0,    0, 2097,    0, 2097,
 2097, 2097, 2097, 2097, 2097, 2097, 2097, 2097,    0,    0,
 1696, 1696, 1696, 1696, 1696,    0, 1696,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1696, 1696,
 1696, 1696,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1696,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1416,    0,    0,    0,    0,    0,    0,
    0,    0, 1417,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1418,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2922,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1419,
    0,    0,    0,    0,    0,    0, 1420,    0,    0,    0,
    0,    0,    0,    0, 1421,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1422,    0, 1423,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1424,    0, 1425, 1426, 1427,    0,    0,
    0,    0, 1428,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1429,    0,    0, 1696,    0, 1696,    0,
    0, 1696,    0, 1696, 1696, 1696,    0, 1696, 1696,    0,
 1696,    0,    0,    0,    0,    0, 1696,    0, 1696, 1696,
 1696, 1696,    0, 1696,    0,    0, 1696,    0,    0, 1696,
    0,    0,    0,    0,    0,    0, 1696,    0, 1696, 1696,
    0, 1696, 1696, 1696, 1696, 1696,    0,    0, 1696,    0,
    0, 1696,    0, 1696, 1696,    0,    0, 1696, 1696, 1696,
    0, 1696, 1696, 1696, 1696, 1696, 1696, 1696,    0,    0,
    0, 1696, 1696, 1696, 1696, 1696,    0,    0,    0, 1696,
    0,    0,    0,    0,    0,    0,    0, 1696, 1696, 1696,
 1696, 1696, 1696,    0,    0,    0, 1696, 1696,    0, 1696,
    0, 1696,    0, 1696, 1696, 1696,    0, 1696,    0, 1696,
 1696, 1696,    0, 1696, 1696, 1696, 1696, 1696,    0, 1696,
 1696,    0,    0,    0,    0, 1696,    0, 1696, 1696,    0,
    0, 1696, 1696, 1696,    0,    0, 1696,    0, 1696,    0,
    0, 1696, 1696, 1696, 1696,    0, 1696,    0, 1696,    0,
 1696, 1696, 1696, 1696, 1696,    0,    0, 1696, 1696, 1696,
    0, 1696, 1696,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1696, 1696, 1696,    0, 1696, 1696, 1696,    0,
    0,    0,    0, 1430, 1696,    0,    0,    0, 1696,    0,
 1696, 1696, 1696, 1696,    0, 1696,    0, 1696, 1696, 1696,
 1696, 1696, 1696, 1696, 1696,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1696, 1696,    0, 1696, 1696, 1696,
    0,    0,    0,    0, 1696, 1696, 1696, 1696, 1696,    0,
 1696,    0,    0, 1696, 1696,    0,    0,    0, 1696, 1696,
    0,    0, 1696, 1696, 1696, 1696, 1696, 1696, 1696, 1696,
 1696,    0, 1696,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1696, 1696, 1696, 1696, 1696, 1696, 1696, 1696,
 1696, 1696, 1696, 1696, 1696, 1696, 1696, 1696, 1696, 1696,
 1696, 1696, 1696,    0, 1696, 1696, 1696, 1696, 1696, 1696,
    0, 1696, 1696, 1696, 1696,    0, 1696,    0, 1696, 1696,
 1696, 1696, 1696, 1696, 1696, 1696, 1696, 1696, 1696, 1696,
 1696, 1696, 1696, 1696, 1696, 1696,    0, 1696, 1696, 1696,
 1696,    0, 1696, 1696, 1696, 1696, 1696,    0, 1696, 1696,
 1696, 1696, 1696, 1696, 1696, 1696, 1696, 1696, 1696, 1696,
 1696, 1696, 1696, 1696, 1696, 1696, 1696, 1696,    0, 1696,
 1696, 1696, 1696, 1696, 1696, 1696, 1696,    0, 1696, 1696,
 1432, 1431, 1433, 1696, 1696, 1696, 1696, 1696, 1696,    0,
    0, 1696, 1696, 1696, 1696, 1696, 1696, 1696, 1696, 1696,
    0,    0,    0,    0,    0, 1696,    0, 1696, 1696, 1696,
 1696, 1696, 1696,    0, 1696,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1696, 1696,    0, 1696, 1696, 1696, 1696, 1696, 1696,
 1696, 1696, 1696,    0, 1696, 1696, 1696, 1696, 1696, 1696,
 1696, 1696, 1696, 1696, 1696, 1696,    0, 1696, 1696, 1696,
    0, 1696,    0,    0,    0, 1696, 1696, 1696, 1696, 1696,
 1696, 1696, 1696, 1696, 1696, 1696, 1696, 1696, 1687, 1696,
 1696,    0,    0,    0,    0,    0, 1696, 1696, 1696, 1696,
 1696, 1696, 1696, 1696, 1696, 1696, 1696, 1696, 1696, 1696,
 1696, 1696, 1696, 1696,    0,    0, 1696,    0, 1696, 1696,
 1696, 1696, 1696, 1696, 1696, 1696, 1696,    0,    0, 1687,
 1689, 1689, 1687, 1689,    0, 1689,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1687, 1687, 1687,
 1687,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1687,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1416,    0,    0,    0,    0,    0,    0,    0,
    0, 1417,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1418,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1419,    0,
    0,    0,    0,    0,    0, 1420,    0,    0,    0,    0,
    0,    0,    0, 1421,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1422,    0, 1423,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1424,    0, 1425, 1426, 1427,    0,    0,    0,
    0, 1428,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1429,    0,    0, 1687,    0, 1687,    0, 2934,
 1687,    0, 1687, 1687, 1689,    0, 1687, 1687,    0, 1687,
    0,    0,    0,    0,    0, 1689,    0, 1687, 1687, 1689,
 1687,    0, 1687,    0,    0, 1687,    0,    0, 1687,    0,
    0,    0,    0,    0,    0, 1687,    0, 1687, 1687,    0,
 1687, 1687, 1687, 1687, 1687,    0,    0, 1687,    0,    0,
 1687,    0, 1687, 1687,    0,    0, 1687, 1687, 1687,    0,
 1687, 1687, 1687, 1687, 1687, 1687, 1687,    0,    0,    0,
 1687, 1687, 1687, 1687, 1687,    0,    0,    0, 1687,    0,
    0,    0,    0,    0,    0,    0, 1687, 1687, 1687, 1687,
 1687, 1687,    0,    0,    0, 1687, 1687,    0, 1687,    0,
 1687,    0, 1687, 1687, 1687,    0, 1687,    0, 1687, 1687,
 1687,    0, 1687, 1687, 1687, 1687, 1687,    0, 1687, 1687,
    0,    0,    0,    0, 1687,    0, 1687, 1687,    0,    0,
 1687, 1687, 1687,    0,    0, 1687,    0, 1687,    0,    0,
 1687, 1687, 1687, 1687,    0, 1687,    0, 1687,    0, 1687,
 1687, 1687, 1687, 1687,    0,    0, 1687, 1687, 1687,    0,
 1687, 1687,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1687, 1687, 1687,    0, 1687, 1687, 1687,    0,    0,
    0,    0, 1430, 1687,    0,    0,    0, 1687,    0, 1687,
 1687, 1687, 1687,    0, 1687,    0, 1687, 1687, 1687, 1687,
 1687, 1687, 1687, 1687,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1687, 1687,    0, 1687, 1687, 1687,    0,
    0,    0,    0, 1687, 1687, 1687, 1687, 1687,    0, 1687,
    0,    0, 1687, 1687,    0,    0,    0, 1687, 1687,    0,
    0, 1687, 1687, 1687, 1687, 1687, 1687, 1687, 1687, 1687,
    0, 1687,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1687, 1687, 1687, 1687, 1687, 1687, 1687, 1687, 1687,
 1687, 1687, 1687, 1687, 1687, 1687, 1687, 1687, 1687, 1687,
 1687, 1687,    0, 1687, 1687, 1687, 1687, 1687, 1687,    0,
 1687, 1687, 1687, 1687,    0, 1687,    0, 1687, 1687, 1687,
 1687, 1687, 1687, 1687, 1687, 1687, 1687, 1687, 1687, 1687,
 1687, 1687, 1687, 1687, 1687,    0, 1687, 1687, 1687, 1687,
    0, 1687, 1687, 1687, 1687, 1687,    0, 1687, 1687, 1687,
 1687, 1687, 1687, 1687, 1687, 1687, 1687, 1687, 1687, 1687,
 1687, 1687, 1687, 1687, 1687, 1687, 1687,    0, 1687, 1687,
 1687, 1687, 1687, 1687, 1687, 1687,    0, 1687, 1687, 1432,
 1431, 1433, 1687, 1687, 1687, 1687, 1687, 1687,    0,    0,
 1687, 1687, 1687, 1687, 1687, 1687, 1687, 1687, 1687,    0,
    0,    0,    0,    0, 1687,    0, 1687, 1687, 1687, 1687,
 1687, 1687,    0, 1687,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1687, 1687,    0, 1687, 1687, 1687, 1687, 1687, 1687, 1687,
 1687, 1687,    0, 1687, 1687, 1687, 1687, 1687, 1687, 1687,
 1687, 1687, 1687, 1687, 1687,    0, 1687, 1687, 1687,    0,
 1687,    0,    0,    0, 1687, 1687, 1687, 1687, 1687, 1687,
 1687, 1687, 1687, 1687, 1687, 1687, 1687, 1562, 1687, 1687,
    0,    0,    0,    0,    0, 1687, 1687, 1687, 1687, 1687,
 1687, 1687, 1687, 1687, 1687, 1687, 1687, 1687, 1687, 1687,
 1687, 1687, 1687,    0,    0, 1687,    0, 1687, 1687, 1687,
 1687, 1687, 1687, 1687, 1687, 1687,    0,    0, 1562, 1690,
 1690, 1562, 1690,    0, 1690,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1562, 1562, 1562, 1562,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1562,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1416,    0,    0,    0,    0,    0,    0,    0,    0,
 1417,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1418,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2942,    0,    0,    0, 1419,    0,    0,
    0,    0,    0,    0, 1420,    0,    0,    0,    0,    0,
    0,    0, 1421,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1422,
    0, 1423,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1424,    0, 1425, 1426, 1427,    0,    0,    0,    0,
 1428,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1429,    0,    0, 1562,    0, 1562,    0,    0, 1562,
    0, 1562, 1562, 1690,    0, 1562, 1562,    0, 1562,    0,
    0,    0,    0,    0, 1690,    0, 1562, 1562, 1690, 1562,
    0, 1562,    0,    0, 1562,    0,    0, 1562,    0,    0,
    0,    0,    0,    0, 1562,    0, 1562, 1562,    0, 1562,
 1562, 1562, 1562, 1562,    0,    0, 1562,    0,    0, 1562,
    0, 1562, 1562,    0,    0, 1562, 1562, 1562,    0, 1562,
 1562, 1562, 1562, 1562, 1562, 1562,    0,    0,    0, 1562,
 1562, 1562, 1562, 1562,    0,    0,    0, 1562,    0,    0,
    0,    0,    0,    0,    0, 1562, 1562, 1562, 1562, 1562,
 1562,    0,    0,    0, 1562, 1562,    0, 1562,    0, 1562,
    0, 1562, 1562, 1562,    0, 1562,    0, 1562, 1562, 1562,
    0, 1562, 1562, 1562, 1562, 1562,    0, 1562, 1562,    0,
    0,    0,    0, 1562,    0, 1562, 1562,    0,    0, 1562,
 1562, 1562,    0,    0, 1562,    0, 1562,    0,    0, 1562,
 1562, 1562, 1562,    0, 1562,    0, 1562,    0, 1562, 1562,
 1562, 1562, 1562,    0,    0, 1562, 1562, 1562,    0, 1562,
 1562,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1562, 1562, 1562,    0, 1562, 1562, 1562,    0,    0,    0,
    0, 1430, 1562,    0,    0,    0, 1562,    0, 1562, 1562,
 1562, 1562,    0, 1562,    0, 1562, 1562, 1562, 1562, 1562,
 1562, 1562, 1562,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1562, 1562,    0, 1562, 1562, 1562,    0,    0,
    0,    0, 1562, 1562, 1562, 1562, 1562,    0, 1562,    0,
    0, 1562, 1562,    0,    0,    0, 1562, 1562,    0,    0,
 1562, 1562, 1562, 1562, 1562, 1562, 1562, 1562, 1562,    0,
 1562,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1562, 1562, 1562, 1562, 1562, 1562, 1562, 1562, 1562, 1562,
 1562, 1562, 1562, 1562, 1562, 1562, 1562, 1562, 1562, 1562,
 1562,    0, 1562, 1562, 1562, 1562, 1562, 1562,    0, 1562,
 1562, 1562, 1562,    0, 1562,    0, 1562, 1562, 1562, 1562,
 1562, 1562, 1562, 1562, 1562, 1562, 1562, 1562, 1562, 1562,
 1562, 1562, 1562, 1562,    0, 1562, 1562, 1562, 1562,    0,
 1562, 1562, 1562, 1562, 1562,    0, 1562, 1562, 1562, 1562,
 1562, 1562, 1562, 1562, 1562, 1562, 1562, 1562, 1562, 1562,
 1562, 1562, 1562, 1562, 1562, 1562,    0, 1562, 1562, 1562,
 1562, 1562, 1562, 1562, 1562,    0, 1562, 1562,    0,    0,
    0, 1562, 1562, 1562, 1562, 1562, 1562,    0,    0, 1562,
 1562, 1562, 1562, 1562, 1562, 1562, 1562, 1562,    0,    0,
 1432, 1431, 1433, 1562,    0, 1562, 1562, 1562, 1562, 1562,
 1562,    0, 1562,    0,    0,    0,    0,    0, 1432, 1431,
 1433,    0,    0,    0,    0,    0,    0,    0,    0, 1562,
 1562,    0, 1562, 1562, 1562, 1562, 1562, 1562, 1562, 1562,
 1562,    0, 1562, 1562, 1562, 1562, 1562, 1562, 1562, 1562,
 1562, 1562, 1562, 1562,    0, 1562, 1562, 1562,    0, 1562,
    0,    0,    0, 1562, 1562, 1562, 1562, 1562, 1562, 1562,
 1562, 1562, 1562, 1562, 1562, 1562, 1710, 1562, 1562,    0,
    0,    0,    0,    0, 1562, 1562, 1562, 1562, 1562, 1562,
 1562, 1562, 1562, 1562, 1562, 1562, 1562, 1562, 1562, 1562,
 1562, 1562,    0,    0, 1562,    0, 1562, 1562, 1562, 1562,
 1562, 1562, 1562, 1562, 1562,    0,    0, 1710, 1710, 1710,
 1710, 1710,    0, 1710,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1710, 1710, 1710, 1710,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1710,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1416,    0,    0,    0,    0,    0,    0,    0,
    0, 1417,    0,    0,    0,    0,    0,    0,    0,    0,
 1416,    0,    0,    0, 1418,    0,    0,    0,    0, 1417,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1418,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1419,    0,
    0,    0,    0,    0,    0, 1420,    0,    0,    0,    0,
    0,    0,    0, 1421,    0,    0, 1419,    0,    0,    0,
    0,    0,    0, 1420,    0,    0,    0,    0,    0,    0,
 1422, 1421, 1423,    0, 2964,    0,    0,    0,    0,    0,
    0,    0, 1424,    0, 1425, 1426, 1427,    0, 1422,    0,
 1423, 1428,    0,    0,    0,    0,    0,    0,    0,    0,
 1424,    0, 1425, 1426, 1427,    0,    0,    0,    0, 1428,
    0,    0,    0, 1710,    0, 1710,    0,    0, 1710,    0,
 1710, 1710,    0,    0, 1710, 1710,    0, 1710,    0,    0,
    0,    0, 1429,    0,    0, 1710, 1710, 1710, 1710,    0,
 1710,    0,    0, 1710,    0,    0, 1710,    0,    0,    0,
 1429,    0,    0, 1710,    0, 1710, 1710,    0, 1710, 1710,
 1710, 1710, 1710,    0,    0, 1710,    0,    0, 1710,    0,
 1710, 1710,    0,    0, 1710, 1710, 1710,    0, 1710, 1710,
 1710, 1710, 1710, 1710, 1710,    0,    0,    0, 1710, 1710,
 1710, 1710, 1710,    0,    0,    0, 1710,    0,    0,    0,
    0,    0,    0,    0, 1710, 1710, 1710, 1710, 1710, 1710,
    0,    0,    0, 1710, 1710,    0, 1710,    0, 1710,    0,
 1710, 1710, 1710,    0, 1710,    0, 1710, 1710, 1710,    0,
 1710, 1710, 1710, 1710, 1710,    0, 1710, 1710,    0,    0,
    0,    0, 1710,    0, 1710, 1710,    0,    0, 1710, 1710,
 1710,    0,    0, 1710,    0, 1710,    0,    0, 1710, 1710,
 1710, 1710,    0, 1710,    0, 1710,    0, 1710, 1710, 1710,
 1710, 1710,    0,    0, 1710, 1710, 1710, 2962, 1710, 1710,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1710,
 1710, 1710,    0, 1710, 1710, 1710,    0,    0,    0,    0,
    0, 1710,    0,    0,    0, 1710,    0, 1710, 1710, 1710,
 1710,    0, 1710,    0, 1710, 1710, 1710, 1710, 1710, 1710,
 1710, 1710, 1430,    0,    0,    0,    0,    0,    0,    0,
    0, 1710, 1710,    0, 1710, 1710, 1710,    0,    0,    0,
 1430, 1710, 1710, 1710, 1710, 1710,    0, 1710,    0,    0,
 1710, 1710,    0,    0,    0, 1710, 1710,    0,    0, 1710,
 1710, 1710, 1710, 1710, 1710, 1710, 1710, 1710,    0, 1710,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1710,
 1710, 1710, 1710, 1710, 1710, 1710, 1710, 1710, 1710, 1710,
 1710, 1710, 1710, 1710, 1710, 1710, 1710, 1710, 1710, 1710,
    0, 1710, 1710, 1710, 1710, 1710, 1710,    0, 1710, 1710,
 1710, 1710,    0, 1710,    0, 1710, 1710, 1710, 1710, 1710,
 1710, 1710, 1710, 1710, 1710, 1710, 1710, 1710, 1710, 1710,
 1710, 1710, 1710,    0, 1710, 1710, 1710, 1710,    0, 1710,
 1710, 1710, 1710, 1710,    0, 1710, 1710, 1710, 1710, 1710,
 1710, 1710, 1710, 1710, 1710, 1710, 1710, 1710, 1710, 1710,
 1710, 1710, 1710, 1710, 1710,    0, 1710, 1710, 1710, 1710,
 1710, 1710, 1710, 1710,    0, 1710, 1710, 1432, 1431, 1433,
 1710, 1710, 1710, 1710, 1710, 1710,    0,    0, 1710, 1710,
 1710, 1710, 1710, 1710, 1710, 1710, 1710,    0,    0,    0,
    0,    0, 1710,    0, 1710, 1710, 1710, 1710, 1710, 1710,
    0, 1710,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1710, 1710,
    0, 1710, 1710, 1710, 1710, 1710, 1710, 1710, 1710, 1710,
    0, 1710, 1710, 1710, 1710, 1710, 1710, 1710, 1710, 1710,
 1710, 1710, 1710,    0, 1710, 1710, 1710,    0, 1710,    0,
    0,    0, 1710, 1710, 1710, 1710, 1710, 1710, 1710, 1710,
 1710, 1710, 1710, 1710, 1710, 1708, 1710, 1710,    0,    0,
    0,    0,    0, 1710, 1710, 1710, 1710, 1710, 1710, 1710,
 1710, 1710, 1710, 1710, 1710, 1710, 1710, 1710, 1710, 1710,
 1710,    0,    0, 1710,    0, 1710, 1710, 1710, 1710, 1710,
 1710, 1710, 1710, 1710,    0,    0, 1708, 1708, 1708, 1708,
 1708,    0, 1708,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1708, 1708, 1708, 1708,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1708,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1416,
    0,    0,    0,    0,    0,    0,    0,    0, 1417,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1418,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1419,    0,    0,    0,    0,
    0,    0, 1420,    0,    0,    0,    0,    0,    0,    0,
 1421,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1422,    0, 1423,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1424,
    0, 1425, 1426, 1427,    0,    0,    0,    0, 1428,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1429,
    0,    0, 1708,    0, 1708,    0,    0, 1708,    0, 1708,
 1708,    0,    0, 1708, 1708,    0, 1708,    0,    0,    0,
    0,    0,    0,    0, 1708, 1708,    0, 1708,    0, 1708,
    0,    0, 1708,    0,    0, 1708,    0,    0,    0,    0,
    0,    0, 1708,    0, 1708, 1708,    0, 1708, 1708, 1708,
 1708, 1708,    0,    0, 1708,    0,    0, 1708,    0, 1708,
 1708,    0,    0, 1708, 1708, 1708,    0, 1708, 1708, 1708,
 1708, 1708, 1708, 1708,    0,    0,    0, 1708, 1708, 1708,
 1708, 1708,    0,    0,    0, 1708,    0,    0,    0,    0,
    0,    0,    0, 1708, 1708, 1708, 1708, 1708, 1708,    0,
    0,    0, 1708, 1708,    0, 1708,    0, 1708,    0, 1708,
 1708, 1708,    0, 1708,    0, 1708, 1708, 1708,    0, 1708,
 1708, 1708, 1708, 1708,    0, 1708, 1708,    0,    0,    0,
    0, 1708,    0, 1708, 1708,    0,    0, 1708, 1708, 1708,
    0,    0, 1708,    0, 1708,    0,    0, 1708, 1708, 1708,
 1708,    0, 1708,    0, 1708,    0, 1708, 1708, 1708, 1708,
 1708,    0,    0, 1708, 1708, 1708,    0, 1708, 1708,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1708, 1708,
 1708,    0, 1708, 1708, 1708,    0,    0,    0,    0, 1430,
 1708,    0,    0,    0, 1708,    0, 1708, 1708, 1708, 1708,
    0, 1708,    0, 1708, 1708, 1708, 1708, 1708, 1708, 1708,
 1708,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1708, 1708,    0, 1708, 1708, 1708,    0,    0,    0,    0,
 1708, 1708, 1708, 1708, 1708,    0, 1708,    0,    0, 1708,
 1708,    0,    0,    0, 1708, 1708,    0,    0, 1708, 1708,
 1708, 1708, 1708, 1708, 1708, 1708, 1708,    0, 1708,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1708, 1708,
 1708, 1708, 1708, 1708, 1708, 1708, 1708, 1708, 1708, 1708,
 1708, 1708, 1708, 1708, 1708, 1708, 1708, 1708, 1708,    0,
 1708, 1708, 1708, 1708, 1708, 1708,    0, 1708, 1708, 1708,
 1708,    0, 1708,    0, 1708, 1708, 1708, 1708, 1708, 1708,
 1708, 1708, 1708, 1708, 1708, 1708, 1708, 1708, 1708, 1708,
 1708, 1708,    0, 1708, 1708, 1708, 1708,    0, 1708, 1708,
 1708, 1708, 1708,    0, 1708, 1708, 1708, 1708, 1708, 1708,
 1708, 1708, 1708, 1708, 1708, 1708, 1708, 1708, 1708, 1708,
 1708, 1708, 1708, 1708,    0, 1708, 1708, 1708, 1708, 1708,
 1708, 1708, 1708,    0, 1708, 1708, 1432, 1431, 1433, 1708,
 1708, 1708, 1708, 1708, 1708,    0,    0, 1708, 1708, 1708,
 1708, 1708, 1708, 1708, 1708, 1708,    0,    0,    0,    0,
    0, 1708,    0, 1708, 1708, 1708, 1708, 1708, 1708,    0,
 1708,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1708, 1708,    0,
 1708, 1708, 1708, 1708, 1708, 1708, 1708, 1708, 1708,    0,
 1708, 1708, 1708, 1708, 1708, 1708, 1708, 1708, 1708, 1708,
 1708, 1708,    0, 1708, 1708, 1708,    0, 1708,    0,    0,
    0, 1708, 1708, 1708, 1708, 1708, 1708, 1708, 1708, 1708,
 1708, 1708, 1708, 1708, 1707, 1708, 1708,    0,    0,    0,
    0,    0, 1708, 1708, 1708, 1708, 1708, 1708, 1708, 1708,
 1708, 1708, 1708, 1708, 1708, 1708, 1708, 1708, 1708, 1708,
    0,    0, 1708,    0, 1708, 1708, 1708, 1708, 1708, 1708,
 1708, 1708, 1708,    0,    0, 1707, 1707, 1707, 1707, 1707,
    0, 1707,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1707, 1707, 1707, 1707,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1707,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1416,    0,
    0,    0,    0,    0,    0,    0,    0, 1417,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1418,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1419,    0,    0,    0,    0,    0,
    0, 2130,    0,    0,    0,    0,    0,    0,    0, 1421,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1422,    0, 1423,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1424,    0,
 1425, 1426, 1427,    0,    0,    0,    0, 1428,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1429,    0,
    0, 1707,    0, 1707,    0,    0, 1707,    0, 1707, 1707,
    0,    0, 1707, 1707,    0, 1707,    0,    0,    0,    0,
    0,    0,    0, 1707, 1707,    0, 1707,    0, 1707,    0,
    0, 1707,    0,    0, 1707,    0,    0,    0,    0,    0,
    0, 1707,    0, 1707, 1707,    0, 1707, 1707, 1707, 1707,
 1707,    0,    0, 1707,    0,    0, 1707,    0, 1707, 1707,
    0,    0, 1707, 1707, 1707,    0, 1707, 1707, 1707, 1707,
 1707, 1707, 1707,    0,    0,    0, 1707, 1707, 1707, 1707,
 1707,    0,    0,    0, 1707,    0,    0,    0,    0,    0,
    0,    0, 1707, 1707, 1707, 1707, 1707, 1707,    0,    0,
    0, 1707, 1707,    0, 1707,    0, 1707,    0, 1707, 1707,
 1707,    0, 1707,    0, 1707, 1707, 1707,    0, 1707, 1707,
 1707, 1707, 1707,    0, 1707, 1707,    0,    0,    0,    0,
 1707,    0, 1707, 1707,    0,    0, 1707, 1707, 1707,    0,
    0, 1707,    0, 1707,    0,    0, 1707, 1707, 1707, 1707,
    0, 1707,    0, 1707,    0, 1707, 1707, 1707, 1707, 1707,
    0,    0, 1707, 1707, 1707,    0, 1707, 1707,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1707, 1707, 1707,
    0, 1707, 1707, 1707,    0,    0,    0,    0, 1430, 1707,
    0,    0,    0, 1707,    0, 1707, 1707, 1707, 1707,    0,
 1707,    0, 1707, 1707, 1707, 1707, 1707, 1707, 1707, 1707,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1707,
 1707,    0, 1707, 1707, 1707,    0,    0,    0,    0, 1707,
 1707, 1707, 1707, 1707,    0, 1707,    0,    0, 1707, 1707,
    0,    0,    0, 1707, 1707,    0,    0, 1707, 1707, 1707,
 1707, 1707, 1707, 1707, 1707, 1707,    0, 1707,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1707, 1707, 1707,
 1707, 1707, 1707, 1707, 1707, 1707, 1707, 1707, 1707, 1707,
 1707, 1707, 1707, 1707, 1707, 1707, 1707, 1707,    0, 1707,
 1707, 1707, 1707, 1707, 1707,    0, 1707, 1707, 1707, 1707,
    0, 1707,    0, 1707, 1707, 1707, 1707, 1707, 1707, 1707,
 1707, 1707, 1707, 1707, 1707, 1707, 1707, 1707, 1707, 1707,
 1707,    0, 1707, 1707, 1707, 1707,    0, 1707, 1707, 1707,
 1707, 1707,    0, 1707, 1707, 1707, 1707, 1707, 1707, 1707,
 1707, 1707, 1707, 1707, 1707, 1707, 1707, 1707, 1707, 1707,
 1707, 1707, 1707,    0, 1707, 1707, 1707, 1707, 1707, 1707,
 1707, 1707,    0, 1707, 1707, 1688, 1688, 1688, 1707, 1707,
 1707, 1707, 1707, 1707,    0,    0, 1707, 1707, 1707, 1707,
 1707, 1707, 1707, 1707, 1707,    0,    0,    0,    0,    0,
 1707,    0, 1707, 1707, 1707, 1707, 1707, 1707,    0, 1707,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1707, 1707,    0, 1707,
 1707, 1707, 1707, 1707, 1707, 1707, 1707, 1707,    0, 1707,
 1707, 1707, 1707, 1707, 1707, 1707, 1707, 1707, 1707, 1707,
 1707,    0, 1707, 1707, 1707,    0, 1707,    0,    0,    0,
 1707, 1707, 1707, 1707, 1707, 1707, 1707, 1707, 1707, 1707,
 1707, 1707, 1707, 1715, 1707, 1707,    0,    0,    0,    0,
    0, 1707, 1707, 1707, 1707, 1707, 1707, 1707, 1707, 1707,
 1707, 1707, 1707, 1707, 1707, 1707, 1707, 1707, 1707,    0,
    0, 1707,    0, 1707, 1707, 1707, 1707, 1707, 1707, 1707,
 1707, 1707,    0,    0, 1715, 1715, 1715, 1715, 1715,    0,
 1715,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1715, 1715, 1715, 1715,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1715,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1688,    0,    0,
    0,    0,    0,    0,    0,    0, 1688,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1688,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1688,    0,    0,    0,    0,    0,    0,
 1688,    0,    0,    0,    0,    0,    0,    0, 1688,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1688,    0, 1688,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1688,    0, 1688,
 1688, 1688,    0,    0,    0,    0, 1688,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1688,    0,    0,
 1715,    0, 1715,    0,    0, 1715,    0, 1715, 1715,    0,
    0, 1715, 1715,    0, 1715,    0,    0,    0,    0,    0,
    0,    0, 1715, 1715,    0, 1715,    0, 1715,    0,    0,
 1715,    0,    0, 1715,    0,    0,    0,    0,    0,    0,
 1715,    0, 1715, 1715,    0, 1715, 1715, 1715, 1715, 1715,
    0,    0, 1715,    0,    0, 1715,    0, 1715, 1715,    0,
    0, 1715, 1715, 1715,    0, 1715, 1715, 1715, 1715, 1715,
 1715, 1715,    0,    0,    0, 1715, 1715, 1715, 1715, 1715,
    0,    0,    0, 1715,    0,    0,    0,    0,    0,    0,
    0, 1715, 1715, 1715, 1715, 1715, 1715,    0,    0,    0,
 1715, 1715,    0, 1715,    0, 1715,    0, 1715, 1715, 1715,
    0, 1715,    0, 1715, 1715, 1715,    0, 1715, 1715, 1715,
 1715, 1715,    0, 1715, 1715,    0,    0,    0,    0, 1715,
    0, 1715, 1715,    0,    0, 1715, 1715, 1715,    0,    0,
 1715,    0, 1715,    0,    0, 1715, 1715, 1715, 1715,    0,
 1715,    0, 1715,    0, 1715, 1715, 1715, 1715, 1715,    0,
    0, 1715, 1715, 1715,    0, 1715, 1715,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1715, 1715, 1715,    0,
 1715, 1715, 1715,    0,    0,    0,    0, 1688, 1715,    0,
    0,    0, 1715,    0, 1715, 1715, 1715, 1715,    0, 1715,
    0, 1715, 1715, 1715, 1715, 1715, 1715, 1715, 1715,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1715, 1715,
    0, 1715, 1715, 1715,    0,    0,    0,    0, 1715, 1715,
 1715, 1715, 1715,    0, 1715,    0,    0, 1715, 1715,    0,
    0,    0, 1715, 1715,    0,    0, 1715, 1715, 1715, 1715,
 1715, 1715, 1715, 1715, 1715,    0, 1715,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1715, 1715, 1715, 1715,
 1715, 1715, 1715, 1715, 1715, 1715, 1715, 1715, 1715, 1715,
 1715, 1715, 1715, 1715, 1715, 1715, 1715,    0, 1715, 1715,
 1715, 1715, 1715, 1715,    0, 1715, 1715, 1715, 1715,    0,
 1715,    0, 1715, 1715, 1715, 1715, 1715, 1715, 1715, 1715,
 1715, 1715, 1715, 1715, 1715, 1715, 1715, 1715, 1715, 1715,
    0, 1715, 1715, 1715, 1715,    0, 1715, 1715, 1715, 1715,
 1715,    0, 1715, 1715, 1715, 1715, 1715, 1715, 1715, 1715,
 1715, 1715, 1715, 1715, 1715, 1715, 1715, 1715, 1715, 1715,
 1715, 1715,    0, 1715, 1715, 1715, 1715, 1715, 1715, 1715,
 1715,    0, 1715, 1715,    0,    0,    0, 1715, 1715, 1715,
 1715, 1715, 1715,    0,    0, 1715, 1715, 1715, 1715, 1715,
 1715, 1715, 1715, 1715,    0,    0,    0,    0,    0, 1715,
    0, 1715, 1715, 1715, 1715, 1715, 1715,    0, 1715,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1715, 1715,    0, 1715, 1715,
 1715, 1715, 1715, 1715, 1715, 1715, 1715,    0, 1715, 1715,
 1715, 1715, 1715, 1715, 1715, 1715, 1715, 1715, 1715, 1715,
    0, 1715, 1715, 1715,    0, 1715,    0,    0,    0, 1715,
 1715, 1715, 1715, 1715, 1715, 1715, 1715, 1715, 1715, 1715,
 1715, 1715, 1716, 1715, 1715,    0,    0,    0,    0,    0,
 1715, 1715, 1715, 1715, 1715, 1715, 1715, 1715, 1715, 1715,
 1715, 1715, 1715, 1715, 1715, 1715, 1715, 1715,    0,    0,
 1715,    0, 1715, 1715, 1715, 1715, 1715, 1715, 1715, 1715,
 1715,    0,    0, 1716, 1716, 1716, 1716, 1716,    0, 1716,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1716, 1716, 1716, 1716,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1716,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1716,
    0, 1716,    0,    0, 1716,    0, 1716, 1716,    0,    0,
 1716, 1716,    0, 1716,    0,    0,    0,    0,    0,    0,
    0, 1716, 1716,    0, 1716,    0, 1716,    0,    0, 1716,
    0,    0, 1716,    0,    0,    0,    0,    0,    0, 1716,
    0, 1716, 1716,    0, 1716, 1716, 1716, 1716, 1716,    0,
    0, 1716,    0,    0, 1716,    0, 1716, 1716,    0,    0,
 1716, 1716, 1716,    0, 1716, 1716, 1716, 1716, 1716, 1716,
 1716,    0,    0,    0, 1716, 1716, 1716, 1716, 1716,    0,
    0,    0, 1716,    0,    0,    0,    0,    0,    0,    0,
 1716, 1716, 1716, 1716, 1716, 1716,    0,    0,    0, 1716,
 1716,    0, 1716,    0, 1716,    0, 1716, 1716, 1716,    0,
 1716,    0, 1716, 1716, 1716,    0, 1716, 1716, 1716, 1716,
 1716,    0, 1716, 1716,    0,    0,    0,    0, 1716,    0,
 1716, 1716,    0,    0, 1716, 1716, 1716,    0,    0, 1716,
    0, 1716,    0,    0, 1716, 1716, 1716, 1716,    0, 1716,
    0, 1716,    0, 1716, 1716, 1716, 1716, 1716,    0,    0,
 1716, 1716, 1716,    0, 1716, 1716,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1716, 1716, 1716,    0, 1716,
 1716, 1716,    0,    0,    0,    0,    0, 1716,    0,    0,
    0, 1716,    0, 1716, 1716, 1716, 1716,    0, 1716,    0,
 1716, 1716, 1716, 1716, 1716, 1716, 1716, 1716,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1716, 1716,    0,
 1716, 1716, 1716,    0,    0,    0,    0, 1716, 1716, 1716,
 1716, 1716,    0, 1716,    0,    0, 1716, 1716,    0,    0,
    0, 1716, 1716,    0,    0, 1716, 1716, 1716, 1716, 1716,
 1716, 1716, 1716, 1716,    0, 1716,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1716, 1716, 1716, 1716, 1716,
 1716, 1716, 1716, 1716, 1716, 1716, 1716, 1716, 1716, 1716,
 1716, 1716, 1716, 1716, 1716, 1716,    0, 1716, 1716, 1716,
 1716, 1716, 1716,    0, 1716, 1716, 1716, 1716,    0, 1716,
    0, 1716, 1716, 1716, 1716, 1716, 1716, 1716, 1716, 1716,
 1716, 1716, 1716, 1716, 1716, 1716, 1716, 1716, 1716,    0,
 1716, 1716, 1716, 1716,    0, 1716, 1716, 1716, 1716, 1716,
    0, 1716, 1716, 1716, 1716, 1716, 1716, 1716, 1716, 1716,
 1716, 1716, 1716, 1716, 1716, 1716, 1716, 1716, 1716, 1716,
 1716,    0, 1716, 1716, 1716, 1716, 1716, 1716, 1716, 1716,
    0, 1716, 1716,    0,    0,    0, 1716, 1716, 1716, 1716,
 1716, 1716,    0,    0, 1716, 1716, 1716, 1716, 1716, 1716,
 1716, 1716, 1716,    0,    0,    0,    0,    0, 1716,    0,
 1716, 1716, 1716, 1716, 1716, 1716,    0, 1716,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1716, 1716,    0, 1716, 1716, 1716,
 1716, 1716, 1716, 1716, 1716, 1716,    0, 1716, 1716, 1716,
 1716, 1716, 1716, 1716, 1716, 1716, 1716, 1716, 1716,    0,
 1716, 1716, 1716,    0, 1716,    0,    0,    0, 1716, 1716,
 1716, 1716, 1716, 1716, 1716, 1716, 1716, 1716, 1716, 1716,
 1716, 1709, 1716, 1716,    0,    0,    0,    0,    0, 1716,
 1716, 1716, 1716, 1716, 1716, 1716, 1716, 1716, 1716, 1716,
 1716, 1716, 1716, 1716, 1716, 1716, 1716,    0,    0, 1716,
    0, 1716, 1716, 1716, 1716, 1716, 1716, 1716, 1716, 1716,
    0,    0, 1709,    0, 1709, 1709, 1709,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1709, 1709, 1709, 1709,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1709,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1709,    0,
 1709,    0,    0, 1709,    0, 1709, 1709,    0,    0, 1709,
 1709,    0, 1709,    0,    0,    0,    0,    0,    0,    0,
 1709, 1709,    0, 1709,    0, 1709,    0,    0, 1709,    0,
    0, 1709,    0,    0,    0,    0,    0,    0, 1709,    0,
 1709, 1709,    0, 1709, 1709, 1709, 1709, 1709,    0,    0,
 1709,    0,    0, 1709,    0, 1709, 1709,    0,    0, 1709,
 1709, 1709,    0, 1709, 1709, 1709, 1709, 1709, 1709, 1709,
    0,    0,    0, 1709, 1709, 1709, 1709, 1709,    0,    0,
    0, 1709,    0,    0,    0,    0,    0,    0,    0, 1709,
 1709, 1709, 1709, 1709, 1709,    0,    0,    0, 1709, 1709,
    0, 1709,    0, 1709,    0, 1709, 1709, 1709,    0, 1709,
    0, 1709, 1709, 1709,    0, 1709, 1709, 1709, 1709, 1709,
    0, 1709, 1709,    0,    0,    0,    0, 1709,    0, 1709,
 1709,    0,    0, 1709, 1709, 1709,    0,    0, 1709,    0,
 1709,    0,    0, 1709, 1709, 1709, 1709,    0, 1709,    0,
 1709,    0, 1709, 1709, 1709, 1709, 1709,    0,    0, 1709,
 1709, 1709,    0, 1709, 1709,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1709, 1709, 1709,    0, 1709, 1709,
 1709,    0,    0,    0,    0,    0, 1709,    0,    0,    0,
 1709,    0, 1709, 1709, 1709, 1709,    0, 1709,    0, 1709,
 1709, 1709, 1709, 1709, 1709, 1709, 1709,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1709, 1709,    0, 1709,
 1709, 1709,    0,    0,    0,    0, 1709, 1709, 1709, 1709,
 1709,    0, 1709,    0,    0, 1709, 1709,    0,    0,    0,
 1709, 1709,    0,    0, 1709, 1709, 1709, 1709, 1709, 1709,
 1709, 1709, 1709,    0, 1709,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1709, 1709, 1709, 1709, 1709, 1709,
 1709, 1709, 1709, 1709, 1709, 1709, 1709, 1709, 1709, 1709,
 1709, 1709, 1709, 1709, 1709,    0, 1709, 1709, 1709, 1709,
 1709, 1709,    0, 1709, 1709, 1709, 1709,    0, 1709,    0,
 1709, 1709, 1709, 1709, 1709, 1709, 1709, 1709, 1709, 1709,
 1709, 1709, 1709, 1709, 1709, 1709, 1709, 1709,    0, 1709,
 1709, 1709, 1709,    0, 1709, 1709, 1709, 1709, 1709,    0,
 1709, 1709, 1709, 1709, 1709, 1709, 1709, 1709, 1709, 1709,
 1709, 1709, 1709, 1709, 1709, 1709, 1709, 1709, 1709, 1709,
    0, 1709, 1709, 1709, 1709, 1709, 1709, 1709, 1709,    0,
 1709, 1709,    0,    0,    0, 1709, 1709, 1709, 1709, 1709,
 1709,    0,    0, 1709, 1709, 1709, 1709, 1709, 1709, 1709,
 1709, 1709,    0,    0,    0,    0,    0, 1709,    0, 1709,
 1709, 1709, 1709, 1709, 1709,    0, 1709,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1709, 1709,    0, 1709, 1709, 1709, 1709,
 1709, 1709, 1709, 1709, 1709,    0, 1709, 1709, 1709, 1709,
 1709, 1709, 1709, 1709, 1709, 1709, 1709, 1709,    0, 1709,
 1709, 1709,    0, 1709,    0,    0,    0, 1709, 1709, 1709,
 1709, 1709, 1709, 1709, 1709, 1709, 1709, 1709, 1709, 1709,
 1714, 1709, 1709,    0,    0,    0,    0,    0, 1709, 1709,
 1709, 1709, 1709, 1709, 1709, 1709, 1709, 1709, 1709, 1709,
 1709, 1709, 1709, 1709, 1709, 1709,    0,    0, 1709,    0,
 1709, 1709, 1709, 1709, 1709, 1709, 1709, 1709, 1709,    0,
    0, 1714,    0, 1714, 1714, 1714,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1714,
 1714, 1714, 1714,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1714,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1714,    0, 1714,
    0,    0, 1714,    0, 1714, 1714,    0,    0, 1714, 1714,
    0, 1714,    0,    0,    0,    0,    0,    0,    0, 1714,
 1714,    0, 1714,    0, 1714,    0,    0, 1714,    0,    0,
 1714,    0,    0,    0,    0,    0,    0, 1714,    0, 1714,
 1714,    0, 1714, 1714, 1714, 1714, 1714,    0,    0, 1714,
    0,    0, 1714,    0, 1714, 1714,    0,    0, 1714, 1714,
 1714,    0, 1714, 1714, 1714, 1714, 1714, 1714, 1714,    0,
    0,    0, 1714, 1714, 1714, 1714, 1714,    0,    0,    0,
 1714,    0,    0,    0,    0,    0,    0,    0, 1714, 1714,
 1714, 1714, 1714, 1714,    0,    0,    0, 1714, 1714,    0,
 1714,    0, 1714,    0, 1714, 1714, 1714,    0, 1714,    0,
 1714, 1714, 1714,    0, 1714, 1714, 1714, 1714, 1714,    0,
 1714, 1714,    0,    0,    0,    0, 1714,    0, 1714, 1714,
    0,    0, 1714, 1714, 1714,    0,    0, 1714,    0, 1714,
    0,    0, 1714, 1714, 1714, 1714,    0, 1714,    0, 1714,
    0, 1714, 1714, 1714, 1714, 1714,    0,    0, 1714, 1714,
 1714,    0, 1714, 1714,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1714, 1714, 1714,    0, 1714, 1714, 1714,
    0,    0,    0,    0,    0, 1714,    0,    0,    0, 1714,
    0, 1714, 1714, 1714, 1714,    0, 1714,    0, 1714, 1714,
 1714, 1714, 1714, 1714, 1714, 1714,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1714, 1714,    0, 1714, 1714,
 1714,    0,    0,    0,    0, 1714, 1714, 1714, 1714, 1714,
    0, 1714,    0,    0, 1714, 1714,    0,    0,    0, 1714,
 1714,    0,    0, 1714, 1714, 1714, 1714, 1714, 1714, 1714,
 1714, 1714,    0, 1714,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1714, 1714, 1714, 1714, 1714, 1714, 1714,
 1714, 1714, 1714, 1714, 1714, 1714, 1714, 1714, 1714, 1714,
 1714, 1714, 1714, 1714,    0, 1714, 1714, 1714, 1714, 1714,
 1714,    0, 1714, 1714, 1714, 1714,    0, 1714,    0, 1714,
 1714, 1714, 1714, 1714, 1714, 1714, 1714, 1714, 1714, 1714,
 1714, 1714, 1714, 1714, 1714, 1714, 1714,    0, 1714, 1714,
 1714, 1714,    0, 1714, 1714, 1714, 1714, 1714,    0, 1714,
 1714, 1714, 1714, 1714, 1714, 1714, 1714, 1714, 1714, 1714,
 1714, 1714, 1714, 1714, 1714, 1714, 1714, 1714, 1714,    0,
 1714, 1714, 1714, 1714, 1714, 1714, 1714, 1714,    0, 1714,
 1714,    0,    0,    0, 1714, 1714, 1714, 1714, 1714, 1714,
    0,    0, 1714, 1714, 1714, 1714, 1714, 1714, 1714, 1714,
 1714,    0,    0,    0,    0,    0, 1714,    0, 1714, 1714,
 1714, 1714, 1714, 1714,    0, 1714,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1714, 1714,    0, 1714, 1714, 1714, 1714, 1714,
 1714, 1714, 1714, 1714,    0, 1714, 1714, 1714, 1714, 1714,
 1714, 1714, 1714, 1714, 1714, 1714, 1714,    0, 1714, 1714,
 1714,    0, 1714,    0, 1592,    0, 1714, 1714, 1714, 1714,
 1714, 1714, 1714, 1714, 1714, 1714, 1714, 1714, 1714,    0,
 1714, 1714,    0,    0,    0,    0,    0, 1714, 1714, 1714,
 1714, 1714, 1714, 1714, 1714, 1714, 1714, 1714, 1714, 1714,
 1714, 1714, 1714, 1714, 1714, 1592,    0, 1714, 1592, 1714,
 1714, 1714, 1714, 1714, 1714, 1714, 1714, 1714,    0,    0,
    0,    0,    0, 1592, 1592, 1592, 1592,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1592,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1592,    0, 1592,    0,    0, 1592,    0, 1592, 1592,
    0,    0, 1592, 1592,    0, 1592,    0,    0,    0,    0,
    0,    0,    0, 1592, 1592,    0, 1592,    0, 1592,    0,
    0, 1592,    0,    0, 1592,    0,    0,    0,    0,    0,
    0, 1592,    0, 1592, 1592,    0, 1592, 1592, 1592, 1592,
 1592,    0,    0, 1592,    0,    0, 1592,    0, 1592, 1592,
    0,    0, 1592, 1592, 1592,    0, 1592, 1592, 1592, 1592,
 1592, 1592, 1592,    0,    0,    0, 1592, 1592, 1592, 1592,
 1592,    0,    0,    0, 1592,    0,    0,    0,    0,    0,
    0,    0, 1592, 1592, 1592, 1592, 1592, 1592,    0,    0,
    0, 1592, 1592,    0, 1592,    0, 1592,    0, 1592, 1592,
 1592,    0, 1592,    0, 1592, 1592, 1592,    0, 1592, 1592,
 1592, 1592, 1592,    0, 1592, 1592,    0,    0,    0,    0,
 1592,    0, 1592, 1592,    0,    0, 1592, 1592, 1592,    0,
    0, 1592,    0, 1592,    0,    0, 1592, 1592, 1592, 1592,
    0, 1592,    0, 1592,    0, 1592, 1592, 1592, 1592, 1592,
    0,    0, 1592, 1592, 1592,    0, 1592, 1592,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1592, 1592, 1592,
    0, 1592, 1592, 1592,    0,    0,    0,    0,    0, 1592,
    0,    0,    0, 1592,    0, 1592, 1592, 1592, 1592,    0,
 1592,    0, 1592, 1592, 1592, 1592, 1592, 1592, 1592, 1592,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1592,
 1592,    0, 1592, 1592, 1592,    0,    0,    0,    0, 1592,
 1592, 1592, 1592, 1592,    0, 1592,    0,    0, 1592, 1592,
    0,    0,    0, 1592, 1592,    0,    0, 1592, 1592, 1592,
 1592, 1592, 1592, 1592, 1592, 1592,    0, 1592,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1592, 1592, 1592,
 1592, 1592, 1592, 1592, 1592, 1592, 1592, 1592, 1592, 1592,
 1592, 1592, 1592, 1592, 1592, 1592, 1592, 1592,    0, 1592,
 1592, 1592, 1592, 1592, 1592,    0, 1592, 1592, 1592, 1592,
    0, 1592,    0, 1592, 1592, 1592, 1592, 1592, 1592, 1592,
 1592, 1592, 1592, 1592, 1592, 1592, 1592, 1592, 1592, 1592,
 1592,    0, 1592, 1592, 1592, 1592,    0, 1592, 1592, 1592,
 1592, 1592,    0, 1592, 1592, 1592, 1592, 1592, 1592, 1592,
 1592, 1592, 1592, 1592, 1592, 1592, 1592, 1592, 1592, 1592,
 1592, 1592, 1592,    0, 1592, 1592, 1592, 1592, 1592, 1592,
 1592, 1592,    0, 1592, 1592,    0,    0,    0, 1592, 1592,
 1592, 1592, 1592, 1592,    0,    0, 1592, 1592, 1592, 1592,
 1592, 1592, 1592, 1592, 1592,    0,    0,    0,    0,    0,
 1592,    0, 1592, 1592, 1592, 1592, 1592, 1592,    0, 1592,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1592, 1592,    0, 1592,
 1592, 1592, 1592, 1592, 1592, 1592, 1592, 1592,    0, 1592,
 1592, 1592, 1592, 1592, 1592, 1592, 1592, 1592, 1592, 1592,
 1592,    0, 1592, 1592, 1592,    0, 1592,    0, 1593,    0,
 1592, 1592, 1592, 1592, 1592, 1592, 1592, 1592, 1592, 1592,
 1592, 1592, 1592,    0, 1592, 1592,    0,    0,    0,    0,
    0, 1592, 1592, 1592, 1592, 1592, 1592, 1592, 1592, 1592,
 1592, 1592, 1592, 1592, 1592, 1592, 1592, 1592, 1592, 1593,
    0, 1592, 1593, 1592, 1592, 1592, 1592, 1592, 1592, 1592,
 1592, 1592,    0,    0,    0,    0,    0, 1593, 1593, 1593,
 1593,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1593,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1593,    0, 1593,    0,    0,
 1593,    0, 1593, 1593,    0,    0, 1593, 1593,    0, 1593,
    0,    0,    0,    0,    0,    0,    0, 1593, 1593,    0,
 1593,    0, 1593,    0,    0, 1593,    0,    0, 1593,    0,
    0,    0,    0,    0,    0, 1593,    0, 1593, 1593,    0,
 1593, 1593, 1593, 1593, 1593,    0,    0, 1593,    0,    0,
 1593,    0, 1593, 1593,    0,    0, 1593, 1593, 1593,    0,
 1593, 1593, 1593, 1593, 1593, 1593, 1593,    0,    0,    0,
 1593, 1593, 1593, 1593, 1593,    0,    0,    0, 1593,    0,
    0,    0,    0,    0,    0,    0, 1593, 1593, 1593, 1593,
 1593, 1593,    0,    0,    0, 1593, 1593,    0, 1593,    0,
 1593,    0, 1593, 1593, 1593,    0, 1593,    0, 1593, 1593,
 1593,    0, 1593, 1593, 1593, 1593, 1593,    0, 1593, 1593,
    0,    0,    0,    0, 1593,    0, 1593, 1593,    0,    0,
 1593, 1593, 1593,    0,    0, 1593,    0, 1593,    0,    0,
 1593, 1593, 1593, 1593,    0, 1593,    0, 1593,    0, 1593,
 1593, 1593, 1593, 1593,    0,    0, 1593, 1593, 1593,    0,
 1593, 1593,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1593, 1593, 1593,    0, 1593, 1593, 1593,    0,    0,
    0,    0,    0, 1593,    0,    0,    0, 1593,    0, 1593,
 1593, 1593, 1593,    0, 1593,    0, 1593, 1593, 1593, 1593,
 1593, 1593, 1593, 1593,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1593, 1593,    0, 1593, 1593, 1593,    0,
    0,    0,    0, 1593, 1593, 1593, 1593, 1593,    0, 1593,
    0,    0, 1593, 1593,    0,    0,    0, 1593, 1593,    0,
    0, 1593, 1593, 1593, 1593, 1593, 1593, 1593, 1593, 1593,
    0, 1593,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1593, 1593, 1593, 1593, 1593, 1593, 1593, 1593, 1593,
 1593, 1593, 1593, 1593, 1593, 1593, 1593, 1593, 1593, 1593,
 1593, 1593,    0, 1593, 1593, 1593, 1593, 1593, 1593,    0,
 1593, 1593, 1593, 1593,    0, 1593,    0, 1593, 1593, 1593,
 1593, 1593, 1593, 1593, 1593, 1593, 1593, 1593, 1593, 1593,
 1593, 1593, 1593, 1593, 1593,    0, 1593, 1593, 1593, 1593,
    0, 1593, 1593, 1593, 1593, 1593,    0, 1593, 1593, 1593,
 1593, 1593, 1593, 1593, 1593, 1593, 1593, 1593, 1593, 1593,
 1593, 1593, 1593, 1593, 1593, 1593, 1593,    0, 1593, 1593,
 1593, 1593, 1593, 1593, 1593, 1593,    0, 1593, 1593,    0,
    0,    0, 1593, 1593, 1593, 1593, 1593, 1593,    0,    0,
 1593, 1593, 1593, 1593, 1593, 1593, 1593, 1593, 1593,    0,
    0,    0,    0,    0, 1593,    0, 1593, 1593, 1593, 1593,
 1593, 1593,    0, 1593,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1593, 1593,    0, 1593, 1593, 1593, 1593, 1593, 1593, 1593,
 1593, 1593,    0, 1593, 1593, 1593, 1593, 1593, 1593, 1593,
 1593, 1593, 1593, 1593, 1593,    0, 1593, 1593, 1593,    0,
 1593,    0, 1577,    0, 1593, 1593, 1593, 1593, 1593, 1593,
 1593, 1593, 1593, 1593, 1593, 1593, 1593,    0, 1593, 1593,
    0,    0,    0,    0,    0, 1593, 1593, 1593, 1593, 1593,
 1593, 1593, 1593, 1593, 1593, 1593, 1593, 1593, 1593, 1593,
 1593, 1593, 1593, 1577,    0, 1593, 1577, 1593, 1593, 1593,
 1593, 1593, 1593, 1593, 1593, 1593,    0,    0,    0,    0,
    0, 1577, 1577, 1577, 1577,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1577,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1577,
    0, 1577,    0,    0, 1577,    0, 1577, 1577,    0,    0,
 1577, 1577,    0, 1577,    0,    0,    0,    0,    0,    0,
    0, 1577, 1577,    0, 1577,    0, 1577,    0,    0, 1577,
    0,    0, 1577,    0,    0,    0,    0,    0,    0, 1577,
    0, 1577, 1577,    0, 1577, 1577, 1577, 1577, 1577,    0,
    0, 1577,    0,    0, 1577,    0, 1577, 1577,    0,    0,
 1577, 1577, 1577,    0, 1577, 1577, 1577, 1577, 1577, 1577,
 1577,    0,    0,    0, 1577,    0, 1577, 1577, 1577,    0,
    0,    0, 1577,    0,    0,    0,    0,    0,    0,    0,
 1577, 1577, 1577, 1577, 1577, 1577,    0,    0,    0, 1577,
 1577,    0, 1577,    0, 1577,    0, 1577, 1577, 1577,    0,
 1577,    0, 1577, 1577, 1577,    0, 1577, 1577, 1577, 1577,
 1577,    0, 1577, 1577,    0,    0,    0,    0, 1577,    0,
 1577, 1577,    0,    0, 1577, 1577, 1577,    0,    0, 1577,
    0, 1577,    0,    0, 1577, 1577, 1577, 1577,    0, 1577,
    0, 1577,    0, 1577, 1577, 1577, 1577, 1577,    0,    0,
 1577, 1577, 1577,    0, 1577, 1577,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1577, 1577, 1577,    0, 1577,
 1577, 1577,    0,    0,    0,    0,    0, 1577,    0,    0,
    0, 1577,    0, 1577, 1577, 1577, 1577,    0, 1577,    0,
 1577, 1577, 1577, 1577, 1577, 1577, 1577, 1577,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1577, 1577,    0,
 1577, 1577, 1577,    0,    0,    0,    0, 1577, 1577, 1577,
 1577, 1577,    0, 1577,    0,    0, 1577, 1577,    0,    0,
    0, 1577, 1577,    0,    0, 1577, 1577, 1577, 1577, 1577,
 1577, 1577, 1577, 1577,    0, 1577,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1577, 1577, 1577, 1577, 1577,
 1577, 1577, 1577, 1577, 1577, 1577, 1577, 1577, 1577, 1577,
 1577, 1577, 1577, 1577, 1577, 1577,    0, 1577, 1577, 1577,
 1577, 1577, 1577,    0, 1577, 1577, 1577, 1577,    0, 1577,
    0, 1577, 1577, 1577, 1577, 1577, 1577, 1577, 1577, 1577,
 1577, 1577, 1577, 1577, 1577, 1577, 1577, 1577, 1577,    0,
 1577, 1577, 1577, 1577,    0, 1577, 1577, 1577, 1577, 1577,
    0, 1577, 1577, 1577, 1577, 1577, 1577, 1577, 1577, 1577,
 1577, 1577, 1577, 1577, 1577, 1577, 1577, 1577, 1577, 1577,
 1577,    0, 1577, 1577, 1577, 1577, 1577, 1577, 1577, 1577,
    0, 1577, 1577,    0,    0,    0, 1577, 1577, 1577, 1577,
 1577, 1577,    0,    0, 1577, 1577, 1577, 1577, 1577, 1577,
 1577, 1577, 1577,    0,    0,    0,    0,    0, 1577,    0,
 1577, 1577, 1577, 1577, 1577, 1577,    0, 1577,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1577, 1577,    0, 1577, 1577, 1577,
 1577, 1577, 1577, 1577, 1577, 1577,    0, 1577, 1577, 1577,
 1577, 1577, 1577, 1577, 1577, 1577, 1577, 1577, 1577,    0,
 1577, 1577, 1577,    0, 1577,    0, 1594,    0, 1577, 1577,
 1577, 1577, 1577, 1577, 1577, 1577, 1577, 1577, 1577, 1577,
 1577,    0, 1577, 1577,    0,    0,    0,    0,    0, 1577,
 1577, 1577, 1577, 1577, 1577, 1577, 1577, 1577, 1577, 1577,
 1577, 1577, 1577, 1577, 1577, 1577, 1577, 1594,    0, 1577,
 1594, 1577, 1577, 1577, 1577, 1577, 1577, 1577, 1577, 1577,
    0,    0,    0,    0,    0, 1594, 1594, 1594, 1594,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1594,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1594,    0, 1594,    0,    0, 1594,    0,
 1594, 1594,    0,    0, 1594, 1594,    0, 1594,    0,    0,
    0,    0,    0,    0,    0, 1594, 1594,    0, 1594,    0,
 1594,    0,    0, 1594,    0,    0, 1594,    0,    0,    0,
    0,    0,    0, 1594,    0, 1594, 1594,    0, 1594, 1594,
 1594, 1594, 1594,    0,    0, 1594,    0,    0, 1594,    0,
 1594, 1594,    0,    0, 1594, 1594, 1594,    0, 1594, 1594,
 1594, 1594, 1594, 1594, 1594,    0,    0,    0, 1594,    0,
 1594, 1594, 1594,    0,    0,    0, 1594,    0,    0,    0,
    0,    0,    0,    0, 1594, 1594, 1594, 1594, 1594, 1594,
    0,    0,    0, 1594, 1594,    0, 1594,    0, 1594,    0,
 1594, 1594, 1594,    0, 1594,    0, 1594, 1594, 1594,    0,
 1594, 1594, 1594, 1594, 1594,    0, 1594, 1594,    0,    0,
    0,    0, 1594,    0, 1594, 1594,    0,    0, 1594, 1594,
 1594,    0,    0, 1594,    0, 1594,    0,    0, 1594, 1594,
 1594, 1594,    0, 1594,    0, 1594,    0, 1594, 1594, 1594,
 1594, 1594,    0,    0, 1594, 1594, 1594,    0, 1594, 1594,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1594,
 1594, 1594,    0, 1594, 1594, 1594,    0,    0,    0,    0,
    0, 1594,    0,    0,    0, 1594,    0, 1594, 1594, 1594,
 1594,    0, 1594,    0, 1594, 1594, 1594, 1594, 1594, 1594,
 1594, 1594,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1594, 1594,    0, 1594, 1594, 1594,    0,    0,    0,
    0, 1594, 1594, 1594, 1594, 1594,    0, 1594,    0,    0,
 1594, 1594,    0,    0,    0, 1594, 1594,    0,    0, 1594,
 1594, 1594, 1594, 1594, 1594, 1594, 1594, 1594,    0, 1594,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1594,
 1594, 1594, 1594, 1594, 1594, 1594, 1594, 1594, 1594, 1594,
 1594, 1594, 1594, 1594, 1594, 1594, 1594, 1594, 1594, 1594,
    0, 1594, 1594, 1594, 1594, 1594, 1594,    0, 1594, 1594,
 1594, 1594,    0, 1594,    0, 1594, 1594, 1594, 1594, 1594,
 1594, 1594, 1594, 1594, 1594, 1594, 1594, 1594, 1594, 1594,
 1594, 1594, 1594,    0, 1594, 1594, 1594, 1594,    0, 1594,
 1594, 1594, 1594, 1594,    0, 1594, 1594, 1594, 1594, 1594,
 1594, 1594, 1594, 1594, 1594, 1594, 1594, 1594, 1594, 1594,
 1594, 1594, 1594, 1594, 1594,    0, 1594, 1594, 1594, 1594,
 1594, 1594, 1594, 1594,    0, 1594, 1594,    0,    0,    0,
 1594, 1594, 1594, 1594, 1594, 1594,    0,    0, 1594, 1594,
 1594, 1594, 1594, 1594, 1594, 1594, 1594,    0,    0,    0,
    0,    0, 1594,    0, 1594, 1594, 1594, 1594, 1594, 1594,
    0, 1594,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1594, 1594,
    0, 1594, 1594, 1594, 1594, 1594, 1594, 1594, 1594, 1594,
    0, 1594, 1594, 1594, 1594, 1594, 1594, 1594, 1594, 1594,
 1594, 1594, 1594,    0, 1594, 1594, 1594,    0, 1594,    0,
 1595,    0, 1594, 1594, 1594, 1594, 1594, 1594, 1594, 1594,
 1594, 1594, 1594, 1594, 1594,    0, 1594, 1594,    0,    0,
    0,    0,    0, 1594, 1594, 1594, 1594, 1594, 1594, 1594,
 1594, 1594, 1594, 1594, 1594, 1594, 1594, 1594, 1594, 1594,
 1594, 1595,    0, 1594, 1595, 1594, 1594, 1594, 1594, 1594,
 1594, 1594, 1594, 1594,    0,    0,    0,    0,    0, 1595,
 1595, 1595, 1595,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1595,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1595,    0, 1595,
    0,    0, 1595,    0, 1595, 1595,    0,    0, 1595, 1595,
    0, 1595,    0,    0,    0,    0,    0,    0,    0, 1595,
 1595,    0, 1595,    0, 1595,    0,    0, 1595,    0,    0,
 1595,    0,    0,    0,    0,    0,    0, 1595,    0, 1595,
 1595,    0, 1595, 1595, 1595, 1595, 1595,    0,    0, 1595,
    0,    0, 1595,    0, 1595, 1595,    0,    0, 1595, 1595,
 1595,    0, 1595, 1595, 1595, 1595, 1595, 1595, 1595,    0,
    0,    0, 1595,    0, 1595, 1595, 1595,    0,    0,    0,
 1595,    0,    0,    0,    0,    0,    0,    0, 1595, 1595,
 1595, 1595, 1595, 1595,    0,    0,    0, 1595, 1595,    0,
 1595,    0, 1595,    0, 1595, 1595, 1595,    0, 1595,    0,
 1595, 1595, 1595,    0, 1595, 1595, 1595, 1595, 1595,    0,
 1595, 1595,    0,    0,    0,    0, 1595,    0, 1595, 1595,
    0,    0, 1595, 1595, 1595,    0,    0, 1595,    0, 1595,
    0,    0, 1595, 1595, 1595, 1595,    0, 1595,    0, 1595,
    0, 1595, 1595, 1595, 1595, 1595,    0,    0, 1595, 1595,
 1595,    0, 1595, 1595,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1595, 1595, 1595,    0, 1595, 1595, 1595,
    0,    0,    0,    0,    0, 1595,    0,    0,    0, 1595,
    0, 1595, 1595, 1595, 1595,    0, 1595,    0, 1595, 1595,
 1595, 1595, 1595, 1595, 1595, 1595,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1595, 1595,    0, 1595, 1595,
 1595,    0,    0,    0,    0, 1595, 1595, 1595, 1595, 1595,
    0, 1595,    0,    0, 1595, 1595,    0,    0,    0, 1595,
 1595,    0,    0, 1595, 1595, 1595, 1595, 1595, 1595, 1595,
 1595, 1595,    0, 1595,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1595, 1595, 1595, 1595, 1595, 1595, 1595,
 1595, 1595, 1595, 1595, 1595, 1595, 1595, 1595, 1595, 1595,
 1595, 1595, 1595, 1595,    0, 1595, 1595, 1595, 1595, 1595,
 1595,    0, 1595, 1595, 1595, 1595,    0, 1595,    0, 1595,
 1595, 1595, 1595, 1595, 1595, 1595, 1595, 1595, 1595, 1595,
 1595, 1595, 1595, 1595, 1595, 1595, 1595,    0, 1595, 1595,
 1595, 1595,    0, 1595, 1595, 1595, 1595, 1595,    0, 1595,
 1595, 1595, 1595, 1595, 1595, 1595, 1595, 1595, 1595, 1595,
 1595, 1595, 1595, 1595, 1595, 1595, 1595, 1595, 1595,    0,
 1595, 1595, 1595, 1595, 1595, 1595, 1595, 1595,    0, 1595,
 1595,    0,    0,    0, 1595, 1595, 1595, 1595, 1595, 1595,
    0,    0, 1595, 1595, 1595, 1595, 1595, 1595, 1595, 1595,
 1595,    0,    0,    0,    0,    0, 1595,    0, 1595, 1595,
 1595, 1595, 1595, 1595,    0, 1595,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1595, 1595,    0, 1595, 1595, 1595, 1595, 1595,
 1595, 1595, 1595, 1595,    0, 1595, 1595, 1595, 1595, 1595,
 1595, 1595, 1595, 1595, 1595, 1595, 1595,    0, 1595, 1595,
 1595,    0, 1595,    0, 1600,    0, 1595, 1595, 1595, 1595,
 1595, 1595, 1595, 1595, 1595, 1595, 1595, 1595, 1595,    0,
 1595, 1595,    0,    0,    0,    0,    0, 1595, 1595, 1595,
 1595, 1595, 1595, 1595, 1595, 1595, 1595, 1595, 1595, 1595,
 1595, 1595, 1595, 1595, 1595, 1600,    0, 1595, 1600, 1595,
 1595, 1595, 1595, 1595, 1595, 1595, 1595, 1595,    0,    0,
    0,    0,    0, 1600, 1600, 1600, 1600,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1600,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1600,    0, 1600,    0,    0, 1600,    0, 1600, 1600,
    0,    0, 1600, 1600,    0, 1600,    0,    0,    0,    0,
    0,    0,    0, 1600, 1600,    0, 1600,    0, 1600,    0,
    0, 1600,    0,    0, 1600,    0,    0,    0,    0,    0,
    0, 1600,    0, 1600, 1600,    0, 1600, 1600, 1600, 1600,
 1600,    0,    0, 1600,    0,    0, 1600,    0, 1600, 1600,
    0,    0, 1600, 1600, 1600,    0, 1600, 1600, 1600, 1600,
 1600, 1600, 1600,    0,    0,    0, 1600,    0, 1600, 1600,
 1600,    0,    0,    0, 1600,    0,    0,    0,    0,    0,
    0,    0, 1600, 1600, 1600, 1600, 1600, 1600,    0,    0,
    0, 1600, 1600,    0, 1600,    0, 1600,    0, 1600, 1600,
 1600,    0, 1600,    0, 1600, 1600, 1600,    0, 1600, 1600,
 1600, 1600, 1600,    0, 1600, 1600,    0,    0,    0,    0,
 1600,    0, 1600, 1600,    0,    0, 1600, 1600, 1600,    0,
    0, 1600,    0, 1600,    0,    0, 1600, 1600, 1600, 1600,
    0, 1600,    0, 1600,    0, 1600, 1600, 1600, 1600, 1600,
    0,    0, 1600, 1600, 1600,    0, 1600, 1600,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1600, 1600, 1600,
    0, 1600, 1600, 1600,    0,    0,    0,    0,    0, 1600,
    0,    0,    0, 1600,    0, 1600, 1600, 1600, 1600,    0,
 1600,    0, 1600, 1600, 1600, 1600, 1600, 1600, 1600, 1600,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1600,
 1600,    0, 1600, 1600, 1600,    0,    0,    0,    0, 1600,
 1600, 1600, 1600, 1600,    0, 1600,    0,    0, 1600, 1600,
    0,    0,    0, 1600, 1600,    0,    0, 1600, 1600, 1600,
 1600, 1600, 1600, 1600, 1600, 1600,    0, 1600,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1600, 1600, 1600,
 1600, 1600, 1600, 1600, 1600, 1600, 1600, 1600, 1600, 1600,
 1600, 1600, 1600, 1600, 1600, 1600, 1600, 1600,    0, 1600,
 1600, 1600, 1600, 1600, 1600,    0, 1600, 1600, 1600, 1600,
    0, 1600,    0, 1600, 1600, 1600, 1600, 1600, 1600, 1600,
 1600, 1600, 1600, 1600, 1600, 1600, 1600, 1600, 1600, 1600,
 1600,    0, 1600, 1600, 1600, 1600,    0, 1600, 1600, 1600,
 1600, 1600,    0, 1600, 1600, 1600, 1600, 1600, 1600, 1600,
 1600, 1600, 1600, 1600, 1600, 1600, 1600, 1600, 1600, 1600,
 1600, 1600, 1600,    0, 1600, 1600, 1600, 1600, 1600, 1600,
 1600, 1600,    0, 1600, 1600,    0,    0,    0, 1600, 1600,
 1600, 1600, 1600, 1600,    0,    0, 1600, 1600, 1600, 1600,
 1600, 1600, 1600, 1600, 1600,    0,    0,    0,    0,    0,
 1600,    0, 1600, 1600, 1600, 1600, 1600, 1600,    0, 1600,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1600, 1600,    0, 1600,
 1600, 1600, 1600, 1600, 1600, 1600, 1600, 1600,    0, 1600,
 1600, 1600, 1600, 1600, 1600, 1600, 1600, 1600, 1600, 1600,
 1600,    0, 1600, 1600, 1600,    0, 1600,    0, 1602,    0,
 1600, 1600, 1600, 1600, 1600, 1600, 1600, 1600, 1600, 1600,
 1600, 1600, 1600,    0, 1600, 1600,    0,    0,    0,    0,
    0, 1600, 1600, 1600, 1600, 1600, 1600, 1600, 1600, 1600,
 1600, 1600, 1600, 1600, 1600, 1600, 1600, 1600, 1600, 1602,
    0, 1600, 1602, 1600, 1600, 1600, 1600, 1600, 1600, 1600,
 1600, 1600,    0,    0,    0,    0,    0, 1602, 1602, 1602,
 1602,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1602,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1602,    0, 1602,    0,    0,
 1602,    0, 1602, 1602,    0,    0, 1602, 1602,    0, 1602,
    0,    0,    0,    0,    0,    0,    0, 1602, 1602,    0,
 1602,    0, 1602,    0,    0, 1602,    0,    0, 1602,    0,
    0,    0,    0,    0,    0, 1602,    0, 1602, 1602,    0,
 1602, 1602, 1602, 1602, 1602,    0,    0, 1602,    0,    0,
 1602,    0, 1602, 1602,    0,    0, 1602, 1602, 1602,    0,
 1602, 1602, 1602, 1602, 1602, 1602, 1602,    0,    0,    0,
 1602,    0, 1602, 1602, 1602,    0,    0,    0, 1602,    0,
    0,    0,    0,    0,    0,    0, 1602, 1602, 1602, 1602,
 1602, 1602,    0,    0,    0, 1602, 1602,    0, 1602,    0,
 1602,    0, 1602, 1602, 1602,    0, 1602,    0, 1602, 1602,
 1602,    0, 1602, 1602, 1602, 1602, 1602,    0, 1602, 1602,
    0,    0,    0,    0, 1602,    0, 1602, 1602,    0,    0,
 1602, 1602, 1602,    0,    0, 1602,    0, 1602,    0,    0,
 1602, 1602, 1602, 1602,    0, 1602,    0, 1602,    0, 1602,
 1602, 1602, 1602, 1602,    0,    0, 1602, 1602, 1602,    0,
 1602, 1602,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1602, 1602, 1602,    0, 1602, 1602, 1602,    0,    0,
    0,    0,    0, 1602,    0,    0,    0, 1602,    0, 1602,
 1602, 1602, 1602,    0, 1602,    0, 1602, 1602, 1602, 1602,
 1602, 1602, 1602, 1602,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1602, 1602,    0, 1602, 1602, 1602,    0,
    0,    0,    0, 1602, 1602, 1602, 1602, 1602,    0, 1602,
    0,    0, 1602, 1602,    0,    0,    0, 1602, 1602,    0,
    0, 1602, 1602, 1602, 1602, 1602, 1602, 1602, 1602, 1602,
    0, 1602,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1602, 1602, 1602, 1602, 1602, 1602, 1602, 1602, 1602,
 1602, 1602, 1602, 1602, 1602, 1602, 1602, 1602, 1602, 1602,
 1602, 1602,    0, 1602, 1602, 1602, 1602, 1602, 1602,    0,
 1602, 1602, 1602, 1602,    0, 1602,    0, 1602, 1602, 1602,
 1602, 1602, 1602, 1602, 1602, 1602, 1602, 1602, 1602, 1602,
 1602, 1602, 1602, 1602, 1602,    0, 1602, 1602, 1602, 1602,
    0, 1602, 1602, 1602, 1602, 1602,    0, 1602, 1602, 1602,
 1602, 1602, 1602, 1602, 1602, 1602, 1602, 1602, 1602, 1602,
 1602, 1602, 1602, 1602, 1602, 1602, 1602,    0, 1602, 1602,
 1602, 1602, 1602, 1602, 1602, 1602,    0, 1602, 1602,    0,
    0,    0, 1602, 1602, 1602, 1602, 1602, 1602,    0,    0,
 1602, 1602, 1602, 1602, 1602, 1602, 1602, 1602, 1602,    0,
    0,    0,    0,    0, 1602,    0, 1602, 1602, 1602, 1602,
 1602, 1602,    0, 1602,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1602, 1602,    0, 1602, 1602, 1602, 1602, 1602, 1602, 1602,
 1602, 1602,    0, 1602, 1602, 1602, 1602, 1602, 1602, 1602,
 1602, 1602, 1602, 1602, 1602,    0, 1602, 1602, 1602,    0,
 1602,    0, 1604,    0, 1602, 1602, 1602, 1602, 1602, 1602,
 1602, 1602, 1602, 1602, 1602, 1602, 1602,    0, 1602, 1602,
    0,    0,    0,    0,    0, 1602, 1602, 1602, 1602, 1602,
 1602, 1602, 1602, 1602, 1602, 1602, 1602, 1602, 1602, 1602,
 1602, 1602, 1602, 1604,    0, 1602, 1604, 1602, 1602, 1602,
 1602, 1602, 1602, 1602, 1602, 1602,    0,    0,    0,    0,
    0, 1604, 1604, 1604, 1604,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1604,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1604,
    0, 1604,    0,    0, 1604,    0, 1604, 1604,    0,    0,
 1604, 1604,    0, 1604,    0,    0,    0,    0,    0,    0,
    0, 1604, 1604,    0, 1604,    0, 1604,    0,    0, 1604,
    0,    0, 1604,    0,    0,    0,    0,    0,    0, 1604,
    0, 1604, 1604,    0, 1604, 1604, 1604, 1604, 1604,    0,
    0, 1604,    0,    0, 1604,    0, 1604, 1604,    0,    0,
 1604, 1604, 1604,    0, 1604, 1604, 1604, 1604, 1604, 1604,
 1604,    0,    0,    0, 1604,    0, 1604, 1604, 1604,    0,
    0,    0, 1604,    0,    0,    0,    0,    0,    0,    0,
 1604, 1604, 1604, 1604, 1604, 1604,    0,    0,    0, 1604,
 1604,    0, 1604,    0, 1604,    0, 1604, 1604, 1604,    0,
 1604,    0, 1604, 1604, 1604,    0, 1604, 1604, 1604, 1604,
 1604,    0, 1604, 1604,    0,    0,    0,    0, 1604,    0,
 1604, 1604,    0,    0, 1604, 1604, 1604,    0,    0, 1604,
    0, 1604,    0,    0, 1604, 1604, 1604, 1604,    0, 1604,
    0, 1604,    0, 1604, 1604, 1604, 1604, 1604,    0,    0,
 1604, 1604, 1604,    0, 1604, 1604,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1604, 1604, 1604,    0, 1604,
 1604, 1604,    0,    0,    0,    0,    0, 1604,    0,    0,
    0, 1604,    0, 1604, 1604, 1604, 1604,    0, 1604,    0,
 1604, 1604, 1604, 1604, 1604, 1604, 1604, 1604,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1604, 1604,    0,
 1604, 1604, 1604,    0,    0,    0,    0, 1604, 1604, 1604,
 1604, 1604,    0, 1604,    0,    0, 1604, 1604,    0,    0,
    0, 1604, 1604,    0,    0, 1604, 1604, 1604, 1604, 1604,
 1604, 1604, 1604, 1604,    0, 1604,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1604, 1604, 1604, 1604, 1604,
 1604, 1604, 1604, 1604, 1604, 1604, 1604, 1604, 1604, 1604,
 1604, 1604, 1604, 1604, 1604, 1604,    0, 1604, 1604, 1604,
 1604, 1604, 1604,    0, 1604, 1604, 1604, 1604,    0, 1604,
    0, 1604, 1604, 1604, 1604, 1604, 1604, 1604, 1604, 1604,
 1604, 1604, 1604, 1604, 1604, 1604, 1604, 1604, 1604,    0,
 1604, 1604, 1604, 1604,    0, 1604, 1604, 1604, 1604, 1604,
    0, 1604, 1604, 1604, 1604, 1604, 1604, 1604, 1604, 1604,
 1604, 1604, 1604, 1604, 1604, 1604, 1604, 1604, 1604, 1604,
 1604,    0, 1604, 1604, 1604, 1604, 1604, 1604, 1604, 1604,
    0, 1604, 1604,    0,    0,    0, 1604, 1604, 1604, 1604,
 1604, 1604,    0,    0, 1604, 1604, 1604, 1604, 1604, 1604,
 1604, 1604, 1604,    0,    0,    0,    0,    0, 1604,    0,
 1604, 1604, 1604, 1604, 1604, 1604,    0, 1604,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1604, 1604,    0, 1604, 1604, 1604,
 1604, 1604, 1604, 1604, 1604, 1604,    0, 1604, 1604, 1604,
 1604, 1604, 1604, 1604, 1604, 1604, 1604, 1604, 1604,    0,
 1604, 1604, 1604,    0, 1604,    0, 1606,    0, 1604, 1604,
 1604, 1604, 1604, 1604, 1604, 1604, 1604, 1604, 1604, 1604,
 1604,    0, 1604, 1604,    0,    0,    0,    0,    0, 1604,
 1604, 1604, 1604, 1604, 1604, 1604, 1604, 1604, 1604, 1604,
 1604, 1604, 1604, 1604, 1604, 1604, 1604, 1606,    0, 1604,
 1606, 1604, 1604, 1604, 1604, 1604, 1604, 1604, 1604, 1604,
    0,    0,    0,    0,    0, 1606, 1606, 1606, 1606,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1606,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1606,    0, 1606,    0,    0, 1606,    0,
 1606, 1606,    0,    0, 1606, 1606,    0, 1606,    0,    0,
    0,    0,    0,    0,    0, 1606, 1606,    0, 1606,    0,
 1606,    0,    0, 1606,    0,    0, 1606,    0,    0,    0,
    0,    0,    0, 1606,    0, 1606, 1606,    0, 1606, 1606,
 1606, 1606, 1606,    0,    0, 1606,    0,    0, 1606,    0,
 1606, 1606,    0,    0, 1606, 1606, 1606,    0, 1606, 1606,
 1606, 1606, 1606, 1606, 1606,    0,    0,    0, 1606,    0,
 1606, 1606, 1606,    0,    0,    0, 1606,    0,    0,    0,
    0,    0,    0,    0, 1606, 1606, 1606, 1606, 1606, 1606,
    0,    0,    0, 1606, 1606,    0, 1606,    0, 1606,    0,
 1606, 1606, 1606,    0, 1606,    0, 1606, 1606, 1606,    0,
 1606, 1606, 1606, 1606, 1606,    0, 1606, 1606,    0,    0,
    0,    0, 1606,    0, 1606, 1606,    0,    0, 1606, 1606,
 1606,    0,    0, 1606,    0, 1606,    0,    0, 1606, 1606,
 1606, 1606,    0, 1606,    0, 1606,    0, 1606, 1606, 1606,
 1606, 1606,    0,    0, 1606, 1606, 1606,    0, 1606, 1606,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1606,
 1606, 1606,    0, 1606, 1606, 1606,    0,    0,    0,    0,
    0, 1606,    0,    0,    0, 1606,    0, 1606, 1606, 1606,
 1606,    0, 1606,    0, 1606, 1606, 1606, 1606, 1606, 1606,
 1606, 1606,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1606, 1606,    0, 1606, 1606, 1606,    0,    0,    0,
    0, 1606, 1606, 1606, 1606, 1606,    0, 1606,    0,    0,
 1606, 1606,    0,    0,    0, 1606, 1606,    0,    0, 1606,
 1606, 1606, 1606, 1606, 1606, 1606, 1606, 1606,    0, 1606,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1606,
 1606, 1606, 1606, 1606, 1606, 1606, 1606, 1606, 1606, 1606,
 1606, 1606, 1606, 1606, 1606, 1606, 1606, 1606, 1606, 1606,
    0, 1606, 1606, 1606, 1606, 1606, 1606,    0, 1606, 1606,
 1606, 1606,    0, 1606,    0, 1606, 1606, 1606, 1606, 1606,
 1606, 1606, 1606, 1606, 1606, 1606, 1606, 1606, 1606, 1606,
 1606, 1606, 1606,    0, 1606, 1606, 1606, 1606,    0, 1606,
 1606, 1606, 1606, 1606,    0, 1606, 1606, 1606, 1606, 1606,
 1606, 1606, 1606, 1606, 1606, 1606, 1606, 1606, 1606, 1606,
 1606, 1606, 1606, 1606, 1606,    0, 1606, 1606, 1606, 1606,
 1606, 1606, 1606, 1606,    0, 1606, 1606,    0,    0,    0,
 1606, 1606, 1606, 1606, 1606, 1606,    0,    0, 1606, 1606,
 1606, 1606, 1606, 1606, 1606, 1606, 1606,    0,    0,    0,
    0,    0, 1606,    0, 1606, 1606, 1606, 1606, 1606, 1606,
    0, 1606,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1606, 1606,
    0, 1606, 1606, 1606, 1606, 1606, 1606, 1606, 1606, 1606,
    0, 1606, 1606, 1606, 1606, 1606, 1606, 1606, 1606, 1606,
 1606, 1606, 1606,    0, 1606, 1606, 1606,    0, 1606,    0,
 1599,    0, 1606, 1606, 1606, 1606, 1606, 1606, 1606, 1606,
 1606, 1606, 1606, 1606, 1606,    0, 1606, 1606,    0,    0,
    0,    0,    0, 1606, 1606, 1606, 1606, 1606, 1606, 1606,
 1606, 1606, 1606, 1606, 1606, 1606, 1606, 1606, 1606, 1606,
 1606, 1599,    0, 1606, 1599, 1606, 1606, 1606, 1606, 1606,
 1606, 1606, 1606, 1606,    0,    0,    0,    0,    0, 1599,
 1599, 1599, 1599,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1599,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1599,    0, 1599,
    0,    0, 1599,    0, 1599, 1599,    0,    0, 1599, 1599,
    0, 1599,    0,    0,    0,    0,    0,    0,    0, 1599,
 1599,    0, 1599,    0, 1599,    0,    0, 1599,    0,    0,
 1599,    0,    0,    0,    0,    0,    0, 1599,    0, 1599,
 1599,    0, 1599, 1599, 1599,    0, 1599,    0,    0, 1599,
    0,    0, 1599,    0, 1599, 1599,    0,    0, 1599, 1599,
 1599,    0, 1599, 1599, 1599, 1599, 1599, 1599, 1599,    0,
    0,    0, 1599,    0, 1599, 1599, 1599,    0,    0,    0,
 1599,    0,    0,    0,    0,    0,    0,    0, 1599, 1599,
 1599, 1599, 1599, 1599,    0,    0,    0, 1599, 1599,    0,
 1599,    0, 1599,    0, 1599, 1599, 1599,    0, 1599,    0,
 1599, 1599, 1599,    0, 1599, 1599, 1599, 1599, 1599,    0,
 1599, 1599,    0,    0,    0,    0, 1599,    0, 1599, 1599,
    0,    0, 1599, 1599, 1599,    0,    0, 1599,    0, 1599,
    0,    0, 1599, 1599, 1599, 1599,    0, 1599,    0, 1599,
    0, 1599, 1599, 1599, 1599, 1599,    0,    0, 1599, 1599,
 1599,    0, 1599, 1599,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1599, 1599, 1599,    0, 1599, 1599, 1599,
    0,    0,    0,    0,    0, 1599,    0,    0,    0, 1599,
    0, 1599, 1599, 1599, 1599,    0, 1599,    0, 1599, 1599,
 1599, 1599, 1599, 1599, 1599, 1599,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1599, 1599,    0, 1599, 1599,
 1599,    0,    0,    0,    0, 1599, 1599, 1599, 1599, 1599,
    0, 1599,    0,    0, 1599, 1599,    0,    0,    0, 1599,
 1599,    0,    0, 1599, 1599, 1599, 1599, 1599, 1599, 1599,
 1599, 1599,    0, 1599,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1599, 1599, 1599, 1599, 1599, 1599, 1599,
 1599, 1599, 1599, 1599, 1599, 1599, 1599, 1599, 1599, 1599,
 1599, 1599, 1599, 1599,    0, 1599, 1599, 1599, 1599, 1599,
 1599,    0, 1599, 1599, 1599, 1599,    0, 1599,    0, 1599,
 1599, 1599, 1599, 1599, 1599, 1599, 1599, 1599, 1599, 1599,
 1599, 1599, 1599, 1599, 1599, 1599, 1599,    0, 1599, 1599,
 1599, 1599,    0, 1599, 1599, 1599, 1599, 1599,    0, 1599,
 1599, 1599, 1599, 1599, 1599, 1599, 1599, 1599, 1599, 1599,
 1599, 1599, 1599, 1599, 1599, 1599, 1599, 1599, 1599,    0,
 1599, 1599, 1599, 1599, 1599, 1599, 1599, 1599,    0, 1599,
 1599,    0,    0,    0, 1599, 1599, 1599, 1599, 1599, 1599,
    0,    0, 1599, 1599, 1599, 1599, 1599, 1599, 1599, 1599,
 1599,    0,    0,    0,    0,    0, 1599,    0, 1599, 1599,
 1599, 1599, 1599, 1599,    0, 1599,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1599, 1599,    0, 1599, 1599, 1599, 1599, 1599,
 1599, 1599, 1599, 1599,    0, 1599, 1599, 1599, 1599, 1599,
 1599, 1599, 1599, 1599, 1599, 1599, 1599,    0, 1599, 1599,
 1599,    0, 1599,    0, 1601,    0, 1599, 1599, 1599, 1599,
 1599, 1599, 1599, 1599, 1599, 1599, 1599, 1599, 1599,    0,
 1599, 1599,    0,    0,    0,    0,    0, 1599, 1599, 1599,
 1599, 1599, 1599, 1599, 1599, 1599, 1599, 1599, 1599, 1599,
 1599, 1599, 1599, 1599, 1599, 1601,    0, 1599, 1601, 1599,
 1599, 1599, 1599, 1599, 1599, 1599, 1599, 1599,    0,    0,
    0,    0,    0, 1601, 1601, 1601, 1601,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1601,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1601,    0, 1601,    0,    0, 1601,    0, 1601, 1601,
    0,    0, 1601, 1601,    0, 1601,    0,    0,    0,    0,
    0,    0,    0, 1601, 1601,    0, 1601,    0, 1601,    0,
    0, 1601,    0,    0, 1601,    0,    0,    0,    0,    0,
    0, 1601,    0, 1601, 1601,    0, 1601, 1601, 1601,    0,
 1601,    0,    0, 1601,    0,    0, 1601,    0, 1601, 1601,
    0,    0, 1601, 1601, 1601,    0, 1601, 1601, 1601, 1601,
 1601, 1601, 1601,    0,    0,    0, 1601,    0, 1601, 1601,
 1601,    0,    0,    0, 1601,    0,    0,    0,    0,    0,
    0,    0, 1601, 1601, 1601, 1601, 1601, 1601,    0,    0,
    0, 1601, 1601,    0, 1601,    0, 1601,    0, 1601, 1601,
 1601,    0, 1601,    0, 1601, 1601, 1601,    0, 1601, 1601,
 1601, 1601, 1601,    0, 1601, 1601,    0,    0,    0,    0,
 1601,    0, 1601, 1601,    0,    0, 1601, 1601, 1601,    0,
    0, 1601,    0, 1601,    0,    0, 1601, 1601, 1601, 1601,
    0, 1601,    0, 1601,    0, 1601, 1601, 1601, 1601, 1601,
    0,    0, 1601, 1601, 1601,    0, 1601, 1601,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1601, 1601, 1601,
    0, 1601, 1601, 1601,    0,    0,    0,    0,    0, 1601,
    0,    0,    0, 1601,    0, 1601, 1601, 1601, 1601,    0,
 1601,    0, 1601, 1601, 1601, 1601, 1601, 1601, 1601, 1601,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1601,
 1601,    0, 1601, 1601, 1601,    0,    0,    0,    0, 1601,
 1601, 1601, 1601, 1601,    0, 1601,    0,    0, 1601, 1601,
    0,    0,    0, 1601, 1601,    0,    0, 1601, 1601, 1601,
 1601, 1601, 1601, 1601, 1601, 1601,    0, 1601,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1601, 1601, 1601,
 1601, 1601, 1601, 1601, 1601, 1601, 1601, 1601, 1601, 1601,
 1601, 1601, 1601, 1601, 1601, 1601, 1601, 1601,    0, 1601,
 1601, 1601, 1601, 1601, 1601,    0, 1601, 1601, 1601, 1601,
    0, 1601,    0, 1601, 1601, 1601, 1601, 1601, 1601, 1601,
 1601, 1601, 1601, 1601, 1601, 1601, 1601, 1601, 1601, 1601,
 1601,    0, 1601, 1601, 1601, 1601,    0, 1601, 1601, 1601,
 1601, 1601,    0, 1601, 1601, 1601, 1601, 1601, 1601, 1601,
 1601, 1601, 1601, 1601, 1601, 1601, 1601, 1601, 1601, 1601,
 1601, 1601, 1601,    0, 1601, 1601, 1601, 1601, 1601, 1601,
 1601, 1601,    0, 1601, 1601,    0,    0,    0, 1601, 1601,
 1601, 1601, 1601, 1601,    0,    0, 1601, 1601, 1601, 1601,
 1601, 1601, 1601, 1601, 1601,    0,    0,    0,    0,    0,
 1601,    0, 1601, 1601, 1601, 1601, 1601, 1601,    0, 1601,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1601, 1601,    0, 1601,
 1601, 1601, 1601, 1601, 1601, 1601, 1601, 1601,    0, 1601,
 1601, 1601, 1601, 1601, 1601, 1601, 1601, 1601, 1601, 1601,
 1601,    0, 1601, 1601, 1601,    0, 1601,    0, 1603,    0,
 1601, 1601, 1601, 1601, 1601, 1601, 1601, 1601, 1601, 1601,
 1601, 1601, 1601,    0, 1601, 1601,    0,    0,    0,    0,
    0, 1601, 1601, 1601, 1601, 1601, 1601, 1601, 1601, 1601,
 1601, 1601, 1601, 1601, 1601, 1601, 1601, 1601, 1601, 1603,
    0, 1601, 1603, 1601, 1601, 1601, 1601, 1601, 1601, 1601,
 1601, 1601,    0,    0,    0,    0,    0, 1603, 1603, 1603,
 1603,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1603,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1603,    0, 1603,    0,    0,
 1603,    0, 1603, 1603,    0,    0, 1603, 1603,    0, 1603,
    0,    0,    0,    0,    0,    0,    0, 1603, 1603,    0,
 1603,    0, 1603,    0,    0, 1603,    0,    0, 1603,    0,
    0,    0,    0,    0,    0, 1603,    0, 1603, 1603,    0,
 1603, 1603, 1603,    0, 1603,    0,    0, 1603,    0,    0,
 1603,    0, 1603, 1603,    0,    0, 1603, 1603, 1603,    0,
 1603, 1603, 1603, 1603, 1603, 1603, 1603,    0,    0,    0,
 1603,    0, 1603, 1603, 1603,    0,    0,    0, 1603,    0,
    0,    0,    0,    0,    0,    0, 1603, 1603, 1603, 1603,
 1603, 1603,    0,    0,    0, 1603, 1603,    0, 1603,    0,
 1603,    0, 1603, 1603, 1603,    0, 1603,    0, 1603, 1603,
 1603,    0, 1603, 1603, 1603, 1603, 1603,    0, 1603, 1603,
    0,    0,    0,    0, 1603,    0, 1603, 1603,    0,    0,
 1603, 1603, 1603,    0,    0, 1603,    0, 1603,    0,    0,
 1603, 1603, 1603, 1603,    0, 1603,    0, 1603,    0, 1603,
 1603, 1603, 1603, 1603,    0,    0, 1603, 1603, 1603,    0,
 1603, 1603,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1603, 1603, 1603,    0, 1603, 1603, 1603,    0,    0,
    0,    0,    0, 1603,    0,    0,    0, 1603,    0, 1603,
 1603, 1603, 1603,    0, 1603,    0, 1603, 1603, 1603, 1603,
 1603, 1603, 1603, 1603,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1603, 1603,    0, 1603, 1603, 1603,    0,
    0,    0,    0, 1603, 1603, 1603, 1603, 1603,    0, 1603,
    0,    0, 1603, 1603,    0,    0,    0, 1603, 1603,    0,
    0, 1603, 1603, 1603, 1603, 1603, 1603, 1603, 1603, 1603,
    0, 1603,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1603, 1603, 1603, 1603, 1603, 1603, 1603, 1603, 1603,
 1603, 1603, 1603, 1603, 1603, 1603, 1603, 1603, 1603, 1603,
 1603, 1603,    0, 1603, 1603, 1603, 1603, 1603, 1603,    0,
 1603, 1603, 1603, 1603,    0, 1603,    0, 1603, 1603, 1603,
 1603, 1603, 1603, 1603, 1603, 1603, 1603, 1603, 1603, 1603,
 1603, 1603, 1603, 1603, 1603,    0, 1603, 1603, 1603, 1603,
    0, 1603, 1603, 1603, 1603, 1603,    0, 1603, 1603, 1603,
 1603, 1603, 1603, 1603, 1603, 1603, 1603, 1603, 1603, 1603,
 1603, 1603, 1603, 1603, 1603, 1603, 1603,    0, 1603, 1603,
 1603, 1603, 1603, 1603, 1603, 1603,    0, 1603, 1603,    0,
    0,    0, 1603, 1603, 1603, 1603, 1603, 1603,    0,    0,
 1603, 1603, 1603, 1603, 1603, 1603, 1603, 1603, 1603,    0,
    0,    0,    0,    0, 1603,    0, 1603, 1603, 1603, 1603,
 1603, 1603,    0, 1603,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1603, 1603,    0, 1603, 1603, 1603, 1603, 1603, 1603, 1603,
 1603, 1603,    0, 1603, 1603, 1603, 1603, 1603, 1603, 1603,
 1603, 1603, 1603, 1603, 1603,    0, 1603, 1603, 1603,    0,
 1603,    0, 1605,    0, 1603, 1603, 1603, 1603, 1603, 1603,
 1603, 1603, 1603, 1603, 1603, 1603, 1603,    0, 1603, 1603,
    0,    0,    0,    0,    0, 1603, 1603, 1603, 1603, 1603,
 1603, 1603, 1603, 1603, 1603, 1603, 1603, 1603, 1603, 1603,
 1603, 1603, 1603, 1605,    0, 1603, 1605, 1603, 1603, 1603,
 1603, 1603, 1603, 1603, 1603, 1603,    0,    0,    0,    0,
    0, 1605, 1605, 1605, 1605,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1605,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1605,
    0, 1605,    0,    0, 1605,    0, 1605, 1605,    0,    0,
 1605, 1605,    0, 1605,    0,    0,    0,    0,    0,    0,
    0, 1605, 1605,    0, 1605,    0, 1605,    0,    0, 1605,
    0,    0, 1605,    0,    0,    0,    0,    0,    0, 1605,
    0, 1605, 1605,    0, 1605, 1605, 1605,    0, 1605,    0,
    0, 1605,    0,    0, 1605,    0, 1605, 1605,    0,    0,
 1605, 1605, 1605,    0, 1605, 1605, 1605, 1605, 1605, 1605,
 1605,    0,    0,    0, 1605,    0, 1605, 1605, 1605,    0,
    0,    0, 1605,    0,    0,    0,    0,    0,    0,    0,
 1605, 1605, 1605, 1605, 1605, 1605,    0,    0,    0, 1605,
 1605,    0, 1605,    0, 1605,    0, 1605, 1605, 1605,    0,
 1605,    0, 1605, 1605, 1605,    0, 1605, 1605, 1605, 1605,
 1605,    0, 1605, 1605,    0,    0,    0,    0, 1605,    0,
 1605, 1605,    0,    0, 1605, 1605, 1605,    0,    0, 1605,
    0, 1605,    0,    0, 1605, 1605, 1605, 1605,    0, 1605,
    0, 1605,    0, 1605, 1605, 1605, 1605, 1605,    0,    0,
 1605, 1605, 1605,    0, 1605, 1605,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1605, 1605, 1605,    0, 1605,
 1605, 1605,    0,    0,    0,    0,    0, 1605,    0,    0,
    0, 1605,    0, 1605, 1605, 1605, 1605,    0, 1605,    0,
 1605, 1605, 1605, 1605, 1605, 1605, 1605, 1605,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1605, 1605,    0,
 1605, 1605, 1605,    0,    0,    0,    0, 1605, 1605, 1605,
 1605, 1605,    0, 1605,    0,    0, 1605, 1605,    0,    0,
    0, 1605, 1605,    0,    0, 1605, 1605, 1605, 1605, 1605,
 1605, 1605, 1605, 1605,    0, 1605,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1605, 1605, 1605, 1605, 1605,
 1605, 1605, 1605, 1605, 1605, 1605, 1605, 1605, 1605, 1605,
 1605, 1605, 1605, 1605, 1605, 1605,    0, 1605, 1605, 1605,
 1605, 1605, 1605,    0, 1605, 1605, 1605, 1605,    0, 1605,
    0, 1605, 1605, 1605, 1605, 1605, 1605, 1605, 1605, 1605,
 1605, 1605, 1605, 1605, 1605, 1605, 1605, 1605, 1605,    0,
 1605, 1605, 1605, 1605,    0, 1605, 1605, 1605, 1605, 1605,
    0, 1605, 1605, 1605, 1605, 1605, 1605, 1605, 1605, 1605,
 1605, 1605, 1605, 1605, 1605, 1605, 1605, 1605, 1605, 1605,
 1605,    0, 1605, 1605, 1605, 1605, 1605, 1605, 1605, 1605,
    0, 1605, 1605,    0,    0,    0, 1605, 1605, 1605, 1605,
 1605, 1605,    0,    0, 1605, 1605, 1605, 1605, 1605, 1605,
 1605, 1605, 1605,    0,    0,    0,    0,    0, 1605,    0,
 1605, 1605, 1605, 1605, 1605, 1605,    0, 1605,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1605, 1605,    0, 1605, 1605, 1605,
 1605, 1605, 1605, 1605, 1605, 1605,    0, 1605, 1605, 1605,
 1605, 1605, 1605, 1605, 1605, 1605, 1605, 1605, 1605,    0,
 1605, 1605, 1605,    0, 1605,    0, 1561,    0, 1605, 1605,
 1605, 1605, 1605, 1605, 1605, 1605, 1605, 1605, 1605, 1605,
 1605,    0, 1605, 1605,    0,    0,    0,    0,    0, 1605,
 1605, 1605, 1605, 1605, 1605, 1605, 1605, 1605, 1605, 1605,
 1605, 1605, 1605, 1605, 1605, 1605, 1605, 1561,    0, 1605,
 1561, 1605, 1605, 1605, 1605, 1605, 1605, 1605, 1605, 1605,
    0,    0,    0,    0,    0, 1561,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1561,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1561,    0, 1561,    0,    0, 1561,    0,
 1561, 1561,    0,    0, 1561, 1561,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1561, 1561,    0, 1561,    0,
    0,    0,    0, 1561,    0,    0, 1561,    0,    0,    0,
    0,    0,    0, 1561,    0, 1561, 1561,    0, 1561, 1561,
 1561, 1561, 1561,    0,    0, 1561,    0,    0, 1561,    0,
 1561, 1561,    0,    0,    0, 1561, 1561,    0, 1561, 1561,
 1561,    0, 1561, 1561, 1561,    0,    0,    0, 1561,    0,
 1561, 1561, 1561,    0,    0,    0, 1561,    0,    0,    0,
    0,    0,    0,    0, 1561, 1561,    0, 1561,    0, 1561,
    0,    0,    0, 1561, 1561,    0, 1561,    0,    0,    0,
 1561,    0,    0,    0, 1561,    0, 1561, 1561, 1561,    0,
 1561, 1561, 1561, 1561, 1561,    0, 1561, 1561,    0,    0,
    0,    0, 1561,    0, 1561, 1561,    0,    0, 1561, 1561,
 1561,    0,    0, 1561,    0, 1561,    0,    0, 1561, 1561,
 1561, 1561,    0, 1561,    0, 1561,    0, 1561,    0, 1561,
 1561, 1561,    0,    0, 1561, 1561, 1561,    0, 1561, 1561,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1561,
 1561, 1561,    0, 1561, 1561, 1561,    0,    0,    0,    0,
    0, 1561,    0,    0,    0, 1561,    0, 1561, 1561, 1561,
 1561,    0, 1561,    0, 1561, 1561, 1561, 1561, 1561, 1561,
 1561, 1561,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1561, 1561,    0, 1561, 1561, 1561,    0,    0,    0,
    0, 1561, 1561, 1561, 1561, 1561,    0, 1561,    0,    0,
 1561, 1561,    0,    0,    0, 1561, 1561,    0,    0, 1561,
 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1561,    0, 1561,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1561,
 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1561,
 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1561,
    0, 1561, 1561, 1561, 1561, 1561, 1561,    0, 1561, 1561,
 1561, 1561,    0, 1561,    0, 1561, 1561, 1561, 1561, 1561,
 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1561,
 1561, 1561, 1561,    0, 1561, 1561, 1561, 1561,    0, 1561,
 1561, 1561, 1561, 1561,    0, 1561, 1561, 1561, 1561, 1561,
 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1561,    0, 1561,
 1561, 1561, 1561, 1561, 1561,    0, 1561, 1561, 1561, 1561,
 1561, 1561, 1561, 1561,    0, 1561, 1561,    0,    0,    0,
 1561, 1561, 1561, 1561, 1561, 1561,    0,    0, 1561, 1561,
 1561, 1561, 1561, 1561, 1561, 1561, 1561,    0,    0,    0,
    0,    0, 1561,    0, 1561, 1561, 1561, 1561, 1561, 1561,
    0, 1561,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1561, 1561,
    0, 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1561,
    0, 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1561,
 1561, 1561, 1561,    0, 1561, 1561, 1561,    0, 1561,    0,
 1560,    0, 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1561,
 1561, 1561, 1561, 1561, 1561,    0, 1561, 1561,    0,    0,
    0,    0,    0, 1561, 1561, 1561, 1561, 1561, 1561, 1561,
 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1561, 1561,
 1561, 1560,    0, 1561, 1560, 1561, 1561, 1561, 1561, 1561,
 1561, 1561, 1561, 1561,    0,    0,    0,    0,    0, 1560,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1560,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1560,    0, 1560,
    0,    0, 1560,    0, 1560, 1560,    0,    0, 1560, 1560,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1560,
 1560,    0, 1560,    0,    0,    0,    0, 1560,    0,    0,
 1560,    0,    0,    0,    0,    0,    0, 1560,    0, 1560,
 1560,    0, 1560, 1560, 1560, 1560, 1560,    0,    0, 1560,
    0,    0, 1560,    0, 1560, 1560,    0,    0,    0, 1560,
 1560,    0, 1560, 1560, 1560,    0, 1560, 1560, 1560,    0,
    0,    0, 1560,    0, 1560, 1560, 1560,    0,    0,    0,
 1560,    0,    0,    0,    0,    0,    0,    0, 1560, 1560,
    0, 1560,    0, 1560,    0,    0,    0, 1560, 1560,    0,
 1560,    0,    0,    0,    0,    0,    0,    0, 1560,    0,
 1560, 1560, 1560,    0, 1560, 1560, 1560, 1560, 1560,    0,
 1560, 1560,    0,    0,    0,    0, 1560,    0, 1560, 1560,
    0,    0, 1560, 1560, 1560,    0,    0, 1560,    0, 1560,
    0,    0, 1560, 1560, 1560, 1560,    0, 1560,    0, 1560,
    0, 1560,    0, 1560, 1560, 1560,    0,    0, 1560, 1560,
 1560,    0, 1560, 1560,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1560, 1560, 1560,    0, 1560, 1560, 1560,
    0,    0,    0,    0,    0, 1560,    0,    0,    0, 1560,
    0, 1560, 1560, 1560, 1560,    0, 1560,    0, 1560, 1560,
 1560, 1560, 1560, 1560, 1560, 1560,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1560, 1560,    0, 1560, 1560,
 1560,    0,    0,    0,    0, 1560, 1560, 1560, 1560, 1560,
    0, 1560,    0,    0, 1560, 1560,    0,    0,    0, 1560,
 1560,    0,    0, 1560, 1560, 1560, 1560, 1560, 1560, 1560,
 1560, 1560,    0, 1560,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1560, 1560, 1560, 1560, 1560, 1560, 1560,
 1560, 1560, 1560, 1560, 1560, 1560, 1560, 1560, 1560, 1560,
 1560, 1560, 1560, 1560,    0, 1560, 1560, 1560, 1560, 1560,
 1560,    0, 1560, 1560, 1560, 1560,    0, 1560,    0, 1560,
 1560, 1560, 1560, 1560, 1560, 1560, 1560, 1560, 1560, 1560,
 1560, 1560, 1560, 1560, 1560, 1560, 1560,    0, 1560, 1560,
 1560, 1560,    0, 1560, 1560, 1560, 1560, 1560,    0, 1560,
 1560, 1560, 1560, 1560, 1560, 1560, 1560, 1560, 1560, 1560,
 1560, 1560,    0, 1560, 1560, 1560, 1560, 1560, 1560,    0,
 1560, 1560, 1560, 1560, 1560, 1560, 1560, 1560,    0, 1560,
 1560,    0,    0,    0, 1560, 1560, 1560, 1560, 1560, 1560,
    0,    0, 1560, 1560, 1560, 1560, 1560, 1560, 1560, 1560,
 1560,    0,    0,    0,    0,    0, 1560,    0, 1560, 1560,
 1560, 1560, 1560, 1560,    0, 1560,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1560, 1560,    0, 1560, 1560, 1560, 1560, 1560,
 1560, 1560, 1560, 1560,    0, 1560, 1560, 1560, 1560, 1560,
 1560, 1560, 1560, 1560, 1560, 1560, 1560,    0, 1560, 1560,
 1560,    0, 1560,    0, 1559,    0, 1560, 1560, 1560, 1560,
 1560, 1560, 1560, 1560, 1560, 1560, 1560, 1560, 1560,    0,
 1560, 1560,    0,    0,    0,    0,    0, 1560, 1560, 1560,
 1560, 1560, 1560, 1560, 1560, 1560, 1560, 1560, 1560, 1560,
 1560, 1560, 1560, 1560, 1560, 1559,    0, 1560, 1559, 1560,
 1560, 1560, 1560, 1560, 1560, 1560, 1560, 1560,    0,    0,
    0,    0,    0, 1559,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1559,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1559,    0, 1559,    0,    0,    0,    0, 1559, 1559,
    0,    0, 1559, 1559,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1559, 1559,    0, 1559,    0,    0,    0,
    0, 1559,    0,    0, 1559,    0,    0,    0,    0,    0,
    0, 1559,    0, 1559, 1559,    0, 1559, 1559, 1559, 1559,
 1559,    0,    0, 1559,    0,    0, 1559,    0, 1559, 1559,
    0,    0,    0, 1559, 1559,    0, 1559, 1559, 1559,    0,
 1559, 1559, 1559,    0,    0,    0, 1559,    0, 1559, 1559,
 1559,    0,    0,    0, 1559,    0,    0,    0,    0,    0,
    0,    0, 1559, 1559,    0, 1559,    0, 1559,    0,    0,
    0, 1559, 1559,    0, 1559,    0,    0,    0,    0,    0,
    0,    0, 1559,    0, 1559, 1559, 1559,    0, 1559, 1559,
 1559, 1559, 1559,    0, 1559, 1559,    0,    0,    0,    0,
 1559,    0, 1559, 1559,    0,    0, 1559, 1559, 1559,    0,
    0, 1559,    0, 1559,    0,    0, 1559, 1559, 1559, 1559,
    0, 1559,    0, 1559,    0, 1559,    0, 1559, 1559, 1559,
    0,    0, 1559, 1559, 1559,    0, 1559, 1559,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1559, 1559, 1559,
    0, 1559, 1559, 1559,    0,    0,    0,    0,    0, 1559,
    0,    0,    0, 1559,    0, 1559, 1559, 1559, 1559,    0,
 1559,    0, 1559, 1559, 1559, 1559, 1559, 1559, 1559, 1559,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1559,
 1559,    0, 1559, 1559, 1559,    0,    0,    0,    0, 1559,
 1559, 1559, 1559, 1559,    0, 1559,    0,    0, 1559, 1559,
    0,    0,    0, 1559, 1559,    0,    0, 1559, 1559, 1559,
 1559, 1559, 1559, 1559, 1559, 1559,    0, 1559,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1559, 1559, 1559,
 1559, 1559, 1559, 1559, 1559, 1559, 1559, 1559, 1559, 1559,
 1559, 1559, 1559, 1559, 1559, 1559, 1559, 1559,    0, 1559,
 1559, 1559, 1559, 1559, 1559,    0, 1559, 1559, 1559, 1559,
    0, 1559,    0, 1559, 1559, 1559, 1559, 1559, 1559, 1559,
 1559, 1559, 1559, 1559, 1559, 1559, 1559, 1559, 1559, 1559,
 1559,    0, 1559, 1559, 1559, 1559,    0, 1559, 1559, 1559,
 1559, 1559,    0, 1559, 1559, 1559, 1559, 1559, 1559, 1559,
 1559, 1559, 1559, 1559, 1559, 1559,    0, 1559, 1559, 1559,
 1559, 1559, 1559,    0, 1559, 1559, 1559, 1559, 1559, 1559,
 1559, 1559,    0, 1559, 1559,    0,    0,    0, 1559, 1559,
 1559, 1559, 1559, 1559,    0,    0, 1559, 1559, 1559, 1559,
 1559, 1559, 1559, 1559, 1559,    0,    0,    0,    0,    0,
 1559,    0, 1559, 1559, 1559, 1559, 1559, 1559,    0, 1559,
    0,    0,    0,    0, 1392,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1559, 1559,    0, 1559,
 1559, 1559, 1559, 1559, 1559, 1559, 1559, 1559,    0, 1559,
 1559, 1559, 1559, 1559, 1559, 1559, 1559, 1559, 1559, 1559,
 1559,    0, 1559, 1559, 1559, 1392, 1559,    0, 1392,    0,
 1559, 1559, 1559, 1559, 1559, 1559, 1559, 1559, 1559, 1559,
 1559, 1559, 1559, 1392, 1559, 1559,    0,    0,    0,    0,
    0, 1559, 1559, 1559, 1559, 1559, 1559, 1559, 1559, 1559,
 1559, 1559, 1559, 1559, 1559, 1559, 1559, 1559, 1559,    0,
    0, 1559,    0, 1559, 1559, 1559, 1559, 1559, 1559, 1559,
 1559, 1559,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1392,    0, 1392,    0,    0,    0,    0, 1392, 1392,
    0,    0, 1392, 1392,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1392, 1392,    0, 1392,    0, 1392,    0,
    0, 1392,    0,    0, 1392,    0,    0,    0,    0,    0,
    0, 1392,    0, 1392, 1392,    0,    0,    0, 1392,    0,
 1392,    0,    0, 1392,    0,    0, 1392,    0,    0, 1392,
    0,    0,    0, 1392, 1392,    0, 1392, 1392, 1392,    0,
 1392, 1392, 1392,    0,    0,    0, 1392,    0, 1392, 1392,
 1392,    0,    0,    0, 1392,    0,    0,    0,    0,    0,
    0,    0, 1392, 1392,    0, 1392,    0, 1392,    0,    0,
    0, 1392, 1392,    0, 1392,    0,    0,    0,    0,    0,
    0,    0, 1392,    0, 1392,    0, 1392,    0, 1392, 1392,
 1392, 1392, 1392,    0, 1392, 1392,    0,    0,    0,    0,
 1392,    0, 1392, 1392,    0,    0, 1392, 1392,    0,    0,
    0, 1392,    0, 1392,    0,    0, 1392, 1392, 1392, 1392,
    0, 1392,    0, 1392,    0, 1392, 1392, 1392, 1392, 1392,
    0,    0,    0,    0, 1392,    0, 1392, 1392,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1392,    0, 1392,
    0, 1392, 1392, 1392,    0,    0,    0,    0,    0, 1392,
    0,    0,    0, 1392,    0, 1392, 1392, 1392, 1392,    0,
 1392,    0,    0,    0,    0,    0,    0,    0, 1392, 1392,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1392,
 1392,    0, 1392, 1392, 1392,    0,    0,    0,    0, 1392,
 1392, 1392, 1392, 1392,    0, 1392,    0,    0, 1392, 1392,
    0,    0,    0, 1392, 1392,    0,    0, 1392, 1392, 1392,
 1392, 1392, 1392, 1392, 1392, 1392,    0, 1392,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1392, 1392, 1392,
 1392, 1392, 1392, 1392, 1392, 1392, 1392, 1392, 1392, 1392,
 1392, 1392, 1392, 1392, 1392, 1392, 1392, 1392,    0, 1392,
 1392, 1392, 1392, 1392, 1392,    0, 1392, 1392, 1392, 1392,
    0, 1392,    0, 1392, 1392, 1392, 1392, 1392, 1392, 1392,
 1392, 1392, 1392, 1392, 1392, 1392, 1392, 1392, 1392, 1392,
 1392,    0, 1392, 1392, 1392, 1392,    0, 1392, 1392, 1392,
 1392, 1392,    0, 1392, 1392, 1392, 1392, 1392, 1392, 1392,
 1392, 1392, 1392, 1392, 1392, 1392,    0, 1392, 1392, 1392,
 1392, 1392, 1392,    0, 1392, 1392, 1392, 1392, 1392, 1392,
 1392, 1392,    0, 1392, 1392,    0,    0,    0, 1392, 1392,
 1392, 1392, 1392, 1392,    0,    0, 1392, 1392, 1392, 1392,
 1392, 1392, 1392, 1392, 1392,    0,    0,    0,    0,    0,
 1392,    0, 1392, 1392, 1392, 1392, 1392, 1392,    0, 1392,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1392, 1392,    0, 1392,
 1392, 1392, 1392, 1392, 1392, 1392, 1392, 1392,    0, 1392,
 1392, 1392, 1392, 1392, 1392, 1392, 1392, 1392, 1392, 1392,
 1392,    0, 1392, 1392, 1392, 1360, 1392,    0,    0,    0,
 1392, 1392, 1392, 1392, 1392, 1392, 1392, 1392, 1392, 1392,
 1392, 1392, 1392,    0, 1392, 1392,    0,    0,    0,    0,
    0, 1392, 1392, 1392, 1392, 1392, 1392, 1392, 1392, 1392,
 1392, 1392, 1392, 1392, 1392, 1360, 1360, 1392, 1392, 1360,
    0, 1392,    0, 1392, 1392, 1392, 1392, 1392, 1392, 1392,
 1392, 1392,    0,    0, 1360,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1360,    0, 1360,    0,    0,    0,    0,    0,
 1360,    0,    0, 1360, 1360,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1360, 1360,    0, 1360,    0, 1360,
    0,    0, 1360,    0,    0, 1360,    0,    0,    0,    0,
    0,    0, 1360,    0, 1360, 1360,    0,    0,    0, 1360,
    0, 1360,    0,    0, 1360,    0,    0, 1360,    0,    0,
 1360,    0,    0,    0, 1360, 1360,    0, 1360, 1360, 1360,
    0, 1360, 1360, 1360,    0,    0,    0, 1360,    0, 1360,
 1360, 1360,    0,    0,    0, 1360,    0,    0,    0,    0,
    0,    0,    0, 1360, 1360,    0, 1360,    0, 1360,    0,
    0,    0, 1360, 1360,    0, 1360,    0,    0,    0,    0,
    0,    0,    0, 1360,    0, 1360,    0, 1360,    0, 1360,
 1360, 1360, 1360, 1360,    0, 1360, 1360,    0,    0,    0,
    0, 1360,    0, 1360, 1360,    0,    0, 1360, 1360,    0,
    0,    0, 1360,    0, 1360,    0,    0, 1360, 1360, 1360,
 1360,    0, 1360,    0, 1360,    0, 1360, 1360, 1360, 1360,
 1360,    0,    0,    0,    0, 1360,    0, 1360, 1360,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1360,    0,
 1360,    0, 1360, 1360, 1360,    0,    0,    0,    0,    0,
 1360,    0,    0,    0, 1360,    0, 1360, 1360, 1360, 1360,
    0, 1360,    0,    0,    0,    0,    0,    0,    0, 1360,
 1360,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1360, 1360,    0, 1360, 1360, 1360,    0,    0,    0,    0,
 1360, 1360, 1360, 1360, 1360,    0, 1360,    0,    0, 1360,
 1360,    0,    0,    0, 1360, 1360,    0,    0, 1360, 1360,
 1360, 1360, 1360, 1360, 1360, 1360, 1360,    0, 1360,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1360, 1360,
 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,    0,
 1360, 1360, 1360, 1360, 1360, 1360,    0, 1360, 1360, 1360,
 1360,    0, 1360,    0, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360,    0, 1360, 1360, 1360, 1360,    0, 1360, 1360,
 1360, 1360, 1360,    0, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360, 1360, 1360, 1360, 1360, 1360,    0, 1360, 1360,
 1360, 1360, 1360, 1360,    0, 1360, 1360, 1360, 1360, 1360,
 1360, 1360, 1360,    0, 1360, 1360,    0,    0,    0, 1360,
 1360, 1360, 1360, 1360, 1360,    0,    0, 1360, 1360, 1360,
 1360, 1360, 1360, 1360, 1360, 1360,    0,    0,    0,    0,
    0, 1360,    0, 1360, 1360, 1360, 1360, 1360, 1360,    0,
 1360,    0,    0,    0,    0, 1389,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1360, 1360,    0,
 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,    0,
 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360,    0, 1360, 1360, 1360, 1389, 1360,    0, 1389,
    0, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360, 1360, 1360, 1389, 1360, 1360,    0,    0,    0,
    0,    0, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360, 1360, 1360, 1360, 1360,    0,    0, 1360, 1360,
    0,    0, 1360,    0, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360, 1360,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1360,    0, 1360,    0,    0,    0,    0,    0,
 1360,    0,    0, 1360, 1360,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1360, 1360,    0, 1360,    0, 1360,
    0,    0, 1360,    0,    0, 1360,    0,    0,    0,    0,
    0,    0, 1360,    0, 1360, 1360,    0,    0,    0, 1360,
    0, 1360,    0,    0, 1360,    0,    0, 1389,    0,    0,
 1389,    0,    0,    0, 1360, 1360,    0, 1389, 1389, 1360,
    0, 1360, 1389, 1360,    0,    0,    0, 1389,    0, 1360,
 1389, 1360,    0,    0,    0, 1360,    0,    0,    0,    0,
    0,    0,    0, 1360, 1389,    0, 1360,    0, 1360,    0,
    0,    0, 1360, 1360,    0, 1389,    0,    0,    0,    0,
    0,    0,    0, 1389,    0, 1360,    0, 1389,    0, 1360,
 1360, 1360, 1360, 1360,    0, 1360, 1389,    0,    0,    0,
    0, 1360,    0, 1360, 1360,    0,    0, 1360, 1360,    0,
    0,    0, 1389,    0, 1360,    0,    0, 1360, 1360, 1360,
 1360,    0, 1360,    0, 1360,    0, 1360, 1360, 1360, 1360,
 1360,    0,    0,    0,    0, 1360,    0, 1360, 1389,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1360,    0,
 1389,    0, 1389, 1360, 1360,    0,    0,    0,    0,    0,
 1360,    0,    0,    0, 1360,    0, 1360, 1360, 1360, 1360,
    0, 1360,    0,    0,    0,    0,    0,    0,    0, 1360,
 1360,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1360, 1360,    0, 1360, 1360, 1360,    0,    0,    0,    0,
 1360, 1360, 1389, 1360, 1360,    0, 1360,    0,    0, 1360,
 1360,    0,    0,    0, 1360, 1360,    0,    0, 1389, 1389,
 1360, 1360, 1360, 1389, 1360, 1360, 1360,    0, 1360,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1360,
 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,    0,
 1360, 1360, 1360, 1360, 1360, 1360,    0, 1360, 1360, 1360,
 1360,    0, 1360,    0, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360,    0, 1360, 1360, 1360, 1360,    0, 1360, 1360,
 1360, 1360, 1360,    0, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360, 1360, 1360, 1360, 1360, 1360,    0, 1360, 1360,
 1360, 1360, 1360, 1360,    0, 1360, 1360, 1360, 1360, 1360,
 1360, 1360, 1360,    0, 1360, 1360,    0,    0,    0, 1360,
 1360, 1360, 1360, 1360, 1360,    0,    0, 1360, 1360, 1360,
 1360, 1360, 1360, 1360, 1360, 1360,    0,    0,    0,    0,
    0, 1360,    0, 1360, 1360, 1360, 1360, 1360, 1360,    0,
 1389,    0,    0,    0,    0, 1391,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1360, 1360,    0,
 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,    0,
 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360,    0, 1360, 1360, 1360, 1391, 1360,    0, 1391,
    0, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360, 1360, 1360, 1391, 1360, 1360,    0,    0,    0,
    0,    0, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360, 1360, 1360, 1360, 1360,    0,    0, 1360, 1360,
    0,    0, 1389,    0, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360, 1360,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1360,    0, 1360,    0,    0,    0,    0,    0,
 1360,    0,    0, 1360, 1360,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1360, 1360,    0, 1360,    0, 1360,
    0,    0, 1360,    0,    0, 1360,    0,    0,    0,    0,
    0,    0, 1360,    0, 1360, 1360,    0,    0,    0, 1360,
    0, 1360,    0,    0, 1360,    0,    0, 1391,    0,    0,
 1391,    0,    0,    0, 1360, 1360,    0, 1391, 1391, 1360,
    0, 1360, 1391, 1360,    0,    0,    0, 1391,    0, 1360,
 1391, 1360,    0,    0,    0, 1360,    0,    0,    0,    0,
    0,    0,    0, 1360, 1391,    0, 1360,    0, 1360,    0,
    0,    0, 1360, 1360,    0, 1391,    0,    0,    0,    0,
    0,    0,    0, 1391,    0, 1360,    0, 1391,    0, 1360,
 1360, 1360, 1360, 1360,    0, 1360, 1391,    0,    0,    0,
    0, 1360,    0, 1360, 1360,    0,    0, 1360, 1360,    0,
    0,    0, 1391,    0, 1360,    0,    0, 1360, 1360, 1360,
 1360,    0, 1360,    0, 1360,    0, 1360, 1360, 1360, 1360,
 1360,    0,    0,    0,    0, 1360,    0, 1360, 1391,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1360,    0,
 1391,    0, 1391, 1360, 1360,    0,    0,    0,    0,    0,
 1360,    0,    0,    0, 1360,    0, 1360, 1360, 1360, 1360,
    0, 1360,    0,    0,    0,    0,    0,    0,    0, 1360,
 1360,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1360, 1360,    0, 1360, 1360, 1360,    0,    0,    0,    0,
 1360, 1360, 1391, 1360, 1360,    0, 1360,    0,    0, 1360,
 1360,    0,    0,    0, 1360, 1360,    0,    0, 1391, 1391,
 1360, 1360, 1360, 1391, 1360, 1360, 1360,    0, 1360,    0,
    0,    0,    0, 1396,    0,    0,    0,    0,    0, 1360,
 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,    0,
 1360, 1360, 1360, 1360, 1360, 1360,    0, 1360, 1360, 1360,
 1360,    0, 1360,    0, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360, 1396, 1360, 1360, 1360, 1360,    0, 1360, 1360,
 1360, 1360, 1360,    0, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360, 1360, 1360, 1360, 1360, 1360,    0, 1360, 1360,
 1360, 1360, 1360, 1360,    0, 1360, 1360, 1360, 1360, 1360,
 1360, 1360, 1360,    0, 1360, 1360,    0,    0,    0, 1360,
 1360, 1360, 1360, 1360, 1360,    0,    0, 1360, 1360, 1360,
 1360, 1360, 1360, 1360, 1360, 1360,    0,    0,    0,    0,
    0, 1360,    0, 1360, 1360, 1360, 1360, 1360, 1360,    0,
 1391,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1360, 1360,    0,
 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,    0,
 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360,    0, 1360, 1360, 1360,    0, 1360,    0,    0,
    0, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360, 1360, 1360,    0, 1360, 1360,    0,    0,    0,
    0,    0, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360, 1360, 1360, 1360, 1360,    0,    0, 1360, 1360,
    0,    0, 1391,    0, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360, 1360,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1360,    0, 1360,    0,    0,    0,    0,    0, 1360,    0,
    0, 1360, 1360,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1360, 1360,    0, 1360,    0, 1360,    0,    0,
 1360,    0,    0, 1360,    0,    0,    0,    0,    0,    0,
 1360,    0, 1360, 1360,    0,    0,    0, 1360,    0, 1360,
    0,    0, 1360,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1360, 1360,    0,    0,    0, 1360,    0, 1360,
    0, 1360,    0,    0,    0,    0,    0, 1360,    0, 1360,
    0,    0,    0, 1360,    0,    0,    0,    0,    0,    0,
    0, 1360,    0,    0, 1360,    0, 1360,    0,    0,    0,
 1360, 1360,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1360,    0, 1396,    0, 1360, 1360, 1360,
 1360, 1360,    0, 1360, 1396,    0,    0,    0,    0, 1360,
    0, 1360, 1360,    0,    0, 1360, 1360,    0,    0,    0,
    0,    0, 1360,    0, 1396, 1360, 1360, 1360, 1360,    0,
 1360,    0, 1360,    0, 1360, 1360, 1360, 1360, 1360,    0,
    0,    0,    0, 1360,    0, 1360,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1360,    0, 1396,    0,
    0, 1360, 1360,    0,    0,    0,    0,    0, 1360,    0,
    0,    0, 1360,    0, 1360, 1360, 1360, 1360,    0, 1360,
    0,    0,    0,    0,    0,    0,    0, 1360, 1360,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1360, 1360,
    0, 1360, 1360, 1360,    0,    0,    0,    0, 1360, 1360,
 1396, 1360, 1360,    0, 1360,    0,    0, 1360, 1360,    0,
    0,    0, 1360, 1360,    0,    0,    0, 1396, 1360, 1360,
 1360,    0, 1360, 1360, 1360,    0, 1360,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1360, 1360, 1360,
 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360, 1360, 1360, 1360, 1360, 1360,    0, 1360, 1360,
 1360, 1360, 1360, 1360,    0, 1360, 1360, 1360, 1360,    0,
 1360,    0, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,
    0, 1360, 1360, 1360, 1360,    0, 1360, 1360, 1360, 1360,
 1360,    0, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360, 1360, 1360, 1360,    0, 1360, 1360, 1360, 1360,
 1360, 1360,    0, 1360, 1360, 1360, 1360, 1360, 1360, 1360,
 1360,    0, 1360, 1360,    0,    0,    0, 1360, 1360, 1360,
 1360, 1360, 1360,    0,    0, 1360, 1360, 1360, 1360, 1360,
 1360, 1360, 1360, 1360,    0,    0,    0,    0,    0, 1360,
    0, 1360, 1360, 1360, 1360, 1360, 1360,    0,    0,    0,
    0,    0,    0, 1358,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1360, 1360,    0, 1360, 1360,
 1360, 1360, 1360, 1360, 1360, 1360, 1360,    0, 1360, 1360,
 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,
    0, 1360, 1360, 1360,    0, 1360,    0, 1358,    0, 1360,
 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360, 1358, 1360, 1360,    0,    0,    0,    0,    0,
 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360, 1360, 1360,    0,    0, 1360, 1360,    0,    0,
    0,    0, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,
 1360,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1360,    0, 1360,    0,    0,    0,    0,    0, 1360,    0,
    0, 1360, 1360,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1360, 1360,    0, 1360,    0,    0,    0,    0,
 1360,    0,    0, 1360,    0,    0,    0,    0,    0,    0,
 1360,    0, 1360, 1360,    0,    0,    0, 1360,    0, 1360,
    0,    0, 1360,    0,    0,    0,    0, 1358,    0,    0,
    0,    0, 1360, 1360,    0,    0,    0, 1360,    0, 1360,
    0, 1360,    0,    0,    0, 1358,    0, 1360,    0, 1360,
    0,    0,    0, 1360,    0,    0,    0,    0,    0,    0,
    0, 1360,    0,    0, 1360,    0, 1360,    0,    0,    0,
 1360, 1360,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1360,    0,    0,    0, 1360, 1360, 1360,
 1360, 1360,    0, 1360,    0,    0,    0,    0,    0, 1360,
    0, 1360, 1360,    0,    0, 1360, 1360,    0,    0,    0,
    0,    0, 1360,    0,    0, 1360, 1360, 1360, 1360,    0,
 1360,    0, 1360,    0, 1360,    0, 1360, 1360, 1360,    0,
    0,    0,    0, 1360,    0, 1360,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1360,    0,    0,    0,
    0, 1360, 1360,    0,    0,    0,    0,    0, 1360,    0,
    0,    0, 1360,    0, 1360, 1360, 1360, 1360,    0, 1360,
    0,    0,    0,    0,    0,    0,    0, 1360, 1360,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1360, 1360,
    0, 1360, 1360, 1360,    0,    0,    0,    0, 1360, 1360,
    0, 1360, 1360,    0, 1360,    0,    0, 1360, 1360,    0,
    0,    0, 1360, 1360,    0,    0,    0,    0, 1360, 1360,
 1360,    0, 1360, 1360, 1360,    0, 1360,    0,    0,    0,
    0, 1215,    0,    0,    0,    0, 1360, 1360, 1360, 1360,
 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360, 1360, 1360, 1360, 1360, 1360,    0, 1360, 1360,
 1360, 1360, 1360, 1360,    0, 1360, 1360, 1360, 1360,    0,
 1360,    0, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,
 1215, 1360, 1360, 1360, 1360,    0, 1360, 1360, 1360, 1360,
 1360,    0, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360, 1360, 1360, 1360,    0, 1360, 1360, 1360, 1360,
 1360, 1360,    0, 1360, 1360, 1360, 1360, 1360, 1360, 1360,
 1360,    0, 1360, 1360,    0,    0,    0, 1360, 1360, 1360,
 1360, 1360, 1360,    0,    0, 1360, 1360, 1360, 1360, 1360,
 1360, 1360, 1360, 1360,    0,    0,    0,    0,    0, 1360,
    0, 1360, 1360, 1360, 1360, 1360, 1360,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1360, 1360,    0, 1360, 1360,
 1360, 1360, 1360, 1360, 1360, 1360, 1360,    0, 1360, 1360,
 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,
    0, 1360, 1360, 1360,    0, 1360,    0,    0,    0, 1360,
 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360,    0, 1360, 1360,    0,    0,    0,    0,    0,
 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,
 1360, 1360, 1360, 1360,    0,    0, 1360, 1360,    0,    0,
    0,    0, 1360, 1360, 1360, 1360, 1360, 1360, 1360, 1360,
 1360,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1202,    0,
 1202,    0,    0,    0,    0,    0, 1202,    0,    0, 1202,
 1202,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1202, 1202,    0, 1202,    0, 1202,    0,    0, 1202,    0,
    0, 1202,    0,    0,    0,    0,    0,    0, 1202,    0,
 1202, 1202,    0,    0,    0, 1202,    0, 1202,    0,    0,
 1202,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1202, 1202,    0,    0,    0, 1202,    0, 1202,    0, 1202,
    0,    0,    0,    0,    0, 1202,    0, 1202,    0,    0,
    0, 1202,    0,    0,    0,    0,    0,    0,    0, 1202,
    0,    0, 1202,    0, 1202,    0,    0,    0, 1202, 1202,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1202,    0,    0,    0, 1202, 1202, 1202, 1202, 1202,
    0, 1202,    0,    0,    0,    0,    0, 1202,    0, 1202,
 1202,    0,    0, 1202, 1202,    0,    0,    0,    0,    0,
 1202,    0,    0, 1202, 1202, 1202, 1202,    0, 1202,    0,
 1202,    0, 1202, 1202, 1202, 1202, 1202,    0,    0,    0,
    0, 1202,    0, 1202,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1202,    0,    0,    0,    0, 1202,
 1202,    0,    0,    0,    0,    0, 1202,    0,    0,    0,
 1202,    0, 1202, 1202, 1202, 1202,    0, 1202,    0,    0,
    0,    0,    0,    0,    0, 1202, 1202,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1202, 1202,    0, 1202,
 1202, 1202,    0,    0,    0,    0, 1202, 1202,    0, 1202,
 1202,    0, 1202,    0,    0, 1202, 1202,    0,    0,    0,
 1202, 1202,    0,    0,    0,    0, 1202, 1202, 1202,    0,
 1202, 1202, 1202,    0, 1202,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1202, 1202, 1202, 1202, 1202, 1202,
 1202, 1202, 1202, 1202, 1202, 1202, 1202, 1202, 1202, 1202,
 1202, 1202, 1202, 1202, 1202,    0, 1202, 1202, 1202, 1202,
 1202, 1202,    0, 1202, 1202, 1202, 1202,    0, 1202,    0,
 1202, 1202, 1202, 1202, 1202, 1202, 1202, 1202, 1202, 1202,
 1202, 1202, 1202, 1202, 1202, 1202, 1202, 1202,    0, 1202,
 1202, 1202, 1202,    0, 1202, 1202, 1202, 1202, 1202,    0,
 1202, 1202, 1202, 1202, 1202, 1202, 1202, 1202, 1202, 1202,
 1202, 1202, 1202,    0, 1202, 1202, 1202, 1202, 1202, 1202,
    0, 1202, 1202, 1202, 1202, 1202, 1202, 1202, 1202,    0,
 1202, 1202,    0,    0,    0, 1202, 1202, 1202, 1202, 1202,
 1202,    0,    0, 1202, 1202, 1202, 1202, 1202, 1202, 1202,
 1202, 1202,    0, 1314,    0,    0, 1024, 1202, 1025, 1202,
 1202, 1202, 1202, 1202, 1202,    0,    0,    0,    0,    0,
    0, 1027,    0,    0,    0,    0, 1028,    0,    0,    0,
    0,    0,    0, 1202, 1202,    0, 1202, 1202, 1202, 1202,
 1202, 1202, 1202, 1202, 1202,    0, 1202, 1202, 1202, 1202,
 1202, 1202, 1202, 1202, 1202, 1202, 1202, 1202,    0, 1202,
 1202, 1202,    0, 1202,    0,    0,    0, 1202, 1202, 1202,
 1202, 1202, 1202, 1202, 1202, 1202, 1202, 1202, 1202, 1202,
    0, 1202, 1202,    0,    0,    0,    0,    0, 1202, 1202,
 1202, 1202, 1202, 1202, 1202, 1202, 1202, 1202, 1202, 1202,
 1202, 1202,    0,    0, 1202, 1202,    0,    0,    0,    0,
 1202, 1202, 1202, 1202, 1202, 1202, 1202, 1202, 1202,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  154,    0,  155,    0,    0,    0,    0,    0,  156,    0,
  854,  157,  158,    0,    0,    0,    0,  855,    0,    0,
    0,    0,  159,  160,    0,  161,    0,  162,  856,    0,
  163,    0,    0,  164,  857,  858,    0,    0,    0,    0,
  165,    0,  166,  167,    0,    0,    0,  168,    0,  169,
    0,  859,  170,    0,    0,    0,    0,    0,    0,    0,
  860,    0,  171,  861,    0,    0,    0,  173,    0,  174,
    0,  175,    0,    0,    0,    0,    0,  176,    0,  177,
    0,    0,    0,  178,    0,    0,    0,  862,    0,  863,
  864,  179,  865,    0,  180,    0,  181,  866,    0,  867,
  182,  183,    0,    0,    0,    0,    0,  868,    0,    0,
    0,    0,    0,  184,    0,    0,    0,  186,  187,  188,
  189,  190,    0,  191,    0,  869,    0,    0,    0,  192,
    0,  193,  194,    0,    0,  195,  196,    0,    0,    0,
  870,    0,  197,    0,    0,  198,  199,  871,  201,    0,
  202,    0,  203,  872,  204,  205,  206,  207,  208,  873,
    0,    0,    0,  209,    0,  210,    0,    0,    0,  874,
    0,    0,    0,    0,    0,    0,  211,    0,    0,    0,
    0,  212,  213,  875,  876,  877,  878,  879,  880,  881,
  606,  607,  215,    0,  216,  217,  218,  219,    0,  220,
  882, 1706, 1707, 1708, 1709, 1710, 1711, 1741, 1742,  883,
  884,  885,  886,  887,  888,  889,  890,  891,  223,  892,
    0,  225,  226,  227,  893,  894,    0,  895,  896,  897,
    0,  230,  231,  898,  232,    0,    0,  233,  234,  899,
  900,  901,  235,  236,    0,    0,    0,    0,  237,  902,
  239,    0,  903,  241,  242,    0,  243,    0,  904,  905,
  906,    0,  907,  908,    0,  909,  244,  245,  246,  247,
  248,  249,  910,  251,  911,  253,  912,  913,  914,  915,
  916,  917,  918,  919,  920,  921,  922,    0,  923,  924,
  925,  926,  927,  928,    0,  929,  930,  931,  274,    0,
  932,    0,  933,  934,  935,  936,  937,  281,  282,  938,
 1743,  939,  940,  941,  288,  942,  290,  943,  292,  944,
    0,  945,  946,  947,  948,    0,  949,  950,  951,  301,
  952,    0,  953,  954,  305,  955, 1744,  308,  956,  310,
  311,  312,  313,  314,  315,    0,  957,  317,  318,  319,
  320,  321,    0,  958,  323,  324,  325,  959,  960,  328,
  329,    0,  330,  331,  961,  962,    0,  332,  333,  334,
  963,  964,  965,    0,    0,  338,  966,  967,  968,  969,
  970,  971,  972,  973,  974,    0,  975,  976,  977,  347,
  978,  348,  349,  350,  351,  352,  353,    0,    0,  979,
  980,  981,  982,  983,  984,  985,  986,  987,  988,  989,
  990,  991,  992,  993,  994,  995,  996,    0,  356,  997,
  358,  359,  998,  361,  362,  363,  999,    0,  365,  366,
  367,  368,  369,  370, 1000,  372, 1001, 1002,  375,  376,
    0,  377,  378, 1003,    0,  380,    0, 1004, 1005,  381,
 1006,  383,  384,  385, 1007, 1008,  388,  389,  390, 1009,
  392,  393,    0, 1010,  395, 1011, 1012, 1013, 1014, 1015,
  396, 1016, 1017, 1018, 1019, 1020, 1021,  403,  404,  405,
  406,  407,  408,  409, 1716, 1717, 1022,  411,    0,    0,
    0,    0,  412,  413,  414,  415,  416,  417,  418,  419,
 1023, 1314,    0,    0, 1024,    0, 1025,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1027,
    0,    0,    0,    0, 1028,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  154,    0,
  155,    0,    0,    0,    0,    0,  156,    0,  854,  157,
  158,    0,    0,    0,    0,  855,    0,    0,    0,    0,
  159,  160,    0,  161,    0,  162,  856,    0,  163,    0,
    0,  164,  857,  858,    0,    0,    0,    0,  165,    0,
  166,  167,    0,    0,    0,  168,    0,  169,    0,  859,
  170,    0,    0,    0,    0,    0,    0,    0,  860,    0,
  171,  861,    0,    0,    0,  173,    0,  174,    0,  175,
    0,    0,    0,    0,    0,  176,    0,  177,    0,    0,
    0,  178,    0,    0,    0,  862,    0,  863,  864,  179,
  865,    0,  180,    0,  181,  866,    0,  867,  182,  183,
    0,    0,    0,    0,    0,  868,    0,    0,    0,    0,
    0,  184,    0,    0,    0,  186,  187,  188,  189,  190,
    0,  191,    0,  869,    0,    0,    0,  192,    0,  193,
  194,    0,    0,  195,  196,    0,    0,    0,  870,    0,
  197,    0,    0,  198,  199,  871,  201,    0,  202,    0,
  203,  872,  204,  205,  206,  207,  208,  873,    0,    0,
    0,  209,    0,  210,    0,    0,    0,  874,    0,    0,
    0,    0,    0,    0,  211,    0,    0,    0,    0,  212,
  213,  875,  876,  877,  878,  879,  880,  881,  606,  607,
  215,    0,  216,  217,  218,  219,    0,  220,  882,    0,
    0,    0,    0,    0,    0,  221,  222,  883,  884,  885,
  886,  887,  888,  889,  890,  891,  223,  892,    0,  225,
  226,  227,  893,  894,    0,  895,  896,  897,    0,  230,
  231,  898,  232,    0,    0,  233,  234,  899,  900,  901,
  235,  236,    0,    0,    0,    0,  237,  902,  239,    0,
  903,  241,  242, 1736,  243,    0,  904,  905,  906, 1737,
  907,  908, 1738,  909,  244,  245,  246,  247,  248,  249,
  910,  251,  911,  253,  912,  913,  914,  915,  916,  917,
  918,  919,  920,  921,  922,    0,  923,  924,  925,  926,
  927,  928,    0,  929,  930,  931,  274,    0,  932,    0,
  933,  934,  935,  936,  937,  281,  282,  938,  284,  939,
  940,  941,  288,  942,  290,  943,  292,  944,    0,  945,
  946,  947,  948,    0,  949,  950,  951,  301,  952,    0,
  953,  954,  305,  955,  307,  308,  956,  310,  311,  312,
  313,  314,  315,    0,  957,  317,  318,  319,  320,  321,
    0,  958,  323,  324,  325,  959,  960,  328,  329,    0,
  330,  331,  961,  962,    0,  332,  333,  334,  963,  964,
  965,    0,    0,  338,  966,  967,  968,  969,  970,  971,
  972,  973,  974,    0,  975,  976,  977,  347,  978,  348,
  349,  350,  351,  352,  353,    0,    0,  979,  980,  981,
  982,  983,  984,  985,  986,  987,  988,  989,  990,  991,
  992,  993,  994,  995,  996,    0,  356,  997,  358,  359,
  998,  361,  362,  363,  999,    0,  365,  366,  367,  368,
  369,  370, 1000,  372, 1001, 1002,  375,  376,    0,  377,
  378, 1003,    0,  380,    0, 1004, 1005,  381, 1006,  383,
  384,  385, 1007, 1008,  388,  389,  390, 1009,  392,  393,
    0, 1010,  395, 1011, 1012, 1013, 1014, 1015,  396, 1016,
 1017, 1018, 1019, 1020, 1021,  403,  404,  405,  406,  407,
  408,  409,    0, 1314, 1022,  411, 1024,    0, 1025,    0,
  412,  413,  414,  415,  416,  417,  418,  419, 1023,    0,
    0, 1027,    0,    0,    0,    0, 1028,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  154,    0,  155, 1827,    0,    0, 1828,    0,  156,    0,
  854,  157,  158,    0,    0,    0,    0,  855,    0,    0,
    0,    0,  159,  160,    0,  161,    0,  162,  856,    0,
  163,    0,    0,  164,  857,  858,    0,    0,    0,    0,
  165,    0,  166,  167,    0,    0,    0,  168,    0,  169,
    0,  859,  170,    0,    0,    0,    0,    0,    0,    0,
  860,    0,  171,  861,    0,    0,    0,  173,    0,  174,
    0,  175,    0,    0,    0,    0,    0,  176,    0,  177,
    0,    0,    0,  178,    0,    0,    0,  862,    0,  863,
  864,  179,  865,    0,  180,    0,  181,  866,    0,  867,
  182,  183,    0,    0,    0,    0,    0,  868,    0,    0,
    0,    0,    0,  184,    0,    0,    0,  186,  187,  188,
  189,  190,    0,  191,    0,  869,    0,    0,    0,  192,
    0,  193,  194,    0,    0,  195,  196,    0,    0,    0,
  870,    0,  197,    0,    0,  198,  199,  871,  201,    0,
  202, 1829,  203,  872,  204,  205,  206,  207,  208,  873,
    0,    0,    0,  209,    0,  210,    0,    0,    0,  874,
    0,    0,    0,    0,    0,    0,  211,    0,    0,    0,
    0,  212,  213,  875,  876,  877,  878,  879,  880,  881,
  606,  607,  215,    0,  216,  217,  218,  219,    0,  220,
  882,    0,    0,    0,    0,    0,    0,  221,  222,  883,
  884,  885,  886,  887,  888,  889,  890,  891,  223,  892,
    0,  225,  226,  227,  893,  894,    0,  895,  896,  897,
    0,  230,  231,  898,  232,    0,    0,  233,  234,  899,
  900,  901,  235,  236,    0,    0,    0,    0,  237,  902,
  239,    0,  903,  241,  242,    0,  243,    0,  904,  905,
  906,    0,  907,  908,    0,  909,  244,  245,  246,  247,
  248,  249,  910,  251,  911,  253,  912,  913,  914,  915,
  916,  917,  918,  919,  920,  921,  922,    0,  923,  924,
  925,  926,  927,  928,    0,  929,  930,  931,  274,    0,
  932,    0,  933,  934,  935,  936,  937,  281,  282,  938,
  284,  939,  940,  941,  288,  942,  290,  943,  292,  944,
    0,  945,  946,  947,  948,    0,  949,  950,  951,  301,
  952,    0,  953,  954,  305,  955,  307,  308,  956,  310,
  311,  312,  313,  314,  315,    0,  957,  317,  318,  319,
  320,  321,    0,  958,  323,  324,  325,  959,  960,  328,
  329,    0,  330,  331,  961,  962,    0,  332,  333,  334,
  963,  964,  965,    0,    0,  338,  966,  967,  968,  969,
  970,  971,  972,  973,  974,    0,  975,  976,  977,  347,
  978,  348,  349,  350,  351,  352,  353,    0,    0,  979,
  980,  981,  982,  983,  984,  985,  986,  987,  988,  989,
  990,  991,  992,  993,  994,  995,  996,    0,  356,  997,
  358,  359,  998,  361,  362,  363,  999,    0,  365,  366,
  367,  368,  369,  370, 1000,  372, 1001, 1002,  375,  376,
    0,  377,  378, 1003,    0,  380,    0, 1004, 1005,  381,
 1006,  383,  384,  385, 1007, 1008,  388,  389,  390, 1009,
  392,  393,    0, 1010,  395, 1011, 1012, 1013, 1014, 1015,
  396, 1016, 1017, 1018, 1019, 1020, 1021,  403,  404,  405,
  406,  407,  408,  409,    0, 1314, 1022,  411, 1024,    0,
 1025,    0,  412,  413,  414,  415,  416,  417,  418,  419,
 1023,    0,    0, 1027,    0,    0,    0,    0, 1028,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  154,    0,  155,    0,    0,    0,    0,    0,
  156,    0,  854,  157,  158,    0, 3759,    0,    0,  855,
    0,    0,    0,    0,  159,  160,    0,  161,    0,  162,
  856,    0,  163, 3760,    0,  164,  857,  858,    0,    0,
    0,    0,  165,    0,  166,  167,    0,    0,    0,  168,
    0,  169,    0,  859,  170,    0,    0,    0,    0,    0,
    0,    0,  860,    0,  171,  861,    0,    0,    0,  173,
    0,  174,    0,  175,    0,    0,    0,    0,    0,  176,
    0,  177,    0,    0,    0,  178,    0,    0,    0,  862,
    0,  863,  864,  179,  865,    0,  180,    0,  181,  866,
    0,  867,  182,  183,    0,    0,    0,    0,    0,  868,
    0,    0,    0,    0,    0,  184,    0,    0,    0,  186,
  187,  188,  189,  190,    0,  191,    0,  869,    0,    0,
    0,  192,    0,  193,  194,    0,    0,  195,  196,    0,
    0,    0,  870,    0,  197,    0,    0,  198,  199,  871,
  201,    0,  202,    0,  203,  872,  204,  205,  206,  207,
  208,  873,    0,    0,    0,  209,    0,  210,    0,    0,
    0,  874,    0,    0,    0,    0,    0,    0,  211,    0,
    0,    0,    0,  212,  213,  875,  876,  877,  878,  879,
  880,  881,  606,  607,  215,    0,  216,  217,  218,  219,
    0,  220,  882,    0,    0,    0,    0,    0,    0,  221,
  222,  883,  884,  885,  886,  887,  888,  889,  890,  891,
  223,  892,    0,  225,  226,  227,  893,  894,    0,  895,
  896,  897,    0,  230,  231,  898,  232,    0,    0,  233,
  234,  899,  900,  901,  235,  236,    0,    0,    0,    0,
  237,  902,  239,    0,  903,  241,  242,    0,  243,    0,
  904,  905,  906,    0,  907,  908,    0,  909,  244,  245,
  246,  247,  248,  249,  910,  251,  911,  253,  912,  913,
  914,  915,  916,  917,  918,  919,  920,  921,  922,    0,
  923,  924,  925,  926,  927,  928,    0,  929,  930,  931,
  274,    0,  932,    0,  933,  934,  935,  936,  937,  281,
  282,  938,  284,  939,  940,  941,  288,  942,  290,  943,
  292,  944,    0,  945,  946,  947,  948,    0,  949,  950,
  951,  301,  952,    0,  953,  954,  305,  955,  307,  308,
  956,  310,  311,  312,  313,  314,  315,    0,  957,  317,
  318,  319,  320,  321,    0,  958,  323,  324,  325,  959,
  960,  328,  329,    0,  330,  331,  961,  962,    0,  332,
  333,  334,  963,  964,  965,    0,    0,  338,  966,  967,
  968,  969,  970,  971,  972,  973,  974,    0,  975,  976,
  977,  347,  978,  348,  349,  350,  351,  352,  353,    0,
    0,  979,  980,  981,  982,  983,  984,  985,  986,  987,
  988,  989,  990,  991,  992,  993,  994,  995,  996,    0,
  356,  997,  358,  359,  998,  361,  362,  363,  999,    0,
  365,  366,  367,  368,  369,  370, 1000,  372, 1001, 1002,
  375,  376,    0,  377,  378, 1003,    0,  380,    0, 1004,
 1005,  381, 1006,  383,  384,  385, 1007, 1008,  388,  389,
  390, 1009,  392,  393,    0, 1010,  395, 1011, 1012, 1013,
 1014, 1015,  396, 1016, 1017, 1018, 1019, 1020, 1021,  403,
  404,  405,  406,  407,  408,  409,    0,    0, 1022,  411,
 3761,    0,    0,    0,  412,  413,  414,  415,  416,  417,
  418,  419, 1023, 1314,    0,    0, 1024,    0, 1025,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1027,    0,    0,    0,    0, 1028,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  154,    0,  155,    0,    0,    0,    0,    0,  156,    0,
  854,  157,  158,    0,    0,    0,    0,  855,    0,    0,
    0,    0,  159,  160,    0,  161,    0,  162,  856,    0,
  163, 3852,    0,  164,  857,  858,    0,    0,    0,    0,
  165,    0,  166,  167,    0,    0,    0,  168,    0,  169,
    0,  859,  170,    0,    0,    0,    0,    0,    0,    0,
  860,    0,  171,  861,    0,    0,    0,  173,    0,  174,
    0,  175,    0,    0,    0,    0,    0,  176,    0,  177,
    0,    0,    0,  178,    0,    0,    0,  862,    0,  863,
  864,  179,  865,    0,  180,    0,  181,  866,    0,  867,
  182,  183,    0,    0,    0,    0,    0,  868,    0,    0,
    0,    0,    0,  184,    0,    0,    0,  186,  187,  188,
  189,  190,    0,  191,    0,  869,    0,    0,    0,  192,
    0,  193,  194,    0,    0,  195,  196,    0,    0,    0,
  870,    0,  197,    0,    0,  198,  199,  871,  201,    0,
  202,    0,  203,  872,  204,  205,  206,  207,  208,  873,
    0,    0,    0,  209,    0,  210,    0,    0,    0,  874,
    0,    0,    0,    0,    0,    0,  211,    0,    0,    0,
    0,  212,  213,  875,  876,  877,  878,  879,  880,  881,
  606,  607,  215,    0,  216,  217,  218,  219,    0,  220,
  882,    0,    0,    0,    0,    0,    0,  221,  222,  883,
  884,  885,  886,  887,  888,  889,  890,  891,  223,  892,
    0,  225,  226,  227,  893,  894,    0,  895,  896,  897,
    0,  230,  231,  898,  232,    0,    0,  233,  234,  899,
  900,  901,  235,  236,    0,    0,    0,    0,  237,  902,
  239,    0,  903,  241,  242,    0,  243,    0,  904,  905,
  906,    0,  907,  908,    0,  909,  244,  245,  246,  247,
  248,  249,  910,  251,  911,  253,  912,  913,  914,  915,
  916,  917,  918,  919,  920,  921,  922,    0,  923,  924,
  925,  926,  927,  928,    0,  929,  930,  931,  274,    0,
  932,    0,  933,  934,  935,  936,  937,  281,  282,  938,
  284,  939,  940,  941,  288,  942,  290,  943,  292,  944,
    0,  945,  946,  947,  948,    0,  949,  950,  951,  301,
  952,    0,  953,  954,  305,  955,  307,  308,  956,  310,
  311,  312,  313,  314,  315,    0,  957,  317,  318,  319,
  320,  321,    0,  958,  323,  324,  325,  959,  960,  328,
  329,    0,  330,  331,  961,  962,    0,  332,  333,  334,
  963,  964,  965,    0,    0,  338,  966,  967,  968,  969,
  970,  971,  972,  973,  974,    0,  975,  976,  977,  347,
  978,  348,  349,  350,  351,  352,  353,    0,    0,  979,
  980,  981,  982,  983,  984,  985,  986,  987,  988,  989,
  990,  991,  992,  993,  994,  995,  996,    0,  356,  997,
  358,  359,  998,  361,  362,  363,  999,    0,  365,  366,
  367,  368,  369,  370, 1000,  372, 1001, 1002,  375,  376,
    0,  377,  378, 1003,    0,  380,    0, 1004, 1005,  381,
 1006,  383,  384,  385, 1007, 1008,  388,  389,  390, 1009,
  392,  393,    0, 1010,  395, 1011, 1012, 1013, 1014, 1015,
  396, 1016, 1017, 1018, 1019, 1020, 1021,  403,  404,  405,
  406,  407,  408,  409,    0,    0, 1022,  411, 3853,    0,
    0,    0,  412,  413,  414,  415,  416,  417,  418,  419,
 1023, 1314,    0,    0, 1024,    0, 1025,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1027,
    0,    0,    0,    0, 1028,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  154,    0,
  155,    0,    0,    0,    0,    0,  156,    0,  854,  157,
  158,    0,    0,    0,    0,  855,    0,    0,    0,    0,
  159,  160,    0,  161,    0,  162,  856,    0,  163, 3935,
    0,  164,  857,  858,    0,    0,    0,    0,  165,    0,
  166,  167,    0,    0,    0,  168,    0,  169,    0,  859,
  170,    0,    0,    0,    0,    0,    0,    0,  860,    0,
  171,  861,    0,    0,    0,  173,    0,  174,    0,  175,
    0,    0,    0,    0,    0,  176,    0,  177,    0,    0,
    0,  178,    0,    0,    0,  862,    0,  863,  864,  179,
  865,    0,  180,    0,  181,  866,    0,  867,  182,  183,
    0,    0,    0,    0,    0,  868,    0,    0,    0,    0,
    0,  184,    0,    0,    0,  186,  187,  188,  189,  190,
    0,  191,    0,  869,    0,    0,    0,  192,    0,  193,
  194,    0,    0,  195,  196,    0,    0,    0,  870,    0,
  197,    0,    0,  198,  199,  871,  201,    0,  202,    0,
  203,  872,  204,  205,  206,  207,  208,  873,    0,    0,
    0,  209,    0,  210,    0,    0,    0,  874,    0,    0,
    0,    0,    0,    0,  211,    0,    0,    0,    0,  212,
  213,  875,  876,  877,  878,  879,  880,  881,  606,  607,
  215,    0,  216,  217,  218,  219,    0,  220,  882,    0,
    0,    0,    0,    0,    0,  221,  222,  883,  884,  885,
  886,  887,  888,  889,  890,  891,  223,  892,    0,  225,
  226,  227,  893,  894,    0,  895,  896,  897,    0,  230,
  231,  898,  232,    0,    0,  233,  234,  899,  900,  901,
  235,  236,    0,    0,    0,    0,  237,  902,  239,    0,
  903,  241,  242,    0,  243,    0,  904,  905,  906,    0,
  907,  908,    0,  909,  244,  245,  246,  247,  248,  249,
  910,  251,  911,  253,  912,  913,  914,  915,  916,  917,
  918,  919,  920,  921,  922,    0,  923,  924,  925,  926,
  927,  928,    0,  929,  930,  931,  274,    0,  932,    0,
  933,  934,  935,  936,  937,  281,  282,  938,  284,  939,
  940,  941,  288,  942,  290,  943,  292,  944,    0,  945,
  946,  947,  948,    0,  949,  950,  951,  301,  952,    0,
  953,  954,  305,  955,  307,  308,  956,  310,  311,  312,
  313,  314,  315,    0,  957,  317,  318,  319,  320,  321,
    0,  958,  323,  324,  325,  959,  960,  328,  329,    0,
  330,  331,  961,  962,    0,  332,  333,  334,  963,  964,
  965,    0,    0,  338,  966,  967,  968,  969,  970,  971,
  972,  973,  974,    0,  975,  976,  977,  347,  978,  348,
  349,  350,  351,  352,  353,    0,    0,  979,  980,  981,
  982,  983,  984,  985,  986,  987,  988,  989,  990,  991,
  992,  993,  994,  995,  996,    0,  356,  997,  358,  359,
  998,  361,  362,  363,  999,    0,  365,  366,  367,  368,
  369,  370, 1000,  372, 1001, 1002,  375,  376,    0,  377,
  378, 1003,    0,  380,    0, 1004, 1005,  381, 1006,  383,
  384,  385, 1007, 1008,  388,  389,  390, 1009,  392,  393,
    0, 1010,  395, 1011, 1012, 1013, 1014, 1015,  396, 1016,
 1017, 1018, 1019, 1020, 1021,  403,  404,  405,  406,  407,
  408,  409,    0,    0, 1022,  411, 3936,    0,    0,    0,
  412,  413,  414,  415,  416,  417,  418,  419, 1023, 1342,
    0, 1342, 1342,    0, 1342,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1342,    0,    0,
    0,    0, 1342,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1342,    0, 1342, 1342,
    0,    0,    0,    0, 1342,    0, 1342, 1342, 1342,    0,
    0,    0,    0, 1342,    0,    0,    0,    0, 1342, 1342,
    0, 1342,    0, 1342, 1342,    0, 1342,    0,    0, 1342,
 1342, 1342,    0,    0,    0,    0, 1342, 1342, 1342, 1342,
    0,    0,    0, 1342,    0, 1342,    0, 1342, 1342,    0,
    0,    0,    0,    0,    0,    0, 1342,    0, 1342, 1342,
    0,    0,    0, 1342,    0, 1342,    0, 1342,    0,    0,
    0,    0,    0, 1342,    0, 1342,    0,    0,    0, 1342,
    0,    0,    0, 1342,    0, 1342, 1342, 1342, 1342,    0,
 1342,    0, 1342, 1342,    0, 1342, 1342, 1342,    0,    0,
    0,    0,    0, 1342,    0,    0,    0,    0,    0, 1342,
    0,    0,    0, 1342, 1342, 1342, 1342, 1342,    0, 1342,
    0, 1342,    0,    0,    0, 1342,    0, 1342, 1342,    0,
    0, 1342, 1342,    0,    0,    0, 1342,    0, 1342,    0,
    0, 1342, 1342, 1342, 1342,    0, 1342,    0, 1342, 1342,
 1342, 1342, 1342, 1342, 1342, 1342,    0,    0,    0, 1342,
    0, 1342,    0,    0,    0, 1342,    0,    0,    0,    0,
    0,    0, 1342,    0,    0,    0,    0, 1342, 1342, 1342,
 1342, 1342, 1342, 1342, 1342, 1342, 1342, 1342, 1342,    0,
 1342, 1342, 1342, 1342,    0, 1342, 1342,    0,    0,    0,
    0,    0,    0, 1342, 1342, 1342, 1342, 1342, 1342, 1342,
 1342, 1342, 1342, 1342, 1342, 1342,    0, 1342, 1342,    0,
 1342, 1342,    0, 1342, 1342, 1342,    0, 1342, 1342, 1342,
 1342,    0,    0, 1342, 1342, 1342, 1342, 1342, 1342, 1342,
    0,    0,    0,    0, 1342, 1342, 1342,    0, 1342, 1342,
 1342,    0, 1342,    0, 1342, 1342, 1342,    0, 1342, 1342,
    0, 1342, 1342, 1342, 1342, 1342, 1342, 1342, 1342, 1342,
 1342, 1342, 1342, 1342, 1342, 1342, 1342, 1342, 1342, 1342,
 1342, 1342, 1342,    0, 1342, 1342, 1342, 1342, 1342, 1342,
    0, 1342, 1342, 1342, 1342,    0, 1342,    0, 1342, 1342,
 1342, 1342, 1342, 1342, 1342, 1342, 1342, 1342, 1342, 1342,
 1342, 1342, 1342, 1342, 1342, 1342,    0, 1342, 1342, 1342,
 1342,    0, 1342, 1342, 1342, 1342, 1342,    0, 1342, 1342,
 1342, 1342, 1342, 1342, 1342, 1342, 1342, 1342, 1342, 1342,
 1342,    0, 1342, 1342, 1342, 1342, 1342, 1342,    0, 1342,
 1342, 1342, 1342, 1342, 1342, 1342, 1342,    0, 1342, 1342,
 1342, 1342,    0, 1342, 1342, 1342, 1342, 1342, 1342,    0,
    0, 1342, 1342, 1342, 1342, 1342, 1342, 1342, 1342, 1342,
 1342,    0, 1342, 1342, 1342, 1342, 1342, 1342, 1342, 1342,
 1342, 1342, 1342,    0,    0, 1342, 1342, 1342, 1342, 1342,
 1342, 1342, 1342, 1342, 1342, 1342, 1342, 1342, 1342, 1342,
 1342, 1342, 1342,    0, 1342, 1342, 1342, 1342, 1342, 1342,
 1342, 1342, 1342,    0, 1342, 1342, 1342, 1342, 1342, 1342,
 1342, 1342, 1342, 1342, 1342, 1342,    0, 1342, 1342, 1342,
    0, 1342,    0, 1342, 1342, 1342, 1342, 1342, 1342, 1342,
 1342, 1342, 1342, 1342, 1342, 1342, 1342, 1342,    0, 1342,
 1342, 1342, 1342, 1342, 1342, 1342, 1342, 1342, 1342, 1342,
 1342, 1342, 1342, 1342, 1342, 1342, 1342, 1342, 1342, 1342,
    0, 1314, 1342, 1342, 1024,    0, 1025,    0, 1342, 1342,
 1342, 1342, 1342, 1342, 1342, 1342, 1342,    0,    0, 1027,
    0,    0,    0,    0, 1028,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  154,    0,
  155,    0,    0,    0,    0,    0,  156,    0,  854,  157,
  158,    0,    0,    0,    0,  855,    0,    0,    0,    0,
  159,  160,    0,  161,    0,  162,  856,    0,  163, 1313,
    0,  164,  857,  858,    0,    0,    0,    0,  165,    0,
  166,  167,    0,    0,    0,  168,    0,  169,    0,  859,
  170,    0,    0,    0,    0,    0,    0,    0,  860,    0,
  171,  861,    0,    0,    0,  173,    0,  174,    0,  175,
    0,    0,    0,    0,    0,  176,    0,  177,    0,    0,
    0,  178,    0,    0,    0,  862,    0,  863,  864,  179,
  865,    0,  180,    0,  181,  866,    0,  867,  182,  183,
    0,    0,    0,    0,    0,  868,    0,    0,    0,    0,
    0,  184,    0,    0,    0,  186,  187,  188,  189,  190,
    0,  191,    0,  869,    0,    0,    0,  192,    0,  193,
  194,    0,    0,  195,  196,    0,    0,    0,  870,    0,
  197,    0,    0,  198,  199,  871,  201,    0,  202,    0,
  203,  872,  204,  205,  206,  207,  208,  873,    0,    0,
    0,  209,    0,  210,    0,    0,    0,  874,    0,    0,
    0,    0,    0,    0,  211,    0,    0,    0,    0,  212,
  213,  875,  876,  877,  878,  879,  880,  881,  606,  607,
  215,    0,  216,  217,  218,  219,    0,  220,  882,    0,
    0,    0,    0,    0,    0,  221,  222,  883,  884,  885,
  886,  887,  888,  889,  890,  891,  223,  892,    0,  225,
  226,  227,  893,  894,    0,  895,  896,  897,    0,  230,
  231,  898,  232,    0,    0,  233,  234,  899,  900,  901,
  235,  236,    0,    0,    0,    0,  237,  902,  239,    0,
  903,  241,  242,    0,  243,    0,  904,  905,  906,    0,
  907,  908,    0,  909,  244,  245,  246,  247,  248,  249,
  910,  251,  911,  253,  912,  913,  914,  915,  916,  917,
  918,  919,  920,  921,  922,    0,  923,  924,  925,  926,
  927,  928,    0,  929,  930,  931,  274,    0,  932,    0,
  933,  934,  935,  936,  937,  281,  282,  938,  284,  939,
  940,  941,  288,  942,  290,  943,  292,  944,    0,  945,
  946,  947,  948,    0,  949,  950,  951,  301,  952,    0,
  953,  954,  305,  955,  307,  308,  956,  310,  311,  312,
  313,  314,  315,    0,  957,  317,  318,  319,  320,  321,
    0,  958,  323,  324,  325,  959,  960,  328,  329,    0,
  330,  331,  961,  962,    0,  332,  333,  334,  963,  964,
  965,    0,    0,  338,  966,  967,  968,  969,  970,  971,
  972,  973,  974,    0,  975,  976,  977,  347,  978,  348,
  349,  350,  351,  352,  353,    0,    0,  979,  980,  981,
  982,  983,  984,  985,  986,  987,  988,  989,  990,  991,
  992,  993,  994,  995,  996,    0,  356,  997,  358,  359,
  998,  361,  362,  363,  999,    0,  365,  366,  367,  368,
  369,  370, 1000,  372, 1001, 1002,  375,  376,    0,  377,
  378, 1003,    0,  380,    0, 1004, 1005,  381, 1006,  383,
  384,  385, 1007, 1008,  388,  389,  390, 1009,  392,  393,
    0, 1010,  395, 1011, 1012, 1013, 1014, 1015,  396, 1016,
 1017, 1018, 1019, 1020, 1021,  403,  404,  405,  406,  407,
  408,  409,    0, 1314, 1022,  411, 1024,    0, 1025,    0,
  412,  413,  414,  415,  416,  417,  418,  419, 1023,    0,
    0, 1027,    0,    0,    0,    0, 1028,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  154,    0,  155,    0,    0,    0,    0,    0,  156,    0,
  854,  157,  158,    0,    0,    0,    0,  855,    0,    0,
    0,    0,  159,  160,    0,  161,    0,  162,  856,    0,
  163,    0,    0,  164,  857,  858,    0,    0,    0,    0,
  165,    0,  166,  167,    0,    0,    0,  168,    0,  169,
    0,  859,  170,    0,    0,    0,    0,    0,    0,    0,
  860,    0,  171,  861,    0,    0,    0,  173,    0,  174,
    0,  175,    0,    0,    0,    0,    0,  176,    0,  177,
    0,    0,    0,  178,    0,    0,    0,  862,    0,  863,
  864,  179,  865,    0,  180,    0,  181,  866,    0,  867,
  182,  183,    0,    0,    0,    0,    0,  868,    0,    0,
    0,    0,    0,  184,    0,    0,    0,  186,  187,  188,
  189,  190,    0,  191,    0,  869,    0,    0,    0,  192,
    0,  193,  194,    0,    0,  195,  196,    0,    0,    0,
  870,    0,  197,    0,    0,  198,  199,  871,  201,    0,
  202,    0,  203,  872,  204,  205,  206,  207,  208,  873,
    0,    0,    0,  209,    0,  210,    0,    0,    0,  874,
    0,    0,    0,    0,    0,    0,  211, 1345,    0,    0,
    0,  212,  213,  875,  876,  877,  878,  879,  880,  881,
  606,  607,  215,    0,  216,  217,  218,  219,    0,  220,
  882,    0,    0,    0,    0,    0,    0,  221,  222,  883,
  884,  885,  886,  887,  888,  889,  890,  891,  223,  892,
    0,  225,  226,  227,  893,  894,    0,  895,  896,  897,
    0,  230,  231,  898,  232,    0,    0,  233,  234,  899,
  900,  901,  235,  236,    0,    0,    0,    0,  237,  902,
  239,    0,  903,  241,  242,    0,  243,    0,  904,  905,
  906,    0,  907,  908,    0,  909,  244,  245,  246,  247,
  248,  249,  910,  251,  911,  253,  912,  913,  914,  915,
  916,  917,  918,  919,  920,  921,  922,    0,  923,  924,
  925,  926,  927,  928,    0,  929,  930,  931,  274,    0,
  932,    0,  933,  934,  935,  936,  937,  281,  282,  938,
  284,  939,  940,  941,  288,  942,  290,  943,  292,  944,
    0,  945,  946,  947,  948,    0,  949,  950,  951,  301,
  952,    0,  953,  954,  305,  955,  307,  308,  956,  310,
  311,  312,  313,  314,  315,    0,  957,  317,  318,  319,
  320,  321,    0,  958,  323,  324,  325,  959,  960,  328,
  329,    0,  330,  331,  961,  962,    0,  332,  333,  334,
  963,  964,  965,    0,    0,  338,  966,  967,  968,  969,
  970,  971,  972,  973,  974,    0,  975,  976,  977,  347,
  978,  348,  349,  350,  351,  352,  353,    0,    0,  979,
  980,  981,  982,  983,  984,  985,  986,  987,  988,  989,
  990,  991,  992,  993,  994,  995,  996,    0,  356,  997,
  358,  359,  998,  361,  362,  363,  999,    0,  365,  366,
  367,  368,  369,  370, 1000,  372, 1001, 1002,  375,  376,
    0,  377,  378, 1003,    0,  380,    0, 1004, 1005,  381,
 1006,  383,  384,  385, 1007, 1008,  388,  389,  390, 1009,
  392,  393,    0, 1010,  395, 1011, 1012, 1013, 1014, 1015,
  396, 1016, 1017, 1018, 1019, 1020, 1021,  403,  404,  405,
  406,  407,  408,  409,    0, 1314, 1022,  411, 1024,    0,
 1025,    0,  412,  413,  414,  415,  416,  417,  418,  419,
 1023,    0,    0, 1027,    0,    0,    0,    0, 1028,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  154,    0,  155,    0,    0,    0,    0,    0,
  156,    0,  854,  157,  158,    0,    0,    0,    0,  855,
    0,    0,    0,    0,  159,  160,    0,  161,    0,  162,
  856,    0,  163,    0,    0,  164,  857,  858,    0,    0,
    0,    0,  165,    0,  166,  167,    0,    0,    0,  168,
    0,  169,    0,  859,  170,    0,    0,    0,    0,    0,
    0,    0,  860,    0,  171,  861,    0,    0,    0,  173,
    0,  174,    0,  175,    0,    0,    0,    0,    0,  176,
    0,  177,    0,    0,    0,  178,    0,    0,    0,  862,
    0,  863,  864,  179,  865,    0,  180,    0,  181,  866,
    0,  867,  182,  183,    0,    0,    0,    0,    0,  868,
    0,    0,    0,    0,    0,  184,    0,    0,    0,  186,
  187,  188,  189,  190,    0,  191,    0,  869,    0,    0,
    0,  192,    0,  193,  194,    0,    0,  195,  196,    0,
    0,    0,  870,    0,  197,    0,    0,  198,  199,  871,
  201,    0,  202,    0,  203,  872,  204,  205,  206,  207,
  208,  873,    0,    0,    0,  209,    0,  210,    0,    0,
    0,  874,    0,    0,    0,    0,    0,    0,  211,    0,
    0,    0,   15,  212,  213,  875,  876,  877,  878,  879,
  880,  881,  606,  607,  215,    0,  216,  217,  218,  219,
    0,  220,  882,    0,    0,    0,    0,    0,    0,  221,
  222,  883,  884,  885,  886,  887,  888,  889,  890,  891,
  223,  892,    0,  225,  226,  227,  893,  894,    0,  895,
  896,  897,    0,  230,  231,  898,  232,    0,    0,  233,
  234,  899,  900,  901,  235,  236,    0,    0,    0,    0,
  237,  902,  239,    0,  903,  241,  242,    0,  243,    0,
  904,  905,  906,    0,  907,  908,    0,  909,  244,  245,
  246,  247,  248,  249,  910,  251,  911,  253,  912,  913,
  914,  915,  916,  917,  918,  919,  920,  921,  922,    0,
  923,  924,  925,  926,  927,  928,    0,  929,  930,  931,
  274,    0,  932,    0,  933,  934,  935,  936,  937,  281,
  282,  938,  284,  939,  940,  941,  288,  942,  290,  943,
  292,  944,    0,  945,  946,  947,  948,    0,  949,  950,
  951,  301,  952,    0,  953,  954,  305,  955,  307,  308,
  956,  310,  311,  312,  313,  314,  315,    0,  957,  317,
  318,  319,  320,  321,    0,  958,  323,  324,  325,  959,
  960,  328,  329,    0,  330,  331,  961,  962,    0,  332,
  333,  334,  963,  964,  965,    0,    0,  338,  966,  967,
  968,  969,  970,  971,  972,  973,  974,    0,  975,  976,
  977,  347,  978,  348,  349,  350,  351,  352,  353,    0,
    0,  979,  980,  981,  982,  983,  984,  985,  986,  987,
  988,  989,  990,  991,  992,  993,  994,  995,  996,    0,
  356,  997,  358,  359,  998,  361,  362,  363,  999,    0,
  365,  366,  367,  368,  369,  370, 1000,  372, 1001, 1002,
  375,  376,    0,  377,  378, 1003,    0,  380,    0, 1004,
 1005,  381, 1006,  383,  384,  385, 1007, 1008,  388,  389,
  390, 1009,  392,  393,    0, 1010,  395, 1011, 1012, 1013,
 1014, 1015,  396, 1016, 1017, 1018, 1019, 1020, 1021,  403,
  404,  405,  406,  407,  408,  409,    0,    0, 1022,  411,
    0,    0,    0,    0,  412,  413,  414,  415,  416,  417,
  418,  419, 1023, 1314,    0, 1551, 1024,    0, 1025,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1027,    0,    0,    0,    0, 1028,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  154,    0,  155,    0,    0,    0,    0,    0,  156,    0,
  854,  157,  158,    0,    0,    0,    0,  855,    0,    0,
    0,    0,  159,  160,    0,  161,    0,  162,  856,    0,
  163,    0,    0,  164,  857,  858,    0,    0,    0,    0,
  165,    0,  166,  167,    0,    0,    0,  168,    0,  169,
    0,  859,  170,    0,    0,    0,    0,    0,    0,    0,
  860,    0,  171,  861,    0,    0,    0,  173,    0,  174,
    0,  175,    0,    0,    0,    0,    0,  176,    0,  177,
    0,    0,    0,  178,    0,    0,    0,  862,    0,  863,
  864,  179,  865,    0,  180,    0,  181,  866,    0,  867,
  182,  183,    0,    0,    0,    0,    0,  868,    0,    0,
    0,    0,    0,  184,    0,    0,    0,  186,  187,  188,
  189,  190,    0,  191,    0,  869,    0,    0,    0,  192,
    0,  193,  194,    0,    0,  195,  196,    0,    0,    0,
  870,    0,  197,    0,    0,  198,  199,  871,  201,    0,
  202,    0,  203,  872,  204,  205,  206,  207,  208,  873,
    0,    0,    0,  209,    0,  210,    0,    0,    0,  874,
    0,    0,    0,    0,    0,    0,  211,    0,    0,    0,
    0,  212,  213,  875,  876,  877,  878,  879,  880,  881,
  606,  607,  215,    0,  216,  217,  218,  219,    0,  220,
  882,    0,    0,    0,    0,    0,    0,  221,  222,  883,
  884,  885,  886,  887,  888,  889,  890,  891,  223,  892,
    0,  225,  226,  227,  893,  894,    0,  895,  896,  897,
    0,  230,  231,  898,  232,    0,    0,  233,  234,  899,
  900,  901,  235,  236,    0,    0,    0,    0,  237,  902,
  239,    0,  903,  241,  242,    0,  243,    0,  904,  905,
  906,    0,  907,  908,    0,  909,  244,  245,  246,  247,
  248,  249,  910,  251,  911,  253,  912,  913,  914,  915,
  916,  917,  918,  919,  920,  921,  922,    0,  923,  924,
  925,  926,  927,  928,    0,  929,  930,  931,  274,    0,
  932,    0,  933,  934,  935,  936,  937,  281,  282,  938,
  284,  939,  940,  941,  288,  942,  290,  943,  292,  944,
    0,  945,  946,  947,  948,    0,  949,  950,  951,  301,
  952,    0,  953,  954,  305,  955,  307,  308,  956,  310,
  311,  312,  313,  314,  315,    0,  957,  317,  318,  319,
  320,  321,    0,  958,  323,  324,  325,  959,  960,  328,
  329,    0,  330,  331,  961,  962,    0,  332,  333,  334,
  963,  964,  965,    0,    0,  338,  966,  967,  968,  969,
  970,  971,  972,  973,  974,    0,  975,  976,  977,  347,
  978,  348,  349,  350,  351,  352,  353,    0,    0,  979,
  980,  981,  982,  983,  984,  985,  986,  987,  988,  989,
  990,  991,  992,  993,  994,  995,  996,    0,  356,  997,
  358,  359,  998,  361,  362,  363,  999,    0,  365,  366,
  367,  368,  369,  370, 1000,  372, 1001, 1002,  375,  376,
    0,  377,  378, 1003,    0,  380,    0, 1004, 1005,  381,
 1006,  383,  384,  385, 1007, 1008,  388,  389,  390, 1009,
  392,  393,    0, 1010,  395, 1011, 1012, 1013, 1014, 1015,
  396, 1016, 1017, 1018, 1019, 1020, 1021,  403,  404,  405,
  406,  407,  408,  409,    0,    0, 1022,  411,    0,    0,
    0,    0,  412,  413,  414,  415,  416,  417,  418,  419,
 1023, 1314, 1850,    0, 1024,    0, 1025,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1027,
    0,    0,    0,    0, 1028,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  154,    0,
  155,    0,    0,    0,    0,    0,  156,    0,  854,  157,
  158,    0,    0,    0,    0,  855,    0,    0,    0,    0,
  159,  160,    0,  161,    0,  162,  856,    0,  163,    0,
    0,  164,  857,  858,    0,    0,    0,    0,  165,    0,
  166,  167,    0,    0,    0,  168,    0,  169,    0,  859,
  170,    0,    0,    0,    0,    0,    0,    0,  860,    0,
  171,  861,    0,    0,    0,  173,    0,  174,    0,  175,
    0,    0,    0,    0,    0,  176,    0,  177,    0,    0,
    0,  178,    0,    0,    0,  862,    0,  863,  864,  179,
  865,    0,  180,    0,  181,  866,    0,  867,  182,  183,
    0,    0,    0,    0,    0,  868,    0,    0,    0,    0,
    0,  184,    0,    0,    0,  186,  187,  188,  189,  190,
    0,  191,    0,  869,    0,    0,    0,  192,    0,  193,
  194,    0,    0,  195,  196,    0,    0,    0,  870,    0,
  197,    0,    0,  198,  199,  871,  201,    0,  202,    0,
  203,  872,  204,  205,  206,  207,  208,  873,    0,    0,
    0,  209,    0,  210,    0,    0,    0,  874,    0,    0,
    0,    0,    0,    0,  211,    0,    0,    0,    0,  212,
  213,  875,  876,  877,  878,  879,  880,  881,  606,  607,
  215,    0,  216,  217,  218,  219,    0,  220,  882,    0,
    0,    0,    0,    0,    0,  221,  222,  883,  884,  885,
  886,  887,  888,  889,  890,  891,  223,  892,    0,  225,
  226,  227,  893,  894,    0,  895,  896,  897,    0,  230,
  231,  898,  232,    0,    0,  233,  234,  899,  900,  901,
  235,  236,    0,    0,    0,    0,  237,  902,  239,    0,
  903,  241,  242,    0,  243,    0,  904,  905,  906,    0,
  907,  908,    0,  909,  244,  245,  246,  247,  248,  249,
  910,  251,  911,  253,  912,  913,  914,  915,  916,  917,
  918,  919,  920,  921,  922,    0,  923,  924,  925,  926,
  927,  928,    0,  929,  930,  931,  274,    0,  932,    0,
  933,  934,  935,  936,  937,  281,  282,  938,  284,  939,
  940,  941,  288,  942,  290,  943,  292,  944,    0,  945,
  946,  947,  948,    0,  949,  950,  951,  301,  952,    0,
  953,  954,  305,  955,  307,  308,  956,  310,  311,  312,
  313,  314,  315,    0,  957,  317,  318,  319,  320,  321,
    0,  958,  323,  324,  325,  959,  960,  328,  329,    0,
  330,  331,  961,  962,    0,  332,  333,  334,  963,  964,
  965,    0,    0,  338,  966,  967,  968,  969,  970,  971,
  972,  973,  974,    0,  975,  976,  977,  347,  978,  348,
  349,  350,  351,  352,  353,    0,    0,  979,  980,  981,
  982,  983,  984,  985,  986,  987,  988,  989,  990,  991,
  992,  993,  994,  995,  996,    0,  356,  997,  358,  359,
  998,  361,  362,  363,  999,    0,  365,  366,  367,  368,
  369,  370, 1000,  372, 1001, 1002,  375,  376,    0,  377,
  378, 1003,    0,  380,    0, 1004, 1005,  381, 1006,  383,
  384,  385, 1007, 1008,  388,  389,  390, 1009,  392,  393,
    0, 1010,  395, 1011, 1012, 1013, 1014, 1015,  396, 1016,
 1017, 1018, 1019, 1020, 1021,  403,  404,  405,  406,  407,
  408,  409,    0, 1314, 1022,  411, 1024,    0, 1025,    0,
  412,  413,  414,  415,  416,  417,  418,  419, 1023,    0,
    0, 1027,    0,    0,    0,    0, 1028,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  154,    0,  155,    0,    0,    0,    0,    0,  156,    0,
  854,  157,  158,    0,    0,    0,    0,  855,    0,    0,
    0,    0,  159,  160,    0,  161,    0,  162,  856,    0,
  163,    0,    0,  164,  857,  858,    0,    0,    0,    0,
  165,    0,  166,  167,    0,    0,    0,  168,    0,  169,
    0,  859,  170,    0,    0,    0,    0, 2156,    0,    0,
  860,    0,  171,  861,    0,    0,    0,  173,    0,  174,
    0,  175,    0,    0,    0,    0,    0,  176,    0,  177,
    0,    0,    0,  178,    0,    0,    0,  862,    0,  863,
  864,  179,  865,    0,  180,    0,  181,  866,    0,  867,
  182,  183,    0,    0,    0,    0,    0,  868,    0,    0,
    0,    0,    0,  184,    0,    0,    0,  186,  187,  188,
  189,  190,    0,  191,    0,  869,    0,    0,    0,  192,
    0,  193,  194,    0,    0,  195,  196,    0,    0,    0,
  870,    0,  197,    0,    0,  198,  199,  871,  201,    0,
  202,    0,  203,  872,  204,  205,  206,  207,  208,  873,
    0,    0,    0,  209,    0,  210,    0,    0,    0,  874,
    0,    0,    0,    0,    0,    0,  211,    0,    0,    0,
    0,  212,  213,  875,  876,  877,  878,  879,  880,  881,
  606,  607,  215,    0,  216,  217,  218,  219,    0,  220,
  882,    0,    0,    0,    0,    0,    0,  221,  222,  883,
  884,  885,  886,  887,  888,  889,  890,  891,  223,  892,
    0,  225,  226,  227,  893,  894,    0,  895,  896,  897,
    0,  230,  231,  898,  232,    0,    0,  233,  234,  899,
  900,  901,  235,  236,    0,    0,    0,    0,  237,  902,
  239,    0,  903,  241,  242,    0,  243,    0,  904,  905,
  906,    0,  907,  908,    0,  909,  244,  245,  246,  247,
  248,  249,  910,  251,  911,  253,  912,  913,  914,  915,
  916,  917,  918,  919,  920,  921,  922,    0,  923,  924,
  925,  926,  927,  928,    0,  929,  930,  931,  274,    0,
  932,    0,  933,  934,  935,  936,  937,  281,  282,  938,
  284,  939,  940,  941,  288,  942,  290,  943,  292,  944,
    0,  945,  946,  947,  948,    0,  949,  950,  951,  301,
  952,    0,  953,  954,  305,  955,  307,  308,  956,  310,
  311,  312,  313,  314,  315,    0,  957,  317,  318,  319,
  320,  321,    0,  958,  323,  324,  325,  959,  960,  328,
  329,    0,  330,  331,  961,  962,    0,  332,  333,  334,
  963,  964,  965,    0,    0,  338,  966,  967,  968,  969,
  970,  971,  972,  973,  974,    0,  975,  976,  977,  347,
  978,  348,  349,  350,  351,  352,  353,    0,    0,  979,
  980,  981,  982,  983,  984,  985,  986,  987,  988,  989,
  990,  991,  992,  993,  994,  995,  996,    0,  356,  997,
  358,  359,  998,  361,  362,  363,  999,    0,  365,  366,
  367,  368,  369,  370, 1000,  372, 1001, 1002,  375,  376,
    0,  377,  378, 1003,    0,  380,    0, 1004, 1005,  381,
 1006,  383,  384,  385, 1007, 1008,  388,  389,  390, 1009,
  392,  393,    0, 1010,  395, 1011, 1012, 1013, 1014, 1015,
  396, 1016, 1017, 1018, 1019, 1020, 1021,  403,  404,  405,
  406,  407,  408,  409,    0, 1314, 1022,  411, 1024,    0,
 1025,    0,  412,  413,  414,  415,  416,  417,  418,  419,
 1023,    0,    0, 1027,    0,    0,    0,    0, 1028,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  154,    0,  155,    0,    0,    0,    0,    0,
  156,    0,  854,  157,  158,    0,    0,    0,    0,  855,
    0,    0,    0,    0,  159,  160,    0,  161,    0,  162,
  856,    0,  163,    0,    0,  164,  857,  858,    0,    0,
 2344,    0,  165,    0,  166,  167,    0,    0,    0,  168,
    0,  169,    0,  859,  170,    0,    0,    0,    0,    0,
    0,    0,  860,    0,  171,  861,    0,    0,    0,  173,
    0,  174,    0,  175,    0,    0,    0,    0,    0,  176,
    0,  177,    0,    0,    0,  178,    0,    0,    0,  862,
    0,  863,  864,  179,  865,    0,  180,    0,  181,  866,
    0,  867,  182,  183,    0,    0,    0,    0,    0,  868,
    0,    0,    0,    0,    0,  184,    0,    0,    0,  186,
  187,  188,  189,  190,    0,  191,    0,  869,    0,    0,
    0,  192,    0,  193,  194,    0,    0,  195,  196,    0,
    0,    0,  870,    0,  197,    0,    0,  198,  199,  871,
  201,    0,  202,    0,  203,  872,  204,  205,  206,  207,
  208,  873,    0,    0,    0,  209,    0,  210,    0,    0,
    0,  874,    0,    0,    0,    0,    0,    0,  211,    0,
    0,    0,    0,  212,  213,  875,  876,  877,  878,  879,
  880,  881,  606,  607,  215,    0,  216,  217,  218,  219,
    0,  220,  882,    0,    0,    0,    0,    0,    0,  221,
  222,  883,  884,  885,  886,  887,  888,  889,  890,  891,
  223,  892,    0,  225,  226,  227,  893,  894,    0,  895,
  896,  897,    0,  230,  231,  898,  232,    0,    0,  233,
  234,  899,  900,  901,  235,  236,    0,    0,    0,    0,
  237,  902,  239,    0,  903,  241,  242,    0,  243,    0,
  904,  905,  906,    0,  907,  908,    0,  909,  244,  245,
  246,  247,  248,  249,  910,  251,  911,  253,  912,  913,
  914,  915,  916,  917,  918,  919,  920,  921,  922,    0,
  923,  924,  925,  926,  927,  928,    0,  929,  930,  931,
  274,    0,  932,    0,  933,  934,  935,  936,  937,  281,
  282,  938,  284,  939,  940,  941,  288,  942,  290,  943,
  292,  944,    0,  945,  946,  947,  948,    0,  949,  950,
  951,  301,  952,    0,  953,  954,  305,  955,  307,  308,
  956,  310,  311,  312,  313,  314,  315,    0,  957,  317,
  318,  319,  320,  321,    0,  958,  323,  324,  325,  959,
  960,  328,  329,    0,  330,  331,  961,  962,    0,  332,
  333,  334,  963,  964,  965,    0,    0,  338,  966,  967,
  968,  969,  970,  971,  972,  973,  974,    0,  975,  976,
  977,  347,  978,  348,  349,  350,  351,  352,  353,    0,
    0,  979,  980,  981,  982,  983,  984,  985,  986,  987,
  988,  989,  990,  991,  992,  993,  994,  995,  996,    0,
  356,  997,  358,  359,  998,  361,  362,  363,  999,    0,
  365,  366,  367,  368,  369,  370, 1000,  372, 1001, 1002,
  375,  376,    0,  377,  378, 1003,    0,  380,    0, 1004,
 1005,  381, 1006,  383,  384,  385, 1007, 1008,  388,  389,
  390, 1009,  392,  393,    0, 1010,  395, 1011, 1012, 1013,
 1014, 1015,  396, 1016, 1017, 1018, 1019, 1020, 1021,  403,
  404,  405,  406,  407,  408,  409,    0, 1314, 1022,  411,
 1024,    0, 1025,    0,  412,  413,  414,  415,  416,  417,
  418,  419, 1023,    0,    0, 1027,    0,    0,    0,    0,
 1028,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  154,    0,  155,    0,    0,    0,
    0,    0,  156,    0,  854,  157,  158,    0,    0,    0,
    0,  855,    0,    0,    0,    0,  159,  160,    0,  161,
    0,  162,  856,    0,  163,    0,    0,  164,  857,  858,
    0,    0,    0,    0,  165,    0,  166,  167,    0,    0,
    0,  168,    0,  169,    0,  859,  170,    0,    0,    0,
    0,    0,    0,    0,  860,    0,  171,  861,    0,    0,
    0,  173,    0,  174,    0,  175,    0,    0,    0,    0,
    0,  176,    0,  177,    0,    0,    0,  178,    0,    0,
    0,  862,    0,  863,  864,  179,  865,    0,  180,    0,
  181,  866,    0,  867,  182,  183,    0,    0,    0,    0,
    0,  868,    0,    0,    0,    0,    0,  184,    0,    0,
    0,  186,  187,  188,  189,  190,    0,  191,    0,  869,
    0,    0,    0,  192,    0,  193,  194,    0,    0,  195,
  196,    0,    0,    0,  870,    0,  197,    0,    0,  198,
  199,  871,  201,    0,  202,    0,  203,  872,  204,  205,
  206,  207,  208,  873,    0,    0, 1826,  209,    0,  210,
    0,    0,    0,  874,    0,    0,    0,    0,    0,    0,
  211,    0,    0,    0,    0,  212,  213,  875,  876,  877,
  878,  879,  880,  881,  606,  607,  215,    0,  216,  217,
  218,  219,    0,  220,  882,    0,    0,    0,    0,    0,
    0,  221,  222,  883,  884,  885,  886,  887,  888,  889,
  890,  891,  223,  892,    0,  225,  226,  227,  893,  894,
    0,  895,  896,  897,    0,  230,  231,  898,  232,    0,
    0,  233,  234,  899,  900,  901,  235,  236,    0,    0,
    0,    0,  237,  902,  239,    0,  903,  241,  242,    0,
  243,    0,  904,  905,  906,    0,  907,  908,    0,  909,
  244,  245,  246,  247,  248,  249,  910,  251,  911,  253,
  912,  913,  914,  915,  916,  917,  918,  919,  920,  921,
  922,    0,  923,  924,  925,  926,  927,  928,    0,  929,
  930,  931,  274,    0,  932,    0,  933,  934,  935,  936,
  937,  281,  282,  938,  284,  939,  940,  941,  288,  942,
  290,  943,  292,  944,    0,  945,  946,  947,  948,    0,
  949,  950,  951,  301,  952,    0,  953,  954,  305,  955,
  307,  308,  956,  310,  311,  312,  313,  314,  315,    0,
  957,  317,  318,  319,  320,  321,    0,  958,  323,  324,
  325,  959,  960,  328,  329,    0,  330,  331,  961,  962,
    0,  332,  333,  334,  963,  964,  965,    0,    0,  338,
  966,  967,  968,  969,  970,  971,  972,  973,  974,    0,
  975,  976,  977,  347,  978,  348,  349,  350,  351,  352,
  353,    0,    0,  979,  980,  981,  982,  983,  984,  985,
  986,  987,  988,  989,  990,  991,  992,  993,  994,  995,
  996,    0,  356,  997,  358,  359,  998,  361,  362,  363,
  999,    0,  365,  366,  367,  368,  369,  370, 1000,  372,
 1001, 1002,  375,  376,    0,  377,  378, 1003,    0,  380,
    0, 1004, 1005,  381, 1006,  383,  384,  385, 1007, 1008,
  388,  389,  390, 1009,  392,  393,    0, 1010,  395, 1011,
 1012, 1013, 1014, 1015,  396, 1016, 1017, 1018, 1019, 1020,
 1021,  403,  404,  405,  406,  407,  408,  409,    0,    0,
 1022,  411,    0,    0,    0,    0,  412,  413,  414,  415,
  416,  417,  418,  419, 1023, 1314, 2639,    0, 1024,    0,
 1025,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1027,    0,    0,    0,    0, 1028,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  154,    0,  155,    0,    0,    0,    0,    0,
  156,    0,  854,  157,  158,    0,    0,    0,    0,  855,
    0,    0,    0,    0,  159,  160,    0,  161,    0,  162,
  856,    0,  163,    0,    0,  164,  857,  858,    0,    0,
    0,    0,  165,    0,  166,  167,    0,    0,    0,  168,
    0,  169,    0,  859,  170,    0,    0,    0,    0,    0,
    0,    0,  860,    0,  171,  861,    0,    0,    0,  173,
    0,  174,    0,  175,    0,    0,    0,    0,    0,  176,
    0,  177,    0,    0,    0,  178,    0,    0,    0,  862,
    0,  863,  864,  179,  865,    0,  180,    0,  181,  866,
    0,  867,  182,  183,    0,    0,    0,    0,    0,  868,
    0,    0,    0,    0,    0,  184,    0,    0,    0,  186,
  187,  188,  189,  190,    0,  191,    0,  869,    0,    0,
    0,  192,    0,  193,  194,    0,    0,  195,  196,    0,
    0,    0,  870,    0,  197,    0,    0,  198,  199,  871,
  201,    0,  202,    0,  203,  872,  204,  205,  206,  207,
  208,  873,    0,    0,    0,  209,    0,  210,    0,    0,
    0,  874,    0,    0,    0,    0,    0,    0,  211,    0,
    0,    0,    0,  212,  213,  875,  876,  877,  878,  879,
  880,  881,  606,  607,  215,    0,  216,  217,  218,  219,
    0,  220,  882,    0,    0,    0,    0,    0,    0,  221,
  222,  883,  884,  885,  886,  887,  888,  889,  890,  891,
  223,  892,    0,  225,  226,  227,  893,  894,    0,  895,
  896,  897,    0,  230,  231,  898,  232,    0,    0,  233,
  234,  899,  900,  901,  235,  236,    0,    0,    0,    0,
  237,  902,  239,    0,  903,  241,  242,    0,  243,    0,
  904,  905,  906,    0,  907,  908,    0,  909,  244,  245,
  246,  247,  248,  249,  910,  251,  911,  253,  912,  913,
  914,  915,  916,  917,  918,  919,  920,  921,  922,    0,
  923,  924,  925,  926,  927,  928,    0,  929,  930,  931,
  274,    0,  932,    0,  933,  934,  935,  936,  937,  281,
  282,  938,  284,  939,  940,  941,  288,  942,  290,  943,
  292,  944,    0,  945,  946,  947,  948,    0,  949,  950,
  951,  301,  952,    0,  953,  954,  305,  955,  307,  308,
  956,  310,  311,  312,  313,  314,  315,    0,  957,  317,
  318,  319,  320,  321,    0,  958,  323,  324,  325,  959,
  960,  328,  329,    0,  330,  331,  961,  962,    0,  332,
  333,  334,  963,  964,  965,    0,    0,  338,  966,  967,
  968,  969,  970,  971,  972,  973,  974,    0,  975,  976,
  977,  347,  978,  348,  349,  350,  351,  352,  353,    0,
    0,  979,  980,  981,  982,  983,  984,  985,  986,  987,
  988,  989,  990,  991,  992,  993,  994,  995,  996,    0,
  356,  997,  358,  359,  998,  361,  362,  363,  999,    0,
  365,  366,  367,  368,  369,  370, 1000,  372, 1001, 1002,
  375,  376,    0,  377,  378, 1003,    0,  380,    0, 1004,
 1005,  381, 1006,  383,  384,  385, 1007, 1008,  388,  389,
  390, 1009,  392,  393,    0, 1010,  395, 1011, 1012, 1013,
 1014, 1015,  396, 1016, 1017, 1018, 1019, 1020, 1021,  403,
  404,  405,  406,  407,  408,  409,    0, 1314, 1022,  411,
 1024,    0, 1025,    0,  412,  413,  414,  415,  416,  417,
  418,  419, 1023,    0,    0, 1027,    0,    0,    0,    0,
 1028,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  154,    0,  155,    0,    0,    0,
    0,    0,  156,    0,  854,  157,  158,    0,    0,    0,
    0,  855,    0,    0,    0,    0,  159,  160,    0,  161,
    0,  162,  856,    0,  163,    0,    0,  164,  857,  858,
    0,    0, 2716,    0,  165,    0,  166,  167,    0,    0,
    0,  168,    0,  169,    0,  859,  170,    0,    0,    0,
    0,    0,    0,    0,  860,    0,  171,  861,    0,    0,
    0,  173,    0,  174,    0,  175,    0,    0,    0,    0,
    0,  176,    0,  177,    0,    0,    0,  178,    0,    0,
    0,  862,    0,  863,  864,  179,  865,    0,  180,    0,
  181,  866,    0,  867,  182,  183,    0,    0,    0,    0,
    0,  868,    0,    0,    0,    0,    0,  184,    0,    0,
    0,  186,  187,  188,  189,  190,    0,  191,    0,  869,
    0,    0,    0,  192,    0,  193,  194,    0,    0,  195,
  196,    0,    0,    0,  870,    0,  197,    0,    0,  198,
  199,  871,  201,    0,  202,    0,  203,  872,  204,  205,
  206,  207,  208,  873,    0,    0,    0,  209,    0,  210,
    0,    0,    0,  874,    0,    0,    0,    0,    0,    0,
  211,    0,    0,    0,    0,  212,  213,  875,  876,  877,
  878,  879,  880,  881,  606,  607,  215,    0,  216,  217,
  218,  219,    0,  220,  882,    0,    0,    0,    0,    0,
    0,  221,  222,  883,  884,  885,  886,  887,  888,  889,
  890,  891,  223,  892,    0,  225,  226,  227,  893,  894,
    0,  895,  896,  897,    0,  230,  231,  898,  232,    0,
    0,  233,  234,  899,  900,  901,  235,  236,    0,    0,
    0,    0,  237,  902,  239,    0,  903,  241,  242,    0,
  243,    0,  904,  905,  906,    0,  907,  908,    0,  909,
  244,  245,  246,  247,  248,  249,  910,  251,  911,  253,
  912,  913,  914,  915,  916,  917,  918,  919,  920,  921,
  922,    0,  923,  924,  925,  926,  927,  928,    0,  929,
  930,  931,  274,    0,  932,    0,  933,  934,  935,  936,
  937,  281,  282,  938,  284,  939,  940,  941,  288,  942,
  290,  943,  292,  944,    0,  945,  946,  947,  948,    0,
  949,  950,  951,  301,  952,    0,  953,  954,  305,  955,
  307,  308,  956,  310,  311,  312,  313,  314,  315,    0,
  957,  317,  318,  319,  320,  321,    0,  958,  323,  324,
  325,  959,  960,  328,  329,    0,  330,  331,  961,  962,
    0,  332,  333,  334,  963,  964,  965,    0,    0,  338,
  966,  967,  968,  969,  970,  971,  972,  973,  974,    0,
  975,  976,  977,  347,  978,  348,  349,  350,  351,  352,
  353,    0,    0,  979,  980,  981,  982,  983,  984,  985,
  986,  987,  988,  989,  990,  991,  992,  993,  994,  995,
  996,    0,  356,  997,  358,  359,  998,  361,  362,  363,
  999,    0,  365,  366,  367,  368,  369,  370, 1000,  372,
 1001, 1002,  375,  376,    0,  377,  378, 1003,    0,  380,
    0, 1004, 1005,  381, 1006,  383,  384,  385, 1007, 1008,
  388,  389,  390, 1009,  392,  393,    0, 1010,  395, 1011,
 1012, 1013, 1014, 1015,  396, 1016, 1017, 1018, 1019, 1020,
 1021,  403,  404,  405,  406,  407,  408,  409,    0, 1314,
 1022,  411, 1024,    0, 1025,    0,  412,  413,  414,  415,
  416,  417,  418,  419, 1023,    0,    0, 1027,    0,    0,
    0,    0, 1028,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  154,    0,  155,    0,
    0,    0,    0,    0,  156,    0,  854,  157,  158,    0,
    0,    0,    0,  855,    0,    0,    0,    0,  159,  160,
    0,  161,    0,  162,  856,    0,  163,    0,    0,  164,
  857,  858,    0,    0,    0,    0,  165,    0,  166,  167,
    0,    0,    0,  168,    0,  169,    0,  859,  170,    0,
    0,    0,    0,    0,    0,    0,  860,    0,  171,  861,
    0,    0,    0,  173,    0,  174,    0,  175,    0,    0,
    0,    0,    0,  176,    0,  177,    0,    0,    0,  178,
    0,    0,    0,  862,    0,  863,  864,  179,  865,    0,
  180,    0,  181,  866,    0,  867,  182,  183,    0,    0,
    0,    0,    0,  868,    0,    0,    0,    0,    0,  184,
    0,    0,    0,  186,  187,  188,  189,  190,    0,  191,
    0,  869,    0,    0,    0,  192,    0,  193,  194,    0,
    0,  195,  196,    0,    0,    0,  870,    0,  197,    0,
    0,  198,  199,  871,  201,    0,  202,    0,  203,  872,
  204,  205,  206,  207,  208,  873,    0,    0,    0,  209,
    0,  210,    0,    0,    0,  874,    0,    0,    0,    0,
    0,    0,  211,    0,    0,    0,    0,  212,  213,  875,
  876,  877,  878,  879,  880,  881,  606,  607,  215,    0,
  216,  217,  218,  219,    0,  220,  882,    0,    0,    0,
    0,    0,    0,  221,  222,  883,  884,  885,  886,  887,
  888,  889,  890,  891,  223,  892,    0,  225,  226,  227,
  893,  894,    0,  895,  896,  897, 3070,  230,  231,  898,
  232,    0,    0,  233,  234,  899,  900,  901,  235,  236,
    0,    0,    0,    0,  237,  902,  239,    0,  903,  241,
  242,    0,  243,    0,  904,  905,  906,    0,  907,  908,
    0,  909,  244,  245,  246,  247,  248,  249,  910,  251,
  911,  253,  912,  913,  914,  915,  916,  917,  918,  919,
  920,  921,  922,    0,  923,  924,  925,  926,  927,  928,
    0,  929,  930,  931,  274,    0,  932,    0,  933,  934,
  935,  936,  937,  281,  282,  938,  284,  939,  940,  941,
  288,  942,  290,  943,  292,  944,    0,  945,  946,  947,
  948,    0,  949,  950,  951,  301,  952,    0,  953,  954,
  305,  955,  307,  308,  956,  310,  311,  312,  313,  314,
  315,    0,  957,  317,  318,  319,  320,  321,    0,  958,
  323,  324,  325,  959,  960,  328,  329,    0,  330,  331,
  961,  962,    0,  332,  333,  334,  963,  964,  965,    0,
    0,  338,  966,  967,  968,  969,  970,  971,  972,  973,
  974,    0,  975,  976,  977,  347,  978,  348,  349,  350,
  351,  352,  353,    0,    0,  979,  980,  981,  982,  983,
  984,  985,  986,  987,  988,  989,  990,  991,  992,  993,
  994,  995,  996,    0,  356,  997,  358,  359,  998,  361,
  362,  363,  999,    0,  365,  366,  367,  368,  369,  370,
 1000,  372, 1001, 1002,  375,  376,    0,  377,  378, 1003,
    0,  380,    0, 1004, 1005,  381, 1006,  383,  384,  385,
 1007, 1008,  388,  389,  390, 1009,  392,  393,    0, 1010,
  395, 1011, 1012, 1013, 1014, 1015,  396, 1016, 1017, 1018,
 1019, 1020, 1021,  403,  404,  405,  406,  407,  408,  409,
    0,    0, 1022,  411,    0,    0,    0,    0,  412,  413,
  414,  415,  416,  417,  418,  419, 1023, 1340,    0, 1340,
 1340,    0, 1340,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1340,    0,    0,    0,    0,
 1340,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1340,    0, 1340, 1340,    0,    0,
    0,    0, 1340,    0, 1340, 1340, 1340,    0,    0,    0,
    0, 1340,    0,    0,    0,    0, 1340, 1340,    0, 1340,
    0, 1340, 1340,    0, 1340,    0,    0, 1340, 1340, 1340,
    0,    0,    0,    0, 1340, 1340, 1340, 1340,    0,    0,
    0, 1340,    0, 1340,    0, 1340, 1340,    0,    0,    0,
    0,    0,    0,    0, 1340,    0, 1340, 1340,    0,    0,
    0, 1340,    0, 1340,    0, 1340,    0,    0,    0,    0,
    0, 1340,    0, 1340,    0,    0,    0, 1340,    0,    0,
    0, 1340,    0, 1340, 1340, 1340, 1340,    0, 1340,    0,
 1340, 1340,    0, 1340, 1340, 1340,    0,    0,    0,    0,
    0, 1340,    0,    0,    0,    0,    0, 1340,    0,    0,
    0, 1340, 1340, 1340, 1340, 1340,    0, 1340,    0, 1340,
    0,    0,    0, 1340,    0, 1340, 1340,    0,    0, 1340,
 1340,    0,    0,    0, 1340,    0, 1340,    0,    0, 1340,
 1340, 1340, 1340,    0, 1340,    0, 1340, 1340, 1340, 1340,
 1340, 1340, 1340, 1340,    0,    0,    0, 1340,    0, 1340,
    0,    0,    0, 1340,    0,    0,    0,    0,    0,    0,
 1340,    0,    0,    0,    0, 1340, 1340, 1340, 1340, 1340,
 1340, 1340, 1340, 1340, 1340, 1340, 1340,    0, 1340, 1340,
 1340, 1340,    0, 1340, 1340,    0,    0,    0,    0,    0,
    0, 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340,
 1340, 1340, 1340, 1340,    0, 1340,    0,    0, 1340, 1340,
    0, 1340, 1340, 1340,    0, 1340, 1340, 1340, 1340,    0,
    0, 1340, 1340, 1340, 1340, 1340, 1340, 1340,    0,    0,
    0,    0, 1340, 1340, 1340,    0, 1340, 1340, 1340,    0,
 1340,    0, 1340, 1340, 1340,    0, 1340, 1340,    0, 1340,
 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340,
 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340,
 1340,    0, 1340, 1340, 1340, 1340, 1340, 1340,    0, 1340,
 1340, 1340, 1340,    0, 1340,    0, 1340, 1340, 1340, 1340,
 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340,
 1340, 1340, 1340, 1340,    0, 1340, 1340, 1340, 1340,    0,
 1340, 1340, 1340, 1340, 1340,    0, 1340, 1340, 1340, 1340,
 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340,    0,
 1340, 1340, 1340, 1340, 1340, 1340,    0, 1340, 1340, 1340,
 1340, 1340, 1340, 1340, 1340,    0, 1340, 1340, 1340, 1340,
    0, 1340, 1340, 1340, 1340, 1340, 1340,    0,    0, 1340,
 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340,    0,
 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340,
 1340,    0,    0, 1340, 1340, 1340, 1340, 1340, 1340, 1340,
 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340,
 1340,    0, 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340,
 1340,    0, 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340,
 1340, 1340, 1340, 1340,    0, 1340, 1340, 1340,    0, 1340,
    0, 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340,
 1340, 1340, 1340, 1340, 1340, 1340,    0, 1340, 1340, 1340,
 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340,
 1340, 1340, 1340, 1340, 1340, 1340, 1340, 1340,    0,    0,
 1340, 1340,    0,    0,    0,    0, 1340, 1340, 1340, 1340,
 1340, 1340, 1340, 1340, 1340, 2066,    0, 2066, 2066,    0,
 2066,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2066,    0,    0,    0,    0, 2066,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2066,    0, 2066,    0,    0,    0,    0,    0,
 2066,    0, 2066, 2066, 2066,    0,    0,    0,    0, 2066,
    0,    0,    0,    0, 2066, 2066,    0, 2066,    0, 2066,
 2066,    0, 2066,    0,    0, 2066, 2066, 2066,    0,    0,
    0,    0, 2066,    0, 2066, 2066,    0,    0,    0, 2066,
    0, 2066,    0, 2066, 2066,    0,    0,    0,    0,    0,
    0,    0, 2066,    0, 2066, 2066,    0,    0,    0, 2066,
    0, 2066,    0, 2066,    0,    0,    0,    0,    0, 2066,
    0, 2066,    0,    0,    0, 2066,    0,    0,    0, 2066,
    0, 2066, 2066, 2066, 2066,    0, 2066,    0, 2066, 2066,
    0, 2066, 2066, 2066,    0,    0,    0,    0,    0, 2066,
    0,    0,    0,    0,    0, 2066,    0,    0,    0, 2066,
 2066, 2066, 2066, 2066,    0, 2066,    0, 2066,    0,    0,
    0, 2066,    0, 2066, 2066,    0,    0, 2066, 2066,    0,
    0,    0, 2066,    0, 2066,    0,    0, 2066, 2066, 2066,
 2066,    0, 2066,    0, 2066, 2066, 2066, 2066, 2066, 2066,
 2066, 2066,    0,    0,    0, 2066,    0, 2066,    0,    0,
    0, 2066,    0,    0,    0,    0,    0,    0, 2066,    0,
    0,    0,    0, 2066, 2066, 2066, 2066, 2066, 2066, 2066,
 2066, 2066, 2066, 2066, 2066,    0, 2066, 2066, 2066, 2066,
    0, 2066, 2066,    0,    0,    0,    0,    0,    0, 2066,
 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066,
 2066, 2066,    0, 2066, 2066, 2066, 2066, 2066,    0, 2066,
 2066, 2066,    0, 2066, 2066, 2066, 2066,    0,    0, 2066,
 2066, 2066, 2066, 2066, 2066, 2066,    0,    0,    0,    0,
 2066, 2066, 2066,    0, 2066, 2066, 2066,    0, 2066,    0,
 2066, 2066, 2066,    0, 2066, 2066,    0, 2066, 2066, 2066,
 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066,
 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066,    0,
 2066, 2066, 2066, 2066, 2066, 2066,    0, 2066, 2066, 2066,
 2066,    0, 2066,    0, 2066, 2066, 2066, 2066, 2066, 2066,
 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066,
 2066, 2066,    0, 2066, 2066, 2066, 2066,    0, 2066, 2066,
 2066, 2066, 2066,    0, 2066, 2066, 2066, 2066, 2066, 2066,
 2066, 2066, 2066, 2066, 2066, 2066, 2066,    0, 2066, 2066,
 2066, 2066, 2066, 2066,    0, 2066, 2066, 2066, 2066, 2066,
 2066, 2066, 2066,    0, 2066, 2066, 2066, 2066,    0, 2066,
 2066, 2066, 2066, 2066, 2066,    0,    0, 2066, 2066, 2066,
 2066, 2066, 2066, 2066, 2066, 2066, 2066,    0, 2066, 2066,
 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066,    0,
    0, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066,
 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066,    0,
 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066,    0,
 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066,
 2066, 2066,    0, 2066, 2066, 2066,    0, 2066,    0, 2066,
 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066,
 2066, 2066, 2066, 2066,    0, 2066, 2066, 2066, 2066, 2066,
 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066,
 2066, 2066, 2066, 2066, 2066, 2066,    0, 1026, 2066, 2066,
 1024,    0, 1025,    0, 2066, 2066, 2066, 2066, 2066, 2066,
 2066, 2066, 2066,    0,    0, 1027,    0,    0,    0,    0,
 1028,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  154,    0,  155,    0,    0,    0,
    0,    0,  156,    0,  854,  157,  158,    0,    0,    0,
    0,  855,    0,    0,    0,    0,  159,  160,    0,  161,
    0,  162,  856,    0,  163,    0,    0,  164,  857,  858,
    0,    0,    0,    0,  165,    0,  166,  167,    0,    0,
    0,  168,    0,  169,    0,  859,  170,    0,    0,    0,
    0,    0,    0,    0,  860,    0,  171,  861,    0,    0,
    0,  173,    0,  174,    0,  175,    0,    0,    0,    0,
    0,  176,    0,  177,    0,    0,    0,  178,    0,    0,
    0,  862,    0,  863,  864,  179,  865,    0,  180,    0,
  181,  866,    0,  867,  182,  183,    0,    0,    0,    0,
    0,  868,    0,    0,    0,    0,    0,  184,    0,    0,
    0,  186,  187,  188,  189,  190,    0,  191,    0,  869,
    0,    0,    0,  192,    0,  193,  194,    0,    0,  195,
  196,    0,    0,    0,  870,    0,  197,    0,    0,  198,
  199,  871,  201,    0,  202,    0,  203,  872,  204,  205,
  206,  207,  208,  873,    0,    0,    0,  209,    0,  210,
    0,    0,    0,  874,    0,    0,    0,    0,    0,    0,
  211,    0,    0,    0,    0,  212,  213,  875,  876,  877,
  878,  879,  880,  881,  606,  607,  215,    0,  216,  217,
  218,  219,    0,  220,  882,    0,    0,    0,    0,    0,
    0,  221,  222,  883,  884,  885,  886,  887,  888,  889,
  890,  891,  223,  892,    0,  225,  226,  227,  893,  894,
    0,  895,  896,  897,    0,  230,  231,  898,  232,    0,
    0,  233,  234,  899,  900,  901,  235,  236,    0,    0,
    0,    0,  237,  902,  239,    0,  903,  241,  242,    0,
  243,    0,  904,  905,  906,    0,  907,  908,    0,  909,
  244,  245,  246,  247,  248,  249,  910,  251,  911,  253,
  912,  913,  914,  915,  916,  917,  918,  919,  920,  921,
  922,    0,  923,  924,  925,  926,  927,  928,    0,  929,
  930,  931,  274,    0,  932,    0,  933,  934,  935,  936,
  937,  281,  282,  938,  284,  939,  940,  941,  288,  942,
  290,  943,  292,  944,    0,  945,  946,  947,  948,    0,
  949,  950,  951,  301,  952,    0,  953,  954,  305,  955,
  307,  308,  956,  310,  311,  312,  313,  314,  315,    0,
  957,  317,  318,  319,  320,  321,    0,  958,  323,  324,
  325,  959,  960,  328,  329,    0,  330,  331,  961,  962,
    0,  332,  333,  334,  963,  964,  965,    0,    0,  338,
  966,  967,  968,  969,  970,  971,  972,  973,  974,    0,
  975,  976,  977,  347,  978,  348,  349,  350,  351,  352,
  353,    0,    0,  979,  980,  981,  982,  983,  984,  985,
  986,  987,  988,  989,  990,  991,  992,  993,  994,  995,
  996,    0,  356,  997,  358,  359,  998,  361,  362,  363,
  999,    0,  365,  366,  367,  368,  369,  370, 1000,  372,
 1001, 1002,  375,  376,    0,  377,  378, 1003,    0,  380,
    0, 1004, 1005,  381, 1006,  383,  384,  385, 1007, 1008,
  388,  389,  390, 1009,  392,  393,    0, 1010,  395, 1011,
 1012, 1013, 1014, 1015,  396, 1016, 1017, 1018, 1019, 1020,
 1021,  403,  404,  405,  406,  407,  408,  409,    0, 1314,
 1022,  411, 1024,    0, 1025,    0,  412,  413,  414,  415,
  416,  417,  418,  419, 1023,    0,    0, 1027,    0,    0,
    0,    0, 1028,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  154,    0,  155,    0,
    0,    0,    0,    0,  156,    0,  854,  157,  158,    0,
    0,    0,    0,  855,    0,    0,    0,    0,  159,  160,
    0,  161,    0,  162,  856,    0,  163,    0,    0,  164,
  857,  858,    0,    0,    0,    0,  165,    0,  166,  167,
    0,    0,    0,  168,    0,  169,    0,  859,  170,    0,
    0,    0,    0,    0,    0,    0,  860,    0,  171,  861,
    0,    0,    0,  173,    0,  174,    0,  175,    0,    0,
    0,    0,    0,  176,    0,  177,    0,    0,    0,  178,
    0,    0,    0,  862,    0,  863,  864,  179,  865,    0,
  180,    0,  181,  866,    0,  867,  182,  183,    0,    0,
    0,    0,    0,  868,    0,    0,    0,    0,    0,  184,
    0,    0,    0,  186,  187,  188,  189,  190,    0,  191,
    0,  869,    0,    0,    0,  192,    0,  193,  194,    0,
    0,  195,  196,    0,    0,    0,  870,    0,  197,    0,
    0,  198,  199,  871,  201,    0,  202,    0,  203,  872,
  204,  205,  206,  207,  208,  873,    0,    0,    0,  209,
    0,  210,    0,    0,    0,  874,    0,    0,    0,    0,
    0,    0,  211,    0,    0,    0,    0,  212,  213,  875,
  876,  877,  878,  879,  880,  881,  606,  607,  215,    0,
  216,  217,  218,  219,    0,  220,  882,    0,    0,    0,
    0,    0,    0,  221,  222,  883,  884,  885,  886,  887,
  888,  889,  890,  891,  223,  892,    0,  225,  226,  227,
  893,  894,    0,  895,  896,  897,    0,  230,  231,  898,
  232,    0,    0,  233,  234,  899,  900,  901,  235,  236,
    0,    0,    0,    0,  237,  902,  239,    0,  903,  241,
  242,    0,  243,    0,  904,  905,  906,    0,  907,  908,
    0,  909,  244,  245,  246,  247,  248,  249,  910,  251,
  911,  253,  912,  913,  914,  915,  916,  917,  918,  919,
  920,  921,  922,    0,  923,  924,  925,  926,  927,  928,
    0,  929,  930,  931,  274,    0,  932,    0,  933,  934,
  935,  936,  937,  281,  282,  938,  284,  939,  940,  941,
  288,  942,  290,  943,  292,  944,    0,  945,  946,  947,
  948,    0,  949,  950,  951,  301,  952,    0,  953,  954,
  305,  955,  307,  308,  956,  310,  311,  312,  313,  314,
  315,    0,  957,  317,  318,  319,  320,  321,    0,  958,
  323,  324,  325,  959,  960,  328,  329,    0,  330,  331,
  961,  962,    0,  332,  333,  334,  963,  964,  965,    0,
    0,  338,  966,  967,  968,  969,  970,  971,  972,  973,
  974,    0,  975,  976,  977,  347,  978,  348,  349,  350,
  351,  352,  353,    0,    0,  979,  980,  981,  982,  983,
  984,  985,  986,  987,  988,  989,  990,  991,  992,  993,
  994,  995,  996,    0,  356,  997,  358,  359,  998,  361,
  362,  363,  999,    0,  365,  366,  367,  368,  369,  370,
 1000,  372, 1001, 1002,  375,  376,    0,  377,  378, 1003,
    0,  380,    0, 1004, 1005,  381, 1006,  383,  384,  385,
 1007, 1008,  388,  389,  390, 1009,  392,  393,    0, 1010,
  395, 1011, 1012, 1013, 1014, 1015,  396, 1016, 1017, 1018,
 1019, 1020, 1021,  403,  404,  405,  406,  407,  408,  409,
    0, 2571, 1022,  411, 1024,    0, 1025,    0,  412,  413,
  414,  415,  416,  417,  418,  419, 1023,    0,    0, 1027,
    0,    0,    0,    0, 1028,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  154,    0,
  155,    0,    0,    0,    0,    0,  156,    0,  854,  157,
  158,    0,    0,    0,    0,  855,    0,    0,    0,    0,
  159,  160,    0,  161,    0,  162,  856,    0,  163,    0,
    0,  164,  857,  858,    0,    0,    0,    0,  165,    0,
  166,  167,    0,    0,    0,  168,    0,  169,    0,  859,
  170,    0,    0,    0,    0,    0,    0,    0,  860,    0,
  171,  861,    0,    0,    0,  173,    0,  174,    0,  175,
    0,    0,    0,    0,    0,  176,    0,  177,    0,    0,
    0,  178,    0,    0,    0,  862,    0,  863,  864,  179,
  865,    0,  180,    0,  181,  866,    0,  867,  182,  183,
    0,    0,    0,    0,    0,  868,    0,    0,    0,    0,
    0,  184,    0,    0,    0,  186,  187,  188,  189,  190,
    0,  191,    0,  869,    0,    0,    0,  192,    0,  193,
  194,    0,    0,  195,  196,    0,    0,    0,  870,    0,
  197,    0,    0,  198,  199,  871,  201,    0,  202,    0,
  203,  872,  204,  205,  206,  207,  208,  873,    0,    0,
    0,  209,    0,  210,    0,    0,    0,  874,    0,    0,
    0,    0,    0,    0,  211,    0,    0,    0,    0,  212,
  213,  875,  876,  877,  878,  879,  880,  881,  606,  607,
  215,    0,  216,  217,  218,  219,    0,  220,  882,    0,
    0,    0,    0,    0,    0,  221,  222,  883,  884,  885,
  886,  887,  888,  889,  890,  891,  223,  892,    0,  225,
  226,  227,  893,  894,    0,  895,  896,  897,    0,  230,
  231,  898,  232,    0,    0,  233,  234,  899,  900,  901,
  235,  236,    0,    0,    0,    0,  237,  902,  239,    0,
  903,  241,  242,    0,  243,    0,  904,  905,  906,    0,
  907,  908,    0,  909,  244,  245,  246,  247,  248,  249,
  910,  251,  911,  253,  912,  913,  914,  915,  916,  917,
  918,  919,  920,  921,  922,    0,  923,  924,  925,  926,
  927,  928,    0,  929,  930,  931,  274,    0,  932,    0,
  933,  934,  935,  936,  937,  281,  282,  938,  284,  939,
  940,  941,  288,  942,  290,  943,  292,  944,    0,  945,
  946,  947,  948,    0,  949,  950,  951,  301,  952,    0,
  953,  954,  305,  955,  307,  308,  956,  310,  311,  312,
  313,  314,  315,    0,  957,  317,  318,  319,  320,  321,
    0,  958,  323,  324,  325,  959,  960,  328,  329,    0,
  330,  331,  961,  962,    0,  332,  333,  334,  963,  964,
  965,    0,    0,  338,  966,  967,  968,  969,  970,  971,
  972,  973,  974,    0,  975,  976,  977,  347,  978,  348,
  349,  350,  351,  352,  353,    0,    0,  979,  980,  981,
  982,  983,  984,  985,  986,  987,  988,  989,  990,  991,
  992,  993,  994,  995,  996,    0,  356,  997,  358,  359,
  998,  361,  362,  363,  999,    0,  365,  366,  367,  368,
  369,  370, 1000,  372, 1001, 1002,  375,  376,    0,  377,
  378, 1003,    0,  380,    0, 1004, 1005,  381, 1006,  383,
  384,  385, 1007, 1008,  388,  389,  390, 1009,  392,  393,
    0, 1010,  395, 1011, 1012, 1013, 1014, 1015,  396, 1016,
 1017, 1018, 1019, 1020, 1021,  403,  404,  405,  406,  407,
  408,  409,    0, 3559, 1022,  411, 1024,    0, 1025,    0,
  412,  413,  414,  415,  416,  417,  418,  419, 1023,    0,
    0, 1027,    0,    0,    0,    0, 1028,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  154,    0,  155,    0,    0,    0,    0,    0,  156,    0,
  854,  157,  158,    0,    0,    0,    0,  855,    0,    0,
    0,    0,  159,  160,    0,  161,    0,  162,  856,    0,
  163,    0,    0,  164,  857,  858,    0,    0,    0,    0,
  165,    0,  166,  167,    0,    0,    0,  168,    0,  169,
    0,  859,  170,    0,    0,    0,    0,    0,    0,    0,
  860,    0,  171,  861,    0,    0,    0,  173,    0,  174,
    0,  175,    0,    0,    0,    0,    0,  176,    0,  177,
    0,    0,    0,  178,    0,    0,    0,  862,    0,  863,
  864,  179,  865,    0,  180,    0,  181,  866,    0,  867,
  182,  183,    0,    0,    0,    0,    0,  868,    0,    0,
    0,    0,    0,  184,    0,    0,    0,  186,  187,  188,
  189,  190,    0,  191,    0,  869,    0,    0,    0,  192,
    0,  193,  194,    0,    0,  195,  196,    0,    0,    0,
  870,    0,  197,    0,    0,  198,  199,  871,  201,    0,
  202,    0,  203,  872,  204,  205,  206,  207,  208,  873,
    0,    0,    0,  209,    0,  210,    0,    0,    0,  874,
    0,    0,    0,    0,    0,    0,  211,    0,    0,    0,
    0,  212,  213,  875,  876,  877,  878,  879,  880,  881,
  606,  607,  215,    0,  216,  217,  218,  219,    0,  220,
  882,    0,    0,    0,    0,    0,    0,  221,  222,  883,
  884,  885,  886,  887,  888,  889,  890,  891,  223,  892,
    0,  225,  226,  227,  893,  894,    0,  895,  896,  897,
    0,  230,  231,  898,  232,    0,    0,  233,  234,  899,
  900,  901,  235,  236,    0,    0,    0,    0,  237,  902,
  239,    0,  903,  241,  242,    0,  243,    0,  904,  905,
  906,    0,  907,  908,    0,  909,  244,  245,  246,  247,
  248,  249,  910,  251,  911,  253,  912,  913,  914,  915,
  916,  917,  918,  919,  920,  921,  922,    0,  923,  924,
  925,  926,  927,  928,    0,  929,  930,  931,  274,    0,
  932,    0,  933,  934,  935,  936,  937,  281,  282,  938,
  284,  939,  940,  941,  288,  942,  290,  943,  292,  944,
    0,  945,  946,  947,  948,    0,  949,  950,  951,  301,
  952,    0,  953,  954,  305,  955,  307,  308,  956,  310,
  311,  312,  313,  314,  315,    0,  957,  317,  318,  319,
  320,  321,    0,  958,  323,  324,  325,  959,  960,  328,
  329,    0,  330,  331,  961,  962,    0,  332,  333,  334,
  963,  964,  965,    0,    0,  338,  966,  967,  968,  969,
  970,  971,  972,  973,  974,    0,  975,  976,  977,  347,
  978,  348,  349,  350,  351,  352,  353,    0,    0,  979,
  980,  981,  982,  983,  984,  985,  986,  987,  988,  989,
  990,  991,  992,  993,  994,  995,  996,    0,  356,  997,
  358,  359,  998,  361,  362,  363,  999,    0,  365,  366,
  367,  368,  369,  370, 1000,  372, 1001, 1002,  375,  376,
    0,  377,  378, 1003,    0,  380,    0, 1004, 1005,  381,
 1006,  383,  384,  385, 1007, 1008,  388,  389,  390, 1009,
  392,  393,    0, 1010,  395, 1011, 1012, 1013, 1014, 1015,
  396, 1016, 1017, 1018, 1019, 1020, 1021,  403,  404,  405,
  406,  407,  408,  409,    0, 1314, 1022,  411, 1024,    0,
 1025,    0,  412,  413,  414,  415,  416,  417,  418,  419,
 1023,    0,    0, 1027,    0,    0,    0,    0, 1028,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  154,    0,  155,    0,    0,    0,    0,    0,
  156,    0,  854,  157,  158,    0,    0,    0,    0,  855,
    0,    0,    0,    0,  159,  160,    0,  161,    0,  162,
  856,    0,  163,    0,    0,  164,  857,  858,    0,    0,
    0,    0,  165,    0,  166,  167,    0,    0,    0,  168,
    0,  169,    0,  859,  170,    0,    0,    0,    0,    0,
    0,    0,  860,    0,  171,  861,    0,    0,    0,  173,
    0,  174,    0,  175,    0,    0,    0,    0,    0,  176,
    0,  177,    0,    0,    0,  178,    0,    0,    0,  862,
    0,  863,  864,  179,  865,    0,  180,    0,  181,  866,
    0,  867,  182,  183,    0,    0,    0,    0,    0,  868,
    0,    0,    0,    0,    0,  184,    0,    0,    0,  186,
  187,  188,  189,  190,    0,  191,    0,  869,    0,    0,
    0,  192,    0,  193,  194,    0,    0,  195,  196,    0,
    0,    0,  870,    0,  197,    0,    0,  198,  199,  871,
  201,    0,  202,    0,  203,  872,  204,  205,  206,  207,
  208,  873,    0,    0,    0,  209,    0,  210,    0,    0,
    0,  874,    0,    0,    0,    0,    0,    0,  211,    0,
    0,    0,    0,  212,  213,  875,  876,  877,  878,  879,
  880,  881,  606,  607,  215,    0,  216,  217,  218,  219,
    0,  220,  882,    0,    0,    0,    0,    0,    0,  221,
  222,  883,  884,  885,  886,  887,  888,  889,  890,  891,
  223,  892,    0,  225,  226,  227,  893,  894,    0,  895,
  896,  897,    0,  230,  231,  898,  232,    0,    0,  233,
  234,  899,  900,  901,  235,  236,    0,    0,    0,    0,
  237,  902,  239,    0,  903,  241,  242,    0,  243,    0,
  904,  905,  906,    0,  907,  908,    0,  909,  244,  245,
  246,  247,  248,  249,  910,  251,  911,  253,  912,  913,
  914,  915,  916,  917,  918,  919,  920,  921,  922,    0,
  923,  924,  925,  926,  927,  928,    0,  929,  930,  931,
  274,    0,  932,    0,  933,  934,  935,  936,  937,  281,
  282,  938,  284,  939,  940,  941,  288,  942,  290,  943,
  292,  944,    0,  945,  946,  947,  948,    0,  949,  950,
  951,  301,  952,    0,  953,  954,  305,  955,  307,  308,
  956,  310,  311,  312,  313,  314,  315,    0,  957,  317,
  318,  319,  320,  321,    0,  958,  323,  324,  325,  959,
  960,  328,  329,    0,  330,  331,  961,  962,    0,  332,
  333,  334,  963,  964,  965,    0,    0,  338,  966,  967,
  968,  969,  970,  971,  972,  973,  974,    0,  975,  976,
  977,  347,  978,  348,  349,  350,  351,  352,  353,    0,
    0,  979,  980,  981,  982,  983,  984,  985,  986,  987,
  988,  989,  990,  991,  992,  993,  994,  995,  996,    0,
  356,  997,  358,  359,  998,  361,  362,  363,  999,    0,
  365,  366,  367, 3983,  369,  370, 1000,  372, 1001, 1002,
  375,  376,    0,  377,  378, 1003,    0,  380,    0, 1004,
 1005,  381, 1006,  383,  384,  385, 1007, 1008,  388,  389,
  390, 1009,  392,  393,    0, 1010,  395, 1011, 1012, 1013,
 1014, 1015,  396, 1016, 1017, 1018, 1019, 1020, 1021,  403,
  404,  405,  406,  407,  408,  409,    0, 1314, 1022,  411,
 1024,    0, 1025,    0,  412,  413,  414,  415,  416,  417,
  418,  419, 1023,    0,    0, 1027,    0,    0,    0,    0,
 1028,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  154,    0,  155,    0,    0,    0,
    0,    0,  156,    0,  854,  157,  158,    0,    0,    0,
    0,  855,    0,    0,    0,    0,  159,  160,    0,  161,
    0,  162,  856,    0,  163,    0,    0,  164,  857,  858,
    0,    0,    0,    0,  165,    0,  166,  167,    0,    0,
    0,  168,    0,  169,    0,  859,  170,    0,    0,    0,
    0,    0,    0,    0,  860,    0,  171,  861,    0,    0,
    0,  173,    0,  174,    0,  175,    0,    0,    0,    0,
    0,  176,    0,  177,    0,    0,    0,  178,    0,    0,
    0,  862,    0,  863,  864,  179,  865,    0,  180,    0,
  181,  866,    0,  867,  182,  183,    0,    0,    0,    0,
    0,  868,    0,    0,    0,    0,    0,  184,    0,    0,
    0,  186,  187,  188,  189,  190,    0,  191,    0,  869,
    0,    0,    0,  192,    0,  193,  194,    0,    0,  195,
  196,    0,    0,    0,  870,    0,  197,    0,    0,  198,
  199,  871,  201,    0,  202,    0,  203,  872,  204,  205,
  206,  207,  208,  873,    0,    0,    0,  209,    0,  210,
    0,    0,    0,  874,    0,    0,    0,    0,    0,    0,
  211,    0,    0,    0,    0,  212,  213,  875,  876,  877,
  878,  879,  880,  881,  606,  607,  215,    0,  216,  217,
  218,  219,    0,  220,  882,    0,    0,    0,    0,    0,
    0,  221,  222,  883,  884,  885,  886,  887,  888,  889,
  890,  891,  223,  892,    0,  225,  226,  227,  893,  894,
    0,  895,  896,  897,    0,  230,  231,  898,  232,    0,
    0,  233,  234,  899,  900,  901,  235,  236,    0,    0,
    0,    0,  237,  902,  239,    0,  903,  241,  242,    0,
  243,    0,  904,  905,  906,    0,  907,  908,    0,  909,
  244,  245,  246,  247,  248,  249,  910,  251,  911,  253,
  912,  913,  914,  915,  916,  917,  918,  919,  920,  921,
  922,    0,  923,  924,  925,  926,  927,  928,    0,  929,
  930,  931,  274,    0,  932,    0,  933,  934,  935,  936,
  937,  281,  282,  938,  284,  939,  940,  941,  288,  942,
  290,  943,  292,  944,    0,  945,  946,  947,  948,    0,
  949,  950,  951,  301,  952,    0,  953,  954,  305,  955,
  307,  308,  956,  310,  311,  312,  313,  314,  315,    0,
  957,  317,  318, 3990,  320,  321,    0,  958,  323,  324,
  325,  959,  960,  328,  329,    0,  330,  331,  961,  962,
    0,  332,  333,  334,  963,  964,  965,    0,    0,  338,
  966,  967,  968,  969,  970,  971,  972,  973,  974,    0,
  975,  976,  977,  347,  978,  348,  349,  350,  351,  352,
  353,    0,    0,  979,  980,  981,  982,  983,  984,  985,
  986,  987,  988,  989,  990,  991,  992,  993,  994,  995,
  996,    0,  356,  997,  358,  359,  998,  361,  362,  363,
  999,    0,  365,  366,  367,  368,  369,  370, 1000,  372,
 1001, 1002,  375,  376,    0,  377,  378, 1003,    0,  380,
    0, 1004, 1005,  381, 1006,  383,  384,  385, 1007, 1008,
  388,  389,  390, 1009,  392,  393,    0, 1010,  395, 1011,
 1012, 1013, 1014, 1015,  396, 1016, 1017, 1018, 1019, 1020,
 1021,  403,  404,  405,  406,  407,  408,  409,    0, 2066,
 1022,  411, 2066,    0, 2066,    0,  412,  413,  414,  415,
  416,  417,  418,  419, 1023,    0,    0, 2066,    0,    0,
    0,    0, 2066,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2066,    0, 2066,    0,
    0,    0,    0,    0, 2066,    0, 2066, 2066, 2066,    0,
    0,    0,    0, 2066,    0,    0,    0,    0, 2066, 2066,
    0, 2066,    0, 2066, 2066,    0, 2066,    0,    0, 2066,
 2066, 2066,    0,    0,    0,    0, 2066,    0, 2066, 2066,
    0,    0,    0, 2066,    0, 2066,    0, 2066, 2066,    0,
    0,    0,    0,    0,    0,    0, 2066,    0, 2066, 2066,
    0,    0,    0, 2066,    0, 2066,    0, 2066,    0,    0,
    0,    0,    0, 2066,    0, 2066,    0,    0,    0, 2066,
    0,    0,    0, 2066,    0, 2066, 2066, 2066, 2066,    0,
 2066,    0, 2066, 2066,    0, 2066, 2066, 2066,    0,    0,
    0,    0,    0, 2066,    0,    0,    0,    0,    0, 2066,
    0,    0,    0, 2066, 2066, 2066, 2066, 2066,    0, 2066,
    0, 2066,    0,    0,    0, 2066,    0, 2066, 2066,    0,
    0, 2066, 2066,    0,    0,    0, 2066,    0, 2066,    0,
    0, 2066, 2066, 2066, 2066,    0, 2066,    0, 2066, 2066,
 2066, 2066, 2066, 2066, 2066, 2066,    0,    0,    0, 2066,
    0, 2066,    0,    0,    0, 2066,    0,    0,    0,    0,
    0,    0, 2066,    0,    0,    0,    0, 2066, 2066, 2066,
 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066,    0,
 2066, 2066, 2066, 2066,    0, 2066, 2066,    0,    0,    0,
    0,    0,    0, 2066, 2066, 2066, 2066, 2066, 2066, 2066,
 2066, 2066, 2066, 2066, 2066, 2066,    0, 2066, 2066, 2066,
 2066, 2066,    0, 2066, 2066, 2066,    0, 2066, 2066, 2066,
 2066,    0,    0, 2066, 2066, 2066, 2066, 2066, 2066, 2066,
    0,    0,    0,    0, 2066, 2066, 2066,    0, 2066, 2066,
 2066,    0, 2066,    0, 2066, 2066, 2066,    0, 2066, 2066,
    0, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066,
 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066,
 2066, 2066, 2066,    0, 2066, 2066, 2066, 2066, 2066, 2066,
    0, 2066, 2066, 2066, 2066,    0, 2066,    0, 2066, 2066,
 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066,
 2066, 2066, 2066, 2066, 2066, 2066,    0, 2066, 2066, 2066,
 2066,    0, 2066, 2066, 2066, 2066, 2066,    0, 2066, 2066,
 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066,
 2066,    0, 2066, 2066, 2066, 2066, 2066, 2066,    0, 2066,
 2066, 2066, 2066, 2066, 2066, 2066, 2066,    0, 2066, 2066,
 2066, 2066,    0, 2066, 2066, 2066, 2066, 2066, 2066,    0,
    0, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066,
 2066,    0, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066,
 2066, 2066, 2066,    0,    0, 2066, 2066, 2066, 2066, 2066,
 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066,
 2066, 2066, 2066,    0, 2066, 2066, 2066, 2066, 2066, 2066,
 2066, 2066, 2066,    0, 2066, 2066, 2066, 2066, 2066, 2066,
 2066, 2066, 2066, 2066, 2066, 2066,    0, 2066, 2066, 2066,
    0, 2066,    0, 2066, 2066, 2066, 2066, 2066, 2066, 2066,
 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066,    0, 2066,
 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066,
 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066, 2066,
    0, 1597, 2066, 2066, 1597,    0, 1597,    0, 2066, 2066,
 2066, 2066, 2066, 2066, 2066, 2066, 2066,    0,    0, 1597,
    0,    0,    0,    0, 1597,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1597,    0,
 1597,    0,    0,    0,    0,    0, 1597,    0, 1597, 1597,
 1597,    0,    0,    0,    0, 1597,    0,    0,    0,    0,
 1597, 1597,    0, 1597,    0, 1597, 1597,    0, 1597,    0,
    0, 1597, 1597, 1597,    0,    0,    0,    0, 1597,    0,
 1597, 1597,    0,    0,    0, 1597,    0, 1597,    0, 1597,
 1597,    0,    0,    0,    0,    0,    0,    0, 1597,    0,
 1597, 1597,    0,    0,    0, 1597,    0, 1597,    0, 1597,
    0,    0,    0,    0,    0, 1597,    0, 1597,    0,    0,
    0, 1597,    0,    0,    0, 1597,    0, 1597, 1597, 1597,
 1597,    0, 1597,    0, 1597, 1597,    0, 1597, 1597, 1597,
    0,    0,    0,    0,    0, 1597,    0,    0,    0,    0,
    0, 1597,    0,    0,    0, 1597, 1597, 1597, 1597, 1597,
    0, 1597,    0, 1597,    0,    0,    0, 1597,    0, 1597,
 1597,    0,    0, 1597, 1597,    0,    0,    0, 1597,    0,
 1597,    0,    0, 1597, 1597, 1597, 1597,    0, 1597,    0,
 1597, 1597, 1597, 1597, 1597, 1597, 1597, 1597,    0,    0,
    0, 1597,    0, 1597,    0,    0,    0, 1597,    0,    0,
    0,    0,    0,    0, 1597,    0,    0,    0,    0, 1597,
 1597, 1597, 1597, 1597, 1597, 1597, 1597, 1597, 1597, 1597,
 1597,    0, 1597, 1597, 1597, 1597,    0, 1597, 1597,    0,
    0,    0,    0,    0,    0, 1597, 1597, 1597, 1597, 1597,
 1597, 1597, 1597, 1597, 1597, 1597, 1597, 1597,    0, 1597,
 1597, 1597, 1597, 1597,    0, 1597, 1597, 1597,    0, 1597,
 1597, 1597, 1597,    0,    0, 1597, 1597, 1597, 1597, 1597,
 1597, 1597,    0,    0,    0,    0, 1597, 1597, 1597,    0,
 1597, 1597, 1597,    0, 1597,    0, 1597, 1597, 1597,    0,
 1597, 1597,    0, 1597, 1597, 1597, 1597, 1597, 1597, 1597,
 1597, 1597, 1597, 1597, 1597, 1597, 1597, 1597, 1597, 1597,
 1597, 1597, 1597, 1597, 1597,    0, 1597, 1597, 1597, 1597,
 1597, 1597,    0, 1597, 1597, 1597, 1597,    0, 1597,    0,
 1597, 1597, 1597, 1597, 1597, 1597, 1597, 1597, 1597, 1597,
 1597, 1597, 1597, 1597, 1597, 1597, 1597, 1597,    0, 1597,
 1597, 1597, 1597,    0, 1597, 1597, 1597, 1597, 1597,    0,
 1597, 1597, 1597, 1597, 1597, 1597, 1597, 1597, 1597, 1597,
 1597, 1597, 1597,    0, 1597, 1597, 1597, 1597, 1597, 1597,
    0, 1597, 1597, 1597, 1597, 1597, 1597, 1597, 1597,    0,
 1597, 1597, 1597, 1597,    0, 1597, 1597, 1597, 1597, 1597,
 1597,    0,    0, 1597, 1597, 1597, 1597, 1597, 1597, 1597,
 1597, 1597, 1597,    0, 1597, 1597, 1597, 1597, 1597, 1597,
 1597, 1597, 1597, 1597, 1597,    0,    0, 1597, 1597, 1597,
 1597, 1597, 1597, 1597, 1597, 1597, 1597, 1597, 1597, 1597,
 1597, 1597, 1597, 1597, 1597,    0, 1597, 1597, 1597, 1597,
 1597, 1597, 1597, 1597, 1597,    0, 1597, 1597, 1597, 1597,
 1597, 1597, 1597, 1597, 1597, 1597, 1597, 1597,    0, 1597,
 1597, 1597,    0, 1597,    0, 1597, 1597, 1597, 1597, 1597,
 1597, 1597, 1597, 1597, 1597, 1597, 1597, 1597, 1597, 1597,
    0, 1597, 1597, 1597, 1597, 1597, 1597, 1597, 1597, 1597,
 1597, 1597, 1597, 1597, 1597, 1597, 1597, 1597, 1597, 1597,
 1597, 1597,    0, 1400, 1597, 1597, 1024,    0, 1025,    0,
 1597, 1597, 1597, 1597, 1597, 1597, 1597, 1597, 1597,    0,
    0, 1027,    0,    0,    0,    0, 1028,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  154,    0,  155,    0,    0,    0,    0,    0,  156,    0,
  854,  157,  158,    0,    0,    0,    0,  855,    0,    0,
    0,    0,  159,  160,    0,  161,    0,  162,  856,    0,
  163,    0,    0,  164,  857,  858,    0,    0,    0,    0,
  165,    0,  166,  167,    0,    0,    0,  168,    0,  169,
    0,    0,  170,    0,    0,    0,    0,    0,    0,    0,
  860,    0,  171,  861,    0,    0,    0,  173,    0,  174,
    0,  175,    0,    0,    0,    0,    0,  176,    0,  177,
    0,    0,    0,  178,    0,    0,    0,  862,    0,  863,
  864,  179,  865,    0,  180,    0,  181,  866,    0,  867,
  182,  183,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  184,    0,    0,    0,  186,  187,  188,
  189,  190,    0,  191,    0,  869,    0,    0,    0,  192,
    0,  193,  194,    0,    0,  195,  196,    0,    0,    0,
  870,    0,  197,    0,    0,  198,  199,  200,  201,    0,
  202,    0,  203,  872,  204,  205,  206,  207,  208,  873,
    0,    0,    0,  209,    0,  210,    0,    0,    0,  874,
    0,    0,    0,    0,    0,    0,  211,    0,    0,    0,
    0,  212,  213,  875,  876,  877,  878,  879,  880,  881,
  606,  607,  215,    0,  216,  217,  218,  219,    0,  220,
  882,    0,    0,    0,    0,    0,    0,  221,  222,  883,
  884,  885,  886,  887,  888,  889,  890,  891,  223,  892,
    0,  225,  226,  227,  893,  894,    0,  895,  896,  897,
    0,  230,  231,  898,  232,    0,    0,  233,  234,    0,
    0,    0,  235,  236,    0,    0,    0,    0,  237,  902,
  239,    0,  903,  241,  242,    0,  243,    0,  904,  905,
  906,    0,  907,  908,    0,  909,  244,  245,  246,  247,
  248,  249,  910,  251,  911,  253,  912,  913,  914,  915,
  916,  917,  918,  919,  920,  921,  922, 1430,  923,  924,
  925,  926,  927,  928,    0,  929,  930,  931,  274,    0,
  932,    0,  933,  934,  935,  936,  937,  281,  282,  938,
  284,  939,  940,  941,  288,  942,  290,  943,  292,  944,
    0,  945,  946,  947,  948,    0,  949,  950,  951,  301,
  952,    0,  953,  954,  305,  955,  307,  308,  956,  310,
  311,  312,  313,  314,  315,    0,  957,  317,  318,  319,
  320,  321,    0,  958,  323,  324,  325,  959,  960,  328,
  329,    0,  330,  331,  961,  962,    0,  332,  333,  334,
  963,  964,  965,    0,    0,  338,  966,  967,  968,  969,
  970,  971,  972,  973,  974,    0,  975,  976,  977,  347,
  978,  348,  349,  350,  351,  352,  353,    0,    0,  979,
  980,  981,  982,  983,  984,  985,  986,  987,  988,  989,
  990,  991,  992,  993,  994,  995,  996,    0,  356,  997,
  358,  359,  998,  361,  362,  363,  999,    0,  365,  366,
  367,  368,  369,  370, 1000,  372, 1001, 1002,  375,  376,
    0,  377,  378, 1003,    0,  380,    0, 1004, 1005,  381,
 1006,  383,  384,  385, 1007, 1008,  388,  389,  390, 1009,
  392,  393,    0, 1010,  395,    0, 1012, 1013, 1014, 1015,
  396, 1016, 1017, 1018, 1019, 1020, 1021,  403,  404,  405,
  406,  407,  408,  409,    0,    0, 1022,  411,    0,    0,
    0,    0,  412,  413,  414,  415,  416,  417,  418,  419,
 1023,    0,    0,    0, 2259,    0, 2259,    0,    0,    0,
    0,    0, 2259,    0,    0, 2259, 2259,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2259, 2259,    0, 2259,
    0, 2259,    0,    0, 2259,    0,    0, 2259,    0,    0,
    0,    0,    0,    0, 2259,    0, 2259, 2259,    0,    0,
    0, 2259,    0, 2259,    0,    0, 2259,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2259, 2259,    0,    0,
    0, 2259,    0, 2259,    0, 2259, 2259,    0,    0,    0,
    0, 2259,    0, 2259,    0,    0,    0, 2259,    0,    0,
    0,    0,    0,    0,    0, 2259,    0,    0, 2259,    0,
 2259,    0,    0,    0, 2259, 2259,    0, 2259,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2259,    0, 2259,
    0, 2259, 2259, 2259, 2259, 2259,    0, 2259,    0,    0,
    0,    0,    0, 2259,    0, 2259, 2259,    0,    0, 2259,
 2259,    0,    0,    0,    0,    0, 2259,    0,    0, 2259,
 2259, 2259, 2259,    0, 2259,    0, 2259,    0, 2259, 2259,
 2259, 2259, 2259,    0,    0,    0,    0, 2259,    0, 2259,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2259,    0,    0,    0,    0, 2259, 2259,    0,    0,    0,
    0,    0, 2259,    0,    0,    0, 2259,    0, 2259, 2259,
 2259, 2259,    0, 2259,    0,    0,    0,    0,    0,    0,
    0, 2259, 2259,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2259, 2259,    0, 2259, 2259, 2259,    0,    0,
    0,    0, 2259, 2259,    0, 2259, 2259,    0, 2259,    0,
    0, 2259, 2259,    0,    0,    0, 2259, 2259,    0,    0,
    0,    0, 2259, 2259, 2259,    0, 2259, 2259, 2259,    0,
 2259,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2259, 2259, 2259, 2259, 2259, 2259, 2259, 2259, 2259, 2259,
 2259, 2259, 2259, 2259, 2259, 2259, 2259, 2259, 2259, 2259,
 2259, 1429, 2259, 2259, 2259, 2259, 2259, 2259,    0, 2259,
 2259, 2259, 2259,    0, 2259,    0, 2259, 2259, 2259, 2259,
 2259, 2259, 2259, 2259, 2259, 2259, 2259, 2259, 2259, 2259,
 2259, 2259, 2259, 2259,    0, 2259, 2259, 2259, 2259,    0,
 2259, 2259, 2259, 2259, 2259,    0, 2259, 2259, 2259, 2259,
 2259, 2259, 2259, 2259, 2259, 2259, 2259, 2259, 2259,    0,
 2259, 2259, 2259, 2259, 2259, 2259,    0, 2259, 2259, 2259,
 2259, 2259, 2259, 2259, 2259,    0, 2259, 2259,    0,    0,
    0, 2259, 2259, 2259, 2259, 2259, 2259,    0,    0, 2259,
 2259, 2259, 2259, 2259, 2259, 2259, 2259, 2259,    0,    0,
    0,    0,    0, 2259,    0, 2259, 2259, 2259, 2259, 2259,
 2259,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2259,
 2259,    0, 2259, 2259, 2259, 2259, 2259, 2259, 2259, 2259,
 2259,    0, 2259, 2259, 2259, 2259, 2259, 2259, 2259, 2259,
 2259, 2259, 2259, 2259,    0, 2259, 2259, 2259,    0, 2259,
    0,    0,    0, 2259, 2259, 2259, 2259, 2259, 2259, 2259,
 2259, 2259, 2259, 2259, 2259, 2259,    0, 2259, 2259,    0,
    0,    0,    0,    0, 2259, 2259, 2259, 2259, 2259, 2259,
 2259, 2259, 2259, 2259, 2259, 2259, 2259, 2259,    0,    0,
 2259, 2259,    0,    0,    0,    0, 2259, 2259, 2259, 2259,
 2259, 2259, 2259, 2259, 2259,    0,    0,    0, 2164,    0,
 2164,    0,    0,    0,    0,    0, 2164,    0,    0, 2164,
 2164,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2164, 2164,    0, 2164,    0, 2164,    0,    0, 2164,    0,
    0, 2164,    0,    0,    0,    0,    0,    0, 2164,    0,
 2164, 2164,    0,    0,    0, 2164,    0, 2164,    0,    0,
 2164,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2164, 2164,    0,    0,    0, 2164,    0, 2164,    0, 2164,
 2164,    0,    0,    0,    0, 2164,    0, 2164,    0,    0,
    0, 2164,    0,    0,    0,    0,    0,    0,    0, 2164,
    0,    0, 2164,    0, 2164,    0,    0,    0, 2164, 2164,
    0, 2164,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 2164,    0, 2164,    0, 2164, 2164, 2164, 2164, 2164,
    0, 2164,    0,    0,    0,    0,    0, 2164,    0, 2164,
 2164,    0,    0, 2164, 2164,    0,    0,    0,    0,    0,
 2164,    0,    0, 2164, 2164, 2164, 2164,    0, 2164,    0,
 2164,    0, 2164, 2164, 2164, 2164, 2164,    0,    0,    0,
    0, 2164,    0, 2164,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2164,    0,    0,    0,    0, 2164,
 2164,    0,    0,    0,    0,    0, 2164,    0,    0,    0,
 2164,    0, 2164, 2164, 2164, 2164,    0, 2164,    0,    0,
    0,    0,    0,    0,    0, 2164, 2164,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2164, 2164,    0, 2164,
 2164, 2164,    0,    0,    0,    0, 2164, 2164,    0, 2164,
 2164,    0, 2164,    0,    0, 2164, 2164,    0,    0,    0,
 2164, 2164,    0,    0,    0,    0, 2164, 2164, 2164,    0,
 2164, 2164, 2164,    0, 2164,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2164, 2164, 2164, 2164, 2164, 2164,
 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164,
 2164, 2164, 2164, 2164, 2164, 1468, 2164, 2164, 2164, 2164,
 2164, 2164,    0, 2164, 2164, 2164, 2164,    0, 2164,    0,
 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164,
 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164,    0, 2164,
 2164, 2164, 2164,    0, 2164, 2164, 2164, 2164, 2164,    0,
 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164,
 2164, 2164, 2164,    0, 2164, 2164, 2164, 2164, 2164, 2164,
    0, 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164,    0,
 2164, 2164,    0,    0,    0, 2164, 2164, 2164, 2164, 2164,
 2164,    0,    0, 2164, 2164, 2164, 2164, 2164, 2164, 2164,
 2164, 2164,    0,    0,    0,    0,    0, 2164,    0, 2164,
 2164, 2164, 2164, 2164, 2164,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2164, 2164,    0, 2164, 2164, 2164, 2164,
 2164, 2164, 2164, 2164, 2164,    0, 2164, 2164, 2164, 2164,
 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164,    0, 2164,
 2164, 2164,    0, 2164,    0,    0,    0, 2164, 2164, 2164,
 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164,
    0, 2164, 2164,    0,    0,    0,    0,    0, 2164, 2164,
 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164,
 2164, 2164,    0,    0, 2164, 2164,    0,    0,    0,    0,
 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164, 2164,    0,
    0,    0,  154,    0,  155,    0,    0,    0,    0,    0,
  156,    0,    0,  157,  158,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  159,  160,    0,  161,    0,  162,
    0,    0,  163,    0,    0,  164,    0,    0,    0,    0,
    0,    0,  165,    0,  166,  167,    0,    0,    0,  168,
    0,  169,    0,    0,  170,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  171,  172,    0,    0,    0,  173,
    0,  174,    0,  175,    0,    0,    0,    0,    0,  176,
    0,  177,    0,    0,    0,  178,    0,    0,    0,    0,
    0,    0,    0,  179,    0,    0,  180,    0,  181,    0,
    0,    0,  182,  183,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  184,    0,    0,    0,  186,
  187,  188,  189,  190,    0,  191,    0,    0,    0,    0,
    0,  192,    0,  193,  194,    0,    0,  195,  196,    0,
    0,    0,    0,    0,  197,    0,    0,  198,  199,  200,
  201,    0,  202,    0,  203,    0,  204,  205,  206,  207,
  208,    0,    0,    0,    0,  209,    0,  210,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  211,    0,
    0,    0,   15,  212,  213,    0,    0,    0,    0,    0,
  214,    0,    0,    0,  215,    0,  216,  217,  218,  219,
    0,  220,    0,    0,    0,    0,    0,    0,    0,  221,
  222,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  223,  224,    0,  225,  226,  227,    0,    0,    0,    0,
  228,  229,    0,  230,  231,    0,  232,    0,    0,  233,
  234,    0,    0,    0,  235,  236,    0,    0,    0,    0,
  237,  238,  239,    0,  240,  241,  242,    0,  243,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  244,  245,
  246,  247,  248,  249,  250,  251,  252,  253,  254,  255,
  256,  257,  258,  259,  260,  261,  262,  263,  264, 1468,
  265,  266,  267,  268,  269,  270,    0,  271,  272,  273,
  274,    0,  275,    0,  276,  277,  278,  279,  280,  281,
  282,  283,  284,  285,  286,  287,  288,  289,  290,  291,
  292,  293,    0,  294,  295,  296,  297,    0,  298,  299,
  300,  301,  302,    0,  303,  304,  305,  306,  307,  308,
  309,  310,  311,  312,  313,  314,  315,    0,  316,  317,
  318,  319,  320,  321,    0,  322,  323,  324,  325,  326,
  327,  328,  329,    0,  330,  331,    0,    0,    0,  332,
  333,  334,  335,  336,  337,    0,    0,  338,  339,  340,
  341,  342,  343,  344,  345,  346,    0,    0,    0,    0,
    0,  347,    0,  348,  349,  350,  351,  352,  353,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  354,  355,    0,
  356,  357,  358,  359,  360,  361,  362,  363,  364,    0,
  365,  366,  367,  368,  369,  370,  371,  372,  373,  374,
  375,  376,    0,  377,  378,  379, 1467,  380,    0,    0,
    0,  381,  382,  383,  384,  385,  386,  387,  388,  389,
  390,  391,  392,  393,    0,  394,  395,    0,    0,    0,
    0,    0,  396,  397,  398,  399,  400,  401,  402,  403,
  404,  405,  406,  407,  408,  409,    0,    0,  410,  411,
    0,    0,    0,    0,  412,  413,  414,  415,  416,  417,
  418,  419,  420,    0,    0,    0,  154,    0,  155,    0,
    0,    0,    0,    0,  156,    0,    0,  157,  158,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  159,  160,
    0,  161,    0,  162,    0,    0,  163,    0,    0,  164,
    0,    0,    0,    0,    0,    0,  165,    0,  166,  167,
    0,    0,    0,  168,    0,  169,    0,    0,  170,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  171,  172,
    0,    0,    0,  173,    0,  174,    0,  175,    0,    0,
    0,    0,    0,  176,    0,  177,    0,    0,    0,  178,
    0,    0,    0,    0,    0,    0,    0,  179,    0,    0,
  180,    0,  181,    0,    0,    0,  182,  183,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  184,
    0,    0,    0,  186,  187,  188,  189,  190,    0,  191,
    0,    0,    0,    0,    0,  192,    0,  193,  194,    0,
    0,  195,  196,    0,    0,    0,    0,    0,  197,    0,
    0,  198,  199,  200,  201,    0,  202,    0,  203,    0,
  204,  205,  206,  207,  208,    0,    0,    0,    0,  209,
    0,  210,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  211,    0,    0,    0,    0,  212,  213,    0,
    0,    0,    0,    0,  214,    0,    0,    0,  215,    0,
  216,  217,  218,  219,    0,  220,    0,    0,    0,    0,
    0,    0,    0,  221,  222,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  223,  224,    0,  225,  226,  227,
    0,    0,    0,    0,  228,  229,    0,  230,  231,    0,
  232,    0,    0,  233,  234,    0,    0,    0,  235,  236,
    0,    0,    0,    0,  237,  238,  239,    0,  240,  241,
  242,    0,  243,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  244,  245,  246,  247,  248,  249,  250,  251,
  252,  253,  254,  255,  256,  257,  258,  259,  260,  261,
  262,  263,  264,    0,  265,  266,  267,  268,  269,  270,
    0,  271,  272,  273,  274,    0,  275,    0,  276,  277,
  278,  279,  280,  281,  282,  283,  284,  285,  286,  287,
  288,  289,  290,  291,  292,  293,    0,  294,  295,  296,
  297,    0,  298,  299,  300,  301,  302,    0,  303,  304,
  305,  306,  307,  308,  309,  310,  311,  312,  313,  314,
  315,    0,  316,  317,  318,  319,  320,  321,    0,  322,
  323,  324,  325,  326,  327,  328,  329,    0,  330,  331,
    0,    0, 1801,  332,  333,  334,  335,  336,  337,    0,
    0,  338,  339,  340,  341,  342,  343,  344,  345,  346,
 1027,    0,    0,    0,    0,  347,    0,  348,  349,  350,
  351,  352,  353,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  354,  355,    0,  356,  357,  358,  359,  360,  361,
  362,  363,  364,    0,  365,  366,  367,  368,  369,  370,
  371,  372,  373,  374,  375,  376,    0,  377,  378,  379,
 1467,  380,    0,    0,    0,  381,  382,  383,  384,  385,
  386,  387,  388,  389,  390,  391,  392,  393,    0,  394,
  395,    0,    0,    0,    0,    0,  396,  397,  398,  399,
  400,  401,  402,  403,  404,  405,  406,  407,  408,  409,
    0,    0,  410,  411,    0,    0,    0,    0,  412,  413,
  414,  415,  416,  417,  418,  419,  420,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  154,
    0,  155,    0,    0,    0,    0,    0,  156,    0,    0,
  157,  158,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  159,  160,    0,  161,    0,  162,    0,    0,  163,
    0,    0,  164,    0,    0,    0,    0,    0,    0,  165,
    0,  166,  167,    0,    0,    0,  168,    0,  169,    0,
    0,  170,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  171,  172,    0,    0,    0,  173,    0,  174,    0,
  175,    0,    0,    0,    0,    0,  176,    0,  177,    0,
    0,    0,  178,    0,    0,    0,    0,    0,    0,    0,
  179,    0,    0,  180,    0,  181,    0,    0,    0,  182,
  183,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  184,    0,    0,    0,  186,  187,  188,  189,
  190,    0,  191,    0,    0,    0,    0,    0,  192,    0,
  193,  194,    0,    0,  195,  196,    0,    0,    0,    0,
    0,  197,    0,    0,  198,  199,  200,  201,    0,  202,
    0,  203,    0,  204,  205,  206,  207,  208,    0,    0,
    0,    0,  209,    0,  210,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  211,    0,    0,    0,    0,
  212,  213,    0,    0,    0,    0,    0,  214,    0,    0,
    0,  215,    0,  216,  217,  218,  219,    0,  220,    0,
    0,    0,    0,    0,    0,    0,  221,  222,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  223,  224,    0,
  225,  226,  227,    0,    0,    0,    0,  228,  229,    0,
  230,  231,    0,  232,    0,    0,  233,  234,    0,    0,
    0,  235,  236,    0,    0,    0,    0,  237,  238,  239,
    0,  240,  241,  242,    0,  243,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  244,  245,  246,  247,  248,
  249,  250,  251,  252,  253,  254,  255,  256,  257,  258,
  259,  260,  261,  262,  263,  264, 1843,  265,  266,  267,
  268,  269,  270,    0,  271,  272,  273,  274,    0,  275,
    0,  276,  277,  278,  279,  280,  281,  282,  283,  284,
  285,  286,  287,  288,  289,  290,  291,  292,  293,    0,
  294,  295,  296,  297,    0,  298,  299,  300,  301,  302,
    0,  303,  304,  305,  306,  307,  308,  309,  310,  311,
  312,  313,  314,  315,    0,  316,  317,  318,  319,  320,
  321,    0,  322,  323,  324,  325,  326,  327,  328,  329,
    0,  330,  331,    0,    0,    0,  332,  333,  334,  335,
  336,  337,    0,    0,  338,  339,  340,  341,  342,  343,
  344,  345,  346,    0,    0,    0,    0,    0,  347,    0,
  348,  349,  350,  351,  352,  353,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  354,  355,    0,  356,  357,  358,
  359,  360,  361,  362,  363,  364,    0,  365,  366,  367,
  368,  369,  370,  371,  372,  373,  374,  375,  376,    0,
  377,  378,  379,    0,  380,    0,    0,    0,  381,  382,
  383,  384,  385,  386,  387,  388,  389,  390,  391,  392,
  393,    0,  394,  395,    0,    0,    0,    0,    0,  396,
  397,  398,  399,  400,  401,  402,  403,  404,  405,  406,
  407,  408,  409,    0,    0,  410,  411,    0,    0,    0,
    0,  412,  413,  414,  415,  416,  417,  418,  419,  420,
    0,    0,    0,  154,    0,  155,    0,    0,    0,    0,
    0,  156,    0,    0,  157,  158,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  159,  160,    0,  161,    0,
  162,    0,    0,  163,    0,    0,  164,    0,    0,    0,
    0,    0,    0,  165,    0,  166,  167,    0,    0,    0,
  168,    0,  169,    0,    0,  170,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  171,  172,    0,    0,    0,
  173,    0,  174,    0,  175,    0,    0,    0,    0,    0,
  176,    0,  177,    0,    0,    0,  178,    0,    0,    0,
    0,    0,    0,    0,  179,    0,    0,  180,    0,  181,
    0,    0,    0,  182,  183,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  184,    0,    0,    0,
  186,  187,  188,  189,  190,    0,  191,    0,    0,    0,
    0,    0,  192,    0,  193,  194,    0,    0,  195,  196,
    0,    0,    0,    0,    0,  197,    0,    0,  198,  199,
  200,  201,    0,  202,    0,  203,    0,  204,  205,  206,
  207,  208,    0,    0,    0,    0,  209,    0,  210,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  211,
    0,    0,    0,    0,  212,  213,    0,    0,    0,    0,
    0,  214,    0,    0,    0,  215,    0,  216,  217,  218,
  219,    0,  220,    0,    0,    0,    0,    0,    0,    0,
  221,  222,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  223,  224,    0,  225,  226,  227,    0,    0,    0,
    0,  228,  229,    0,  230,  231,    0,  232,    0,    0,
  233,  234,    0,    0,    0,  235,  236,    0,    0,    0,
    0,  237,  238,  239,    0,  240,  241,  242,    0,  243,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  244,
  245,  246,  247,  248,  249,  250,  251,  252,  253,  254,
  255,  256,  257,  258,  259,  260,  261,  262,  263,  264,
  788,  265,  266,  267,  268,  269,  270,    0,  271,  272,
  273,  274,    0,  275,    0,  276,  277,  278,  279,  280,
  281,  282,  283,  284,  285,  286,  287,  288,  289,  290,
  291,  292,  293,    0,  294,  295,  296,  297,    0,  298,
  299,  300,  301,  302,    0,  303,  304,  305,  306,  307,
  308,  309,  310,  311,  312,  313,  314,  315,    0,  316,
  317,  318,  319,  320,  321,    0,  322,  323,  324,  325,
  326,  327,  328,  329,    0,  330,  331,    0,    0,    0,
  332,  333,  334,  335,  336,  337,    0,    0,  338,  339,
  340,  341,  342,  343,  344,  345,  346,    0,    0,    0,
    0,    0,  347,    0,  348,  349,  350,  351,  352,  353,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  354,  355,
    0,  356,  357,  358,  359,  360,  361,  362,  363,  364,
    0,  365,  366,  367,  368,  369,  370,  371,  372,  373,
  374,  375,  376,    0,  377,  378,  379,    0,  380,    0,
    0,    0,  381,  382,  383,  384,  385,  386,  387,  388,
  389,  390,  391,  392,  393,    0,  394,  395,    0,    0,
    0,    0,    0,  396,  397,  398,  399,  400,  401,  402,
  403,  404,  405,  406,  407,  408,  409,    0,    0,  410,
  411,    0,    0,    0,    0,  412,  413,  414,  415,  416,
  417,  418,  419,  420,    0,    0,    0,  154,    0,  155,
    0,    0,    0,    0,    0,  156,    0,    0,  157,  158,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  159,
 3110,    0,  161,    0,  162,    0,    0,  163,    0,    0,
  164,    0,    0,    0,    0,    0,    0,  165,    0,  166,
  167,    0,    0,    0,  168,    0,  169,    0,    0,  170,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  171,
  172,    0,    0,    0,  173,    0,  174,    0,  175,    0,
    0,    0,    0,    0,  176,    0,  177,    0,    0,    0,
  178,    0,    0,    0,    0,    0,    0,    0,  179,    0,
    0,  180,    0,  181,    0,    0,    0,  182,  183,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  184,    0,    0,    0,  186,  187,  188,  189,  190,    0,
  191,    0,    0,    0,    0,    0,  192,    0,  193,  194,
    0,    0,  195,  196,    0,    0,    0,    0,    0,  197,
    0,    0,  198,  199,  200,  201,    0,  202,    0,  203,
    0,  204,  205,  206,  207,  208,    0,    0,    0,    0,
  209,    0,  210,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  211,    0,    0,    0,    0,  212,  213,
    0,    0,    0,    0,    0,  214,    0,    0,    0,  215,
    0,  216,  217,  218,  219,    0,  220,    0,    0,    0,
    0,    0,    0,    0,  221,  222,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  223,  224,    0,  225,  226,
  227,    0,    0,    0,    0,  228,  229,    0,  230,  231,
    0,  232,    0,    0,  233,  234,    0,    0,    0,  235,
  236,    0,    0,    0,    0,  237,  238,  239,    0,  240,
  241,  242,    0,  243,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  244,  245,  246,  247,  248,  249,  250,
  251,  252,  253,  254,  255,  256,  257,  258,  259,  260,
  261,  262,  263,  264, 2336,  265,  266,  267,  268,  269,
  270,    0,  271,  272,  273,  274,    0,  275,    0,  276,
  277,  278,  279,  280,  281,  282,  283,  284,  285,  286,
  287,  288,  289,  290,  291,  292,  293,    0,  294,  295,
  296,  297,    0,  298,  299,  300,  301,  302,    0,  303,
  304,  305,  306,  307,  308,  309,  310,  311,  312,  313,
  314,  315,    0,  316,  317,  318,  319,  320,  321,    0,
  322,  323,  324,  325,  326,  327,  328,  329,    0,  330,
  331,    0,    0,    0,  332,  333,  334,  335,  336,  337,
    0,    0,  338,  339,  340,  341,  342,  343,  344,  345,
  346,    0,    0,    0,    0,    0,  347,    0,  348,  349,
  350,  351,  352,  353,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  354,  355,    0,  356,  357,  358,  359,  360,
  361,  362,  363,  364,    0,  365,  366,  367,  368,  369,
  370,  371,  372,  373,  374,  375,  376,    0,  377,  378,
  379,    0,  380,    0,    0,    0,  381,  382,  383,  384,
  385,  386,  387,  388,  389,  390,  391,  392,  393,    0,
  394,  395,    0,    0,    0,    0,    0,  396,  397,  398,
  399,  400,  401,  402,  403,  404,  405,  406,  407,  408,
  409,    0,    0,  410,  411,    0,    0,    0,    0,  412,
  413,  414,  415,  416,  417,  418,  419,  420,    0,  154,
    0,  155,    0,    0,    0,    0,    0,  156,    0,    0,
  157,  158,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  159,  160,    0,  161,    0,  162,    0,    0,  163,
    0,    0,  164,    0,  858,    0,    0,    0,    0,  165,
    0,  166,  167,    0,    0,    0,  168,    0,  169,    0,
    0,  170,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  171,  172,    0,    0,    0,  173,    0,  174,    0,
  175,    0,    0,    0,    0,    0,  176,    0,  177,    0,
    0,    0,  178,    0,    0,    0,    0,    0,    0,    0,
  179,    0,    0,  180,    0,  181,    0,    0,    0,  182,
  183,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  184,    0,    0,    0,  186,  187,  188,  189,
  190,    0,  191,    0,    0,    0,    0,    0,  192,    0,
  193,  194,    0,    0,  195,  196,    0,    0,    0,    0,
    0,  197,    0,    0,  198,  199,  200,  201,    0,  202,
    0,  203,    0,  204,  205,  206,  207,  208,    0,    0,
    0,    0,  209,    0,  210,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  211,    0,    0,    0,    0,
  212,  213,    0,    0,    0,    0,    0,  214,    0,    0,
    0,  215,    0,  216,  217,  218,  219,    0,  220,    0,
    0,    0,    0,    0,    0,    0,  221,  222,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  223,  224,    0,
  225,  226,  227,    0,    0,    0,    0,  228,  229,    0,
  230,  231,    0,  232,    0,    0,  233,  234,    0,    0,
    0,  235,  236,    0,    0,    0,    0,  237,  238,  239,
    0,  240,  241,  242,    0,  243,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  244,  245,  246,  247,  248,
  249,  250,  251,  252,  253,  254,  255,  256,  257,  258,
  259,  260,  261,  262,  263,  264,    0,  265,  266,  267,
  268,  269,  270, 1307,  271,  272,  273,  274,    0,  275,
    0,  276,  277,  278,  279,  280,  281,  282,  283,  284,
  285,  286,  287,  288,  289,  290,  291,  292,  293,    0,
  294,  295,  296,  297,    0,  298,  299,  300,  301,  302,
    0,  303,  304,  305,  306,  307,  308,  309,  310,  311,
  312,  313,  314,  315,    0,  316,  317,  318,  319,  320,
  321,    0,  322,  323,  324,  325,  326,  327,  328,  329,
    0,  330,  331,    0,    0,    0,  332,  333,  334,  335,
  336,  337,    0,    0,  338,  339,  340,  341,  342,  343,
  344,  345,  346,    0,    0,    0,    0,    0,  347,  978,
  348,  349,  350,  351,  352,  353,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  354,  355,    0,  356,  357,  358,
  359,  360,  361,  362,  363,  364,    0,  365,  366,  367,
  368,  369,  370,  371,  372,  373,  374,  375,  376,    0,
  377,  378,  379,    0,  380,    0,    0,    0,  381,  382,
  383,  384,  385,  386,  387,  388,  389,  390,  391,  392,
  393,    0,  394,  395,    0,    0,    0,    0,    0,  396,
  397,  398,  399,  400,  401,  402,  403,  404,  405,  406,
  407,  408,  409,    0,    0,  410,  411,    0,    0,    0,
    0,  412,  413,  414,  415,  416,  417,  418,  419,  420,
    0,    0,    0,    0,    0,  154,    0,  155,    0,    0,
    0,    0,    0,  156,    0,    0,  157,  158,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  159,  160,    0,
  161,    0,  162,    0,    0,  163,    0,    0,  164,    0,
    0,    0,    0,    0,    0,  165,    0,  166,  167,    0,
    0,    0,  168,    0,  169,    0,    0,  170,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  171,  172,    0,
    0,    0,  173,    0,  174,    0,  175,    0,    0,    0,
    0,    0,  176,    0,  177,    0,    0,    0,  178,    0,
    0,    0,    0,    0,    0,    0,  179,    0,    0,  180,
    0,  181,    0,    0,    0,  182,  183,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  184,    0,
    0,    0,  186,  187,  188,  189,  190,    0,  191,    0,
    0,    0,    0,    0,  192,    0,  193,  194,    0,    0,
  195,  196,    0,    0,    0,    0,    0,  197,    0,    0,
  198,  199,  200,  201,    0,  202,    0,  203,    0,  204,
  205,  206,  207,  208,    0,    0,    0,    0,  209,    0,
  210,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  211,    0,    0,    0,    0,  212,  213,    0,    0,
    0,    0,    0,  214,  622,    0,    0,  215,    0,  216,
  217,  218,  219,    0,  220,    0,    0,    0,    0,    0,
    0,    0,  221,  222,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  223,  224,    0,  225,  226,  227,    0,
    0,    0,    0,  228,  229,    0,  230,  231,    0,  232,
    0,    0,  233,  234,    0,    0,    0,  235,  236,    0,
    0,    0,    0,  237,  238,  239,    0,  240,  241,  242,
    0,  243,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  244,  245,  246,  247,  248,  249,  250,  251,  252,
  253,  254,  255,  256,  257,  258,  259,  260,  261,  262,
  263,  264,    0,  265,  266,  267,  268,  269,  270,    0,
  271,  272,  273,  274,    0,  275,    0,  276,  277,  278,
  279,  280,  281,  282,  283,  284,  285,  286,  287,  288,
  289,  290,  291,  292,  293,    0,  294,  295,  296,  297,
    0,  298,  299,  300,  301,  302,    0,  303,  304,  305,
  306,  307,  308,  309,  310,  311,  312,  313,  314,  315,
    0,  316,  317,  318,  319,  320,  321,    0,  322,  323,
  324,  325,  326,  327,  328,  329,    0,  330,  331,    0,
    0,    0,  332,  333,  334,  335,  336,  337,    0,    0,
  338,  339,  340,  341,  342,  343,  344,  345,  346,    0,
    0,    0,    0,    0,  347,    0,  348,  349,  350,  351,
  352,  353,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  354,  355, 1306,  356,  357,  358,  359,  360,  361,  362,
  363,  364,    0,  365,  366,  367,  368,  369,  370,  371,
  372,  373,  374,  375,  376,    0,  377,  378,  379,    0,
  380,    0,    0,    0,  381,  382,  383,  384,  385,  386,
  387,  388,  389,  390,  391,  392,  393,    0,  394,  395,
    0,    0,    0,    0,    0,  396,  397,  398,  399,  400,
  401,  402,  403,  404,  405,  406,  407,  408,  409,    0,
    0,  410,  411,    0,    0,    0,    0,  412,  413,  414,
  415,  416,  417,  418,  419,  420, 2268, 2268, 2063, 2268,
 2268, 2268,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2268, 2268, 2268,    0,    0, 2079,
 2079, 2079, 2079, 2079,    0, 2079,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2079, 2079,
 2079,    0,    0,    0,    0, 2268,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 2079,
 1123,    0,    0, 1124,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1125,
    0, 1126,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1127,
    0,    0,    0,    0,    0, 1128, 1129, 1130,    0, 1131,
 1132, 1133,    0, 1134,    0,    0, 2318, 2318, 2318, 2318,
 2318, 2318, 2318,    0,    0,    0,    0, 1135,    0, 1136,
    0,    0,    0,    0,    0, 2318, 2318, 2318,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1137,    0,
    0,    0,    0,    0,    0,    0, 2318,    0,    0,    0,
    0,    0,    0,    0, 1138,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2268,    0,    0,    0,
 2268,    0,    0,    0,    0, 2268, 1139,    0,    0,    0,
    0, 2268,    0,    0,    0, 2268,    0,    0, 2268,    0,
 2079,    0,    0,    0, 2079,    0,    0,    0,    0, 2079,
    0,    0,    0,    0,    0, 2079,    0,    0,    0, 2079,
    0,    0, 2079,    0, 1260, 1141,    0,    0,    0,    0,
    0,    0, 2268,    0,    0,    0,    0,    0,    0, 2268,
    0, 1142,    0,    0,    0,    0,    0, 2268,    0,    0,
    0,  685,    0,    0,    0,    0, 2079,    0,    0,    0,
    0,    0,    0, 2079, 2268,    0, 2268,    0,    0,    0,
    0, 2079,    0,    0,    0,    0, 2268,    0, 2268, 2268,
 2268,    0,    0,    0,    0, 2268,    0,    0, 2079,    0,
 2079,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 2079,    0, 2079, 2079, 2079,    0,    0,    0,    0, 2079,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2268, 2318,    0,    0,
    0, 2318,    0,    0,    0,    0, 2318,    0,    0,    0,
    0,    0, 2318,    0,    0,    0, 2318,    0,    0,    0,
 2079,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 2268, 2268, 2268, 2268, 2268, 2268, 2268, 2268,
    0,    0,    0, 2318,    0,    0,    0,    0,    0,    0,
 2318,    0,    0,    0,    0,    0,    0,    0, 2318,    0,
 1143,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 2318,    0, 2318,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2318,    0, 2318,
 2318, 2318, 1144,    0,    0,    0, 2318,    0,    0,    0,
    0,    0, 1145,    0,    0,    0,    0,    0, 1929,    0,
  685,    0,  685,    0,  685, 1146,    0,    0,  685,    0,
 1930,  685,  685,  685,    0,    0,    0,    0, 1931,    0,
    0,    0,  685,  685,    0,  685,    0,  685,    0,    0,
  685, 2268,    0,  685,    0,    0,    0,    0,    0,  685,
  685,    0,  685,  685,    0,    0,  685,  685,    0,  685,
  685,    0,  685,    0, 1147,  685,    0, 2268,    0,    0,
    0,    0,  685,  685,    0,    0, 2268,  685,  685,  685,
    0,  685,    0,  685,    0,    0,    0,  685,    0,  685,
    0,    0,    0,  685,    0,    0,    0,    0,    0,  685,
 2079,  685,  685,    0,  685,    0,  685, 2097,  685,    0,
  685,  685,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  685,    0,    0,    0,  685,  685,  685,
  685,  685,    0,  685,    0,  685,  685,    0,    0,  685,
    0,  685,  685,    0,    0,  685,  685,    0,    0,    0,
  685,    0,  685,  685,  685,  685,  685,  685,  685,    0,
  685,    0,  685,    0,  685,  685,  685,  685,  685,    0,
    0,    0,    0,  685,    0,  685,    0,    0,  685,    0,
    0,    0,    0,    0,    0,    0,  685,  685,    0,  685,
  685,  685,  685,    0,    0,    0,    0,    0,  685,    0,
    0,    0,  685,    0,  685,  685,  685,  685,    0,  685,
  685,    0,    0,    0,    0, 2268, 2268,  685,  685,    0,
    0,    0,    0,    0,    0,    0,    0, 2318,  685,  685,
    0,  685,  685,  685, 2318,    0,    0,    0,  685,  685,
    0,  685,  685,    0,  685,    0,    0,  685,  685,    0,
    0,    0,  685,  685,  685,  685,  685,    0,  685,  685,
  685,    0,  685,  685,  685,    0,  685,    0,  685,  685,
  685,    0,  685,  685,    0,  685,  685,  685,  685,  685,
  685,  685,  685,  685,  685,  685,  685,  685,  685,  685,
  685,  685,  685,  685,  685,  685,  685,    0,  685,  685,
  685,  685,  685,  685,    0,  685,  685,  685,  685,    0,
  685,    0,  685,  685,  685,  685,  685,  685,  685,  685,
  685,  685,  685,  685,  685,  685,  685,  685,  685,  685,
 2398,  685,  685,  685,  685,    0,  685,  685,  685,  685,
  685,    0,  685,  685,  685,  685,  685,  685,  685,  685,
  685,  685,  685,  685,  685,    0,  685,  685,  685,  685,
  685,  685,    0,  685,  685,  685,  685,  685,  685,  685,
  685,    0,  685,  685,  685,  685,    0,  685,  685,  685,
  685,  685,  685,  685,    0,  685,  685,  685,  685,  685,
  685,  685,  685,  685,    0,    0,    0,    0,    0,  685,
    0,  685,  685,  685,  685,  685,  685,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  685,  685,    0,  685,  685,
  685,  685,  685,  685,  685,  685,  685,    0,  685,  685,
  685,  685,  685,  685,  685,  685,  685,  685,  685,  685,
    0,  685,  685,  685,    0,  685,    0,    0,    0,  685,
  685,  685,  685,  685,  685,  685,  685,  685,  685,  685,
  685,  685,    0,  685,  685,    0,    0,  685,  685,  685,
  685,  685,  685,  685,  685,  685,  685,  685,  685,  685,
  685,  685,  685,  685,    0,    0,  685,  685,    0,    0,
    0,    0,  685,  685,  685,  685,  685,  685,  685,  685,
  685,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  154,
    0,  155,    0, 2382,    0,    0,    0,  156,    0,    0,
  157,  158, 2020,    0,    0,    0,    0,    0,    0,    0,
    0,  159,  160,    0,  161,    0,  162,    0,    0,  163,
    0,    0,  164,    0,    0,    0,    0,    0,    5,  165,
    0,  166,  167,    0,    0,    0,  168,    0, 2383, 2384,
    0, 2385,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  171,  172,    0,    0,    0, 2386, 2387,  174,    0,
  175,    0,    9,    0,    0,    0,  176,    0,  177,    0,
    0,    0,  178,    0,    0,    0,    0,    0,  863,    0,
  179,  865,    0,  180,    0,  181,    0,   10,    0,  182,
  183,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  184,    0,    0,    0,  186,  187,  188,  189,
  190,    0,  191,    0,  869, 2388,    0,    0,  192,    0,
  193,  194,    0,    0,  195,  196,    0,    0,    0,  870,
    0,  197,    0, 2389,  198,  199,  200,  201,    0,  202,
    0,  203,    0,  204,  205,  206,  207, 2390,    0,    0,
    0,    0,  209,    0,  210,    0,    0,   14,    0,    0,
    0,    0,    0,    0,    0,  211, 2764,    0,    0,   15,
  212,  213,    0,    0,    0,    0,    0,  880,    0,    0,
    0,  215,    0,  216,  217,  218,  219,    0,  220,  882,
    0,    0,    0,    0,    0,    0,  221,  222,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2391,  892,    0,
  225,  226,  227,    0,    0,    0,    0,  228,  229,    0,
  230,  231,    0,  232,    0,    0,  233, 2392,    0,    0,
    0,  235,  236, 2393, 2394, 2395,    0,  237,  238,  239,
    0,  240,  241,  242,    0,  243,    0,  904,  905,  906,
    0,  907,  908,    0,  909,  244,  245,  246,  247,  248,
  249,  910,  251,  911,  253,  912,  913,  914,  915,  916,
  917,  918,  919,  920,  921,  922,    0,  923,  924,  925,
  926,  927,  270,    0,  929,  930,  931,  274,    0,  932,
    0,  276,  934,  935,  936,  937,  281,  282,  938,  284,
  939,  940,  941,  288,  942,  290,  943,  292,  944, 2398,
  945,  946,  947,  948,    0,  949,  950,  951,  301,  952,
    0,  953,  954,  305,  955,  307,  308,  956,  310,  311,
  312,  313,  314,  315,    0,  957,  317,  318,  319,  320,
  321,    0,  958,  323, 2396,  325,  959,  960,  328,  329,
    0,  330,  331,  961,  962,    0,  332,  333,  334,  963,
  964,  965, 2397,    0,  338,  339,  340,  341,  342,  343,
  344,  345,  346,    0,    0,    0,    0,    0,  347,    0,
  348,  349,  350,  351,  352,  353,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  995,  996,    0,  356,  997,  358,
  359,  998,  361,  362,  363,  364,    0,  365,  366,  367,
  368,  369,  370, 1000,  372, 1001, 1002,  375,  376,    0,
  377,  378, 1003,    0,  380,    0,    0,    0,  381, 1006,
  383,  384,  385, 1007,  387,  388,  389,  390,  391,  392,
  393,    0, 1010,  395,    0,    0, 1013, 1014, 1015,  396,
 1016, 1017, 1018, 1019, 1020, 1021,  403,  404,  405,  406,
  407,  408,  409,    0,    0, 1022,  411,    0,    0,    0,
    0,  412,  413,  414,  415,  416,  417,  418,  419, 1023,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  154,    0,
  155,    0, 2382,    0,    0,    0,  156,    0,    0,  157,
  158, 2020,    0,    0,    0,    0,    0,    0,    0,    0,
  159,  160,    0,  161,    0,  162,    0,    0,  163,    0,
    0,  164,    0,    0,    0,    0,    0,    5,  165,    0,
  166,  167,    0,    0,    0,  168,    0, 2383, 2384,    0,
 2385,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  171,  172,    0,    0,    0, 2386, 2387,  174,    0,  175,
    0,    9,    0,    0,    0,  176,    0,  177,    0,    0,
    0,  178,    0,    0,    0,    0,    0,  863,    0,  179,
  865,    0,  180,    0,  181,    0,   10,    0,  182,  183,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  184,    0,    0,    0,  186,  187,  188,  189,  190,
    0,  191,    0,  869, 2388,    0,    0,  192,    0,  193,
  194,    0,    0,  195,  196,    0,    0,    0,  870,    0,
  197,    0, 2389,  198,  199,  200,  201,    0,  202,    0,
  203,    0,  204,  205,  206,  207, 2390,    0,    0,    0,
    0,  209,    0,  210,    0,    0,   14,    0,    0,    0,
    0,    0,    0,    0,  211,    0,    0,    0,   15,  212,
  213,    0,    0,    0,    0,    0,  880,    0,    0,    0,
  215,    0,  216,  217,  218,  219,    0,  220,  882,    0,
    0,    0,    0,    0,    0,  221,  222,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2391,  892,    0,  225,
  226,  227,    0,    0,    0,    0,  228,  229,    0,  230,
  231,    0,  232,    0,    0,  233, 2392,    0,    0,    0,
  235,  236, 2393, 2394, 2395,    0,  237,  238,  239,    0,
  240,  241,  242,    0,  243,    0,  904,  905,  906,    0,
  907,  908,    0,  909,  244,  245,  246,  247,  248,  249,
  910,  251,  911,  253,  912,  913,  914,  915,  916,  917,
  918,  919,  920,  921,  922,    0,  923,  924,  925,  926,
  927,  270,    0,  929,  930,  931,  274,    0,  932,    0,
  276,  934,  935,  936,  937,  281,  282,  938,  284,  939,
  940,  941,  288,  942,  290,  943,  292,  944, 1027,  945,
  946,  947,  948,    0,  949,  950,  951,  301,  952,    0,
  953,  954,  305,  955,  307,  308,  956,  310,  311,  312,
  313,  314,  315,    0,  957,  317,  318,  319,  320,  321,
    0,  958,  323, 2396,  325,  959,  960,  328,  329,    0,
  330,  331,  961,  962,    0,  332,  333,  334,  963,  964,
  965, 2397,    0,  338,  339,  340,  341,  342,  343,  344,
  345,  346,    0,    0,    0,    0,    0,  347,    0,  348,
  349,  350,  351,  352,  353,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  995,  996,    0,  356,  997,  358,  359,
  998,  361,  362,  363,  364,    0,  365,  366,  367,  368,
  369,  370, 1000,  372, 1001, 1002,  375,  376,    0,  377,
  378, 1003,    0,  380,    0,    0,    0,  381, 1006,  383,
  384,  385, 1007,  387,  388,  389,  390,  391,  392,  393,
    0, 1010,  395,    0,    0, 1013, 1014, 1015,  396, 1016,
 1017, 1018, 1019, 1020, 1021,  403,  404,  405,  406,  407,
  408,  409,    0,    0, 1022,  411,    0,    0,    0,    0,
  412,  413,  414,  415,  416,  417,  418,  419, 1023,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  154,    0,  155,
    0,    0,    0,    0,    0,  156,    0,    0,  157,  158,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  159,
  160,    0,  161,    0,  162,    0,    0,  163,    0,    0,
  164,    0,    0,    0,    0,    0,    0,  165,    0,  166,
  167,    0,    0,    0,  168,    0,  169,    0,    0,  170,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  171,
  172,    0,    0,    0,  173,    0,  174,    0,  175,    0,
    0,    0,    0,    0,  176,    0,  177,    0,    0,    0,
  178,    0,    0,    0,    0,    0,    0,    0,  179,    0,
    0,  180,    0,  181,    0,    0,    0,  182,  183,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  184,    0,    0,    0,  186,  187,  188,  189,  190,    0,
  191,    0,    0,    0,    0,    0,  192,    0,  193,  194,
    0,    0,  195,  196,    0,    0,    0,    0,    0,  197,
    0,    0,  198,  199,  200,  201,    0,  202,    0,  203,
    0,  204,  205,  206,  207,  208,    0,    0,    0,    0,
  209,    0,  210,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  211,    0,    0,    0,    0,  212,  213,
    0,    0,    0,    0,    0,  214,    0,    0,    0,  215,
    0,  216,  217,  218,  219,    0,  220,    0,    0,    0,
    0,    0,    0,    0,  221,  222,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  223,  224,    0,  225,  226,
  227,    0,    0,    0,    0,  228,  229,    0,  230,  231,
    0,  232,    0,    0,  233,  234,    0,    0,    0,  235,
  236,    0,    0,    0,    0,  237,  238,  239,    0,  240,
  241,  242,    0,  243,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  244,  245,  246,  247,  248,  249,  250,
  251,  252,  253,  254,  255,  256,  257,  258,  259,  260,
  261,  262,  263,  264,    0,  265,  266,  267,  268,  269,
  270,    0,  271,  272,  273,  274,    0,  275,    0,  276,
  277,  278,  279,  280,  281,  282,  283,  284,  285,  286,
  287,  288,  289,  290,  291,  292,  293,    0,  294,  295,
  296,  297,    0,  298,  299,  300,  301,  302,    0,  303,
  304,  305,  306,  307,  308,  309,  310,  311,  312,  313,
  314,  315,    0,  316,  317,  318,  319,  320,  321,    0,
  322,  323,  324,  325,  326,  327,  328,  329,    0,  330,
  331,    0,    0,    0,  332,  333,  334,  335,  336,  337,
    0,    0,  338,  339,  340,  341,  342,  343,  344,  345,
  346,    0,    0,    0,    0,    0,  347,    0,  348,  349,
  350,  351,  352,  353,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  354,  355,    0,  356,  357,  358,  359,  360,
  361,  362,  363,  364,    0,  365,  366,  367,  368,  369,
  370,  371,  372,  373,  374,  375,  376,    0,  377,  378,
  379,    0,  380,    0,    0,    0,  381,  382,  383,  384,
  385,  386,  387,  388,  389,  390,  391,  392,  393,    0,
  394,  395,    0,    0,    0,    0,    0,  396,  397,  398,
  399,  400,  401,  402,  403,  404,  405,  406,  407,  408,
  409,    0,    0,  410,  411,    0,    0,    0,    0,  412,
  413,  414,  415,  416,  417,  418,  419,  420, 2207, 2207,
    0, 2207, 2207, 2207,    0, 2907,    0,    0, 1124,    0,
    0,    0,    0,    0,    0, 2207, 2207, 2207, 2207,    0,
 2908,    0,    0,    0, 1125,    0, 1126,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2207,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1127,    0,    0,    0,    0,    0,
 1128, 1129, 1130,    0, 1131, 1132, 1133,    0, 1134,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1135,    0, 1136,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 3449,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1137,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1138,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1139,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1260,
 1141,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1142,    0, 2207,    0,
 2207,    0, 2207,    0,    0,    0,    0, 2207,    0,    0,
    0,    0,    0, 2207,    0,    0,    0, 2207,    0,    0,
 2207,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 2207,    0,    0,    0,    0,    0,
    0, 2207,    0,    0,    0,    0,    0,    0, 2207, 2207,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2207,    0, 2207,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2207,    0,
 2207, 2207, 2207,    0, 2207,    0,    0, 2207,    0,    0,
    0,    0,    0,    0,    0,    0, 2207,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 2207,  154,
    0,  155,    0,    0,    0, 1143,    0,  156,    0,    0,
  157,  158,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  159,  160, 2207,  161,    0,  162,    0,    0,  163,
    0,    0,  164,    0,    0,    0,    0, 1144,    0,  165,
 2207,  166,  167,    0,    0,    0,  168, 1145,  169,    0,
    0,  170,    0,    0,    0,    0,    0,    0,    0,    0,
 1146,  171,  172,    0,    0,    0,  173,    0,  174,    0,
  175,    0,    0,    0,    0,    0,  176,    0,  177,    0,
    0,    0,  178,    0,    0,    0,    0,    0,    0,    0,
  179,    0,    0,  180,    0,  181,    0,    0,    0,  182,
  183,    0,    0,    0,    0,    0,    0,    0,    0, 1147,
    0,    0,  184,    0,    0,    0,  186,  187,  188,  189,
  190,    0,  191,    0,    0,    0,    0,    0,  192,    0,
  193,  194,    0,    0,  195,  196,    0,    0,    0,    0,
    0,  197,    0,    0,  198,  199,  200,  201,    0,  202,
    0,  203,    0,  204,  205,  206,  207,  208,    0,    0,
    0,    0,  209,    0,  210,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  211,    0,    0,    0,    0,
  212,  213,    0,    0,    0,    0,    0,  214, 2207,    0,
    0,  215,  459,  216,  217,  218,  219,  460,  220,  461,
  462,  463,  464,  465,  466,  467,  221,  222,  468,  469,
  470,  471,  472,    0,    0,  473,  474,  223,  224,  475,
  225,  226,  227,  476,  477,  478,  479,  228,  229,  480,
  230,  231,  481,  232,  482,  483,  233,  234,  484,  485,
  486,  235,  236,  487,  488,  489,  490,  237,  238,  239,
  491,  240,  241,  242,  492,  243,  493,  494,  495,  496,
  497,  498,  499,  500,  501,  244,  245,  246,  247,  248,
  249,  250,  251,  252,  253,  254,  255,  256,  257,  258,
  259,  260,  261,  262,  263,  264,  502,  265,  266,  267,
  268,  269,  270,  503,  271,  272,  273,  274,  504,  275,
  505,  276,  277,  278,  279,  280,  281,  282,  283,  284,
  285,  286,  287,  288,  289,  290,  291,  292,  293,  506,
  294,  295,  296,  297,  507,  298,  299,  300,  301,  302,
  508,  303,  304,  305,  306,  307,  308,  309,  310,  311,
  312,  313,  314,  315,  509,  316,  317,  318,  319,  320,
  321,    0,  322,  323,  324,  325,  326,  327,  328,  329,
  510,  330,  331,    0,    0,  511,  332,  333,  334,  335,
  336,  337,  512,  513,  338,  339,  340,  341,  342,  343,
  344,  345,  346,  514,  515,  516,  517,  518,  347,    0,
  348,  349,  350,  351,  352,  353,  519,  520,  521,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  354,  355,  537,  356,  357,  358,
  359,  360,  361,  362,  363,  364,  538,  365,  366,  367,
  368,  369,  370,  371,  372,  373,  374,  375,  376,  539,
  377,  378,  379,  540,  380,  541,  542,  543,  381,  382,
  383,  384,  385,  386,  387,  388,  389,  390,  391,  392,
  393,  544,  394,  395,  545,    0,    0,    0,    0,  396,
  397,  398,  399,  400,  401,  402,  403,  404,  405,  406,
  407,  408,  409,  546,  547,  410,  411,  548,  549,  550,
  551,  412,  413,  414,  415,  416,  417,  418,  419,  420,
 1000,    0, 1000,    0,    0,    0,    0,    0, 1000,    0,
    0, 1000, 1000,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1000, 1000,    0, 1000,    0, 1000,    0,    0,
 1000,    0,    0, 1000,    0,    0,    0,    0,    0,    0,
 1000,    0, 1000, 1000,    0,    0,    0, 1000,    0, 1000,
    0,    0, 1000,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1000, 1000,    0,    0,    0, 1000,    0, 1000,
    0, 1000,    0,    0,    0,    0,    0, 1000,    0, 1000,
    0,    0,    0, 1000,    0,    0,    0,    0,    0,    0,
    0, 1000,    0,    0, 1000,    0, 1000,    0,    0,    0,
 1000, 1000,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1000,    0,    0,    0, 1000, 1000, 1000,
 1000, 1000,    0, 1000,    0,    0,    0,    0,    0, 1000,
    0, 1000, 1000,    0,    0, 1000, 1000,    0,    0,    0,
    0,    0, 1000,    0,    0, 1000, 1000, 1000, 1000,    0,
 1000,    0, 1000,    0, 1000, 1000, 1000, 1000, 1000,    0,
    0,    0,    0, 1000,    0, 1000,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1000,    0,    0,    0,
    0, 1000, 1000,    0,    0,    0,    0,    0, 1000,    0,
    0,    0, 1000, 1000, 1000, 1000, 1000, 1000,    0, 1000,
 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000,
 1000, 1000, 1000, 1000,    0,    0, 1000, 1000, 1000, 1000,
 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000,
 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000,
 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000,
 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000,
 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000,
 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000,
 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000,
 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000,
 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000,
 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000,
 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000,
 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000,
 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000,
 1000, 1000,    0, 1000, 1000, 1000, 1000, 1000, 1000, 1000,
 1000, 1000, 1000, 1000,    0,    0, 1000, 1000, 1000, 1000,
 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000,
 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000,
    0, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000,
 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000,
 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000,
 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000,
 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000,
 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000,
 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000,
 1000, 1000, 1000, 1000, 1000, 1000,    0,    0,    0,    0,
 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000,
 1000,    0, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000,
 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000, 1000,
 1000, 2079,    0, 2079,    0,    0,    0,    0,    0, 2079,
    0,    0, 2079, 2079,    0,    0, 2079,    0,    0, 2079,
    0,    0,    0, 2079, 2079,    0, 2079,    0, 2079,    0,
    0, 2079,    0, 2081, 2079, 2079,    0, 2079,    0,    0,
    0, 2079,    0, 2079, 2079,    0,    0,    0, 2079,    0,
 2079,    0,    0, 2079,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 2079, 2079,    0,    0,    0, 2079,    0,
 2079,    0, 2079,    0,    0, 2079,    0,    0, 2079,    0,
 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079,    0, 2079,
    0,    0, 2079,    0,    0, 2079,    0, 2079,    0,    0,
    0, 2079, 2079, 2079,    0, 2079,    0, 2081,    0,    0,
    0,    0,    0,    0, 2079,    0,    0,    0, 2079, 2079,
 2079, 2079, 2079,    0, 2079,    0,    0,    0,    0,    0,
 2079,    0, 2079, 2079, 2079,    0, 2079, 2079,    0,    0,
    0,    0,    0, 2079,    0,    0, 2079, 2079, 2079, 2079,
 2079, 2079,    0, 2079,    0, 2079, 2079, 2079, 2079, 2079,
    0,    0,    0,    0, 2079,    0, 2079,    0,    0,    0,
    0,    0, 2079,    0,    0,    0,    0, 2079,    0,    0,
    0,    0, 2079, 2079,    0,    0,    0,    0,    0, 2079,
    0,    0,    0, 2079,    0, 2079, 2079, 2079, 2079,    0,
 2079,    0,    0,    0,    0,    0,    0,    0, 2079, 2079,
 2079, 2079,    0,    0,    0,    0,    0,    0,    0, 2079,
 2079,    0, 2079, 2079, 2079,    0,    0, 2079,    0, 2079,
 2079,    0, 2079, 2079,    0, 2079,    0,    0, 2079, 2079,
    0,    0,    0, 2079, 2079,    0,    0,    0,    0, 2079,
 2079, 2079,    0, 2079, 2079, 2079,    0, 2079,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 2079, 2079, 2079,
 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079,
 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079,    0, 2079,
 2079, 2079, 2079, 2079, 2079,    0, 2079, 2079, 2079, 2079,
    0, 2079,    0, 2079, 2079, 2079, 2079, 2079, 2079, 2079,
 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079,
 2079,    0, 2079, 2079, 2079, 2079,    0, 2079, 2079, 2079,
 2079, 2079,    0, 2079, 2079, 2079, 2079, 2079, 2079, 2079,
 2079, 2079, 2079, 2079, 2079, 2079,    0, 2079, 2079, 2079,
 2079, 2079, 2079,    0, 2079, 2079, 2079, 2079, 2079, 2079,
 2079, 2079,    0, 2079, 2079,    0,    0, 2081, 2079, 2079,
 2079, 2079, 2079, 2079,    0,    0, 2079, 2079, 2079, 2079,
 2079, 2079, 2079, 2079, 2079,    0, 2079,    0,    0,    0,
 2079,    0, 2079, 2079, 2079, 2079, 2079, 2079,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 2079, 2079, 2079, 2079,
 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079,
 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079,
 2079, 2079, 2079, 2079, 2079,    0, 2079,    0,    0,    0,
 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079,
 2079, 2079, 2079,    0, 2079, 2079,    0,    0,    0,    0,
    0, 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079, 2079,
 2079, 2079, 2079, 2079, 2079,    0,    0, 2079, 2079,    0,
 2079,    0,    0, 2079, 2079, 2079, 2079, 2079, 2079, 2079,
 2079, 2079,  154,    0,  155,    0,    0,    0,    0,    0,
  156,    0,    0,  157,  158,    0,    0, 1123,    0,    0,
 1124,    0,    0,    0,  159,  160,    0,  161,    0,  162,
    0,    0,  163,    0,    0,  164, 1125,    0, 1126,    0,
    0,    0,  165,    0,  166,  167,    0,    0,    0,  168,
    0,  169,    0,    0,  170,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  171,  172,    0,    0,    0,  173,
    0,  174,    0,  175,    0,    0, 1127,    0,    0,  176,
    0,  177, 1128, 1129, 1130,  178, 1131, 1132, 1133,    0,
 1134,    0,    0,  179,    0,    0,  180,    0,  181,    0,
    0,    0,  182,  183, 1135,    0, 1136,    0,    0,    0,
    0,    0,    0,    0,    0,  184,    0,    0,    0,  186,
  187,  188,  189,  190,    0,  191,    0,    0,    0,    0,
    0,  192,    0,  193,  194, 1137,    0,  195,  196,    0,
    0,    0,    0,    0,  197,    0,    0,  198,  199,  200,
  201, 1138,  202,    0,  203,    0,  204,  205,  206,  207,
  208,    0,    0,    0,    0,  209,    0,  210,    0,    0,
    0,    0,    0, 1139,    0,    0,    0,    0,  211,    0,
    0,    0,    0,  212,  213,    0,    0,    0,    0,    0,
  214,    0,    0,    0,  215,    0,  216,  217,  218,  219,
    0, 2447,    0,    0,    0,    0,    0,    0,    0,  221,
  222, 1260, 1141,    0,    0,    0,    0,    0,    0,    0,
  223,  224,    0,  225,  226,  227,    0,    0, 1142,    0,
  228,  229,    0,  230,  231,    0,  232,    0,    0,  233,
  234,    0,    0,    0,  235,  236,    0,    0,    0,    0,
  237,  238,  239,    0,  240,  241,  242,    0,  243,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  244,  245,
  246,  247,  248,  249,  250,  251,  252,  253,  254,  255,
  256,  257,  258,  259,  260,  261,  262,  263,  264,    0,
  265,  266,  267,  268,  269,  270,    0,  271,  272,  273,
  274,    0,  275,    0,  276,  277,  278,  279,  280,  281,
  282,  283,  284,  285,  286,  287,  288,  289,  290,  291,
  292,  293,    0,  294,  295,  296,  297,    0,  298,  299,
  300,  301,  302,    0,  303,  304,  305,  306,  307,  308,
  309,  310,  311,  312,  313,  314,  315,    0,  316,  317,
  318,  319,  320,  321,    0,  322,  323,  324,  325,  326,
  327,  328,  329,    0,  330,  331,    0,    0,    0,  332,
  333,  334,  335,  336,  337,    0,    0,  338,  339,  340,
  341,  342,  343,  344,  345,  346,    0, 1143,    0,    0,
    0,  347,    0,  348,  349,  350,  351,  352,  353,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  354,  355, 1144,
  356,  357,  358,  359,  360,  361,  362,  363,  364, 1145,
  365,  366,  367,  368,  369,  370,  371,  372,  373,  374,
  375,  376, 1146,  377,  378,  379,    0,  380,    0,    0,
    0,  381,  382,  383,  384,  385,  386,  387,  388,  389,
  390,  391,  392,  393,    0,  394,  395,    0,    0,    0,
    0,    0,  396,  397,  398,  399,  400,  401,  402,  403,
  404,  405,  406,  407,  408,  409,    0,    0,  410,  411,
    0, 1147,    0,    0,  412,  413,  414,  415,  416,  417,
  418,  419,  420,  154,    0,  155,    0,    0,    0,    0,
    0,  156,    0,    0,  157,  158,    0,    0, 1123,    0,
    0, 1124,    0,    0,    0,  159,  160,    0,  161,    0,
  162,    0,    0,  163,    0,    0,  164, 1125,    0, 1126,
    0,    0,    0,  165,    0,  166,  167,    0,    0,    0,
  168,    0,  169,    0,    0,  170,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  171,  172,    0,    0,    0,
  173,    0,  174,    0,  175,    0,    0, 1127,    0,    0,
  176,    0,  177, 1128, 1129, 1130,  178, 1131, 1132, 1133,
    0, 1134,    0,    0,  179,    0,    0,  180,    0,  181,
    0,    0,    0,  182,  183, 1135,    0, 1136,    0,    0,
    0,    0,    0,    0,    0,    0,  184,    0,    0,    0,
  186,  187,  188,  189,  190,    0,  191,    0,    0,    0,
    0,    0,  192,    0,  193,  194, 1137,    0,  195,  196,
    0,    0,    0,    0,    0,  197,    0,    0,  198,  199,
  200,  201, 1138,  202,    0,  203,    0,  204,  205,  206,
  207,  208,    0,    0,    0,    0,  209,    0,  210,    0,
    0,    0,    0,    0, 1139,    0,    0,    0,    0,  211,
    0,    0,    0,    0,  212,  213,    0,    0,    0,    0,
    0,  214,    0,    0,    0,  215,    0,  216,  217,  218,
  219,    0, 2560,    0,    0,    0,    0,    0,    0,    0,
  221,  222, 1260, 1141,    0,    0,    0,    0,    0,    0,
    0,  223,  224,    0,  225,  226,  227,    0,    0, 1142,
    0,  228,  229,    0,  230,  231,    0,  232,    0,    0,
  233,  234,    0,    0,    0,  235,  236,    0,    0,    0,
    0,  237,  238,  239,    0,  240,  241,  242,    0,  243,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  244,
  245,  246,  247,  248,  249,  250,  251,  252,  253,  254,
  255,  256,  257,  258,  259,  260,  261,  262,  263,  264,
    0,  265,  266,  267,  268,  269,  270,    0,  271,  272,
  273,  274,    0,  275,    0,  276,  277,  278,  279,  280,
  281,  282,  283,  284,  285,  286,  287,  288,  289,  290,
  291,  292,  293,    0,  294,  295,  296,  297,    0,  298,
  299,  300,  301,  302,    0,  303,  304,  305,  306,  307,
  308,  309,  310,  311,  312,  313,  314,  315,    0,  316,
  317,  318,  319,  320,  321,    0,  322,  323,  324,  325,
  326,  327,  328,  329,    0,  330,  331,    0,    0,    0,
  332,  333,  334,  335,  336,  337,    0,    0,  338,  339,
  340,  341,  342,  343,  344,  345,  346,    0, 1143,    0,
    0,    0,  347,    0,  348,  349,  350,  351,  352,  353,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  354,  355,
 1144,  356,  357,  358,  359,  360,  361,  362,  363,  364,
 1145,  365,  366,  367,  368,  369,  370,  371,  372,  373,
  374,  375,  376, 1146,  377,  378,  379,    0,  380,    0,
    0,    0,  381,  382,  383,  384,  385,  386,  387,  388,
  389,  390,  391,  392,  393,    0,  394,  395,    0,    0,
    0,    0,    0,  396,  397,  398,  399,  400,  401,  402,
  403,  404,  405,  406,  407,  408,  409,    0,    0,  410,
  411,    0, 1147,    0,    0,  412,  413,  414,  415,  416,
  417,  418,  419,  420,  154,    0,  155,    0,    0,    0,
    0,    0,  156,    0,    0,  157,  158,    0,    0, 1123,
    0,    0, 1124,    0,    0,    0,  159, 3110,    0,  161,
    0,  162,    0,    0,  163,    0,    0,  164, 1125,    0,
 1126,    0,    0,    0,  165,    0,  166,  167,    0,    0,
    0,  168,    0,  169,    0,    0,  170,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  171,  172,    0,    0,
    0,  173,    0,  174,    0,  175,    0,    0, 1127,    0,
    0,  176,    0,  177, 1128, 1129, 1130,  178, 1131, 1132,
 1133,    0, 1134,    0,    0,  179,    0,    0,  180,    0,
  181,    0,    0,    0,  182,  183, 1135,    0, 1136,    0,
    0,    0,    0,    0,    0,    0,    0,  184,    0,    0,
    0,  186,  187,  188,  189,  190,    0,  191,    0,    0,
    0,    0,    0,  192,    0,  193,  194, 1137,    0,  195,
  196,    0,    0,    0,    0,    0,  197,    0,    0,  198,
  199,  200,  201, 1138,  202,    0,  203,    0,  204,  205,
  206,  207,  208,    0,    0,    0,    0,  209,    0,  210,
    0,    0,    0,    0,    0, 1139,    0,    0,    0,    0,
  211,    0,    0,    0,    0,  212,  213,    0,    0,    0,
    0,    0,  214,    0,    0,    0,  215,    0,  216,  217,
  218,  219,    0,  220,    0,    0,    0,    0,    0,    0,
    0,  221,  222, 1260, 1141,    0,    0,    0,    0,    0,
    0,    0,  223,  224,    0,  225,  226,  227,    0,    0,
 1142,    0,  228,  229,    0,  230,  231,    0,  232,    0,
    0,  233,  234,    0,    0,    0,  235,  236,    0,    0,
    0,    0,  237,  238,  239,    0,  240,  241,  242,    0,
  243,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  244,  245,  246,  247,  248,  249,  250,  251,  252,  253,
  254,  255,  256,  257,  258,  259,  260,  261,  262,  263,
  264,    0,  265,  266,  267,  268,  269,  270,    0,  271,
  272,  273, 3111,    0,  275,    0,  276,  277,  278,  279,
  280,  281,  282,  283,  284,  285,  286,  287,  288,  289,
  290,  291,  292,  293,    0,  294,  295,  296,  297,    0,
  298,  299,  300,  301,  302,    0,  303,  304,  305,  306,
  307,  308,  309,  310,  311,  312,  313,  314,  315,    0,
  316,  317,  318,  319,  320,  321,    0,  322,  323,  324,
  325,  326,  327,  328,  329,    0,  330,  331,    0,    0,
    0,  332,  333,  334,  335,  336,  337,    0,    0,  338,
  339,  340,  341,  342,  343,  344,  345,  346,    0, 1143,
    0,    0,    0,  347,    0,  348,  349,  350,  351,  352,
  353,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  354,
  355, 1144,  356,  357,  358,  359,  360,  361,  362,  363,
  364, 1145,  365,  366,  367,  368,  369,  370,  371,  372,
  373,  374,  375,  376, 1146,  377,  378,  379,    0,  380,
    0,    0,    0,  381,  382,  383,  384,  385,  386,  387,
  388,  389,  390,  391,  392,  393,    0,  394,  395,    0,
    0,    0,    0,    0,  396,  397,  398,  399,  400,  401,
  402,  403,  404,  405,  406,  407,  408,  409,    0,    0,
  410,  411,    0, 1147,    0,    0,  412,  413,  414,  415,
  416,  417,  418,  419,  420,  154,    0,  155,    0,    0,
    0,    0,    0,  156,    0,    0,  157,  158,    0,    0,
 1123,    0,    0, 1124,    0,    0,    0,  159,  160,    0,
  161,    0,  162,    0,    0,  163,    0,    0,  164, 1125,
    0, 1126,    0,    0,    0,  165,    0,  166,  167,    0,
    0,    0,  168,    0,  169,    0,    0,  170,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  171,  172,    0,
    0,    0,  173,    0,  174,    0,  175,    0,    0, 1127,
    0,    0,  176,    0,  177, 1128, 1129, 1130,  178, 1131,
 1132, 1133,    0, 1134,    0,    0,  179,    0,    0,  180,
    0,  181,    0,    0,    0,  182,  183, 1135,    0, 1136,
    0,    0,    0,    0,    0,    0,    0,    0,  184,    0,
    0,    0,  186,  187,  188,  189,  190,    0,  191,    0,
    0,    0,    0,    0,  192,    0,  193,  194, 1137,    0,
  195,  196,    0,    0,    0,    0,    0,  197,    0,    0,
  198,  199,  200,  201, 1138,  202,    0,  203,    0,  204,
  205,  206,  207,  208,    0,    0,    0,    0,  209,    0,
  210,    0,    0,    0,    0,    0, 1139,    0,    0,    0,
    0,  211,    0,    0,    0,    0,  212,  213,    0,    0,
    0,    0,    0,  214,    0,    0,    0,  215,    0,  216,
  217,  218,  219,    0,  220,    0,    0,    0,    0,    0,
    0,    0,  221,  222, 1260, 1141,    0,    0,    0,    0,
    0,    0,    0,  223,  224,    0,  225,  226,  227,    0,
    0, 1142,    0,  228,  229,    0,  230,  231,    0,  232,
    0,    0,  233,  234,    0,    0,    0,  235,  236,    0,
    0,    0,    0,  237,  238,  239,    0,  240,  241,  242,
    0,  243,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  244,  245,  246,  247,  248,  249,  250,  251,  252,
  253,  254,  255,  256,  257,  258,  259,  260,  261,  262,
  263,  264,    0,  265,  266,  267,  268,  269,  270,    0,
  271,  272,  273,  274,    0,  275,    0,  276,  277,  278,
  279,  280,  281,  282,  283,  284,  285,  286,  287,  288,
  289,  290,  291,  292,  293,    0,  294,  295,  296,  297,
    0,  298,  299,  300,  301,  302,    0,  303,  304,  305,
  306,  307,  308,  309,  310,  311,  312,  313,  314,  315,
    0,  316,  317,  318,  319,  320,  321,    0,  322,  323,
  324,  325,  326,  327,  328,  329,    0,  330,  331,    0,
    0,    0,  332,  333,  334,  335,  336,  337,    0,    0,
  338,  339,  340,  341,  342,  343,  344,  345,  346,    0,
 1143,    0,    0,    0,  347,    0,  348,  349,  350,  351,
  352,  353,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  354,  355, 1144,  356,  357,  358,  359,  360,  361,  362,
  363,  364, 1145,  365,  366,  367,  368,  369,  370,  371,
  372,  373,  374,  375,  376, 1146,  377,  378,  379,    0,
  380,    0,    0,    0,  381,  382,  383,  384,  385,  386,
  387,  388,  389,  390,  391,  392,  393,    0,  394,  395,
    0,    0,    0,    0,    0,  396,  397,  398,  399,  400,
  401,  402,  403,  404,  405,  406,  407,  408,  409,    0,
    0,  410,  411,    0, 1147,    0,    0,  412,  413,  414,
  415,  416,  417,  418,  419,  420,   52,    0,   52,   40,
   40,    0,    0,    0,   52,    0,    0,   52,   52,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   52,   52,
    0,   52,    0,   52,    0,   40,   52,    0,    0,   52,
    0,    0,    0,    0,   52,   40,   52,    0,   52,   52,
   40,    0,    0,   52,    0,   52,   40,    0,   52,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   52,   52,
    0,    0,    0,   52,    0,   52,    0,   52,    0,   40,
    0,    0,    0,   52,    0,   52,    0,    0,    0,   52,
    0,    0,    0,    0,    0,    0,    0,   52,    0,    0,
   52,    0,   52,    0,    0,    0,   52,   52,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   52,
    0,    0,    0,   52,   52,   52,   52,   52,    0,   52,
    0,    0,    0,    0,    0,   52,    0,   52,   52,    0,
   40,   52,   52,    0,    0,    0,    0,    0,   52,   40,
    0,   52,   52,   52,   52,    0,   52,    0,   52,    0,
   52,   52,   52,   52,   52,    0,    0,    0,    0,   52,
    0,   52,    0,    0,   40,    0,    0,    0,    0,    0,
    0,    0,   52,    0,    0,    0,    0,   52,   52,    0,
    0,    0,    0,    0,   52,    0,    0,    0,   52,    0,
   52,   52,   52,   52,    0,   52,    0,    0,    0,    0,
    0,    0,    0,   52,   52,    0,    0,    0,    0,    0,
    0,    0,    0,    0,   52,   52,    0,   52,   52,   52,
    0,    0,    0,    0,   52,   52,    0,   52,   52,    0,
   52,    0,    0,   52,   52,    0,    0,    0,   52,   52,
    0,    0,    0,    0,   52,   52,   52,    0,   52,   52,
   52,    0,   52,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   52,   52,   52,   52,   52,   52,   52,   52,
   52,   52,   52,   52,   52,   52,   52,   52,   52,   52,
   52,   52,   52,    0,   52,   52,   52,   52,   52,   52,
    0,   52,   52,   52,   52,    0,   52,    0,   52,   52,
   52,   52,   52,   52,   52,   52,   52,   52,   52,   52,
   52,   52,   52,   52,   52,   52,    0,   52,   52,   52,
   52,    0,   52,   52,   52,   52,   52,    0,   52,   52,
   52,   52,   52,   52,   52,   52,   52,   52,   52,   52,
   52,    0,   52,   52,   52,   52,   52,   52,    0,   52,
   52,   52,   52,   52,   52,   52,   52,    0,   52,   52,
    0,    0,    0,   52,   52,   52,   52,   52,   52,    0,
    0,   52,   52,   52,   52,   52,   52,   52,   52,   52,
    0,    0,    0,    0,    0,    0,    0,   52,   52,   52,
   52,   52,   52,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,   52,   52,    0,   52,   52,   52,   52,   52,   52,
   52,   52,   52,    0,   52,   52,   52,   52,   52,   52,
   52,   52,   52,   52,   52,   52,    0,   52,   52,   52,
    0,   52,    0,    0,    0,   52,   52,   52,   52,   52,
   52,   52,   52,   52,   52,   52,   52,   52,    0,   52,
   52,    0,    0,    0,    0,    0,   52,   52,   52,   52,
   52,   52,   52,   52,   52,   52,   52,   52,   52,   52,
    0,    0,   52,   52,    0,    0,    0,    0,   52,   52,
   52,   52,   52,   52,   52,   52,   52,  129,    0,  129,
    0,  127,    0,    0,    0,  129,    0,    0,  129,  129,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  129,
  129,    0,  129,    0,  129,    0,  127,  129,    0,    0,
  129,    0,    0,    0,    0,  129,  127,  129,    0,  129,
  129,  127,    0,    0,  129,    0,  129,  127,    0,  129,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  129,
  129,    0,    0,    0,  129,    0,  129,    0,  129,    0,
  127,    0,    0,    0,  129,    0,  129,    0,    0,    0,
  129,    0,    0,    0,    0,    0,    0,    0,  129,    0,
    0,  129,    0,  129,    0,    0,    0,  129,  129,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  129,    0,    0,    0,  129,  129,  129,  129,  129,    0,
  129,    0,    0,    0,    0,    0,  129,    0,  129,  129,
    0,  127,  129,  129,    0,    0,    0,    0,    0,  129,
  127,    0,  129,  129,  129,  129,    0,  129,    0,  129,
    0,  129,  129,  129,  129,  129,    0,    0,    0,    0,
  129,    0,  129,    0,    0,  127,    0,    0,    0,    0,
    0,    0,    0,  129,    0,    0,    0,    0,  129,  129,
    0,    0,    0,    0,    0,  129,    0,    0,    0,  129,
    0,  129,  129,  129,  129,    0,  129,    0,    0,    0,
    0,    0,    0,    0,  129,  129,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  129,  129,    0,  129,  129,
  129,    0,    0,    0,    0,  129,  129,    0,  129,  129,
    0,  129,    0,    0,  129,  129,    0,    0,    0,  129,
  129,    0,    0,    0,    0,  129,  129,  129,    0,  129,
  129,  129,    0,  129,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  129,  129,  129,  129,  129,  129,  129,
  129,  129,  129,  129,  129,  129,  129,  129,  129,  129,
  129,  129,  129,  129,    0,  129,  129,  129,  129,  129,
  129,    0,  129,  129,  129,  129,    0,  129,    0,  129,
  129,  129,  129,  129,  129,  129,  129,  129,  129,  129,
  129,  129,  129,  129,  129,  129,  129,    0,  129,  129,
  129,  129,    0,  129,  129,  129,  129,  129,    0,  129,
  129,  129,  129,  129,  129,  129,  129,  129,  129,  129,
  129,  129,    0,  129,  129,  129,  129,  129,  129,    0,
  129,  129,  129,  129,  129,  129,  129,  129,    0,  129,
  129,    0,    0,    0,  129,  129,  129,  129,  129,  129,
    0,    0,  129,  129,  129,  129,  129,  129,  129,  129,
  129,    0,    0,    0,    0,    0,    0,    0,  129,  129,
  129,  129,  129,  129,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  129,  129,    0,  129,  129,  129,  129,  129,
  129,  129,  129,  129,    0,  129,  129,  129,  129,  129,
  129,  129,  129,  129,  129,  129,  129,    0,  129,  129,
  129,    0,  129,    0,    0,    0,  129,  129,  129,  129,
  129,  129,  129,  129,  129,  129,  129,  129,  129,    0,
  129,  129,    0,    0,    0,    0,    0,  129,  129,  129,
  129,  129,  129,  129,  129,  129,  129,  129,  129,  129,
  129,    0,    0,  129,  129,    0,    0,    0,    0,  129,
  129,  129,  129,  129,  129,  129,  129,  129,  154,    0,
  155,    0,    0,    0,    0,    0,  156,    0,    0,  157,
  158,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  159,  160,    0,  161,    0,  162,    0,    0,  163,    0,
    0,  164,    0,    0,    0,    0,    0,    0,  165,    0,
  166,  167,    0,    0,    0,  168,    0,  169,    0,    0,
  170,    0,    0,    0,    0,    0,    0, 3302,    0,    0,
  171,  172,    0, 3303,    0,  173,    0,  174,    0,  175,
    0,    0,    0,    0,    0,  176,    0,  177,    0,    0,
    0,  178,    0,    0,    0,    0,    0,    0,    0,  179,
    0,    0,  180,    0,  181,    0,    0,    0,  182,  183,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  184,    0,    0,    0,  186,  187,  188,  189,  190,
    0,  191,    0,    0,    0,    0,    0,  192, 3304,  193,
  194,    0,    0,  195,  196,    0,    0,    0,    0,    0,
  197,    0,    0,  198,  199,  200,  201,    0,  202,    0,
  203,    0,  204,  205,  206,  207,  208,    0,    0,    0,
    0,  209, 3305,  210,    0,    0,    0, 3306,    0,    0,
    0,    0,    0, 3307,  211,    0,    0,    0,    0,  212,
  213,    0,    0,    0,    0,    0,  214,    0,    0,    0,
  215,    0,  216,  217,  218, 3308,    0,  220,    0,    0,
    0,    0,    0,    0,    0,  221,  222,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  223,  224,    0,  225,
  226,  227,    0,    0,    0,    0,  228,  229,    0,  230,
  231,    0,  232,    0,    0,  233,  234,    0,    0,    0,
  235,  236,    0,    0,    0,    0,  237,  238,  239,    0,
  240,  241,  242,    0,  243,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  244,  245,  246,  247,  248,  249,
  250,  251,  252,  253,  254,  255,  256,  257,  258,  259,
  260,  261,  262,  263,  264,    0,  265,  266,  267,  268,
  269,  270,    0,  271,  272,  273,  274,    0,  275,    0,
  276,  277,  278,  279,  280,  281,  282,  283,  284,  285,
  286,  287,  288,  289,  290,  291,  292,  293,    0,  294,
  295,  296,  297,    0,  298,  299,  300,  301,  302,    0,
  303,  304,  305,  306,  307,  308,  309,  310,  311,  312,
  313,  314,  315,    0,  316,  317,  318,  319,  320,  321,
    0,  322,  323,  324,  325,  326,  327,  328,  329,    0,
 3309,  331,    0,    0,    0,  332,  333,  334,  335,  336,
  337,    0,    0,  338,  339,  340,  341,  342,  343,  344,
  345,  346,    0,    0,    0,    0,    0,  347,    0,  348,
  349,  350,  351,  352,  353,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  354,  355,    0,  356,  357,  358,  359,
  360,  361,  362,  363,  364,    0,  365,  366,  367,  368,
  369,  370,  371,  372,  373,  374,  375,  376,    0,  377,
  378,  379,    0,  380,    0,    0,    0,  381,  382,  383,
  384,  385,  386,  387,  388,  389,  390,  391,  392,  393,
    0,  394,  395,    0,    0,    0,    0,    0,  396,  397,
  398,  399,  400,  401,  402,  403,  404,  405,  406,  407,
 3310,  409,    0,    0,  410,  411,    0,    0,    0,    0,
  412,  413,  414,  415,  416,  417,  418,  419,  420,  154,
    0,  155,    0,    0,    0,    0,    0,  156,    0,    0,
  157,  158,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  159,  160,    0,  161,    0,  162,    0,    0,  163,
    0,    0,  164,    0,    0,    0,    0,    0,    0,  165,
    0,  166,  167,    0,    0,    0,  168,    0,  169,    0,
    0,  170,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  171,  172,    0,    0,    0,  173,    0,  174,    0,
  175, 3459,    0,    0,    0,    0,  176,    0,  177,    0,
    0,    0,  178,    0,    0,    0,    0,    0,    0,    0,
  179,    0,    0,  180,    0,  181,    0,    0,    0,  182,
  183,    0, 3460,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  184,    0, 3461,    0,  186,  187,  188,  189,
  190,    0,  191,    0,    0,    0,    0,    0,  192,    0,
  193,  194,    0,    0,  195,  196,    0,    0,    0,    0,
    0,  197,    0,    0,  198,  199,  200,  201,    0,  202,
    0,  203,    0,  204,  205,  206,  207,  208,    0,    0,
    0,    0,  209,    0,  210,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  211,    0,    0,    0,    0,
  212,  213,    0,    0,    0,    0,    0,  214,    0,    0,
    0,  215,    0,  216,  217,  218,  219,    0,  220,    0,
    0,    0,    0,    0,    0,    0,  221,  222,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  223,  224,    0,
  225,  226,  227,    0,    0,    0,    0,  228,  229,    0,
  230,  231,    0,  232,    0,    0,  233,  234,    0,    0,
    0,  235,  236,    0,    0,    0,    0,  237,  238,  239,
    0,  240,  241,  242,    0,  243,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  244,  245,  246,  247,  248,
  249,  250,  251,  252,  253,  254,  255,  256,  257,  258,
  259,  260,  261,  262,  263,  264,    0,  265,  266,  267,
  268,  269,  270,    0,  271,  272,  273,  274,    0,  275,
    0,  276,  277,  278,  279,  280,  281,  282,  283,  284,
  285,  286,  287,  288,  289,  290,  291,  292,  293,    0,
  294,  295,  296,  297,    0,  298,  299,  300,  301,  302,
    0,  303,  304,  305,  306,  307,  308,  309,  310,  311,
  312,  313,  314,  315,    0,  316,  317,  318,  319,  320,
  321,    0,  322,  323,  324,  325,  326,  327,  328,  329,
    0,  330,  331,    0,    0,    0,  332,  333,  334,  335,
  336,  337,    0,    0,  338,  339,  340,  341,  342,  343,
  344,  345,  346,    0,    0,    0,    0,    0,  347,    0,
  348,  349,  350,  351,  352,  353,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  354,  355,    0,  356,  357,  358,
  359,  360,  361,  362,  363,  364,    0,  365,  366,  367,
  368,  369,  370,  371,  372,  373,  374,  375,  376,    0,
  377,  378,  379,    0,  380,    0,    0,    0,  381,  382,
  383,  384,  385,  386,  387,  388,  389,  390,  391,  392,
  393,    0,  394,  395,    0,    0,    0,    0,    0,  396,
  397,  398,  399,  400,  401,  402,  403,  404,  405,  406,
  407,  408,  409,    0,    0,  410,  411,    0,    0,    0,
    0,  412,  413,  414,  415,  416,  417,  418,  419,  420,
  154,    0,  155,    0,    0,    0, 3591,    0,  156,    0,
    0,  157,  158,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  159,  160,    0,  161,    0,  162,    0,    0,
  163,    0,    0,  164,    0,    0,    0,    0,    0,    0,
  165,    0,  166,  167,    0,    0,    0,  168,    0,  169,
    0,    0,  170,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  171,  172,    0, 3592,    0,  173,    0,  174,
    0,  175,    0,    0,    0,    0,    0,  176,    0,  177,
    0,    0,    0,  178,    0,    0,    0,    0,    0,    0,
    0,  179,    0,    0,  180,    0,  181,    0,    0,    0,
  182,  183,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  184,    0,    0,    0,  186,  187,  188,
  189,  190,    0,  191,    0,    0,    0,    0,    0,  192,
    0,  193,  194,    0,    0,  195,  196,    0,    0,    0,
    0,    0,  197,    0,    0,  198,  199,  200,  201,    0,
  202,    0,  203,    0,  204,  205,  206,  207,  208,    0,
    0,    0,    0,  209,    0,  210,    0,    0,    0, 3593,
    0,    0,    0,    0,    0,    0,  211,    0,    0,    0,
    0,  212,  213,    0,    0,    0,    0,    0,  214,    0,
    0,    0,  215,    0,  216,  217,  218,  219,    0,  220,
    0,    0,    0,    0,    0,    0,    0,  221,  222,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  223,  224,
    0,  225,  226,  227,    0,    0,    0,    0,  228,  229,
    0,  230,  231,    0,  232,    0,    0,  233,  234,    0,
    0,    0,  235,  236,    0,    0,    0,    0,  237,  238,
  239,    0,  240,  241,  242,    0,  243,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  244,  245,  246,  247,
  248,  249,  250,  251,  252,  253,  254,  255,  256,  257,
  258,  259,  260,  261,  262,  263,  264,    0,  265,  266,
  267,  268,  269,  270,    0,  271,  272,  273,  274,    0,
  275,    0,  276,  277,  278,  279,  280,  281,  282,  283,
  284,  285,  286,  287,  288,  289,  290,  291,  292,  293,
    0,  294,  295,  296,  297,    0,  298,  299,  300,  301,
  302,    0,  303,  304,  305,  306,  307,  308,  309,  310,
  311,  312,  313,  314,  315,    0,  316,  317,  318,  319,
  320,  321,    0,  322,  323,  324,  325,  326,  327,  328,
  329,    0,  330,  331,    0,    0,    0,  332,  333,  334,
  335,  336,  337,    0,    0,  338,  339,  340,  341,  342,
  343,  344,  345,  346,    0,    0,    0,    0,    0,  347,
    0,  348,  349,  350,  351,  352,  353,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  354,  355,    0,  356,  357,
  358,  359,  360,  361,  362,  363,  364,    0,  365,  366,
  367,  368,  369,  370,  371,  372,  373,  374,  375,  376,
    0,  377,  378,  379,    0,  380,    0,    0,    0,  381,
  382,  383,  384,  385,  386,  387,  388,  389,  390,  391,
  392,  393,    0,  394,  395,    0,    0,    0,    0,    0,
  396,  397,  398,  399,  400,  401,  402,  403,  404,  405,
  406,  407,  408,  409,    0,    0,  410,  411,    0,    0,
    0,    0,  412,  413,  414,  415,  416,  417,  418,  419,
  420,  154,    0,  155,    0,    0,    0,    0,    0,  156,
    0,    0,  157,  158,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  159,  160,    0,  161,    0,  162,    0,
    0,  163,    0,    0,  164,    0,  858,    0,    0,    0,
    0,  165,    0,  166,  167,    0,    0,    0,  168,    0,
  169,    0,    0,  170,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  171,  172,    0,    0,    0,  173,    0,
  174,    0,  175,    0,    0,    0,    0,    0,  176,    0,
  177,    0,    0,    0,  178,    0,    0,    0,    0,    0,
    0,    0,  179,    0,    0,  180,    0,  181,    0,    0,
    0,  182,  183,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  184,    0,    0,    0,  186,  187,
  188,  189,  190,    0,  191,    0,    0,    0,    0,    0,
  192,    0,  193,  194,    0,    0,  195,  196,    0,    0,
    0,    0,    0,  197,    0,    0,  198,  199,  200,  201,
    0,  202,    0,  203,    0,  204,  205,  206,  207,  208,
    0,    0,    0,    0,  209,    0,  210,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  211,    0,    0,
    0,    0,  212,  213,    0,    0,    0,    0,    0,  214,
    0,    0,    0,  215,    0,  216,  217,  218,  219,    0,
  220,    0,    0,    0,    0,    0,    0,    0,  221,  222,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  223,
  224,    0,  225,  226,  227,    0,    0,    0,    0,  228,
  229,    0,  230,  231,    0,  232,    0,    0,  233,  234,
    0,    0,    0,  235,  236,    0,    0,    0,    0,  237,
  238,  239,    0,  240,  241,  242,    0,  243,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  244,  245,  246,
  247,  248,  249,  250,  251,  252,  253,  254,  255,  256,
  257,  258,  259,  260,  261,  262,  263,  264,    0,  265,
  266,  267,  268,  269,  270,    0,  271,  272,  273,  274,
    0,  275,    0,  276,  277,  278,  279,  280,  281,  282,
  283,  284,  285,  286,  287,  288,  289,  290,  291,  292,
  293,    0,  294,  295,  296,  297,    0,  298,  299,  300,
  301,  302,    0,  303,  304,  305,  306,  307,  308,  309,
  310,  311,  312,  313,  314,  315,    0,  316,  317,  318,
  319,  320,  321,    0,  322,  323,  324,  325,  326,  327,
  328,  329,    0,  330,  331,    0,    0,    0,  332,  333,
  334,  335,  336,  337,    0,    0,  338,  339,  340,  341,
  342,  343,  344,  345,  346,    0,    0,    0,    0,    0,
  347,  978,  348,  349,  350,  351,  352,  353,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  354,  355,    0,  356,
  357,  358,  359,  360,  361,  362,  363,  364,    0,  365,
  366,  367,  368,  369,  370,  371,  372,  373,  374,  375,
  376,    0,  377,  378,  379,    0,  380,    0,    0,    0,
  381,  382,  383,  384,  385,  386,  387,  388,  389,  390,
  391,  392,  393,    0,  394,  395,    0,    0,    0,    0,
    0,  396,  397,  398,  399,  400,  401,  402,  403,  404,
  405,  406,  407,  408,  409,    0,    0,  410,  411,    0,
    0,    0,    0,  412,  413,  414,  415,  416,  417,  418,
  419,  420,  154,    0,  155,    0,    0,    0,    0,    0,
  156,    0,    0,  157,  158,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  159,  160,    0,  161,    0,  162,
    0,    0,  163,    0,    0,  164,    0,    0,    0,    0,
    0,    0,  165,    0,  166,  167,    0,    0,    0,  168,
    0,  169,    0,    0,  170,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  171,  172,    0,    0,    0,  173,
    0,  174,    0,  175,    0,    0,    0,    0,    0,  176,
    0,  177,    0,    0,    0,  178,    0,    0,    0,    0,
    0,    0,    0,  179,    0,    0,  180,    0,  181,    0,
    0,    0,  182,  183,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  184,    0,    0,    0,  186,
  187,  188,  189,  190,    0,  191,    0,    0,    0,    0,
    0,  192,    0,  193,  194,    0,    0,  195,  196,    0,
    0,    0,    0,    0,  197,    0,    0,  198,  199,  200,
  201,    0,  202,    0,  203,    0,  204,  205,  206,  207,
  208,    0,    0,    0,    0,  209,    0,  210,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  211,    0,
    0,    0,    0,  212,  213,    0,    0,    0,    0,    0,
  214,    0,  606,  607,  215,    0,  216,  217,  218,  219,
    0,  220,    0,    0,    0,    0,    0,    0,    0,  221,
  222,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  223,  224,    0,  225,  226,  227,    0,    0,    0,    0,
  228,  229,    0,  230,  231,    0,  232,    0,    0,  233,
  234,    0,    0,    0,  235,  236,    0,    0,    0,    0,
  237,  238,  239,    0,  240,  241,  242,    0,  243,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  244,  245,
  246,  247,  248,  249,  250,  251,  252,  253,  254,  255,
  256,  257,  258,  259,  260,  261,  262,  263,  264,    0,
  265,  266,  267,  268,  269,  270,    0,  271,  272,  273,
  274,    0,  275,    0,  276,  277,  278,  279,  280,  281,
  282,  283,  284,  285,  286,  287,  288,  289,  290,  291,
  292,  293,    0,  294,  295,  296,  297,    0,  298,  299,
  300,  301,  302,    0,  303,  304,  305,  306,  307,  308,
  309,  310,  311,  312,  313,  314,  315,    0,  316,  317,
  318,  319,  320,  321,    0,  322,  323,  324,  325,  326,
  327,  328,  329,    0,  330,  331,    0,    0,    0,  332,
  333,  334,  335,  336,  337,    0,    0,  338,  339,  340,
  341,  342,  343,  344,  345,  346,    0,    0,    0,    0,
    0,  347,    0,  348,  349,  350,  351,  352,  353,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  354,  355,    0,
  356,  357,  358,  359,  360,  361,  362,  363,  364,    0,
  365,  366,  367,  368,  369,  370,  371,  372,  373,  374,
  375,  376,    0,  377,  378,  379,    0,  380,    0,    0,
    0,  381,  382,  383,  384,  385,  386,  387,  388,  389,
  390,  391,  392,  393,    0,  394,  395,    0,    0,    0,
    0,    0,  396,  397,  398,  399,  400,  401,  402,  403,
  404,  405,  406,  407,  408,  409,    0,    0,  410,  411,
    0,    0,    0,    0,  412,  413,  414,  415,  416,  417,
  418,  419,  420,  154,    0,  155,    0,    0,    0,    0,
    0,  156,    0,    0,  157,  158,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  159,  160,    0,  161,    0,
  162,    0,    0,  163,    0,    0,  164,    0,    0,    0,
    0,    0,    0,  165,    0,  166,  167,    0,    0,    0,
  168,    0,  169,    0,    0,  170,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  171,  172,    0,    0,    0,
  173,    0,  174,    0,  175,    0,    0,    0,    0,    0,
  176, 1679,  177,    0,    0,    0,  178,    0,    0,    0,
    0,    0,    0,    0,  179,    0,    0,  180,    0,  181,
    0, 1680,    0,  182,  183,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  184,    0,    0,    0,
  186,  187,  188,  189,  190,    0,  191,    0,    0,    0,
    0,    0,  192,    0,  193,  194,    0,    0,  195,  196,
    0,    0,    0,    0,    0,  197,    0,    0,  198,  199,
  200,  201,    0,  202,    0, 3243,    0,  204,  205,  206,
  207,  208,    0,    0,    0,    0,  209,    0,  210,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  211,
    0,    0,    0,    0,  212,  213,    0,    0,    0,    0,
    0,  214,    0,    0,    0,  215,    0,  216,  217,  218,
  219,    0,  220,    0,    0,    0,    0,    0,    0,    0,
  221,  222,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  223,  224,    0,  225,  226,  227,    0,    0,    0,
    0,  228,  229,    0,  230,  231,    0,  232,    0,    0,
  233,  234,    0,    0,    0,  235,  236,    0,    0,    0,
    0,  237,  238,  239,    0,  240,  241,  242,    0,  243,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  244,
  245,  246,  247,  248,  249,  250,  251,  252,  253,  254,
  255,  256,  257,  258,  259,  260,  261,  262,  263,  264,
    0,  265,  266,  267,  268,  269,  270,    0,  271,  272,
  273,  274,    0, 3244,    0,  276,  277,  278,  279,  280,
  281,  282,  283,  284,  285,  286,  287,  288,  289,  290,
  291,  292,  293,    0,  294,  295,  296,  297,    0,  298,
  299,  300,  301,  302,    0,  303,  304,  305,  306,  307,
  308,  309,  310,  311,  312,  313,  314,  315,    0,  316,
  317,  318,  319,  320,  321,    0,  322,  323,  324,  325,
  326,  327,  328,  329,    0,  330,  331,    0,    0,    0,
  332,  333,  334,  335,  336,  337,    0,    0,  338,  339,
  340,  341,  342,  343,  344,  345,  346,    0,    0,    0,
    0,    0,  347,    0,  348,  349,  350,  351,  352,  353,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  354,  355,
    0,  356,  357,  358,  359,  360,  361,  362,  363,  364,
    0,  365,  366,  367,  368,  369,  370,  371,  372,  373,
  374,  375,  376,    0,  377,  378,  379,    0,  380,    0,
    0,    0,  381,  382,  383,  384,  385,  386,  387,  388,
  389,  390,  391,  392,  393,    0,  394,  395,    0,    0,
    0,    0,    0,  396,  397,  398,  399,  400,  401,  402,
  403,  404,  405,  406,  407,  408,  409,    0,    0,  410,
  411,    0,    0,    0,    0,  412,  413,  414,  415,  416,
  417,  418,  419,  420,  154,    0,  155,    0,    0,    0,
    0,    0,  156,    0,    0,  157,  158,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  159,  160,    0,  161,
    0,  162,    0,    0,  163,    0,    0,  164,    0,    0,
    0,    0,    0,    0,  165,    0,  166,  167,    0,    0,
    0,  168,    0,  169,    0,    0,  170,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  171,  172,    0, 3592,
    0,  173,    0,  174,    0,  175,    0,    0,    0,    0,
    0,  176,    0,  177,    0,    0,    0,  178,    0,    0,
    0,    0,    0,    0,    0,  179,    0,    0,  180,    0,
  181,    0,    0,    0,  182,  183,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  184,    0,    0,
    0,  186,  187,  188,  189,  190,    0,  191,    0,    0,
    0,    0,    0,  192,    0,  193,  194,    0,    0,  195,
  196,    0,    0,    0,    0,    0,  197,    0,    0,  198,
  199,  200,  201,    0,  202,    0,  203,    0,  204,  205,
  206,  207,  208,    0,    0,    0,    0,  209,    0,  210,
    0,    0,    0, 3593,    0,    0,    0,    0,    0,    0,
  211,    0,    0,    0,    0,  212,  213,    0,    0,    0,
    0,    0,  214,    0,    0,    0,  215,    0,  216,  217,
  218,  219,    0,  220,    0,    0,    0,    0,    0,    0,
    0,  221,  222,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  223,  224,    0,  225,  226,  227,    0,    0,
    0,    0,  228,  229,    0,  230,  231,    0,  232,    0,
    0,  233,  234,    0,    0,    0,  235,  236,    0,    0,
    0,    0,  237,  238,  239,    0,  240,  241,  242,    0,
  243,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  244,  245,  246,  247,  248,  249,  250,  251,  252,  253,
  254,  255,  256,  257,  258,  259,  260,  261,  262,  263,
  264,    0,  265,  266,  267,  268,  269,  270,    0,  271,
  272,  273,  274,    0,  275,    0,  276,  277,  278,  279,
  280,  281,  282,  283,  284,  285,  286,  287,  288,  289,
  290,  291,  292,  293,    0,  294,  295,  296,  297,    0,
  298,  299,  300,  301,  302,    0,  303,  304,  305,  306,
  307,  308,  309,  310,  311,  312,  313,  314,  315,    0,
  316,  317,  318,  319,  320,  321,    0,  322,  323,  324,
  325,  326,  327,  328,  329,    0,  330,  331,    0,    0,
    0,  332,  333,  334,  335,  336,  337,    0,    0,  338,
  339,  340,  341,  342,  343,  344,  345,  346,    0,    0,
    0,    0,    0,  347,    0,  348,  349,  350,  351,  352,
  353,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  354,
  355,    0,  356,  357,  358,  359,  360,  361,  362,  363,
  364,    0,  365,  366,  367,  368,  369,  370,  371,  372,
  373,  374,  375,  376,    0,  377,  378,  379,    0,  380,
    0,    0,    0,  381,  382,  383,  384,  385,  386,  387,
  388,  389,  390,  391,  392,  393,    0,  394,  395,    0,
    0,    0,    0,    0,  396,  397,  398,  399,  400,  401,
  402,  403,  404,  405,  406,  407,  408,  409,    0,    0,
  410,  411,    0,    0,    0,    0,  412,  413,  414,  415,
  416,  417,  418,  419,  420,  154,    0,  155,    0,    0,
    0,    0,    0,  156,    0,    0,  157,  158,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  159,  160,    0,
  161,    0,  162,    0,    0,  163,    0,    0,  164,    0,
    0,    0,    0,    0,    0,  165,    0,  166,  167,    0,
    0,    0,  168,    0,  169,    0,    0,  170,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  171,  172,    0,
    0,    0,  173,    0,  174,    0,  175,    0,    0,    0,
    0,    0,  176,    0,  177,    0,    0,    0,  178,    0,
    0,    0,    0,    0,    0,    0,  179,    0,    0,  180,
    0,  181,    0,    0,    0,  182,  183,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  184,  185,
    0,    0,  186,  187,  188,  189,  190,    0,  191,    0,
    0,    0,    0,    0,  192,    0,  193,  194,    0,    0,
  195,  196,    0,    0,    0,    0,    0,  197,    0,    0,
  198,  199,  200,  201,    0,  202,    0,  203,    0,  204,
  205,  206,  207,  208,    0,    0,    0,    0,  209,    0,
  210,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  211,    0,    0,    0,    0,  212,  213,    0,    0,
    0,    0,    0,  214,    0,    0,    0,  215,    0,  216,
  217,  218,  219,    0,  220,    0,    0,    0,    0,    0,
    0,    0,  221,  222,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  223,  224,    0,  225,  226,  227,    0,
    0,    0,    0,  228,  229,    0,  230,  231,    0,  232,
    0,    0,  233,  234,    0,    0,    0,  235,  236,    0,
    0,    0,    0,  237,  238,  239,    0,  240,  241,  242,
    0,  243,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  244,  245,  246,  247,  248,  249,  250,  251,  252,
  253,  254,  255,  256,  257,  258,  259,  260,  261,  262,
  263,  264,    0,  265,  266,  267,  268,  269,  270,    0,
  271,  272,  273,  274,    0,  275,    0,  276,  277,  278,
  279,  280,  281,  282,  283,  284,  285,  286,  287,  288,
  289,  290,  291,  292,  293,    0,  294,  295,  296,  297,
    0,  298,  299,  300,  301,  302,    0,  303,  304,  305,
  306,  307,  308,  309,  310,  311,  312,  313,  314,  315,
    0,  316,  317,  318,  319,  320,  321,    0,  322,  323,
  324,  325,  326,  327,  328,  329,    0,  330,  331,    0,
    0,    0,  332,  333,  334,  335,  336,  337,    0,    0,
  338,  339,  340,  341,  342,  343,  344,  345,  346,    0,
    0,    0,    0,    0,  347,    0,  348,  349,  350,  351,
  352,  353,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  354,  355,    0,  356,  357,  358,  359,  360,  361,  362,
  363,  364,    0,  365,  366,  367,  368,  369,  370,  371,
  372,  373,  374,  375,  376,    0,  377,  378,  379,    0,
  380,    0,    0,    0,  381,  382,  383,  384,  385,  386,
  387,  388,  389,  390,  391,  392,  393,    0,  394,  395,
    0,    0,    0,    0,    0,  396,  397,  398,  399,  400,
  401,  402,  403,  404,  405,  406,  407,  408,  409,    0,
    0,  410,  411,    0,    0,    0,    0,  412,  413,  414,
  415,  416,  417,  418,  419,  420,  154,    0,  155,    0,
    0,    0,    0,    0,  156,    0,    0,  157,  158,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  159,  160,
    0,  161,    0,  162,    0,    0,  163,    0,    0,  164,
    0,    0,    0,    0,    0,    0,  165,    0,  166,  167,
    0,    0,    0,  168,    0,  169,    0,    0,  170,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  171,  172,
    0,    0,    0,  173,    0,  174,    0,  175,    0,    0,
    0,    0,    0,  176,    0,  177,    0,    0,    0,  178,
    0,    0,    0,    0,    0,    0,    0,  179,    0,    0,
  180,    0,  181,    0,    0,    0,  182,  183,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  184,
    0,    0,    0,  186,  187,  188,  189,  190,    0,  191,
    0,    0,    0,    0,    0,  192,    0,  193,  194,    0,
    0,  195,  196,    0,    0,    0,    0,    0,  197,    0,
    0,  198,  199,  200,  201,    0,  202,    0,  203,    0,
  204,  205,  206,  207,  208,    0,    0,    0,    0,  209,
    0,  210,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  211,    0,    0,    0,    0,  212,  213,    0,
    0,    0,    0,    0,  214,    0,    0,    0,  215,    0,
  216,  217,  218,  219,    0,  220,    0,    0,    0,    0,
    0,    0,    0,  221,  222,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  223,  224,    0,  225,  226,  227,
    0,    0,    0,    0,  228,  229,    0,  230,  231,    0,
  232,    0,    0,  233,  234,    0,    0,    0,  235,  236,
    0,    0,    0,    0,  237,  238,  239,    0,  240,  241,
  242,    0,  243,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  244,  245,  246,  247,  248,  249,  250,  251,
  252,  253,  254,  255,  256,  257,  258,  259,  260,  261,
  262,  263,  264,    0,  265,  266,  267,  268,  269,  270,
    0,  271,  272,  273,  274,    0,  275,    0,  276,  277,
  278,  279,  280,  281,  282,  283,  284,  285,  286,  287,
  288,  289,  290,  291,  292,  293,  426,  294,  295,  296,
  297,    0,  298,  299,  300,  301,  302,    0,  303,  304,
  305,  306,  307,  308,  309,  310,  311,  312,  313,  314,
  315,    0,  316,  317,  318,  319,  320,  321,    0,  322,
  323,  324,  325,  326,  327,  328,  329,    0,  330,  331,
    0,    0,    0,  332,  333,  334,  335,  336,  337,    0,
    0,  338,  339,  340,  341,  342,  343,  344,  345,  346,
    0,    0,    0,    0,    0,  347,    0,  348,  349,  350,
  351,  352,  353,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  354,  355,    0,  356,  357,  358,  359,  360,  361,
  362,  363,  364,    0,  365,  366,  367,  368,  369,  370,
  371,  372,  373,  374,  375,  376,    0,  377,  378,  379,
    0,  380,    0,    0,    0,  381,  382,  383,  384,  385,
  386,  387,  388,  389,  390,  391,  392,  393,    0,  394,
  395,    0,    0,    0,    0,    0,  396,  397,  398,  399,
  400,  401,  402,  403,  404,  405,  406,  407,  408,  409,
    0,    0,  410,  411,    0,    0,    0,    0,  412,  413,
  414,  415,  416,  417,  418,  419,  420,  154,    0,  155,
    0,    0,    0,    0,    0,  156,    0,    0,  157,  158,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  159,
  160,    0,  161,    0,  162,    0,    0,  163,    0,    0,
  164,    0,    0,    0,    0,    0,    0,  165,    0,  166,
  167,    0,    0,    0,  168,    0,  169,    0,    0,  170,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  171,
  172,    0,    0,    0,  173,    0,  174,    0,  175,    0,
    0,    0,    0,    0,  176,    0,  177,    0,    0,    0,
  178,    0,    0,    0,    0,    0,    0,    0,  179,    0,
    0,  180,    0,  181,    0,    0,    0,  182,  183,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  184,    0,    0,    0,  186,  187,  188,  189,  190,    0,
  191,    0,    0,    0,    0,    0,  192,    0,  193,  194,
    0,    0,  195,  196,    0,    0,    0,    0,    0,  197,
    0,    0,  198,  199,  200,  201,    0,  202,    0,  203,
    0,  204,  205,  206,  207,  208,    0,    0,    0,    0,
  209,    0,  210,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  211,    0,    0,    0,    0,  212,  213,
    0,    0,    0,    0,    0,  214,    0,    0,    0,  215,
    0,  216,  217,  218,  219,    0,  220,    0,    0,    0,
    0,    0,    0,    0,  221,  222,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  223,  224,    0,  225,  226,
  227,    0,    0,    0,    0,  228,  229,    0,  230,  231,
    0,  232,    0,    0,  233,  234,    0,    0,    0,  235,
  236,    0,    0,    0,    0,  237,  238,  239,    0,  240,
  241,  242,    0,  243,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  244,  245,  246,  247,  248,  249,  250,
  251,  252,  253,  254,  255,  256,  257,  258,  259,  260,
  261,  262,  263,  264,    0,  265,  266,  267,  268,  269,
  270,    0,  271,  272,  273,  274,    0,  275,    0,  276,
  277,  278,  279,  280,  281,  282,  283,  284,  285,  286,
  287,  288,  289,  290,  291,  292,  293,    0,  294,  295,
  296,  297,    0,  298,  299,  300,  301,  302,    0,  303,
  304,  305,  306,  307,  308,  309,  310,  311,  312,  313,
  314,  315,    0,  316,  317,  318,  319,  320,  321,    0,
  322,  323,  324,  325,  326,  327,  328,  329,    0,  330,
  331,    0,    0,    0,  332,  333,  334,  335,  336,  337,
    0,    0,  338,  339,  340,  341,  342,  343,  344,  345,
  346,    0,    0,    0,    0,    0,  347,    0,  348,  349,
  350,  351,  352,  353,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  354,  355,  758,  356,  357,  358,  359,  360,
  361,  362,  363,  364,    0,  365,  366,  367,  368,  369,
  370,  371,  372,  373,  374,  375,  376,    0,  377,  378,
  379,    0,  380,    0,    0,    0,  381,  382,  383,  384,
  385,  386,  387,  388,  389,  390,  391,  392,  393,    0,
  394,  395,    0,    0,    0,    0,    0,  396,  397,  398,
  399,  400,  401,  402,  403,  404,  405,  406,  407,  408,
  409,    0,    0,  410,  411,    0,    0,    0,    0,  412,
  413,  414,  415,  416,  417,  418,  419,  420,  154,    0,
  155,    0,    0,    0,    0,    0,  156,    0,    0,  157,
  158,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  159,  160,    0,  161,    0,  162,    0,    0,  163,    0,
    0,  164,    0,    0,    0,    0, 1884,    0,  165,    0,
  166,  167,    0,    0,    0,  168,    0,  169,    0,    0,
  170,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  171,  172,    0,    0,    0,  173,    0,  174,    0,  175,
    0,    0,    0,    0,    0,  176,    0,  177,    0,    0,
    0,  178,    0,    0,    0,    0,    0,    0,    0,  179,
    0,    0,  180,    0,  181,    0,    0,    0,  182,  183,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  184,    0,    0,    0,  186,  187,  188,  189,  190,
    0,  191,    0,    0,    0,    0,    0,  192,    0,  193,
  194,    0,    0,  195,  196,    0,    0,    0,    0,    0,
  197,    0,    0,  198,  199,  200,  201,    0,  202,    0,
  203,    0,  204,  205,  206,  207,  208,    0,    0,    0,
    0,  209,    0,  210,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  211,    0,    0,    0,    0,  212,
  213,    0,    0,    0,    0,    0,  214,    0,    0,    0,
  215,    0,  216,  217,  218,  219,    0,  220,    0,    0,
    0,    0,    0,    0,    0,  221,  222,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  223,  224,    0,  225,
  226,  227,    0,    0,    0,    0,  228,  229,    0,  230,
  231,    0,  232,    0,    0,  233,  234,    0,    0,    0,
  235,  236,    0,    0,    0,    0,  237,  238,  239,    0,
  240,  241,  242,    0,  243,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  244,  245,  246,  247,  248,  249,
  250,  251,  252,  253,  254,  255,  256,  257,  258,  259,
  260,  261,  262,  263,  264,    0,  265,  266,  267,  268,
  269,  270,    0,  271,  272,  273,  274,    0,  275,    0,
  276,  277,  278,  279,  280,  281,  282,  283,  284,  285,
  286,  287,  288,  289,  290,  291,  292,  293,    0,  294,
  295,  296,  297,    0,  298,  299,  300,  301,  302,    0,
  303,  304,  305,  306,  307,  308,  309,  310,  311,  312,
  313,  314,  315,    0,  316,  317,  318,  319,  320,  321,
    0,  322,  323,  324,  325,  326,  327,  328,  329,    0,
  330,  331,    0,    0,    0,  332,  333,  334,  335,  336,
  337,    0,    0,  338,  339,  340,  341,  342,  343,  344,
  345,  346,    0,    0,    0,    0,    0,  347,    0,  348,
  349,  350,  351,  352,  353,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  354,  355,    0,  356,  357,  358,  359,
  360,  361,  362,  363,  364,    0,  365,  366,  367,  368,
  369,  370,  371,  372,  373,  374,  375,  376,    0,  377,
  378,  379,    0,  380,    0,    0,    0,  381,  382,  383,
  384,  385,  386,  387,  388,  389,  390,  391,  392,  393,
    0,  394,  395,    0,    0,    0,    0,    0,  396,  397,
  398,  399,  400,  401,  402,  403,  404,  405,  406,  407,
  408,  409,    0,    0,  410,  411,    0,    0,    0,    0,
  412,  413,  414,  415,  416,  417,  418,  419,  420,  154,
    0,  155,    0,    0,    0,    0,    0,  156,    0,    0,
  157,  158,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  159,  160,    0,  161, 2463,  162,    0,    0,  163,
    0,    0,  164,    0,    0,    0,    0,    0,    0,  165,
    0,  166,  167,    0,    0,    0,  168,    0,  169,    0,
    0,  170,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  171,  172,    0,    0,    0,  173,    0,  174,    0,
  175,    0,    0,    0,    0,    0,  176,    0,  177,    0,
    0,    0,  178,    0,    0,    0,    0,    0,    0,    0,
  179,    0,    0,  180,    0,  181,    0,    0,    0,  182,
  183,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  184,    0,    0,    0,  186,  187,  188,  189,
  190,    0,  191,    0,    0,    0,    0,    0,  192,    0,
  193,  194,    0,    0,  195,  196,    0,    0,    0,    0,
    0,  197,    0,    0,  198,  199,  200,  201,    0,  202,
    0,  203,    0,  204,  205,  206,  207,  208,    0,    0,
    0,    0,  209,    0,  210,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  211,    0,    0,    0,    0,
  212,  213,    0,    0,    0,    0,    0,  214,    0,    0,
    0,  215,    0,  216,  217,  218,  219,    0,  220,    0,
    0,    0,    0,    0,    0,    0,  221,  222,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  223,  224,    0,
  225,  226,  227,    0,    0,    0,    0,  228,  229,    0,
  230,  231,    0,  232,    0,    0,  233,  234,    0,    0,
    0,  235,  236,    0,    0,    0,    0,  237,  238,  239,
    0,  240,  241,  242,    0,  243,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  244,  245,  246,  247,  248,
  249,  250,  251,  252,  253,  254,  255,  256,  257,  258,
  259,  260,  261,  262,  263,  264,    0,  265,  266,  267,
  268,  269,  270,    0,  271,  272,  273,  274,    0,  275,
    0,  276,  277,  278,  279,  280,  281,  282,  283,  284,
  285,  286,  287,  288,  289,  290,  291,  292,  293,    0,
  294,  295,  296,  297,    0,  298,  299,  300,  301,  302,
    0,  303,  304,  305,  306,  307,  308,  309,  310,  311,
  312,  313,  314,  315,    0,  316,  317,  318,  319,  320,
  321,    0,  322,  323,  324,  325,  326,  327,  328,  329,
    0,  330,  331,    0,    0,    0,  332,  333,  334,  335,
  336,  337,    0,    0,  338,  339,  340,  341,  342,  343,
  344,  345,  346,    0,    0,    0,    0,    0,  347,    0,
  348,  349,  350,  351,  352,  353,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  354,  355,    0,  356,  357,  358,
  359,  360,  361,  362,  363,  364,    0,  365,  366,  367,
  368,  369,  370,  371,  372,  373,  374,  375,  376,    0,
  377,  378,  379,    0,  380,    0,    0,    0,  381,  382,
  383,  384,  385,  386,  387,  388,  389,  390,  391,  392,
  393,    0,  394,  395,    0,    0,    0,    0,    0,  396,
  397,  398,  399,  400,  401,  402,  403,  404,  405,  406,
 2464,  408,  409,    0,    0,  410,  411,    0,    0,    0,
    0,  412,  413,  414,  415,  416,  417,  418,  419,  420,
  154,    0,  155,    0,    0,    0,    0,    0,  156,    0,
    0,  157,  158,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  159,  160,    0,  161, 2797,  162,    0,    0,
  163,    0,    0,  164,    0,    0,    0,    0,    0,    0,
  165,    0,  166,  167,    0,    0,    0,  168,    0,  169,
    0,    0,  170,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  171,  172,    0,    0,    0,  173,    0,  174,
    0,  175,    0,    0,    0,    0,    0,  176,    0,  177,
    0,    0,    0,  178,    0,    0,    0,    0,    0,    0,
    0,  179,    0,    0,  180,    0,  181,    0,    0,    0,
  182,  183,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  184,    0,    0,    0,  186,  187,  188,
  189,  190,    0,  191,    0,    0,    0,    0,    0,  192,
    0,  193,  194,    0,    0,  195,  196,    0,    0,    0,
    0,    0,  197,    0,    0,  198,  199,  200,  201,    0,
  202,    0,  203,    0,  204,  205,  206,  207,  208,    0,
    0,    0,    0,  209,    0,  210,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  211,    0,    0,    0,
    0,  212,  213,    0,    0,    0,    0,    0,  214,    0,
    0,    0,  215,    0,  216,  217,  218,  219,    0,  220,
    0,    0,    0,    0,    0,    0,    0,  221,  222,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  223,  224,
    0,  225,  226,  227,    0,    0,    0,    0,  228,  229,
    0,  230,  231,    0,  232,    0,    0,  233,  234,    0,
    0,    0,  235,  236,    0,    0,    0,    0,  237,  238,
  239,    0,  240,  241,  242,    0,  243,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  244,  245,  246,  247,
  248,  249,  250,  251,  252,  253,  254,  255,  256,  257,
  258,  259,  260,  261,  262,  263,  264,    0,  265,  266,
  267,  268,  269,  270,    0,  271,  272,  273,  274,    0,
  275,    0,  276,  277,  278,  279,  280,  281,  282,  283,
  284,  285,  286,  287,  288,  289,  290,  291,  292,  293,
    0,  294,  295,  296,  297,    0,  298,  299,  300,  301,
  302,    0,  303,  304,  305,  306,  307,  308,  309,  310,
  311,  312,  313,  314,  315,    0,  316,  317,  318,  319,
  320,  321,    0,  322,  323,  324,  325,  326,  327,  328,
  329,    0,  330,  331,    0,    0,    0,  332,  333,  334,
  335,  336,  337,    0,    0,  338,  339,  340,  341,  342,
  343,  344,  345,  346,    0,    0,    0,    0,    0,  347,
    0,  348,  349,  350,  351,  352,  353,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  354,  355,    0,  356,  357,
  358,  359,  360,  361,  362,  363,  364,    0,  365,  366,
  367,  368,  369,  370,  371,  372,  373,  374,  375,  376,
    0,  377,  378,  379,    0,  380,    0,    0,    0,  381,
  382,  383,  384,  385,  386,  387,  388,  389,  390,  391,
  392,  393,    0,  394,  395,    0,    0,    0,    0,    0,
  396,  397,  398,  399,  400,  401,  402,  403,  404,  405,
  406,  407,  408,  409,    0,    0,  410,  411,    0,    0,
    0,    0,  412,  413,  414,  415,  416,  417,  418,  419,
  420,  154,    0,  155,    0,    0,    0,    0,    0,  156,
    0,    0,  157,  158,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  159,  160,    0,  161,    0,  162,    0,
    0,  163,    0,    0,  164,    0,    0,    0,    0,    0,
    0,  165,    0,  166,  167,    0,    0,    0,  168,    0,
  169,    0,    0,  170, 2896,    0,    0,    0,    0,    0,
    0,    0,    0,  171,  172,    0,    0,    0,  173,    0,
  174,    0,  175,    0,    0,    0,    0,    0,  176,    0,
  177,    0,    0,    0,  178,    0,    0,    0,    0,    0,
    0,    0,  179,    0,    0,  180,    0,  181,    0,    0,
    0,  182,  183,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  184,    0,    0,    0,  186,  187,
  188,  189,  190,    0,  191,    0,    0,    0,    0,    0,
  192,    0,  193,  194,    0,    0,  195,  196,    0,    0,
    0,    0,    0,  197,    0,    0,  198,  199,  200,  201,
    0,  202,    0,  203,    0,  204,  205,  206,  207,  208,
    0,    0,    0,    0,  209,    0,  210,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  211,    0,    0,
    0,    0,  212,  213,    0,    0,    0,    0,    0,  214,
    0,    0,    0,  215,    0,  216,  217,  218,  219,    0,
  220,    0,    0,    0,    0,    0,    0,    0,  221,  222,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  223,
  224,    0,  225,  226,  227,    0,    0,    0,    0,  228,
  229,    0,  230,  231,    0,  232,    0,    0,  233,  234,
    0,    0,    0,  235,  236,    0,    0,    0,    0,  237,
  238,  239,    0,  240,  241,  242,    0,  243,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  244,  245,  246,
  247,  248,  249,  250,  251,  252,  253,  254,  255,  256,
  257,  258,  259,  260,  261,  262,  263,  264,    0,  265,
  266,  267,  268,  269,  270,    0,  271,  272,  273,  274,
    0,  275,    0,  276,  277,  278,  279,  280,  281,  282,
  283,  284,  285,  286,  287,  288,  289,  290,  291,  292,
  293,    0,  294,  295,  296,  297,    0,  298,  299,  300,
  301,  302,    0,  303,  304,  305,  306,  307,  308,  309,
  310,  311,  312,  313,  314,  315,    0,  316,  317,  318,
  319,  320,  321,    0,  322,  323,  324,  325,  326,  327,
  328,  329,    0,  330,  331,    0,    0,    0,  332,  333,
  334,  335,  336,  337,    0,    0,  338,  339,  340,  341,
  342,  343,  344,  345,  346,    0,    0,    0,    0,    0,
  347,    0,  348,  349,  350,  351,  352,  353,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  354,  355,    0,  356,
  357,  358,  359,  360,  361,  362,  363,  364,    0,  365,
  366,  367,  368,  369,  370,  371,  372,  373,  374,  375,
  376,    0,  377,  378,  379,    0,  380,    0,    0,    0,
  381,  382,  383,  384,  385,  386,  387,  388,  389,  390,
  391,  392,  393,    0,  394,  395,    0,    0,    0,    0,
    0,  396,  397,  398,  399,  400,  401,  402,  403,  404,
  405,  406,  407,  408,  409,    0,    0,  410,  411,    0,
    0,    0,    0,  412,  413,  414,  415,  416,  417,  418,
  419,  420,  154,    0,  155,    0,    0,    0,    0,    0,
  156,    0,    0,  157,  158,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  159,  160,    0,  161,    0,  162,
    0,    0,  163,    0,    0,  164,    0,    0,    0,    0,
    0,    0,  165,    0,  166,  167,    0,    0,    0,  168,
    0,  169,    0,    0,  170,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  171,  172,    0,    0,    0,  173,
    0,  174,    0,  175,    0,    0,    0,    0,    0,  176,
    0,  177,    0,    0,    0,  178,    0,    0,    0,    0,
    0,    0,    0,  179,    0,    0,  180,    0,  181,    0,
    0,    0,  182,  183,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  184,    0,    0,    0,  186,
  187,  188,  189,  190,    0,  191,    0,    0,    0,    0,
    0,  192,    0,  193,  194,    0,    0,  195,  196,    0,
    0,    0,    0,    0,  197,    0,    0,  198,  199,  200,
  201,    0,  202,    0,  203,    0,  204,  205,  206,  207,
  208,    0,    0,    0,    0,  209,    0,  210,    0,    0,
    0, 3007,    0,    0,    0,    0,    0,    0,  211,    0,
    0,    0,    0,  212,  213,    0,    0,    0,    0,    0,
  214,    0,    0,    0,  215,    0,  216,  217,  218, 3008,
    0,  220,    0,    0,    0,    0,    0,    0,    0,  221,
  222,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  223,  224,    0,  225,  226,  227,    0,    0,    0,    0,
  228,  229,    0,  230,  231,    0,  232,    0,    0,  233,
  234,    0,    0,    0,  235,  236,    0,    0,    0,    0,
  237,  238,  239,    0,  240,  241,  242,    0,  243,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  244,  245,
  246,  247,  248,  249,  250,  251,  252,  253,  254,  255,
  256,  257,  258,  259,  260,  261,  262,  263,  264,    0,
  265,  266,  267,  268,  269,  270,    0,  271,  272,  273,
  274,    0,  275,    0,  276,  277,  278,  279,  280,  281,
  282,  283,  284,  285,  286,  287,  288,  289,  290,  291,
  292,  293,    0,  294,  295,  296,  297,    0,  298,  299,
  300,  301,  302,    0,  303,  304,  305,  306,  307,  308,
  309,  310,  311,  312,  313,  314,  315,    0,  316,  317,
  318,  319,  320,  321,    0,  322,  323,  324,  325,  326,
  327,  328,  329,    0,  330,  331,    0,    0,    0,  332,
  333,  334,  335,  336,  337,    0,    0,  338,  339,  340,
  341,  342,  343,  344,  345,  346,    0,    0,    0,    0,
    0,  347,    0,  348,  349,  350,  351,  352,  353,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  354,  355,    0,
  356,  357,  358,  359,  360,  361,  362,  363,  364,    0,
  365,  366,  367,  368,  369,  370,  371,  372,  373,  374,
  375,  376,    0,  377,  378,  379,    0,  380,    0,    0,
    0,  381,  382,  383,  384,  385,  386,  387,  388,  389,
  390,  391,  392,  393,    0,  394,  395,    0,    0,    0,
    0,    0,  396,  397,  398,  399,  400,  401,  402,  403,
  404,  405,  406,  407,  408,  409,    0,    0,  410,  411,
    0,    0,    0,    0,  412,  413,  414,  415,  416,  417,
  418,  419,  420,  154,    0,  155,    0,    0,    0,    0,
    0,  156,    0,    0,  157,  158,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  159,  160,    0,  161,    0,
  162,    0,    0,  163,    0,    0,  164,    0,    0,    0,
    0,    0,    0,  165,    0,  166,  167,    0,    0,    0,
  168,    0,  169,    0,    0,  170,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  171,  172,    0,    0,    0,
  173,    0,  174,    0,  175,    0,    0,    0,    0,    0,
  176,    0,  177,    0,    0,    0,  178,    0,    0,    0,
    0,    0,    0,    0,  179,    0,    0,  180,    0,  181,
    0,    0,    0,  182,  183,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  184,    0,    0,    0,
  186,  187,  188,  189,  190,    0,  191,    0,    0,    0,
    0,    0,  192,    0,  193,  194,    0,    0,  195,  196,
    0,    0,    0,    0,    0,  197,    0,    0,  198,  199,
  200,  201,    0,  202,    0,  203,    0,  204,  205,  206,
  207,  208,    0,    0,    0,    0,  209,    0,  210,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  211,
    0,    0,    0,    0,  212,  213,    0,    0,    0,    0,
    0,  214,    0,    0,    0,  215,    0,  216,  217,  218,
  219, 3099,  220,    0,    0,    0,    0,    0,    0,    0,
  221,  222,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  223,  224,    0,  225,  226,  227,    0,    0,    0,
    0,  228,  229,    0,  230,  231,    0,  232,    0,    0,
  233,  234,    0,    0,    0,  235,  236,    0,    0,    0,
    0,  237,  238,  239,    0,  240,  241,  242,    0,  243,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  244,
  245,  246,  247,  248,  249,  250,  251,  252,  253,  254,
  255,  256,  257,  258,  259,  260,  261,  262,  263,  264,
    0,  265,  266,  267,  268,  269,  270,    0,  271,  272,
  273,  274,    0,  275,    0,  276,  277,  278,  279,  280,
  281,  282,  283,  284,  285,  286,  287,  288,  289,  290,
  291,  292,  293,    0,  294,  295,  296,  297,    0,  298,
  299,  300,  301,  302,    0,  303,  304,  305,  306,  307,
  308,  309,  310,  311,  312,  313,  314,  315,    0,  316,
  317,  318,  319,  320,  321,    0,  322,  323,  324,  325,
  326,  327,  328,  329,    0,  330,  331,    0,    0,    0,
  332,  333,  334,  335,  336,  337,    0,    0,  338,  339,
  340,  341,  342,  343,  344,  345,  346,    0,    0,    0,
    0,    0,  347,    0,  348,  349,  350,  351,  352,  353,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  354,  355,
    0,  356,  357,  358,  359,  360,  361,  362,  363,  364,
    0,  365,  366,  367,  368,  369,  370,  371,  372,  373,
  374,  375,  376,    0,  377,  378,  379,    0,  380,    0,
    0,    0,  381,  382,  383,  384,  385,  386,  387,  388,
  389,  390,  391,  392,  393,    0,  394,  395,    0,    0,
    0,    0,    0,  396,  397,  398,  399,  400,  401,  402,
  403,  404,  405,  406,  407,  408,  409,    0,    0,  410,
  411,    0,    0,    0,    0,  412,  413,  414,  415,  416,
  417,  418,  419,  420,  154,    0,  155,    0,    0,    0,
    0,    0,  156,    0,    0,  157,  158,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  159,  160,    0,  161,
    0,  162,    0,    0,  163,    0,    0,  164,    0,    0,
    0,    0,    0,    0,  165,    0,  166,  167,    0,    0,
    0,  168,    0,  169,    0,    0,  170,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  171,  172,    0,    0,
    0,  173,    0,  174,    0,  175,    0,    0,    0,    0,
    0,  176,    0,  177,    0,    0,    0,  178,    0,    0,
    0,    0,    0,    0,    0,  179,    0,    0,  180,    0,
  181,    0,    0,    0,  182,  183,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  184,    0,    0,
    0,  186,  187,  188,  189,  190,    0,  191,    0,    0,
    0,    0,    0,  192,    0,  193,  194,    0,    0,  195,
  196,    0,    0,    0,    0,    0,  197,    0,    0,  198,
  199,  200,  201,    0,  202,    0,  203,    0,  204,  205,
  206,  207,  208,    0,    0,    0,    0,  209,    0,  210,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  211,    0,    0,    0,    0,  212,  213,    0,    0,    0,
    0,    0,  214,    0,    0,    0,  215,    0,  216,  217,
  218,  219, 3250,  220,    0,    0,    0,    0,    0,    0,
    0,  221,  222,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  223,  224,    0,  225,  226,  227,    0,    0,
    0,    0,  228,  229,    0,  230,  231,    0,  232,    0,
    0,  233,  234,    0,    0,    0,  235,  236,    0,    0,
    0,    0,  237,  238,  239,    0,  240,  241,  242,    0,
  243,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  244,  245,  246,  247,  248,  249,  250,  251,  252,  253,
  254,  255,  256,  257,  258,  259,  260,  261,  262,  263,
  264,    0,  265,  266,  267,  268,  269,  270,    0,  271,
  272,  273,  274,    0,  275,    0,  276,  277,  278,  279,
  280,  281,  282,  283,  284,  285,  286,  287,  288,  289,
  290,  291,  292,  293,    0,  294,  295,  296,  297,    0,
  298,  299,  300,  301,  302,    0,  303,  304,  305,  306,
  307,  308,  309,  310,  311,  312,  313,  314,  315,    0,
  316,  317,  318,  319,  320,  321,    0,  322,  323,  324,
  325,  326,  327,  328,  329,    0,  330,  331,    0,    0,
    0,  332,  333,  334,  335,  336,  337,    0,    0,  338,
  339,  340,  341,  342,  343,  344,  345,  346,    0,    0,
    0,    0,    0,  347,    0,  348,  349,  350,  351,  352,
  353,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  354,
  355,    0,  356,  357,  358,  359,  360,  361,  362,  363,
  364,    0,  365,  366,  367,  368,  369,  370,  371,  372,
  373,  374,  375,  376,    0,  377,  378,  379,    0,  380,
    0,    0,    0,  381,  382,  383,  384,  385,  386,  387,
  388,  389,  390,  391,  392,  393,    0,  394,  395,    0,
    0,    0,    0,    0,  396,  397,  398,  399,  400,  401,
  402,  403,  404,  405,  406,  407,  408,  409,    0,    0,
  410,  411,    0,    0,    0,    0,  412,  413,  414,  415,
  416,  417,  418,  419,  420,  154,    0,  155,    0,    0,
    0,    0,    0,  156,    0,    0,  157,  158,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  159,  160,    0,
  161,    0,  162,    0,    0,  163,    0,    0,  164,    0,
    0,    0,    0,    0,    0,  165,    0,  166,  167,    0,
    0,    0,  168,    0,  169,    0,    0,  170,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  171,  172,    0,
    0,    0,  173,    0,  174,    0,  175,    0,    0,    0,
    0,    0,  176,    0,  177,    0,    0,    0,  178,    0,
    0,    0,    0,    0,    0,    0,  179,    0,    0,  180,
    0,  181,    0,    0,    0,  182,  183,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  184,    0,
    0,    0,  186,  187,  188,  189,  190,    0,  191,    0,
    0,    0,    0,    0,  192,    0,  193,  194,    0,    0,
  195,  196,    0,    0,    0,    0,    0,  197,    0,    0,
  198,  199,  200,  201,    0,  202,    0,  203,    0,  204,
  205,  206,  207,  208,    0,    0,    0,    0,  209,    0,
  210,    0,    0,    0, 3519,    0,    0,    0,    0,    0,
    0,  211,    0,    0,    0,    0,  212,  213,    0,    0,
    0,    0,    0,  214,    0,    0,    0,  215,    0,  216,
  217,  218,  219,    0,  220,    0,    0,    0,    0,    0,
    0,    0,  221,  222,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  223,  224,    0,  225,  226,  227,    0,
    0,    0,    0,  228,  229,    0,  230,  231,    0,  232,
    0,    0,  233,  234,    0,    0,    0,  235,  236,    0,
    0,    0,    0,  237,  238,  239,    0,  240,  241,  242,
    0,  243,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  244,  245,  246,  247,  248,  249,  250,  251,  252,
  253,  254,  255,  256,  257,  258,  259,  260,  261,  262,
  263,  264,    0,  265,  266,  267,  268,  269,  270,    0,
  271,  272,  273,  274,    0,  275,    0,  276,  277,  278,
  279,  280,  281,  282,  283,  284,  285,  286,  287,  288,
  289,  290,  291,  292,  293,    0,  294,  295,  296,  297,
    0,  298,  299,  300,  301,  302,    0,  303,  304,  305,
  306,  307,  308,  309,  310,  311,  312,  313,  314,  315,
    0,  316,  317,  318,  319,  320,  321,    0,  322,  323,
  324,  325,  326,  327,  328,  329,    0,  330,  331,    0,
    0,    0,  332,  333,  334,  335,  336,  337,    0,    0,
  338,  339,  340,  341,  342,  343,  344,  345,  346,    0,
    0,    0,    0,    0,  347,    0,  348,  349,  350,  351,
  352,  353,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  354,  355,    0,  356,  357,  358,  359,  360,  361,  362,
  363,  364,    0,  365,  366,  367,  368,  369,  370,  371,
  372,  373,  374,  375,  376,    0,  377,  378,  379,    0,
  380,    0,    0,    0,  381,  382,  383,  384,  385,  386,
  387,  388,  389,  390,  391,  392,  393,    0,  394,  395,
    0,    0,    0,    0,    0,  396,  397,  398,  399,  400,
  401,  402,  403,  404,  405,  406,  407,  408,  409,    0,
    0,  410,  411,    0,    0,    0,    0,  412,  413,  414,
  415,  416,  417,  418,  419,  420,  154,    0,  155,    0,
    0,    0,    0,    0,  156,    0,    0,  157,  158,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  159,  160,
    0,  161,    0,  162,    0,    0,  163,    0,    0,  164,
    0,    0,    0,    0,    0,    0,  165,    0,  166,  167,
 3608,    0,    0,  168,    0,  169,    0,    0,  170,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  171,  172,
    0,    0,    0,  173,    0,  174,    0,  175,    0,    0,
    0,    0,    0,  176,    0,  177,    0,    0,    0,  178,
    0,    0,    0,    0,    0,    0,    0,  179,    0,    0,
  180,    0,  181,    0,    0,    0,  182,  183,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  184,
    0,    0,    0,  186,  187,  188,  189,  190,    0,  191,
    0,    0,    0,    0,    0,  192,    0,  193,  194,    0,
    0,  195,  196,    0,    0,    0,    0,    0,  197,    0,
    0,  198,  199,  200,  201,    0,  202,    0,  203,    0,
  204,  205,  206,  207,  208,    0,    0,    0,    0,  209,
    0,  210,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  211,    0,    0,    0,    0,  212,  213,    0,
    0,    0,    0,    0,  214,    0,    0,    0,  215,    0,
  216,  217,  218,  219,    0,  220,    0,    0,    0,    0,
    0,    0,    0,  221,  222,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  223,  224,    0,  225,  226,  227,
    0,    0,    0,    0,  228,  229,    0,  230,  231,    0,
  232,    0,    0,  233,  234,    0,    0,    0,  235,  236,
    0,    0,    0,    0,  237,  238,  239,    0,  240,  241,
  242,    0,  243,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  244,  245,  246,  247,  248,  249,  250,  251,
  252,  253,  254,  255,  256,  257,  258,  259,  260,  261,
  262,  263,  264,    0,  265,  266,  267,  268,  269,  270,
    0,  271,  272,  273,  274,    0,  275,    0,  276,  277,
  278,  279,  280,  281,  282,  283,  284,  285,  286,  287,
  288,  289,  290,  291,  292,  293,    0,  294,  295,  296,
  297,    0,  298,  299,  300,  301,  302,    0,  303,  304,
  305,  306,  307,  308,  309,  310,  311,  312,  313,  314,
  315,    0,  316,  317,  318,  319,  320,  321,    0,  322,
  323,  324,  325,  326,  327,  328,  329,    0,  330,  331,
    0,    0,    0,  332,  333,  334,  335,  336,  337,    0,
    0,  338,  339,  340,  341,  342,  343,  344,  345,  346,
    0,    0,    0,    0,    0,  347,    0,  348,  349,  350,
  351,  352,  353,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  354,  355,    0,  356,  357,  358,  359,  360,  361,
  362,  363,  364,    0,  365,  366,  367,  368,  369,  370,
  371,  372,  373,  374,  375,  376,    0,  377,  378,  379,
    0,  380,    0,    0,    0,  381,  382,  383,  384,  385,
  386,  387,  388,  389,  390,  391,  392,  393,    0,  394,
  395,    0,    0,    0,    0,    0,  396,  397,  398,  399,
  400,  401,  402,  403,  404,  405,  406,  407,  408,  409,
    0,    0,  410,  411,    0,    0,    0,    0,  412,  413,
  414,  415,  416,  417,  418,  419,  420,  154,    0,  155,
    0,    0,    0,    0,    0,  156,    0,    0,  157,  158,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  159,
  160,    0,  161,    0,  162,    0,    0,  163,    0,    0,
  164,    0,    0,    0,    0,    0,    0,  165,    0,  166,
  167,    0,    0,    0,  168,    0,  169,    0,    0,  170,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  171,
  172,    0,    0,    0,  173,    0,  174,    0,  175,    0,
    0,    0,    0,    0,  176,    0,  177,    0,    0,    0,
  178,    0,    0,    0,    0,    0,    0,    0,  179,    0,
    0,  180,    0,  181,    0,    0,    0,  182,  183,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  184,    0,    0,    0,  186,  187,  188,  189,  190,    0,
  191,    0,    0,    0,    0,    0,  192,    0,  193,  194,
    0,    0,  195,  196,    0,    0,    0,    0,    0,  197,
    0,    0,  198,  199,  200,  201,    0,  202,    0,  203,
    0,  204,  205,  206,  207,  208,    0,    0,    0,    0,
  209,    0,  210,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  211,    0,    0,    0,    0,  212,  213,
    0,    0,    0,    0,    0,  214,    0,    0,    0,  215,
    0,  216,  217,  218,  219,    0,  220,    0,    0,    0,
    0,    0,    0,    0,  221,  222,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  223,  224,    0,  225,  226,
  227,    0,    0,    0,    0,  228,  229,    0,  230,  231,
    0,  232,    0,    0,  233,  234,    0,    0,    0,  235,
  236,    0,    0,    0,    0,  237,  238,  239,    0,  240,
  241,  242,    0,  243,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  244,  245,  246,  247,  248,  249,  250,
  251,  252,  253,  254,  255,  256,  257,  258,  259,  260,
  261,  262,  263,  264,    0,  265,  266,  267,  268,  269,
  270,    0,  271,  272,  273,  274,    0,  275,    0,  276,
  277,  278,  279,  280,  281,  282,  283,  284,  285,  286,
  287,  288,  289,  290,  291,  292,  293,    0,  294,  295,
  296,  297,    0,  298,  299,  300,  301,  302,    0,  303,
  304,  305,  306,  307,  308,  309,  310,  311,  312,  313,
  314,  315,    0,  316,  317,  318,  319,  320,  321,    0,
  322,  323,  324,  325,  326,  327,  328,  329,    0,  330,
  331,    0,    0,    0,  332,  333,  334,  335,  336,  337,
    0,    0,  338,  339,  340,  341,  342,  343,  344,  345,
  346,    0,    0,    0,    0,    0,  347,    0,  348,  349,
  350,  351,  352,  353,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  354,  355,    0,  356,  357,  358,  359,  360,
  361,  362,  363,  364,    0,  365,  366,  367,  368,  369,
  370,  371,  372,  373,  374,  375,  376,    0,  377,  378,
  379,    0,  380,    0,    0,    0,  381,  382,  383,  384,
  385,  386,  387,  388,  389,  390,  391,  392,  393,    0,
  394,  395,    0,    0,    0,    0,    0,  396,  397,  398,
  399,  400,  401,  402,  403,  404,  405,  406,  407,  408,
  409,    0,    0,  410,  411,    0,    0,    0,    0,  412,
  413,  414,  415,  416,  417,  418,  419,  420,  154,    0,
  155,    0,    0,    0,    0,    0,  156,    0,    0,  157,
  158,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  159,  160,    0,  161,    0,  162,    0,    0,  163,    0,
    0,  164,    0,    0,    0,    0,    0,    0,  165,    0,
  166,  167,    0,    0,    0,  168,    0,  169,    0,    0,
  170,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  171,  172,    0,    0,    0,  173,    0,  174,    0,  175,
    0,    0,    0,    0,    0,  176,    0,  177,    0,    0,
    0,  178,    0,    0,    0,    0,    0,    0,    0,  179,
    0,    0,  180,    0,  181,    0,    0,    0,  182,  183,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  184,    0,    0,    0,  186,  187,  188,  189,  190,
    0,  191,    0,    0,    0,    0,    0,  192,    0,  193,
  194,    0,    0,  195,  196,    0,    0,    0,    0,    0,
  197,    0,    0,  198,  199,  200,  201,    0,  202,    0,
  203,    0,  204,  205,  206,  207,  208,    0,    0,    0,
    0,  209,    0,  210,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  211,    0,    0,    0,    0,  212,
  213,    0,    0,    0,    0,    0,  214,    0,    0,    0,
  215,    0,  216,  217,  218,  219,    0,  220,    0,    0,
    0,    0,    0,    0,    0,  221,  222,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  223,  224,    0,  225,
  226,  227,    0,    0,    0,    0,  228,  229,    0,  230,
  231,    0,  232,    0,    0,  233,  234,    0,    0,    0,
  235,  236,    0,    0,    0,    0,  237,  238,  239,    0,
  240,  241,  242,    0,  243,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  244,  245,  246,  247,  248,  249,
  250,  251,  252,  253,  254,  255,  256,  257,  258,  259,
  260,  261,  262,  263,  264,    0,  265,  266,  267,  268,
  269,  270,    0,  271,  272,  273,  274,    0,  275,    0,
  276,  277,  278,  279,  280,  281,  282,  283,  284,  285,
  286,  287,  288,  289,  290,  291,  292,  293,    0,  294,
  295,  296,  297,    0,  298,  299,  300,  301,  302,    0,
  303,  304,  305,  306,  307,  308,  309,  310,  311,  312,
  313,  314,  315,    0,  316,  317,  318,  319,  320,  321,
    0,  322,  643,  324,  325,  326,  327,  328,  329,    0,
  330,  331,    0,    0,    0,  332,  333,  334,  335,  336,
  337,    0,    0,  338,  339,  340,  341,  342,  343,  344,
  345,  346,    0,    0,    0,    0,    0,  347,    0,  348,
  349,  350,  351,  352,  353,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  354,  355,    0,  356,  357,  358,  359,
  360,  361,  362,  363,  364,    0,  365,  366,  367,  368,
  369,  370,  371,  372,  373,  374,  375,  376,    0,  377,
  378,  379,    0,  380,    0,    0,    0,  381,  382,  383,
  384,  385,  386,  387,  388,  389,  390,  391,  392,  393,
    0,  394,  395,    0,    0,    0,    0,    0,  396,  397,
  398,  399,  400,  401,  402,  403,  404,  405,  406,  407,
  408,  409,    0,    0,  410,  411,    0,    0,    0,    0,
  412,  413,  414,  415,  416,  417,  418,  419,  420,  154,
    0,  155,    0,    0,    0,    0,    0,  156,    0,    0,
  157,  158,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  159,  160,    0,  161,    0,  162,    0,    0,  163,
    0,    0,  164,    0,    0,    0,    0,    0,    0,  165,
    0,  166,  167,    0,    0,    0,  168,    0,  169,    0,
    0,  170,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  171,  172,    0,    0,    0,  173,    0,  174,    0,
  175,    0,    0,    0,    0,    0,  176,    0,  177,    0,
    0,    0,  178,    0,    0,    0,    0,    0,    0,    0,
  179,    0,    0,  180,    0,  181,    0,    0,    0,  182,
  183,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  184,    0,    0,    0,  186,  187,  188,  189,
  190,    0,  191,    0,    0,    0,    0,    0,  192,    0,
  193,  194,    0,    0,  195,  196,    0,    0,    0,    0,
    0,  197,    0,    0,  198,  199,  200,  201,    0,  202,
    0,  203,    0,  204,  205,  206,  207,  208,    0,    0,
    0,    0,  209,    0,  210,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  211,    0,    0,    0,    0,
  212,  213,    0,    0,    0,    0,    0,  214,    0,    0,
    0,  215,    0,  216,  217,  218,  219,    0,  220,    0,
    0,    0,    0,    0,    0,    0,  221,  222,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  223,  224,    0,
  225,  226,  227,    0,    0,    0,    0,  228,  229,    0,
  230,  231,    0,  232,    0,    0,  233,  234,    0,    0,
    0,  235,  236,    0,    0,    0,    0,  237,  238,  239,
    0,  240,  241,  242,    0,  243,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  244,  245,  246,  247,  248,
  249,  250,  251,  252,  253,  254,  255,  256,  257,  258,
  259,  260,  261,  262,  263,  264,    0,  265,  266,  267,
  268,  269,  270,    0,  271,  272,  273,  274,    0,  275,
    0,  276,  277,  278,  279,  280,  281,  282,  283,  284,
  285,  286,  287,  288,  289,  290,  291,  292,  293,    0,
  294,  295,  296,  297,    0,  298,  299,  300,  301,  302,
    0,  303,  304,  305,  306,  307,  308,  309,  310,  311,
  312,  313,  314,  315,    0,  316,  317,  318,  319,  320,
  321,    0,  322,  673,  324,  325,  326,  327,  328,  329,
    0,  330,  331,    0,    0,    0,  332,  333,  334,  335,
  336,  337,    0,    0,  338,  339,  340,  341,  342,  343,
  344,  345,  346,    0,    0,    0,    0,    0,  347,    0,
  348,  349,  350,  351,  352,  353,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  354,  355,    0,  356,  357,  358,
  359,  360,  361,  362,  363,  364,    0,  365,  366,  367,
  368,  369,  370,  371,  372,  373,  374,  375,  376,    0,
  377,  378,  379,    0,  380,    0,    0,    0,  381,  382,
  383,  384,  385,  386,  387,  388,  389,  390,  391,  392,
  393,    0,  394,  395,    0,    0,    0,    0,    0,  396,
  397,  398,  399,  400,  401,  402,  403,  404,  405,  406,
  407,  408,  409,    0,    0,  410,  411,    0,    0,    0,
    0,  412,  413,  414,  415,  416,  417,  418,  419,  420,
  154,    0,  155,    0,    0,    0,    0,    0,  156,    0,
    0,  157,  158,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  159,  160,    0,  161,    0,  162,    0,    0,
  163,    0,    0,  164,    0,    0,    0,    0,    0,    0,
  165,    0,  166,  167,    0,    0,    0,  168,    0,  169,
    0,    0,  170,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  171,  172,    0,    0,    0,  173,    0,  174,
    0,  175,    0,    0,    0,    0,    0,  176,    0,  177,
    0,    0,    0,  178,    0,    0,    0,    0,    0,    0,
    0,  179,    0,    0,  180,    0,  181,    0,    0,    0,
  182,  183,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  184,    0,    0,    0,  186,  187,  188,
  189,  190,    0,  191,    0,    0,    0,    0,    0,  192,
    0,  193,  194,    0,    0,  195,  196,    0,    0,    0,
    0,    0,  197,    0,    0,  198,  199,  200,  201,    0,
  202,    0,  203,    0,  204,  205,  206,  207,  208,    0,
    0,    0,    0,  209,    0,  210,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  211,    0,    0,    0,
    0,  212,  213,    0,    0,    0,    0,    0,  214,    0,
    0,    0,  215,    0,  216,  217,  218,  219,    0,  220,
    0,    0,    0,    0,    0,    0,    0,  221,  222,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  223,  224,
    0,  225,  226,  227,    0,    0,    0,    0,  228,  229,
    0,  230,  231,    0,  232,    0,    0,  233,  234,    0,
    0,    0,  235,  236,    0,    0,    0,    0,  237,  238,
  239,    0,  240,  241,  242,    0,  243,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  244,  245,  246,  247,
  248,  249,  250,  251,  252,  253,  254,  255,  256,  257,
  258,  259,  260,  261,  262,  263,  264,    0,  265,  266,
  267,  268,  269,  270,    0,  271,  272,  273,  274,    0,
  275,    0,  276,  277,  278,  279,  280,  281,  282,  283,
  284,  285,  286,  287,  288,  289,  290,  291,  292,  293,
    0,  294,  295,  296,  297,    0,  298,  299,  300,  301,
  302,    0,  303,  304,  305,  306,  307,  308,  309,  310,
  311,  312,  313,  314,  315,    0,  316,  317,  318,  319,
  320,  321,    0,  322,  715,  324,  325,  326,  327,  328,
  329,    0,  330,  331,    0,    0,    0,  332,  333,  334,
  335,  336,  337,    0,    0,  338,  339,  340,  341,  342,
  343,  344,  345,  346,    0,    0,    0,    0,    0,  347,
    0,  348,  349,  350,  351,  352,  353,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  354,  355,    0,  356,  357,
  358,  359,  360,  361,  362,  363,  364,    0,  365,  366,
  367,  368,  369,  370,  371,  372,  373,  374,  375,  376,
    0,  377,  378,  379,    0,  380,    0,    0,    0,  381,
  382,  383,  384,  385,  386,  387,  388,  389,  390,  391,
  392,  393,    0,  394,  395,    0,    0,    0,    0,    0,
  396,  397,  398,  399,  400,  401,  402,  403,  404,  405,
  406,  407,  408,  409,    0,    0,  410,  411,    0,    0,
    0,    0,  412,  413,  414,  415,  416,  417,  418,  419,
  420,  154,    0,  155,    0,    0,    0,    0,    0,  156,
    0,    0,  157,  158,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  159,  160,    0,  161,    0,  162,    0,
    0,  163,    0,    0,  164,    0,    0,    0,    0,    0,
    0,  165,    0,  166,  167,    0,    0,    0,  168,    0,
  169,    0,    0,  170,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  171,  172,    0,    0,    0,  173,    0,
  174,    0,  175,    0,    0,    0,    0,    0,  176,    0,
  177,    0,    0,    0,  178,    0,    0,    0,    0,    0,
    0,    0,  179,    0,    0,  180,    0,  181,    0,    0,
    0,  182,  183,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  184,    0,    0,    0,  186,  187,
  188,  189,  190,    0,  191,    0,    0,    0,    0,    0,
  192,    0,  193,  194,    0,    0,  195,  196,    0,    0,
    0,    0,    0,  197,    0,    0,  198,  199,  200,  201,
    0,  202,    0,  203,    0,  204,  205,  206,  207,  208,
    0,    0,    0,    0,  209,    0,  210,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  211,    0,    0,
    0,    0,  212,  213,    0,    0,    0,    0,    0,  214,
    0,    0,    0,  215,    0,  216,  217,  218,  219,    0,
  220,    0,    0,    0,    0,    0,    0,    0,  221,  222,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  223,
  224,    0,  225,  226,  227,    0,    0,    0,    0,  228,
  229,    0,  230,  231,    0,  232,    0,    0,  233,  234,
    0,    0,    0,  235,  236,    0,    0,    0,    0,  237,
  238,  239,    0,  240,  241,  242,    0,  243,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  244,  245,  246,
  247,  248,  249,  250,  251,  252,  253,  254,  255,  256,
  257,  258,  259,  260,  261,  262,  263,  264,    0,  265,
  266,  267,  268,  269,  270,    0,  271,  272,  273,  274,
    0,  275,    0,  276,  277,  278,  279,  280,  281,  282,
  283,  284,  285,  286,  287,  288,  289,  290,  291,  292,
  293,    0,  294,  295,  296,  297,    0,  298,  299,  300,
  301,  302,    0,  303,  304,  305,  306,  307,  308,  309,
  310,  311,  312,  313,  314,  315,    0,  316,  317,  318,
  319,  320,  321,    0,  322,  323,  324,  325,  326,  327,
  328,  329,    0,  330,  331,    0,    0,    0,  332,  333,
  334,  335,  336,  337,    0,    0,  338,  339,  340,  341,
  342,  343,  344,  345,  346,    0,    0,    0,    0,    0,
  347,    0,  348,  349,  350,  351,  352,  353,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  354,  355,    0,  356,
  357,  358,  359,  360,  361,  362,  363,  364,    0,  365,
  366,  367, 3983,  369,  370,  371,  372,  373,  374,  375,
  376,    0,  377,  378,  379,    0,  380,    0,    0,    0,
  381,  382,  383,  384,  385,  386,  387,  388,  389,  390,
  391,  392,  393,    0,  394,  395,    0,    0,    0,    0,
    0,  396,  397,  398,  399,  400,  401,  402,  403,  404,
  405,  406,  407,  408,  409,    0,    0,  410,  411,    0,
    0,    0,    0,  412,  413,  414,  415,  416,  417,  418,
  419,  420, 1183,    0, 1183,    0,    0,    0,    0,    0,
 1183,    0,    0, 1183, 1183,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1183, 1183,    0, 1183,    0, 1183,
    0,    0, 1183,    0,    0, 1183,    0,    0,    0,    0,
    0,    0, 1183,    0, 1183, 1183,    0,    0,    0, 1183,
    0, 1183,    0,    0, 1183,    0,    0,    0,    0,    0,
    0,    0,    0,    0, 1183, 1183,    0,    0,    0, 1183,
    0, 1183,    0, 1183,    0,    0,    0,    0,    0, 1183,
    0, 1183,    0,    0,    0, 1183,    0,    0,    0,    0,
    0,    0,    0, 1183,    0,    0, 1183,    0, 1183,    0,
    0,    0, 1183, 1183,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1183,    0,    0,    0, 1183,
 1183, 1183, 1183, 1183,    0, 1183,    0,    0,    0,    0,
    0, 1183,    0, 1183, 1183,    0,    0, 1183, 1183,    0,
    0,    0,    0,    0, 1183,    0,    0, 1183, 1183, 1183,
 1183,    0, 1183,    0, 1183,    0, 1183, 1183, 1183, 1183,
 1183,    0,    0,    0,    0, 1183,    0, 1183,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1183,    0,
    0,    0,    0, 1183, 1183,    0,    0,    0,    0,    0,
 1183,    0,    0,    0, 1183,    0, 1183, 1183, 1183, 1183,
    0, 1183,    0,    0,    0,    0,    0,    0,    0, 1183,
 1183,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1183, 1183,    0, 1183, 1183, 1183,    0,    0,    0,    0,
 1183, 1183,    0, 1183, 1183,    0, 1183,    0,    0, 1183,
 1183,    0,    0,    0, 1183, 1183,    0,    0,    0,    0,
 1183, 1183, 1183,    0, 1183, 1183, 1183,    0, 1183,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1183, 1183,
 1183, 1183, 1183, 1183, 1183, 1183, 1183, 1183, 1183, 1183,
 1183, 1183, 1183, 1183, 1183, 1183, 1183, 1183, 1183,    0,
 1183, 1183, 1183, 1183, 1183, 1183,    0, 1183, 1183, 1183,
 1183,    0, 1183,    0, 1183, 1183, 1183, 1183, 1183, 1183,
 1183, 1183, 1183, 1183, 1183, 1183, 1183, 1183, 1183, 1183,
 1183, 1183,    0, 1183, 1183, 1183, 1183,    0, 1183, 1183,
 1183, 1183, 1183,    0, 1183, 1183, 1183, 1183, 1183, 1183,
 1183, 1183, 1183, 1183, 1183, 1183, 1183,    0, 1183, 1183,
 1183, 1183, 1183, 1183,    0, 1183, 1183, 1183, 1183, 1183,
 1183, 1183, 1183,    0, 1183, 1183,    0,    0,    0, 1183,
 1183, 1183, 1183, 1183, 1183,    0,    0, 1183, 1183, 1183,
 1183, 1183, 1183, 1183, 1183, 1183,    0,    0,    0,    0,
    0, 1183,    0, 1183, 1183, 1183, 1183, 1183, 1183,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1183, 1183,    0,
 1183, 1183, 1183, 1183, 1183, 1183, 1183, 1183, 1183,    0,
 1183, 1183, 1183, 1183, 1183, 1183, 1183, 1183, 1183, 1183,
 1183, 1183,    0, 1183, 1183, 1183,    0, 1183,    0,    0,
    0, 1183, 1183, 1183, 1183, 1183, 1183, 1183, 1183, 1183,
 1183, 1183, 1183, 1183,    0, 1183, 1183,    0,    0,    0,
    0,    0, 1183, 1183, 1183, 1183, 1183, 1183, 1183, 1183,
 1183, 1183, 1183, 1183, 1183, 1183,    0,    0, 1183, 1183,
    0,    0,    0,    0, 1183, 1183, 1183, 1183, 1183, 1183,
 1183, 1183, 1183, 1312,    0, 1312,    0,    0,    0,    0,
    0, 1312,    0,    0, 1312, 1312,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1312, 1312,    0, 1312,    0,
 1312,    0,    0, 1312,    0,    0, 1312,    0,    0,    0,
    0,    0,    0, 1312,    0, 1312, 1312,    0,    0,    0,
 1312,    0, 1312,    0,    0, 1312,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1312, 1312,    0,    0,    0,
 1312,    0, 1312,    0, 1312,    0,    0,    0,    0,    0,
 1312,    0, 1312,    0,    0,    0, 1312,    0,    0,    0,
    0,    0,    0,    0, 1312,    0,    0, 1312,    0, 1312,
    0,    0,    0, 1312, 1312,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1312,    0,    0,    0,
 1312, 1312, 1312, 1312, 1312,    0, 1312,    0,    0,    0,
    0,    0, 1312,    0, 1312, 1312,    0,    0, 1312, 1312,
    0,    0,    0,    0,    0, 1312,    0,    0, 1312, 1312,
 1312, 1312,    0, 1312,    0, 1312,    0, 1312, 1312, 1312,
 1312, 1312,    0,    0,    0,    0, 1312,    0, 1312,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1312,
    0,    0,    0,    0, 1312, 1312,    0,    0,    0,    0,
    0, 1312,    0,    0,    0, 1312,    0, 1312, 1312, 1312,
 1312,    0, 1312,    0,    0,    0,    0,    0,    0,    0,
 1312, 1312,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1312, 1312,    0, 1312, 1312, 1312,    0,    0,    0,
    0, 1312, 1312,    0, 1312, 1312,    0, 1312,    0,    0,
 1312, 1312,    0,    0,    0, 1312, 1312,    0,    0,    0,
    0, 1312, 1312, 1312,    0, 1312, 1312, 1312,    0, 1312,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1312,
 1312, 1312, 1312, 1312, 1312, 1312, 1312, 1312, 1312, 1312,
 1312, 1312, 1312, 1312, 1312, 1312, 1312, 1312, 1312, 1312,
    0, 1312, 1312, 1312, 1312, 1312, 1312,    0, 1312, 1312,
 1312, 1312,    0, 1312,    0, 1312, 1312, 1312, 1312, 1312,
 1312, 1312, 1312, 1312, 1312, 1312, 1312, 1312, 1312, 1312,
 1312, 1312, 1312,    0, 1312, 1312, 1312, 1312,    0, 1312,
 1312, 1312, 1312, 1312,    0, 1312, 1312, 1312, 1312, 1312,
 1312, 1312, 1312, 1312, 1312, 1312, 1312, 1312,    0, 1312,
 1312, 1312, 1312, 1312, 1312,    0, 1312, 1312, 1312, 1312,
 1312, 1312, 1312, 1312,    0, 1312, 1312,    0,    0,    0,
 1312, 1312, 1312, 1312, 1312, 1312,    0,    0, 1312, 1312,
 1312, 1312, 1312, 1312, 1312, 1312, 1312,    0,    0,    0,
    0,    0, 1312,    0, 1312, 1312, 1312, 1312, 1312, 1312,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1312, 1312,
    0, 1312, 1312, 1312, 1312, 1312, 1312, 1312, 1312, 1312,
    0, 1312, 1312, 1312, 1312, 1312, 1312, 1312, 1312, 1312,
 1312, 1312, 1312,    0, 1312, 1312, 1312,    0, 1312,    0,
    0,    0, 1312, 1312, 1312, 1312, 1312, 1312, 1312, 1312,
 1312, 1312, 1312, 1312, 1312,    0, 1312, 1312,    0,    0,
    0,    0,    0, 1312, 1312, 1312, 1312, 1312, 1312, 1312,
 1312, 1312, 1312, 1312, 1312, 1312, 1312,    0,    0, 1312,
 1312,    0,    0,    0,    0, 1312, 1312, 1312, 1312, 1312,
 1312, 1312, 1312, 1312, 1310,    0, 1310,    0,    0,    0,
    0,    0, 1310,    0,    0, 1310, 1310,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1310, 1310,    0, 1310,
    0, 1310,    0,    0, 1310,    0,    0, 1310,    0,    0,
    0,    0,    0,    0, 1310,    0, 1310, 1310,    0,    0,
    0, 1310,    0, 1310,    0,    0, 1310,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1310, 1310,    0,    0,
    0, 1310,    0, 1310,    0, 1310,    0,    0,    0,    0,
    0, 1310,    0, 1310,    0,    0,    0, 1310,    0,    0,
    0,    0,    0,    0,    0, 1310,    0,    0, 1310,    0,
 1310,    0,    0,    0, 1310, 1310,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1310,    0,    0,
    0, 1310, 1310, 1310, 1310, 1310,    0, 1310,    0,    0,
    0,    0,    0, 1310,    0, 1310, 1310,    0,    0, 1310,
 1310,    0,    0,    0,    0,    0, 1310,    0,    0, 1310,
 1310, 1310, 1310,    0, 1310,    0, 1310,    0, 1310, 1310,
 1310, 1310, 1310,    0,    0,    0,    0, 1310,    0, 1310,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1310,    0,    0,    0,    0, 1310, 1310,    0,    0,    0,
    0,    0, 1310,    0,    0,    0, 1310,    0, 1310, 1310,
 1310, 1310,    0, 1310,    0,    0,    0,    0,    0,    0,
    0, 1310, 1310,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1310, 1310,    0, 1310, 1310, 1310,    0,    0,
    0,    0, 1310, 1310,    0, 1310, 1310,    0, 1310,    0,
    0, 1310, 1310,    0,    0,    0, 1310, 1310,    0,    0,
    0,    0, 1310, 1310, 1310,    0, 1310, 1310, 1310,    0,
 1310,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310,
 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310,
 1310,    0, 1310, 1310, 1310, 1310, 1310, 1310,    0, 1310,
 1310, 1310, 1310,    0, 1310,    0, 1310, 1310, 1310, 1310,
 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310,
 1310, 1310, 1310, 1310,    0, 1310, 1310, 1310, 1310,    0,
 1310, 1310, 1310, 1310, 1310,    0, 1310, 1310, 1310, 1310,
 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310,    0,
 1310, 1310, 1310, 1310, 1310, 1310,    0, 1310, 1310, 1310,
 1310, 1310, 1310, 1310, 1310,    0, 1310, 1310,    0,    0,
    0, 1310, 1310, 1310, 1310, 1310, 1310,    0,    0, 1310,
 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310,    0,    0,
    0,    0,    0, 1310,    0, 1310, 1310, 1310, 1310, 1310,
 1310,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1310,
 1310,    0, 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310,
 1310,    0, 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310,
 1310, 1310, 1310, 1310,    0, 1310, 1310, 1310,    0, 1310,
    0,    0,    0, 1310, 1310, 1310, 1310, 1310, 1310, 1310,
 1310, 1310, 1310, 1310, 1310, 1310,    0, 1310, 1310,    0,
    0,    0,    0,    0, 1310, 1310, 1310, 1310, 1310, 1310,
 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310,    0,    0,
 1310, 1310,    0,    0,    0,    0, 1310, 1310, 1310, 1310,
 1310, 1310, 1310, 1310, 1310,  170,    0,  170,    0,    0,
    0,    0,    0,  170,    0,    0,  170,  170,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  170,  170,    0,
  170,    0,  170,    0,    0,  170,    0,    0,  170,    0,
    0,    0,    0,    0,    0,  170,    0,  170,  170,    0,
    0,    0,  170,    0,  170,    0,    0,  170,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  170,  170,    0,
    0,    0,  170,    0,  170,    0,  170,    0,    0,    0,
    0,    0,  170,    0,  170,    0,    0,    0,  170,    0,
    0,    0,    0,    0,    0,    0,  170,    0,    0,  170,
    0,  170,    0,    0,    0,  170,  170,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  170,    0,
    0,    0,  170,  170,  170,  170,  170,    0,  170,    0,
    0,    0,    0,    0,  170,    0,  170,  170,    0,    0,
  170,  170,    0,    0,    0,    0,    0,  170,    0,    0,
  170,  170,  170,  170,    0,  170,    0,  170,    0,  170,
  170,  170,  170,  170,    0,    0,    0,    0,  170,    0,
  170,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  170,    0,    0,    0,    0,  170,  170,    0,    0,
    0,    0,    0,  170,    0,    0,    0,  170,    0,  170,
  170,  170,  170,    0,  170,    0,    0,    0,    0,    0,
    0,    0,  170,  170,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  170,  170,    0,  170,  170,  170,    0,
    0,    0,    0,  170,  170,    0,  170,  170,    0,  170,
    0,    0,  170,  170,    0,    0,    0,  170,  170,    0,
    0,    0,    0,  170,  170,  170,    0,  170,  170,  170,
    0,  170,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  170,  170,  170,  170,  170,  170,  170,  170,  170,
  170,  170,  170,  170,  170,  170,  170,  170,  170,  170,
  170,  170,    0,  170,  170,  170,  170,  170,  170,    0,
  170,  170,  170,  170,    0,  170,    0,  170,  170,  170,
  170,  170,  170,  170,  170,  170,  170,  170,  170,  170,
  170,  170,  170,  170,  170,    0,  170,  170,  170,  170,
    0,  170,  170,  170,  170,  170,    0,  170,  170,  170,
  170,  170,  170,  170,  170,  170,  170,  170,  170,  170,
    0,  170,  170,  170,  170,  170,  170,    0,  170,  170,
  170,  170,  170,  170,  170,  170,    0,  170,  170,    0,
    0,    0,  170,  170,  170,  170,  170,  170,    0,    0,
  170,  170,  170,  170,  170,  170,  170,  170,  170,    0,
    0,    0,    0,    0,  170,    0,  170,  170,  170,  170,
  170,  170,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  170,  170,    0,  170,  170,  170,  170,  170,  170,  170,
  170,  170,    0,  170,  170,  170,  170,  170,  170,  170,
  170,  170,  170,  170,  170,    0,  170,  170,  170,    0,
  170,    0,    0,    0,  170,  170,  170,  170,  170,  170,
  170,  170,  170,  170,  170,  170,  170,    0,  170,  170,
    0,    0,    0,    0,    0,  170,  170,  170,  170,  170,
  170,  170,  170,  170,  170,  170,  170,  170,  170,    0,
    0,  170,  170,    0,    0,    0,    0,  170,  170,  170,
  170,  170,  170,  170,  170,  170,   68,    0,   68,    0,
    0,    0,    0,    0,   68,    0,    0,   68,   68,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   68,   68,
    0,   68,    0,   68,    0,    0,   68,    0,    0,   68,
    0,    0,    0,    0,    0,    0,   68,    0,   68,   68,
    0,    0,    0,   68,    0,   68,    0,    0,   68,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   68,   68,
    0,    0,    0,   68,    0,   68,    0,   68,    0,    0,
    0,    0,    0,   68,    0,   68,    0,    0,    0,   68,
    0,    0,    0,    0,    0,    0,    0,   68,    0,    0,
   68,    0,   68,    0,    0,    0,   68,   68,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   68,
    0,    0,    0,   68,   68,   68,   68,   68,    0,   68,
    0,    0,    0,    0,    0,   68,    0,   68,   68,    0,
    0,   68,   68,    0,    0,    0,    0,    0,   68,    0,
    0,   68,   68,   68,   68,    0,   68,    0,   68,    0,
   68,   68,   68,   68,   68,    0,    0,    0,    0,   68,
    0,   68,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   68,    0,    0,    0,    0,   68,   68,    0,
    0,    0,    0,    0,   68,    0,    0,    0,   68,    0,
   68,   68,   68,   68,    0,   68,    0,    0,    0,    0,
    0,    0,    0,   68,   68,    0,    0,    0,    0,    0,
    0,    0,    0,    0,   68,   68,    0,   68,   68,   68,
    0,    0,    0,    0,   68,   68,    0,   68,   68,    0,
   68,    0,    0,   68,   68,    0,    0,    0,   68,   68,
    0,    0,    0,    0,   68,   68,   68,    0,   68,   68,
   68,    0,   68,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   68,   68,   68,   68,   68,   68,   68,   68,
   68,   68,   68,   68,   68,   68,   68,   68,   68,   68,
   68,   68,   68,    0,   68,   68,   68,   68,   68,   68,
    0,   68,   68,   68,   68,    0,   68,    0,   68,   68,
   68,   68,   68,   68,   68,   68,   68,   68,   68,   68,
   68,   68,   68,   68,   68,   68,    0,   68,   68,   68,
   68,    0,   68,   68,   68,   68,   68,    0,   68,   68,
   68,   68,   68,   68,   68,   68,   68,   68,   68,   68,
   68,    0,   68,   68,   68,   68,   68,   68,    0,   68,
   68,   68,   68,   68,   68,   68,   68,    0,   68,   68,
    0,    0,    0,   68,   68,   68,   68,   68,   68,    0,
    0,   68,   68,   68,   68,   68,   68,   68,   68,   68,
    0,    0,    0,    0,    0,   68,    0,   68,   68,   68,
   68,   68,   68,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,   68,   68,    0,   68,   68,   68,   68,   68,   68,
   68,   68,   68,    0,   68,   68,   68,   68,   68,   68,
   68,   68,   68,   68,   68,   68,    0,   68,   68,   68,
    0,   68,    0,    0,    0,   68,   68,   68,   68,   68,
   68,   68,   68,   68,   68,   68,   68,   68,    0,   68,
   68,    0,    0,    0,    0,    0,   68,   68,   68,   68,
   68,   68,   68,   68,   68,   68,   68,   68,   68,   68,
    0,    0,   68,   68,    0,    0,    0,    0,   68,   68,
   68,   68,   68,   68,   68,   68,   68,  597,    0,  597,
    0,    0,    0,    0,    0,  597,    0,    0,  597,  597,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  597,
  597,    0,  597,    0,  597,    0,    0,  597,    0,    0,
  597,    0,    0,    0,    0,    0,    0,  597,    0,  597,
  597,    0,    0,    0,  597,    0,  597,    0,    0,  597,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  597,
  597,    0,    0,    0,  597,    0,  597,    0,  597,    0,
    0,    0,    0,    0,  597,    0,  597,    0,    0,    0,
  597,    0,    0,    0,    0,    0,    0,    0,  597,    0,
    0,  597,    0,  597,    0,    0,    0,  597,  597,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  597,    0,    0,    0,  597,  597,  597,  597,  597,    0,
  597,    0,    0,    0,    0,    0,  597,    0,  597,  597,
    0,    0,  597,  597,    0,    0,    0,    0,    0,  597,
    0,    0,  597,  597,  597,  597,    0,  597,    0,  597,
    0,  597,  597,  597,  597,  597,    0,    0,    0,    0,
  597,    0,  597,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  597,    0,    0,    0,    0,  597,  597,
    0,    0,    0,    0,    0,  597,    0,    0,    0,  597,
    0,  597,  597,  597,  597,    0,  597,    0,    0,    0,
    0,    0,    0,    0,  597,  597,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  597,  597,    0,  597,  597,
  597,    0,    0,    0,    0,  597,  597,    0,  597,  597,
    0,  597,    0,    0,  597,  597,    0,    0,    0,  597,
  597,    0,    0,    0,    0,  597,  597,  597,    0,  597,
  597,  597,    0,  597,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  597,  597,  597,  597,  597,  597,  597,
  597,  597,  597,  597,  597,  597,  597,  597,  597,  597,
  597,  597,  597,  597,    0,  597,  597,  597,  597,  597,
  597,    0,  597,  597,  597,  597,    0,  597,    0,  597,
  597,  597,  597,  597,  597,  597,  597,  597,  597,  597,
  597,  597,  597,  597,  597,  597,  597,    0,  597,  597,
  597,  597,    0,  597,  597,  597,  597,  597,    0,  597,
  597,  597,  597,  597,  597,  597,  597,  597,  597,  597,
  597,  597,    0,  597,  597,  597,  597,  597,  597,    0,
  597,  597,  597,  597,  597,  597,  597,  597,    0,  597,
  597,    0,    0,    0,  597,  597,  597,  597,  597,  597,
    0,    0,  597,  597,  597,  597,  597,  597,  597,  597,
  597,    0,    0,    0,    0,    0,  597,    0,  597,  597,
  597,  597,  597,  597,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  597,  597,    0,  597,  597,  597,  597,  597,
  597,  597,  597,  597,    0,  597,  597,  597,  597,  597,
  597,  597,  597,  597,  597,  597,  597,    0,  597,  597,
  597,    0,  597,    0,    0,    0,  597,  597,  597,  597,
  597,  597,  597,  597,  597,  597,  597,  597,  597,    0,
  597,  597,    0,    0,    0,    0,    0,  597,  597,  597,
  597,  597,  597,  597,  597,  597,  597,  597,  597,  597,
  597,    0,    0,  597,  597,    0,    0,    0,    0,  597,
  597,  597,  597,  597,  597,  597,  597,  597,  154,    0,
  155,    0,    0,    0,    0,    0,  156,    0,    0,  157,
  158,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  159,  160,    0,  161,    0,  162,    0,    0,  163,    0,
    0,  164,    0,    0,    0,    0,    0,    0,  165,    0,
  166,  167,    0,    0,    0,  168,    0,  169,    0,    0,
  170,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  171,  172,    0,    0,    0,  173,    0,  174,    0,  175,
    0,    0,    0,    0,    0,  176,    0,  177,    0,    0,
    0,  178,    0,    0,    0,    0,    0,    0,    0,  179,
    0,    0,  180,    0,  181,    0,    0,    0,  182,  183,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  184,    0,    0,    0,  186,  187,  188,  189,  190,
    0,  191,    0,    0,    0,    0,    0,  192,    0,  193,
  194,    0,    0,  195,  196,    0,    0,    0,    0,    0,
  197,    0,    0,  198,  199,  200,  201,    0,  202,    0,
  203,    0,  204,  205,  206,  207,  208,    0,    0,    0,
    0,  209,    0,  210,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  211,    0,    0,    0,    0,  212,
  213,    0,    0,    0,    0,    0,  214,    0,    0,    0,
  215,    0,  216,  217,  218,  219,    0,  220,    0,    0,
    0,    0,    0,    0,    0,  221,  222,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  223,  224,    0,  225,
  226,  227,    0,    0,    0,    0,  228,  229,    0,  230,
  231,    0,  232,    0,    0,  233,  234,    0,    0,    0,
  235,  236,    0,    0,    0,    0,  237,  238,  239,    0,
  240,  241,  242,    0,  243,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  244,  245,  246,  247,  248,  249,
  250,  251,  252,  253,  254,  255,  256,  257,  258,  259,
  260,  261,  262,  263,  264,    0,  265,  266,  267,  268,
  269,  270,    0,  271,  272,  273,  274,    0,  275,    0,
  276,  277,  278,  279,  280,  281,  282,  283,  284,  285,
  286,  287,  288,  289,  290,  291,  292,  293,    0,  294,
  295,  296,  297,    0,  298,  299,  300,  301,  302,    0,
  303,  304,  305,  306,  307,  308,  309,  310,  311,  312,
  313,  314,  315,    0,  316,  317,  318,  319,  320,  321,
    0,  322,  323,  324,  325,  326,  327,  328,  329,    0,
  330,  331,    0,    0,    0,  332,  333,  334,  335,  336,
  337,    0,    0,  338,  339,  340,  341,  342,  343,  344,
  345,  346,    0,    0,    0,    0,    0,  347,    0,  348,
  349,  350,  351,  352,  353,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  354,  355,    0,  356,  357,  358,  359,
  360,  361,  362,  363,  364,    0,  365,  366,  367,  368,
  369,  370,  371,  372,  373,  374,  375,  376,    0,  377,
  378,  379,    0,  380,    0,    0,    0,  381,  382,  383,
  384,  385,  386,  387,  388,  389,  390,  391,  392,  393,
    0,  394,  395,    0,    0,    0,    0,    0,  396,  397,
  398,  399,  400,  401,  402,  403,  404,  405,  406,    0,
  408,  409,    0,    0,  410,  411,    0,    0,    0,    0,
  412,  413,  414,  415,  416,  417,  418,  419,  420,  154,
    0,  155,    0,    0,    0,    0,    0,  156,    0,    0,
  157,  158,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  159,  160,    0,  161,    0,  162,    0,    0,  163,
    0,    0,  164,    0,    0,    0,    0,    0,    0,  165,
    0,  166,  167,    0,    0,    0,  168,    0,  169,    0,
    0,  170,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  171,  172,    0,    0,    0,  173,    0,  174,    0,
  175,    0,    0,    0,    0,    0,  176,    0,  177,    0,
    0,    0,  178,    0,    0,    0,    0,    0,    0,    0,
  179,    0,    0,  180,    0,  181,    0,    0,    0,  182,
  183,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  184,    0,    0,    0,  186,  187,  188,  189,
  190,    0,  191,    0,    0,    0,    0,    0,  192,    0,
  193,  194,    0,    0,  195,  196,    0,    0,    0,    0,
    0,  197,    0,    0,  198,  199,  200,  201,    0,  202,
    0,  203,    0,  204,  205,  206,  207,  208,    0,    0,
    0,    0,  209,    0,  210,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  211,    0,    0,    0,    0,
  212,  213,    0,    0,    0,    0,    0,  214,    0,    0,
    0,  215,    0,  216,  217,  218,  219,    0,  220,    0,
    0,    0,    0,    0,    0,    0,  221,  222,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  223,  224,    0,
  225,  226,  227,    0,    0,    0,    0,  228,  229,    0,
  230,  231,    0,  232,    0,    0,  233,  234,    0,    0,
    0,  235,  236,    0,    0,    0,    0,  237,  238,  239,
    0,  240,  241,  242,    0,  243,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  245,  246,  247,  248,
  249,  250,  251,  252,  253,  254,  255,  256,  257,  258,
  259,  260,  261,  262,  263,  264,    0,  265,  266,  267,
  268,  269,  270,    0,  271,  272,  273,  274,    0,  275,
    0,  276,  277,  278,  279,  280,  281,  282,  283,  284,
  285,  286,  287,  288,  289,  290,  291,  292,  293,    0,
  294,  295,  296,  297,    0,  298,  299,  300,  301,  302,
    0,  303,  304,  305,  306,  307,  308,  309,  310,  311,
  312,  313,  314,  315,    0,  316,  317,  318,  319,  320,
  321,    0,  322,  323,  324,  325,  326,  327,  328,  329,
    0,  330,  331,    0,    0,    0,  332,  333,  334,  335,
  336,  337,    0,    0,  338,  339,  340,  341,  342,  343,
  344,  345,  346,    0,    0,    0,    0,    0,  347,    0,
  348,  349,  350,  351,  352,  353,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  354,  355,    0,  356,  357,  358,
  359,  360,  361,  362,  363,  364,    0,  365,  366,  367,
  368,  369,  370,  371,  372,  373,  374,  375,  376,    0,
  377,  378,  379,    0,  380,    0,    0,    0,  381,  382,
  383,  384,  385,  386,  387,  388,  389,  390,  391,  392,
  393,    0,  394,  395,    0,    0,    0,    0,    0,  396,
  397,  398,  399,  400,  401,  402,  403,  404,  405,  406,
  407,  408,  409,    0,    0,  410,  411,    0,    0,    0,
    0,  412,  413,  414,  415,  416,  417,  418,  419,  420,
  154,    0,  155,    0,    0,    0,    0,    0,  156,    0,
    0,  157,  158,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  159,  160,    0,  161,    0,  162,    0,    0,
  163,    0,    0,  164,    0,    0,    0,    0,    0,    0,
  165,    0,  166,  167,    0,    0,    0,  168,    0,  169,
    0,    0,  170,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  171,  172,    0,    0,    0,  173,    0,  174,
    0,  175,    0,    0,    0,    0,    0,  176,    0,  177,
    0,    0,    0,  178,    0,    0,    0,    0,    0,    0,
    0,  179,    0,    0,  180,    0,  181,    0,    0,    0,
  182,  183,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  184,    0,    0,    0,  186,  187,  188,
  189,  190,    0,  191,    0,    0,    0,    0,    0,  192,
    0,  193,  194,    0,    0,  195,  196,    0,    0,    0,
    0,    0,  197,    0,    0,  198,  199,  200,  201,    0,
  202,    0,  203,    0,  204,  205,  206,  207,  208,    0,
    0,    0,    0,  209,    0,  210,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  211,    0,    0,    0,
    0,  212,  213,    0,    0,    0,    0,    0,  214,    0,
    0,    0,  215,    0,  216,  217,  218,  219,    0,  220,
    0,    0,    0,    0,    0,    0,    0,  221,  222,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  223,  224,
    0,  225,  226,  227,    0,    0,    0,    0,  228,  229,
    0,  230,  231,    0,  232,    0,    0,  233,  234,    0,
    0,    0,  235,  236,    0,    0,    0,    0,  237,  238,
  239,    0,  240,  241,  242,    0,  243,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  244,  245,  246,  247,
  248,  249,  250,  251,  252,  253,  254,  255,  256,  257,
  258,  259,  260,  261,  262,  263,  264,    0,  265,  266,
  267,  268,  269,  270,    0,  271,  272,  273,  274,    0,
  275,    0,  276,  277,  278,  279,  280,  281,  282,  283,
  284,  285,  286,  287,  288,  289,  290,  291,  292,  293,
    0,  294,  295,  296,  297,    0,  298,  299,  300,  301,
  302,    0,  303,  304,  305,  306,  307,  308,  309,  310,
    0,  312,  313,  314,  315,    0,  316,  317,  318,  319,
  320,  321,    0,  322,  323,  324,  325,  326,  327,  328,
  329,    0,  330,  331,    0,    0,    0,  332,  333,  334,
  335,  336,  337,    0,    0,  338,  339,  340,  341,  342,
  343,  344,  345,  346,    0,    0,    0,    0,    0,  347,
    0,  348,  349,  350,  351,  352,  353,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  354,  355,    0,  356,  357,
  358,  359,  360,  361,  362,  363,  364,    0,  365,  366,
  367,  368,  369,  370,  371,  372,  373,  374,  375,  376,
    0,  377,  378,  379,    0,  380,    0,    0,    0,  381,
  382,  383,  384,  385,  386,  387,  388,  389,  390,  391,
  392,  393,    0,  394,  395,    0,    0,    0,    0,    0,
  396,  397,  398,  399,  400,  401,  402,  403,  404,  405,
  406,  407,  408,  409,    0,    0,  410,  411,    0,    0,
    0,    0,  412,  413,  414,  415,  416,  417,  418,  419,
  420,  154,    0,  155,    0,    0,    0,    0,    0,  156,
    0,    0,  157,  158,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  159,  160,    0,  161,    0,    0,    0,
    0,  163,    0,    0,  164,    0,    0,    0,    0,    0,
    0,  165,    0,  166,  167,    0,    0,    0,  168,    0,
  169,    0,    0,  170,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  171,  172,    0,    0,    0,  173,    0,
  174,    0,  175,    0,    0,    0,    0,    0,  176,    0,
  177,    0,    0,    0,  178,    0,    0,    0,    0,    0,
    0,    0,  179,    0,    0,  180,    0,  181,    0,    0,
    0,  182,  183,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  184,    0,    0,    0,  186,  187,
  188,  189,  190,    0,  191,    0,    0,    0,    0,    0,
  192,    0,  193,  194,    0,    0,  195,  196,    0,    0,
    0,    0,    0,  197,    0,    0,  198,  199,  200,  201,
    0,  202,    0,  203,    0,  204,    0,  206,  207,  208,
    0,    0,    0,    0,  209,    0,  210,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  211,    0,    0,
    0,    0,  212,  213,    0,    0,    0,    0,    0,  214,
    0,    0,    0,  215,    0,  216,  217,  218,  219,    0,
  220,    0,    0,    0,    0,    0,    0,    0,  221,  222,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  223,
  224,    0,  225,  226,  227,    0,    0,    0,    0,  228,
  229,    0,  230,  231,    0,  232,    0,    0,  233,  234,
    0,    0,    0,  235,  236,    0,    0,    0,    0,  237,
  238,  239,    0,  240,  241,  242,    0,  243,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  244,  245,  246,
  247,  248,  249,  250,  251,  252,  253,  254,  255,  256,
  257,  258,  259,  260,  261,  262,  263,  264,    0,  265,
  266,  267,  268,  269,  270,    0,  271,  272,  273,  274,
    0,  275,    0,  276,  277,  278,  279,  280,  281,  282,
  283,  284,  285,  286,  287,  288,  289,  290,  291,  292,
  293,    0,  294,  295,  296,  297,    0,  298,  299,  300,
  301,  302,    0,  303,  304,  305,  306,  307,  308,  309,
  310,  311,  312,  313,  314,  315,    0,  316,  317,  318,
  319,  320,  321,    0,  322,  323,  324,  325,  326,  327,
  328,  329,    0,  330,  331,    0,    0,    0,  332,  333,
  334,  335,  336,  337,    0,    0,  338,  339,  340,  341,
  342,  343,  344,  345,  346,    0,    0,    0,    0,    0,
  347,    0,  348,  349,  350,  351,  352,  353,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  354,  355,    0,  356,
  357,  358,  359,  360,  361,  362,  363,  364,    0,  365,
  366,  367,  368,  369,  370,  371,  372,  373,  374,  375,
  376,    0,  377,  378,  379,    0,  380,    0,    0,    0,
  381,  382,  383,  384,  385,  386,  387,  388,  389,  390,
  391,  392,  393,    0,  394,  395,    0,    0,    0,    0,
    0,  396,  397,  398,  399,  400,  401,  402,  403,  404,
  405,  406,  407,  408,  409,    0,    0,  410,  411,    0,
    0,    0,    0,  412,  413,  414,  415,  416,  417,  418,
  419,  420,  154,    0,  155,    0,    0,    0,    0,    0,
  156,    0,    0,  157,  158,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  159,  160,    0,  161,    0,  162,
    0,    0,  163,    0,    0,  164,    0,    0,    0,    0,
    0,    0,  165,    0,  166,  167,    0,    0,    0,  168,
    0,  169,    0,    0,  170,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  171,  172,    0,    0,    0,  173,
    0,  174,    0,  175,    0,    0,    0,    0,    0,  176,
    0,  177,    0,    0,    0,  178,    0,    0,    0,    0,
    0,    0,    0,  179,    0,    0,  180,    0,  181,    0,
    0,    0,  182,  183,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  184,    0,    0,    0,  186,
  187,  188,  189,  190,    0,  191,    0,    0,    0,    0,
    0,  192,    0,  193,  194,    0,    0,  195,  196,    0,
    0,    0,    0,    0,  197,    0,    0,  198,  199,  200,
  201,    0,  202,    0,  203,    0,  204,  205,  206,  207,
  208,    0,    0,    0,    0,  209,    0,  210,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  211,    0,
    0,    0,    0,  212,  213,    0,    0,    0,    0,    0,
  214,    0,    0,    0,  215,    0,  216,  217,  218,  219,
    0,  220,    0,    0,    0,    0,    0,    0,    0,  221,
  222,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  223,  224,    0,  225,  226,  227,    0,    0,    0,    0,
  228,  229,    0,  230,  231,    0,  232,    0,    0,  233,
  234,    0,    0,    0,  235,  236,    0,    0,    0,    0,
  237,  238,  239,    0,  240,  241,  242,    0,  243,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  244,  245,
  246,  247,  248,  249,  250,  251,  252,  253,  254,  255,
  256,  257,  258,  259,  260,  261,  262,  263,  264,    0,
  265,  266,  267,  268,  269,  270,    0,  271,  272,  273,
  274,    0,  275,    0,  276,  277,  278,  279,  280,  281,
  282,  283,  284,  285,  286,  287,  288,  289,  290,  291,
  292,  293,    0,  294,  295,  296,  297,    0,  298,  299,
  300,  301,  302,    0,  303,  304,  305,  306,  307,  308,
  309,  310,  311,  312,  313,  314,  315,    0,  316,  317,
  318,  319,  320,  321,    0,  322,  323,  324,  325,  326,
  327,  328,  329,    0,  330,    0,    0,    0,    0,  332,
  333,  334,  335,  336,  337,    0,    0,  338,  339,  340,
  341,  342,  343,  344,  345,  346,    0,    0,    0,    0,
    0,  347,    0,  348,  349,  350,  351,  352,  353,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  354,  355,    0,
  356,  357,  358,  359,  360,  361,  362,  363,  364,    0,
  365,  366,  367,  368,    0,  370,  371,  372,  373,  374,
  375,  376,    0,  377,  378,  379,    0,  380,    0,    0,
    0,  381,  382,  383,  384,  385,  386,  387,  388,  389,
  390,  391,  392,  393,    0,  394,    0,    0,    0,    0,
    0,    0,  396,  397,  398,  399,  400,  401,  402,  403,
  404,  405,  406,  407,  408,  409,    0,    0,  410,  411,
    0,    0,    0,    0,  412,  413,  414,  415,  416,  417,
  418,  419,  420,  154,    0,  155,    0,    0,    0,    0,
    0,  156,    0,    0,  157,  158,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  159,  160,    0,  161,    0,
  162,    0,    0,  163,    0,    0,  164,    0,    0,    0,
    0,    0,    0,  165,    0,  166,  167,    0,    0,    0,
  168,    0,  169,    0,    0,  170,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  171,  172,    0,    0,    0,
  173,    0,  174,    0,  175,    0,    0,    0,    0,    0,
  176,    0,  177,    0,    0,    0,  178,    0,    0,    0,
    0,    0,    0,    0,  179,    0,    0,  180,    0,  181,
    0,    0,    0,  182,  183,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  184,    0,    0,    0,
  186,  187,  188,  189,  190,    0,  191,    0,    0,    0,
    0,    0,  192,    0,  193,  194,    0,    0,  195,  196,
    0,    0,    0,    0,    0,  197,    0,    0,  198,  199,
  200,  201,    0,  202,    0,  203,    0,  204,  205,  206,
  207,  208,    0,    0,    0,    0,  209,    0,  210,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  211,
    0,    0,    0,    0,  212,  213,    0,    0,    0,    0,
    0,  214,    0,    0,    0,  215,    0,  216,  217,  218,
  219,    0,  220,    0,    0,    0,    0,    0,    0,    0,
  221,  222,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  223,  224,    0,  225,    0,  227,    0,    0,    0,
    0,  228,  229,    0,  230,    0,    0,  232,    0,    0,
  233,  234,    0,    0,    0,  235,  236,    0,    0,    0,
    0,  237,  238,  239,    0,    0,  241,  242,    0,  243,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  244,
  245,  246,  247,  248,  249,  250,  251,  252,  253,  254,
  255,  256,  257,  258,  259,  260,  261,  262,  263,  264,
    0,  265,  266,  267,  268,  269,  270,    0,  271,  272,
  273,  274,    0,  275,    0,  276,  277,  278,  279,  280,
  281,  282,  283,  284,  285,  286,  287,  288,  289,  290,
  291,  292,  293,    0,  294,  295,  296,  297,    0,  298,
  299,  300,  301,  302,    0,  303,  304,  305,  306,  307,
  308,  309,  310,  311,  312,  313,  314,  315,    0,  316,
  317,  318,  319,  320,  321,    0,  322,  323,  324,  325,
  326,  327,  328,  329,    0,  330,  331,    0,    0,    0,
    0,    0,    0,  335,  336,  337,    0,    0,  338,  339,
  340,  341,  342,  343,  344,  345,  346,    0,    0,    0,
    0,    0,  347,    0,  348,  349,  350,  351,  352,  353,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  354,  355,
    0,  356,  357,  358,  359,  360,  361,  362,  363,  364,
    0,  365,  366,  367,  368,  369,  370,  371,  372,  373,
  374,  375,  376,    0,  377,  378,  379,    0,  380,    0,
    0,    0,  381,  382,  383,  384,  385,  386,  387,  388,
  389,  390,  391,  392,  393,    0,  394,  395,    0,    0,
    0,    0,    0,  396,  397,  398,  399,  400,  401,  402,
  403,  404,  405,  406,  407,  408,  409,    0,    0,  410,
  411,  168,    0,    0,  168,  412,  413,  414,  415,  416,
  417,  418,  419,  420,    0,    0,  168,    0,    0,    0,
  168,    0,  168,    0,    0,    0,  180,    0,    0,  180,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  180,    0,    0,    0,  180,    0,  180,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  168,    0,    0,    0,    0,    0,  168,  168,  168,    0,
  168,  168,  168,    0,  168,    0,    0,    0,    0,    0,
    0,    0,    0, 2907,    0,  180, 1124,    0,  168,    0,
  168,  180,  180,  180,    0,  180,  180,  180, 2908,  180,
    0,    0, 1125,    0, 1126,    0,    0,    0,    0,    0,
    0,    0,    0,  180,    0,  180,    0,    0, 1123,  168,
    0, 1124,    0,    0,  167,    0,    0,    0,    0,    0,
    0,    0,    0,  180,    0,  168,    0, 1125,    0, 1126,
    0,    0, 1127,    0,  180,    0,    0,    0, 1128, 1129,
 1130,    0, 1131, 1132, 1133,    0, 1134,  168,    0,    0,
  180,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1135,    0, 1136,    0,    0,    0,    0, 1127,    0,    0,
    0,    0,  180, 1128, 1129, 1130,    0, 1131, 1132, 1133,
    0, 1134,    0,    0,    0,  168,  168, 1123,    0,    0,
 1124, 1137,    0,    0,    0, 1135,    0, 1136,    0,    0,
    0,    0,  168,    0,    0,    0, 1125, 1138, 1126,    0,
  180,  180,    0,    0,    0,    0,    0,    0,    0,    0,
  277,    0,    0,  277,    0,    0, 1137,  180,    0, 1139,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  277,
    0,  277, 1138,    0,    0,    0, 1127,    0,    0,    0,
    0,    0, 1128, 1129, 1130,    0, 1131, 1132, 1133,    0,
 1134,    0,    0,    0, 1139,    0,    0, 1260, 1141,    0,
    0,    0,    0,    0, 1135,    0, 1136,    0,    0,  277,
    0,    0,    0,    0, 1142,  277,  277,  277,    0,  277,
  277,  277,    0,  277,    0,    0,    0,    0,    0,    0,
    0,    0, 1140, 1141,    0, 1137,    0,  277,    0,  277,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1142,
    0, 1138,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  277,    0,
    0,    0,    0, 1139,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  277,    0,    0,    0,    0,    0,
    0,  168,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  277,    0,    0,    0,
    0, 1260, 1141,    0,    0,    0,  180,    0,    0,    0,
    0,    0,    0,  168,    0,    0,    0,    0, 1142,    0,
    0,    0,    0,  168,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  277,  277,  168,    0,  180,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  180,    0,
    0,  277,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  180,    0, 1143,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  168,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1144,    0,    0, 1143,    0,
    0,    0,    0,    0,    0, 1145,    0,    0,    0,    0,
  180,    0,    0,    0,    0,    0,    0,    0, 1146,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1144,    0,    0,    0,    0,    0,    0,    0,    0,    0,
 1145,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1146,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1147,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1143,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1147,    0,    0,    0,    0,    0,    0, 1144,
  277,    0,    0,    0,    0,    0,    0,    0,    0, 1145,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1146,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  277,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  277,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  277,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, 1147,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  277,
};
static int yycheck[] = {                                      14,
   15,   76,   17,  131,   72,  576,    0,  124,   80,  120,
  843,   82,  840,  830, 1506,  123, 1345,  690,  687,  829,
   15,   14, 1351,   79, 1026, 1026,   91, 1445,  136,  788,
  601,  746,  747,  104, 1254, 1214,   91, 1560, 1195,  804,
  777,  804,  576, 1214, 1643, 1026,  765,  122,  692,  117,
 2008, 1243, 2257, 1918, 2259,  127,   71,   72,  129,   74,
   75,   76,   77,   78,   79,   80,   81,   82,   83,  806,
  126,   86, 1413,  746,  747, 1214, 1668,   92,   93,   94,
   95, 1643,   97,  802,   99,  100, 1643,  102,  103,  104,
  105,  106, 1643, 2037,  109,  629, 1948, 1643,  113, 2319,
  115,  116,  117, 2000,  119,  120,  121,  122,  123, 2020,
  125,  126,  127,  128,  129,  130,  131, 1600, 1601,  134,
 1241,  136,  115,   14,  139,  140, 2403, 2713,  143, 2140,
 2020,  146,  125,   75,   86, 2393, 2394, 2395,   92, 1801,
 1610,   83, 1024, 1025, 1026, 1318,  781,  140, 1024, 1025,
 1468, 1621, 2493, 2494, 1646, 1647, 2643,  109, 1542, 2792,
  804, 1592, 1593, 1547, 1556, 2822, 2645, 2504, 2441, 2353,
 1581, 1670, 2554, 2446, 1295,  692,  834, 2646, 2010,  121,
 1533, 1296,  134, 2441,  136,  739,  740,   78,  130, 2084,
 2083,  826, 1662, 2099, 1214, 1810, 3153,  109,   41,  586,
   41,  143,   41,    0,   94,   41,    0,    0,   99,   41,
    0,  103,  445,   41,    0,   41,   97,    0, 1220,   42,
 1631, 2119,    0,   44,  115, 1451, 1579, 2860,  108,   41,
    0,    0,  275,  641,    0,    0,   40,   59,    0,  316,
 1617,    0, 1421,   59, 2094,  783,   59, 3547,  139,  140,
 1252,  260,   59,  133, 2263, 1394,   41, 2101,  260, 2656,
 2903, 2101,   59,  671,    0,   59,   59, 1611, 1532,   59,
 2100,   59,    0,   59, 1413,  310,   59,    0, 2675,   41,
    0,   59,   44,    0,    0,    0, 1145,  401, 2775,   59,
   59,   41,   44,   59,   59,    0,    0,   59,    0, 2786,
   59,  405,    0, 2100,    0,   44,    0,   44,   44,   41,
 1534,   45, 1314, 1314, 2783,    0,    0,    0,  301,    0,
   44,   42, 1984,   59,    0,  273, 1328,  310,    0,    0,
    0,   59,   59, 1335,  296,   41,   59,  280,  288,   59,
   41,  364,   59,   59,   59,  504,   41,   59,  347, 2976,
    0, 1530,   44, 1334,   59,   59,    0,   59, 1611, 1530,
 3570,   59,   40,   59,  466,   59,    0, 2854,  268, 2706,
 2274,  500,  322,  387,   59,   59,   59,   41,   59,  369,
  511,   40,  387,   59,  259,  257,  316,   59,   59,   59,
  334,   40,  504,  275,  269,  266, 1725,   41, 1400, 1400,
   44,   61, 2066,    0,   63,   45,  277,   41, 2366,   59,
   44,  426,  279,  363, 1224,   59,  431,  432,  433,  434,
  435,  436,  437,  438,  439,   59,  441,   40,  438,   45,
  445,  426, 1314, 2298, 1415, 2300, 1195, 2906, 2102, 1249,
  263,  456,  264,  264,   41,  447,  448,  558, 1117,  439,
   63,  264,   45,   44,  326,  337,   44,  387, 1940,   93,
 1801,   44,   59,  407, 1643, 1446, 1468,  368,  314, 1450,
  264,  264, 1643,  259,  264, 3132,  264, 1983,  264,  478,
  494,   40, 3692,  269,   59,  436,  264,   41,  310,  441,
   44,  556, 2403,  368,  310,  654, 1169,  310,  264, 1214,
  505, 2500,  264,  310,  452,  264,  295,  301,  301, 1901,
 1530,  301, 1340, 2403, 1342,  301,  310,  310, 1400,  648,
  310,  652,  310,  301,  310,  264,  295, 3283,  264,  441,
 1267,  264,  310,  433, 1536, 1417,  264,  648,    0,  260,
 1259, 1417,  432,  558,  435,  656,  438,  264,  264,  264,
  312,  616,  264,  434,  264,  422, 1438, 1439, 1440, 1441,
 1442,  323, 1438, 1439, 1440, 1441, 1442, 1896,  264, 2580,
  332,  340,  299,  301,  368, 1959, 1960,  298,  368,  264,
  264,   59,  310,    0,  301,  301,  301,  372,  382,  382,
  368,  301,  382,  310,  310,  310,  382,   59,  290,  437,
  310,  703,  372,  304,  382,  301, 2221,  395,  631,  721,
  372,  686,  555,  575,  310,    0,  301,  301,  295,  381,
 1359, 1360,  372,  427,  689,  310,  310,   44,  643, 2520,
 2521, 3028, 3029,  648,    0,  295, 1815,  646, 2069,  753,
  368,  656,   59, 1984,  368,  295, 1505, 1965,  752, 3276,
    0,  368,  368,  357,  382,    0,   41,  672,  673,  731,
 2844,  423, 1801, 2801,    0,  382,  382,  264, 2518,  340,
  340,  686,  368,  750,   59,  437, 2685,  372,  693, 1394,
 2024,  696,  419,  368,  368,  700,  382,  702,  703,  264,
  340,  643,  504,   59,  446,  738,   41,  382,  382,   44,
  715,  437, 1966,  738, 2548,  700, 1244,  702, 2548,   59,
 2983,  394,  446,    0,   59,  312,  731, 2547,  557,  504,
    0,  673,  400,   59,  739,  740,  741,  742, 1538,  557,
 2107,  500,  434, 2994,  504,  332,  434,  471,  372,  807,
  812,  503,  504, 1969, 1968, 1578,  511,  419,   93,  427,
 2547,  400,  754,  523,  504,  738, 3399,  822,  434,  437,
  394,  523,  837,  715, 2668,   41, 4066,  822,   44,    0,
 4070, 2024,   59,  788, 1533,  372,  597,  600,  427,   59,
    0,  504,  797,   59,  381,   61,  264,  446,  437,  364,
  740,  511,  807,  808,  809,  810,  811,  812,  813,  814,
  523, 1629,  817, 3290, 1983,  588,  446,    0, 1810,  504,
   41, 2303, 1983,   44, 1487,  830,  831,  511,  523,  834,
 1579,  523,  837, 1492, 3097,  840,  423,  650,   59, 1810,
  446,  597,  310,  446,  849, 2341, 2318,  738,  597,   59,
  437,  395,  523,  487, 1983, 1984,  437,  523, 1676,  437,
  500,   44,  435,  446, 3236, 3237, 2855, 1667,  597,  648,
  811,  597, 2203,  689,  597,  817,   59,  809,  588,  652,
  504,  430,  814, 1632, 2266, 1283, 1520,  689,  340,  264,
 3636, 1114,  437, 1620,  325, 1887,  364,  652, 1673,  686,
  687,  734, 1279,  655, 2223, 3292, 3293, 3294, 3295, 3296,
 3297, 3298,    0, 2801,  296,  817,  503,  504,  258,  721,
  748,  715, 1649,  756, 1651,  756,  738,  756,  808, 1900,
  756,  813,  738, 1642,  756,  738,  523,  312,  756,  810,
 2361,  738,  652, 3576, 3577,  301,  816, 1819,  323,  689,
  831,  738,   59, 1819,  738,  738,  678,  332,  738,  681,
  738,  301,  738,  105, 3911,  632, 2571, 2275,  652, 2865,
  738,   59,   41, 1983, 3148,   44,  426, 2320, 2863, 2862,
    0,  721,  678, 3236,  680,  681,  682, 3115, 2093,  437,
   59, 2872,   61, 2815,  401,  747,   41,  372,  264, 1543,
 3128,    0, 1546, 1101,  689, 2348,  381, 1655, 1106,  260,
   59,  277,  316, 1520,   44,  258, 1745,  273,  261, 2501,
  738, 2503, 1027, 2512,  678,  295,  680,  681,  682,  295,
   44,  738,  738,  738, 3493, 2839,  721,  372,  738,   59,
    0,  312, 1027,  264,  310,  401,  372,  715,  423,  273,
  447,  448,  738,   44,  316,  381,  307,   44,  301,  394,
   59,  401,  437,  738,  738,  689,  631,  278,  655, 3716,
  340,    0,    0,    0, 2203, 3447,  715,  340,    0,  419,
    0, 1856,  330,  387,   44, 3364,  363, 3556,  363,   91,
   59,  312,   61,  295,  306,  284, 1101,  721,  364,   59,
 1918, 1106,  672,    0,  511,  317, 1630,  266, 3375, 1114,
 2511,  332,   41,   41,   41,   44,  456, 2769, 3385,   41,
 2772, 1928,   44,  426,   44,  387, 1949,    0,  503,  504,
   59,   59,   59, 1188,  264,   41,  334,   59,   44,   59,
    0, 3528, 3529, 3530, 3531, 3532, 3533, 3534,  523,  492,
  580,  454,  264,  363,  332,  295, 1956,  264, 2321,  264,
  747, 3109,   59,  631, 1106,  436, 1171, 3832,    0,  504,
  447,  448,    0, 1228, 1179, 2146, 1231,  425,  504, 1234,
    0,    0, 1237, 1228,  447,  448,   59,  398,  271, 1234,
 1195,  389, 1237,  575, 3447,  264,  301,  523,  410,   59,
  340,  284,  284,  748,  749,  310,  364,  484,  277, 3686,
  282,  262,   44,    0, 1269,  264,  437,  264,  401,  332,
  651, 1206,   59,  412,   44,   44,  295,   59, 1233, 2221,
  500,   59, 1217, 1288, 1289, 3882, 3708,  447,  448,   59,
   59,  310,  325, 1288, 1289, 3496, 3497, 3498, 3499, 3500,
 3501, 3502,    0,  530,  301, 3429, 3257, 2032,  417,  304,
 1923, 2232,   41,  310,  264,   44,  371,  488,    0,  352,
  738, 2020,   59,  275,  484, 3554,  532,  382, 1983,  849,
  655,  333,  503,  504,  314,  299, 2086,    0,  395,  739,
 1171,  433, 2674, 2116,  571, 3562, 2096,  439, 1179, 3626,
  748,  301,  523,  290,  264,  393,  703, 3690,  532,  263,
  310,   59,   44, 2795,  744,  619, 2898, 1322, 3566, 1437,
  530, 2781, 2782,  314, 1329,  368,  295,   59,  511,  412,
  412,  419, 2443, 2444, 2206,  382,  264,  264, 3142,  363,
 2206, 3145,  264,  298,    0, 2719,   59, 3824,  623, 3826,
 2222, 1452,  306,  555,  689, 4002, 2222,  619, 2085, 2068,
  500,  571,  262,  317, 2119,  631, 2119,  418, 2479, 2829,
 1468,  371,  747,  260,  394,  447,  448,  588, 2012,  276,
  277, 4046,  382, 3646,  312,  312,  721,   44,  302,  344,
  312,  264, 1397,  523,  393,  646, 1503, 1329,  504,  306,
  322,  323,  298,   59,  332,  332,  564,   59, 1413,  364,
  332,  523,  319,  335, 2722, 1522, 1523, 1524, 1525, 1526,
 3803,  307, 2843, 2742, 3076, 2050, 3693,  264, 1413,  641,
  258, 2750, 1437, 4056,  655,  487,   93, 3704, 2769,  368,
 1445, 2772,  270,  686,  687,    0, 1451, 1452,  344,  401,
  372,  314,    0,    0,  420, 4031,  410,    0,    0,  381,
  484, 1466,  299, 1468,  312, 3466, 3797,  364,  689,  400,
  257, 2634,  738,  301, 3375,  303,  280,  437,  458,  459,
 2298,  401, 2300, 4059, 3385, 2119,   41, 1542, 3960,   44,
  302,  303, 1547,   41,  273, 3375,  708,  301,   41,   41,
  721,  423,   44,  363,   59, 3385,  530, 1451,  401,  437,
  437,   59,   59,  435,  312,  437,   59,   59,  418,  602,
  434, 3363,  306,  257, 2984,  304, 1468,  426, 1533, 1534,
  417, 3914,  264, 4005,  321,  319, 2647, 3804, 1543,  326,
  276, 1546,  301, 1598,  295, 3432, 3813,  571, 1533,  655,
  264,  437,  372, 1598, 4026,   44,  419,  321,  487,  511,
 1565,  381,  631,  276,  277,  344,  314, 3040,  301,  401,
    0, 2320,  296,  401, 1579,  503,  503,  504,  544, 2571,
 2571,  503,  504,  301,  332,  551, 4058,  447,  448,  268,
  296,  511,  326,  380, 1579,  523,  523,  600,  264, 2348,
 2571,  523,  400,  510,   93,    0,    0,    0,  259,  396,
  296,   41,  296,  593,  434,  435,  395,  727,  269,    0,
  276,  277,  434, 3557,  484,  363,  296, 1632,  364,   59,
 3878, 3632,  451,  738,  453,    0,   41, 2296,  436,   44,
 2769,  316,  401, 2772,  330, 3227,   41,   41,   41, 2398,
 1655,  364,  456,  316, 2403,  335,   61,  261, 1663,    0,
   41, 3562,  393,  401,   59,   59,   59, 1672,  401,  738,
  530, 1676, 1677,  452,  353,  355,   41,    0,   59,  511,
 1663,  395, 3562,  401,  504, 3880,  450,  641,  643,  644,
  645,  738,  454,    0,   59, 2358, 3015,  302,  303, 2571,
  487,  425,  368,  523,  466,  437,  276,  295,  364,  264,
  257,  571,  387,  451,  380,  389,  264,  368,   59,  425,
   44,  264,  264, 2523,  387, 1730,  510,  265,  655,  409,
  446,  303,  494,  655,   41, 3054,   59,   44,  738,  425,
  312,  425,  479,  313,  600, 3076,    0,  643,  644,  645,
  316,  555,   59,   59, 2626,  425, 2903,  312,  588,  297,
 2626, 3885,  689,  258,  312,  439,  429,  258, 3087,   93,
  312,  437,  509,  315,  321,  270,  364,  332, 2505,  326,
  322,  323, 2491, 2510,  332,  327,  614,  615,  454,  332,
  332, 1672, 3693,  335,  721, 1800, 1801,  620, 1730, 3388,
 3389, 4011, 3926, 3704, 1902,   59,  301,  349,  303,  596,
  301,  598,  599, 3693,  348,  385, 1801,  316,  360, 3963,
  588,  387,  652, 1884, 3704,  747,  368, 1934,  400,  434,
  372,  344, 4027,  380,  264,  316, 3388, 3389, 1843,  381,
 4050, 3388, 3389, 3698,  461,  462,  463, 3388, 3389,  396,
    0, 2514, 3388, 3389,  424,  397, 1800,  316,  686,  687,
  372,  689,  649,  276,  436,  273,  689, 1965,  696,  264,
  264,  264,   59, 1991, 4034, 2693,  418,  557,  412, 1884,
 4024,  423,  437,  264,  652,    0, 3068, 3069,  387,  437,
  295,  653,  434,  435,  437,  437,  296, 1902,  721,  264,
  313, 4061,  332, 3804, 1959, 1960,  401,  588, 2731,   59,
  401,  423, 3813,  675,  260,  620,  257, 2018,  312,  312,
   42, 2019,  684, 1928, 3804,   47,   41,  389,  419, 2736,
  330,  312,  280, 3813,  447,  448,  344,  332,  332,  332,
  487,  322,  323,    0,   59,  487,    0, 3076,  503,  504,
  567,  332,  298, 2392, 3362,  503,  504, 2396,  264,  329,
 1965,  503,  504, 1968, 1969,  456,  508,  332,  523,  276,
  277,  652,  385,  280,  736,  523,  283,  439,  372, 1984,
  321,  523, 1967, 2544,  689,  326, 1991,  381,  295, 3950,
   59,  372,  261,  755,  263,  303,  588, 2002,  301, 1984,
  381, 2972,   59,  749,  312,   59, 2011,  437,   59,  283,
  528,  424, 2017, 2018, 2019, 2020,  721,  286, 3966,  393,
 2544,  295, 3983, 1965,    0, 1969,  332,  296, 2033,  423,
 2739,  295,  301, 2064,  382, 2020, 2041,  260,   44,  380,
 2045,  295,  423,  437,  437,  419, 2801,    0, 2801,  596,
  363,  598,  599, 4014,  435,  396,  437,  364, 2063, 2064,
  652,  330,  368,  479,   40,   41,  257, 2011,   44,  315,
 2101,  419,  437,  489,  380,  298,  389,  264,  385,  382,
  344,  327,    0,   59,  391,   59,  340,   93,   41, 2033,
  364,   44,  400,  509,  348, 2100, 2101, 2041,  401,    0,
  655, 2045,  649,  349,  265,    0,   59,  655,  456,  503,
  504,    0,  260,  655, 2119,    0,  419,  424,  388,  614,
  615,  312,  503,  504,  378,    0,  380,    0,  436,  523,
  523,  437,  454,  403,  689,  326,  297,  296,  367, 2240,
  260,   59,  523, 2241,  266,  332,  487,  401,  454,  264,
  298,  397,    0,    0, 2903,  277,  425,   59,   59,  281,
  685,  478,    0,  511,   59, 2063,  721, 2801,  329,   44,
   59,  330,  426,  698,   59, 2119, 2274, 2275,  298,  446,
 3327,  368, 2816, 2846,   59, 2243,   59,  310,  311,  276,
  507,  686,  687,  380,  689,  264, 3709,  312, 2203, 2204,
  454,  696, 2100, 3413,  471,  747,   44,  555,  624,  625,
  626,   59,   59,  264,  268,  260,    0,  332, 2203, 3388,
 3389,   59,  591, 2228,    0, 2230, 3049, 3388, 3389,  695,
 2235,  600,  391,  260, 2239, 2240, 2241, 2242, 2243, 2244,
 2245,  400,    0,    0,   42,   43,  500,   45,  555,   47,
  437,   59,  276,  298,  261,  596, 2239,  598,  599, 2264,
 2204,  655,    0,  332,  370,   41,  425,  454,   44, 2274,
 2275,  298, 2277, 3681,  655,   59,  260,  364,  330,  286,
  334,  332,    0,   59,   41,    0,   44,   44,  264,    0,
  264, 2235, 2277,    0,  301, 2300, 2351, 2352,  385,  368,
 2242,   59,   59,   41,  391,    0, 2351, 2352,  649,  115,
    0,  380, 2244, 2245,  298, 2320,    0,  368,   59, 2324,
  401,   59,  437,  276,  277, 2383,   41,  280,  363,  380,
  283,  264, 2274, 2275,  140, 2320,  312,  424,  392,  315,
  364,   59,  295, 2348,   59,    0,  322,  323,   59,   44,
    0,  327,   59,  407,  389,    0,  332,   41,  332,  335,
   44,  385,  264, 2348,   59,   44,  747,  391,  437,   59,
    0,   42,   43,  349,   45,   59,   47,   40, 2383,  433,
 2324,  591,  686,  687,  360,  454,  437, 2392, 2393, 2394,
 2395, 2396,  368, 2398,  368,    0,  372,  425, 2403,  443,
  424, 3372,  446,  454,   59,  381,  380, 3889,  523,   59,
    0,  364,  685, 2398,   59,   58,  259, 2535, 2403,  437,
   63,  397,    0,  427, 3224,  698,  269,  471,   41,   59,
  332,   44,  385, 3160,  738, 2497, 2441,  491,  391,    0,
 2495, 2446, 2497, 2498,    0,  401,    0,  423,   41,   45,
 2495,   44, 2497, 2498,   59, 2460,  264,  511, 2463,  435,
    0,  437,   58,  437,  262,  558,  368,   63,  266,   59,
  524,  424, 2527,  751, 2529, 2530, 2531,   40,  380,  277,
  454,   59, 2527,  281, 2529, 2530, 2531,   41,  264,  582,
   44,    0, 2497, 2498,  400,  315,    0, 2441,   59,    0,
 2555, 3324, 2446,   59,  479,   59,  276,  327,  427,  558,
 2555,  487,    0,  283,  489,  451, 2460,  453,  437,   59,
    0,  427,    0,  264,  332,  685,  264,  503,  504,  349,
 2535,  437,  508,  582,  509,  437,  312,  738,  698,  315,
  360,   41, 2547, 2548,   44,  407,  322,  323,  368,  264,
   59,  327,  454,  315,   46,   59,  332,  447,   59,  335,
  368,  261,  264,  263,  261,  327,   58, 3559, 3559,   61,
 2668,   59,  380,  349,  312, 4057, 2677,  397, 3327,   59,
 2678,   59, 3287,  479,  360,  323,  286,  349,  680,  286,
  682,  332,  368,  489,  332,  266,  372,  312,  360,  479,
   46,  301,  555, 2665,  301,  381,  277,  322,  323,  489,
  281, 2248,   58,   59, 1210,   61, 1212,  332,  259,    0,
 3939,  397, 2680, 3942, 2722,  310, 3375,  368,  269,  437,
  268,   60,   61,   62,  372,  397, 3385,  447,  448,  380,
 2645,   46, 2279,  381,  616,  617,  454,  423, 2285,  624,
  625,  626,   41,   58,   59,   44,   61,  372,  312,  435,
 2665,  437, 2667, 2668, 2719,  417,  381,  487,   46,  329,
 2788, 2676, 2677, 2678, 2679, 2680, 2681, 2682,   59,  655,
   58,   59, 2667,   61, 3343,  423,  328, 3559,  508,  266,
 3979,   41, 3981, 2676,   44,  291,  437,  258,  435,  437,
  277, 2645,   41, 2810,  281,   44,  487, 2712,  423,  270,
  264,  487, 1324,  454, 1326,    0,    0, 2722,  258, 1331,
 1332,   46,  437,   46, 1336,  363, 2668,  503,  504,  492,
  270, 2736,  508,   58,   59,   41,   61, 2679,   44,  487,
  301,   41,  303,  419,   44,   41,  508,  523,   44, 2681,
 2682, 1363,   41,  446,  392,   44,   41,   41,  312,   44,
   44,  301,   46,  303, 2769,  503,  504, 2772,  322,  323,
   41,  747,  419,   44,   59,   59,   61,   61,  332,  528,
 2722,  335, 2787, 2788, 2769,  523, 2770, 2772,  503,  504,
 3597,  332, 2797,  264, 2849,  433, 2801,  440,  441,  442,
  443,  444,   46,  446, 2849,  466,  467, 2812,  523,  594,
   46, 2816,  369, 3562,   58,   59,  417,   61,  372,  604,
  605,  401,   58,   59,  257,   61,  316,  381,  471,  472,
 2835,  379,  348, 2838, 2986, 2987, 2988, 2989, 2990, 2991,
  401,    0,  271, 2787,  440,  441,  442,  443,  444,  379,
  446,  447,  448,  491,  333,  284,    0, 2801,  376,  377,
   41,  401,  378,   44,  380,  367, 2871,  491, 2812,  423,
  466,  467, 2816,  511,   41,  471,  472,   44,  273,  655,
 3698,  435,    0,  437,    0,  401,  524,  268,  321,  318,
  523,   41,  715,  326,   44,  319,  325,   41, 2903,   41,
   59,   40,   44,   41,  333,  401,   44,  304, 2913, 2914,
  426,   41,  264,   41,   44,   59,   44,  655,  461,  462,
  463,  350,  315,  352,   40,   41,   41, 2871,   44,   44,
 2913, 2993,  735,  362,  327,  364,  365,  366,  454,  268,
  655,   59,  335,   59, 3693, 3007, 3008,  380,   41,  503,
  504,   44,  264,  334,  264, 3704,  349, 2962,   41,  261,
  264,   44,   41,  396,  600,   44,  264,  360,  282,  523,
 2914,  747, 2977,  258,   41, 2980,    0,   44, 2983,  264,
  264,  735,  363,  412,  286,  461,  462,  463, 2993,  413,
  275,  276,  277,  738,  296,  280,  420,   41,  283,  301,
   44,  264, 3007, 3008,  397,  447,  448,  264,  389,  747,
  295,  392,  479,  480, 3019,  299,  301,   41, 3388, 3389,
   44,    0,   45, 2250, 2251,  310,  407, 3032,  330,  340,
  454,  340,  747,  381, 3019,   59, 2980,   61,  678, 2983,
  650,  681,  466,    0,   40,   40, 3051,  643,  644, 3032,
   40,  447,  433,  614,  615, 3804, 3061, 3618,   41, 3064,
   41,   44,   41,   44, 3813,   41,   41,   40,   44,   44,
  494, 3076,  447,   41,  614,  615,   44,   40,   40,  364,
   59, 3064,   41,  447,   41,   44, 3909,   41,   40,  391,
   44, 3076, 3097,   41, 3099,   40,   44,   40,  400,   40,
  385,  655,   59,  394,   41,   40,  391,   44,   42,   43,
  491,   45,   40,   47,  399,  508,  401,   40,   58,   41,
  264,   61,   44,  425,   41,  686,  687,   44,  689,  414,
  511, 3238,   40,   40,  419,  696,  295,   40, 3143,  424,
  258,   41,   41,  524,   44,   44,  686,  687,   41,  689,
   40,   44,  270, 3097,   40, 3099,  696,  315,  347,   41,
  276,  277,   44,  596,    0,  598,  599,  283,  312,  327,
 3225,  456, 3177,  602,   44,   41,   40,  295,   44,  295,
 3225,  340,   40,  301,   40,  303,   40, 3242,  332,  348,
   40,  349,  138,  747, 3177,  141, 1894, 3242,   40, 1897,
   40, 3302,  360,   40,   91, 3868, 3304, 3870,   40,  675,
  368,   40,  311,   40,   40,   40,  649,   40,   40,  378,
   40,  380,  340,   59,   40,   40,   40,   40,  372,  653,
  348,   40,   40,   40,  258,   40,   40,  381,   40,  397,
  264, 3303,  401, 3248, 3306, 3250,   40, 3308,  364,  273,
   40,  675,   40,  277, 3316,   40,  280,   40, 3320, 3305,
  684,   40,   40,   40,   40, 3248,   40,  426,  291,  385,
  555,  295,   40,   40,   40,  391,   40,  301,   40,  423,
  304,   40,   40,  401, 3845,  264,  310,   40,  618,   40,
   40,   40,    0,  437,  412,  454,   40, 3302, 3303, 3304,
 3305, 3306, 3307, 3308, 3309,   40, 3250,  264,  424,   46,
   40, 3316,  736,   46,  368, 3320,   40,  370,  370,  430,
  344,  430, 3327,  384,   60,   61,   62,   40,  262,  341,
   40,  755,  266,  312, 3330, 3331, 3332, 3333, 3334, 3335,
  364,  500, 3449,  277,  430,  275,  631,  281,  419, 3354,
  508,   59,   40,  332,   40,  312,   40, 3362,   40,  503,
  504,   61,   40,  333,  333,   46, 3421, 3309,  503,  295,
 3375,  395,  357,   40,  382,  332, 3421,  401,  437,  523,
 3385,  450,  500,  295,   91,  270,    0, 3442,   40,  735,
 3375,  270,  374, 3448,  368,  419,  446, 3442,  312,   41,
 3385,  367,  868, 3448,   41,  440,  441,  442,  443,  444,
   41,  446,  372, 3418,   41,  372,  367,  440,  441,  442,
  443,  444,  258,  446,  447,  448,   40,   41,  452,  895,
   44,   41,  456,   41,  270, 3440,  471,  472,   40,  555,
   46,  419, 3504,  466,  467,   59,  437,   61,  471,  472,
   40,  290, 3457,  738,  386,  368,   40, 3519,  437,  295,
   40,    0,  368,  368,   46,  301,  423,  303,  260,  312,
  401,  312,  466,  466, 3457,   40,  275,   91,  306,  466,
  437,  333,  333,   44,  314,   44,   46,   44,  316,   40,
  347,  319,  347,  513,  332,  500,  614,  615,  499, 3504,
  499,  300,   41,  719,  340,   44,  719,  306,  437, 3514,
  446,  655,  348,  616, 3519,  270,   59,  316,   59,  294,
   59,   41,  395,   44,  371,  371,  262,  371,  264,  487,
  329,  555, 3537,  437, 3539,  271,  600,  348,   40,   40,
 3595,   41,   41,  355,  523,   41,  503,  504,  504,   44,
 3555, 3556,   41,  314, 3537,   41, 3539, 3562,   41,  387,
 1026, 3566,   44,   44, 3629,  401,  523,  314,  686,  687,
 3575,  689, 3555,  418,  314,   41,  412, 3562,  696,   41,
   41,   41,  318,   46,  419, 3590, 3591,  295,  387,  325,
 3595,   44, 3597,  421,  314,  333,   40,  333,  426,   41,
  749,  435,   40, 3608,  432,  401,  395,  631,   44,  419,
   44,  417, 3556,   44,  350,   41,  352,   41,  417,  419,
  643,  644,  421,  335, 3629, 3630,  362,  426,  364,  365,
  366, 3575,  340,  432,  373,  371,  335,  314, 3696,  368,
  348, 3646,  368,  261,  258,  368,  290,   41,  749,  414,
  264,  749,  749,   41,   41,  454,   41,   41,   41,  273,
   61,  275,  276,  277,  500,   46,  280,   41,  286,  283,
  378,  488,  380,  419,  340,  435, 3681,  340,  296, 3734,
  340,  295,  510,  301,  455,  264, 3630,  301, 3693, 3734,
  304, 3696, 3697,  401, 3749,  264,  310,  719,  655, 3704,
  719,  264, 3646,  276, 3749,  739,  739,  303, 3693,   58,
  419,  510,  330,   61,  738,    0,  314, 3835,  426, 3704,
  303, 3705,  395,  304,   40,  303,  418, 3732,  556,  419,
  344,   41, 1198,   41,   40, 1201,  620,  276,  277,  314,
 1206,  264,  335, 1209,  283,  263,  454, 1213,  263,  278,
  364, 1217,  314,  525,  306,   40,   41,  527,  314,   44,
   41,  399,  437,  437,  316,    0,   41,  319,    0,  333,
  487,  385,  600,  391,   59,   44,   61,  391,  614,  615,
  528,  395,  400,  369,  322,  401,  314,  401,   40,  419,
 3795,  619,  500,   40,  344,  344,   60,   61,   62, 3804,
  276,  600,    0,  736,   59,  419,   91,  425, 3813,   41,
  424,  303,   44,  594,  367, 3820, 3881,   61,  332, 3804,
  619,  332,   58,  277,   59,  364,  437,   59, 3813, 3834,
 3835,  371,  273,  735,  735,  387,  371, 3820,  452,  371,
  371,  371,  456,  370, 3849,  371,  385,   59, 1314,  386,
  686,  687,  391,  689,   59,  358,  511,   40,  450, 1325,
  696,   59,  386,  437, 1330,  417,  602, 3932, 1334,  421,
   59,   59,   44, 3878,  426,  303, 3881,  367, 1344,  450,
  432,   41,   41, 1349, 1350,  424,  434, 1353, 1354, 1355,
 1356, 1357, 1358, 1359,   41, 1361, 1362,   41, 1364,   41,
 1366, 1367, 1368, 1369, 1370,  273,   41, 1373, 1374, 1375,
 1376, 1377, 1378, 1379, 1380, 1381, 1382, 1383, 1384, 1385,
 1386, 1387, 1388,  709,  351,  419,  419, 3932,  419,  526,
  407,  419, 1398, 1399, 1400,  419,   41,  405,   41,  419,
  419,  555,   44,  273,  466, 3950,  650,  466,  487, 1415,
 1416,  323,  369,  420,  336,  332,  719, 1423,  510,  434,
   40,   59, 1428, 3968,  344,  719,  364,  364, 1434, 1435,
  273,    0,   40,  258,  532,  425,  330, 1443, 3983,  264,
 1446, 1447, 1448, 1449, 1450,  425,  330, 1453,  273,  296,
  275,  276,  277,  650,  296,  280,  419,  325,  283, 4004,
  314,  446,  368,  454,  556,  454,  613,  271,  371, 4014,
  295,   40,   41,   40,   40,   44,  301,  631,   40,  304,
  284, 4004,  357,   41,    0,  310,  314,  336,  734,   61,
   59,  450,   61,  268,   40,   44,  314,  314,  314,  431,
  557,  314,  314,  314,  276,  277,  314,  749,  749,    0,
  747,  283,  427,   44,  318,   41,   40,  299,   41,  344,
  258,  325,   91,  295,  494,   41,  299,  619,   44,  333,
  289,  280,  270,  264,  344,  275,  623,    0,  344,  364,
  340,  401,  494,   59,   40,   61,  350,  631,  352,  304,
  303,  418,  756,   63,   60,   61,   62,  295,  362,  334,
  385,  365,  366,  301,  611,  303,  391,  611,   59,  718,
  395,  321,  689,  370,   44,   91,  401,  273,  312,  434,
  431,  411,  389,  677,  738,  713,   40,   44,  363,  418,
  395,   41,  364,  314,  419,  312,   59,   46,  401,  424,
  336,  336,  340,  344,   41,   41,   46,   41,  412,   41,
  348,   44,  370,  385,  389,  264,  418,  392,  299,  391,
   40,  487,  295,  264,  555,   44,   61,  452,   44,   41,
  357,  456,  407,  719,  719,   40,  654,   40,  458,  459,
  460,  461,  462,  463,  464,  465,  564,  302,  447,  714,
  264,  299,  424,  632,  391,  652,  513,  586,  433,  278,
  571,  452,   41,  401,  717,  266,  654,   40,  289,   41,
  329,  295,  329,  262,  412,   41,   41,  654,  565,    0,
  717, 1687, 1688,  376, 1690,  283, 1692,   40,  310,  258,
 1696, 1697, 1698, 1699,  426,  264,  368,   40, 1704, 1705,
  654,  330,  420,  504,  273,  692,  504,  276,  277,  386,
  420,  280,  368,  418,  283,  368,  491, 1723,  401,  609,
   41,  418,  607,   44,  425,  296,  295,  336,    0,  609,
  555,  330,  301,   41, 1740,  304,  511,   41,   59,  401,
   61,  310,  258,  449, 1750, 1751,  437,  567,  264,  524,
   44,  427,   60,   61,   62,   40,  262,  273,  427,  275,
  276,  277,  500,   40,  280,  271,  400,  283,    0,   41,
   91,  264,   44,  593,  329,  344,  264,  268,  284,  295,
  264,   40,  400,  555,  264,  301,  264,   59,  304,  400,
  400,  419,  333,  270,  310,  364,   40,  434,  602,  395,
   41,  335,  340,  270, 1810,  268,  631,   40,  270,  303,
   41,  303,  318,  264,  368, 1821,  385, 1823,  290,  325,
 1826,  335,  391,  270,  303,   41,  395,  333,  344,  446,
  303,  407,  401,  487,   59,  368,  395,  511,   41,   41,
   61,  336,  427,  334,  350,    0,  352,   59,  364,   59,
  419,   59, 3030,   59,   40,  424,  362,  303,  364,  365,
  366,  289,  314,   41,  303,  371,   59,  618,   59,  385,
   59,  334,  363,   41,   59,  391,  614,  615,  418,  395,
   41,   41,  264,  452,  511,  401,   41,  456,  314,   44,
  314,  299,   41,  446, 1900,  446,   41,  523,  389,  738,
  363,  392,  646,  419,   59,  738,  412,  480,  424,   40,
   46,   46,   41,  738,  294,   41,  407,  294,  294,  294,
  305,  741,  742,  389,  738,   44,  389,  305,  264,  392,
  389,  305,   46,  294,  294,  364,  452,  258,    0,  294,
  456,  401,  433,  264,  407,  294,  305,   41,  686,  687,
  597,  689,  273,  523,  262,  276,  277,  597,  696,  280,
  555, 1967,  283,  271, 1970,  597, 1972,   44,  264,    0,
  433,  401,   46, 2657,  295, 1909,  284, 2658, 1483,   41,
  301, 1987,   44,  304, 2659, 3504,  555, 3504, 1483,  310,
 1483, 2264, 2685, 1483,    0, 1484, 1483,   59, 3316,   61,
  491, 2551, 3237, 3447,  276,  277,  314, 1676,    0,  431,
  318,  283, 3168, 3423, 3113, 2505,   83,  325, 2863, 3160,
  511,  814, 2453,  344, 3719,  333,  104, 3834,  491,   91,
 3614, 2492, 3148,  524, 3796,   41,  435, 3731,   44,  555,
 1179, 3845,  350,  364,  352, 2537, 3169, 2871,  511,   41,
 4044, 3714,   44,   59,  362,   61,  364,  365,  366, 3926,
 2871,  524,  631,  371,  385, 4049, 3961,   59, 3962,   61,
  391, 3996, 3097, 3646,  395, 3098, 3800, 2102, 2104,  715,
  401, 2024, 1671, 1612, 3570,   91, 4014, 2770, 2770, 4015,
 3915, 2396,  364, 3703, 2766, 3807,  602,    0,  419,   91,
 1855, 2980, 2518,  424,  412, 2007, 3221, 1247, 2459, 3830,
 1453, 3717, 2006,  385, 2045,  631, 2501, 1582, 2124,  391,
 3555,  276,  277, 3301, 2130,  142, 1630, 1647,  283, 2135,
 2286,  452, 2138, 2139, 2140,  456, 3314, 3354, 3343, 2145,
 2146, 2147, 3036,   60,   61,   62, 3537, 1520, 2154,  742,
 2156,  426,  424, 2159, 2160, 2161, 2162, 1166, 3336, 3337,
 2166,  749, 2168,  702, 2170, 1192, 2172, 1217, 1967,  738,
 1467, 3011, 2178, 2179, 2180, 2181, 2182, 2183, 2184, 2185,
 2186, 2187, 2188, 2189, 1895, 1468, 2278, 2193, 2194, 3457,
 3548, 3681, 2198, 2199, 3968, 1970,  258,  753, 2715,    0,
 2730, 1317,  264, 2209,    0,    0, 3523, 3523, 2214,  364,
    0,  273, 2218,  368,  276,  277,    0, 3945,  280, 1532,
 2320,  283,  738, 2229, 2398, 1820, 2232, 1425,  437, 3732,
  385,  737, 2523,  295,  555, 2534,  391, 1653,  832,  301,
 3591, 1983,  304,  795,  849, 1005,    0, 1004,  310, 1394,
 1446, 3795,  258, 3638, 2165, 1564, 3485, 1391,  264, 2797,
 3258, 2300,  119, 3307, 3300, 2280,  258,  273, 1564,  424,
  276,  277,  264, 1464,  280, 2684, 3966,  283, 2903, 2098,
 1305,  273,  344, 3603,  276,  277, 3366,   41,  280,  295,
   44,  283, 3445, 3743,  602,  301, 3583, 3825,  304, 3928,
 2800, 1227,  364,  295,  310,   59, 1141,   61,   12,  301,
  631, 3034,  304, 3754, 3908, 3487, 3014, 2323,  310,    0,
   -1, 3606,   -1,  385,   -1,   -1,   -1,   -1,   -1,  391,
   -1,   -1,  487,  395,   -1,   -1,   -1,   91,  344,  401,
   60,   61,   62,   -1,   -1,  262,   -1,   -1,    0,   -1,
   -1,   -1,  344,   -1,  271,   -1,   -1,  419,  364,   -1,
   41,   -1,  424,   44,   -1,   -1,   -1,  284,   -1,   -1,
   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,   59,  385,
   61,   -1, 2388,   -1,   -1,  391,   -1,   -1,   -1,  395,
  452, 2397,   -1,  385,  456,  401,    0,   -1,    0,  391,
   -1,  318,   -1,  395,   -1,   -1,   -1,   59,  325,  401,
   -1,   -1,   -1,  419,  300,   -1,  333,  738,  424,   -1,
  306,   -1,   -1,   -1,   -1,   -1,   -1,  419,   -1,   -1,
  316,   -1,  424,  350,   -1,  352,   -1,   -1,   -1,   41,
    0,   -1,   44,  329,   -1,  362,  452,  364,  365,  366,
  456,   -1,   -1,   -1,  371,   59,   -1,   59,   -1,   61,
  452,   -1,   -1,   -1,  456,   -1,   -1,   -1,   -1, 3647,
 3648, 3649, 3650, 3651, 3652, 3653,   -1,    0,   -1,   -1,
   -1,   41,   -1,   -1,   44,   -1, 3664, 3665, 3666, 3667,
 3668, 3669, 3670,  555,   -1,  412,   -1,   -1,   -1,   59,
   -1,  387,   -1,   -1,  258,   -1,   -1,   -1,   -1,   -1,
  264,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   41,  273,
   -1,   44,  276,  277,   -1,   -1,  280,   -1,   -1,  283,
   -1,  417,   -1,   -1,   -1,  421,   59,   -1,   61,   -1,
  426,  295,  262,   -1,   -1,   -1,  432,  301,   -1,  555,
  304,  271,   -1,   -1,   -1,   -1,  310,   -1,   -1,   -1,
   -1,   -1,   -1,  555,  284, 2571,   -1,   -1,  454,  631,
   -1,   -1,   -1,   -1, 2580,   -1,   -1,  258,   -1,   -1,
   -1, 2587, 2588,  264,   -1,   -1,   -1,   -1, 2594,   -1,
  344,   -1,   -1,   -1,  275,  276,  277,   -1,  318,  280,
   -1,   -1,  283,   -1,   -1,  325,   -1,   -1,   -1,   -1,
  364,   -1,   -1,  333,  295,   -1,  268,   -1, 2624,   -1,
  301, 2627,   -1, 2629,  510,  631,   -1,  513,   -1,  310,
  350,  385,  352,   -1,   -1,   -1,    0,  391,   -1,  631,
   -1,  395,  362,   -1,  364,  365,  366,  401,   -1,   -1,
   -1,  371,   -1,   -1,   -1,   -1,  258,   -1,   -1,   -1,
   -1,   -1,  264,   -1,  268,  419,   -1,   -1,   -1,   -1,
  424,   -1,   -1,  275,  276,  277,  738,   41,  280,   -1,
   44,  283,  334,  364,   -1,  602,   -1,   60,   61,   62,
   -1,   -1,  412,  295,   -1,   59,   -1,   -1,  452,  301,
   -1,   -1,  456,   -1,  385,   -1,   -1,   -1,  310,   -1,
  391,  363,   -1,   -1,  600,   -1,  276,  277,  399,   -1,
  401,   -1,   -1,  283, 2730,   -1,   -1,   -1,   -1,   -1,
  334,   -1,  738,  619,   -1,  258,   -1,  389,  419,   -1,
  392,  264, 2748,  424,   -1,   -1,  738,   -1,   -1,   -1,
   -1,   -1,   -1,  276,  277,  407,   -1,  280,   -1,  363,
  283,   -1,  364,   -1,   -1,   -1,   -1, 2773,   -1,   -1,
   -1,   -1,  295,   -1,   -1,  456,   -1,   -1,  301,   -1,
   -1,  433,   -1,  385,   -1,  389,   -1,  310,  392,  391,
   -1,   42,   43,   44,   45,   46,   47,   -1,   -1,  401,
  717,  555,   -1,  407,  364,   -1,   -1,   -1,   -1,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,  419,   -1,   -1,
   -1,   -1,  424,   -1,   -1,  385,   -1,   -1,   -1,  433,
   -1,  391,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  491,
   91,  364,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  456,   -1,   -1,   -1,   -1,  511,
   -1,   -1,  385,   -1,  424,   -1,   -1,   -1,  391,   -1,
   -1,   -1,  524,   -1,  555,   -1,   -1,  631,  401,   -1,
    0,   -1,  602,   -1,   -1,   -1,   -1,  491,   -1,  262,
   -1,   -1,   -1,   -1,   -1,   -1,  419,   -1,  271,   -1,
   -1,  424,   -1,   -1,   -1,   -1,   -1,  511,   -1,   -1,
   -1,  284,  276,  277, 2920,   -1, 2922,   -1, 2924,  283,
  524,   41, 2928,   -1,   44,   -1,   -1, 2933, 2934, 2935,
 2936, 2937,   -1,  456,   -1,   -1, 2942,   -1, 2944,   59,
 2946,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,
  631,   -1,  325,  555,   -1,   -1,   -1,   -1, 2964,   -1,
  333,   -1, 2968,   -1,   -1,   -1, 2972,   -1,   -1, 2975,
   -1,   -1,  692,   -1,   -1,   -1,   -1,  350,   -1,  352,
   60,   61,   62,   -1,  738,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,   -1,   -1,   -1,  717,  371,   -1,
  364,   -1,   -1,   -1,   42,   43,   44,   45,   46,   47,
   -1,  262,   -1,   -1,   -1,  266,   60,   61,   62,   -1,
  271,  385,   60,   61,   62,   -1,  277,  391,   -1,  631,
  281,   -1,  555,  284,   -1,   -1,   -1,   -1,   -1,  412,
   -1,   -1,   -1,   -1,   -1,   -1,   -1, 3053,   -1,   -1,
   -1,   -1,   -1,   91,   -1,   -1,   -1,  738,   -1,   -1,
  424,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,
   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,    0,   -1,   -1,   -1,   -1,  350,
   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,  631,   45,
    0,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,   58,  487,    0, 3131,   -1,   63,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   41,  738,   -1,   44,   -1,
   -1,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   41,   -1,   59,   44,   -1,  276,  277,   -1,   -1,
   -1,  412,   -1,  283,   -1,   41,   -1,   -1,   44,   59,
   -1,   -1,   -1,   -1,   42,   43,   44,   45,   46,   47,
   -1,   -1,  262,   59,   45,   -1,   -1,   -1,   -1,   -1,
   -1,  271,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  284,   -1,   -1,  458,  459,  460,
  461,  462,  463,  464,  465,  738,   -1,   -1,  262,   -1,
   -1,   -1,   -1,   91,  262,   -1,   -1,  271,  266,  602,
   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,  318,  277,
  284,   -1,   -1,  281,  364,  325,  284,   -1,   -1,   -1,
   -1, 3257, 3258,  333,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  385,   -1,   -1, 3274,   -1,
  350,  391,  352,   -1,  318,   -1,   -1,   -1,   -1, 3285,
  318,  325,  362,   -1,  364,  365,  366,  325,   -1,  333,
    0,  371,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  424,   -1,  350,   -1,  352,   -1,
   -1,   -1,  350,   -1,  352,   -1,  567,   -1,  362,  692,
  364,  365,  366,   -1,  362,   -1,  364,  365,  366,   -1,
   -1,   41,  412,  371,   44,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  593,  262,  717,   -1,   -1,   -1,   -1,   59,
   -1,  602,  271,   -1,   -1,  291,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  284, 3372, 3373,  412,   -1,
  276,  277,   -1,   -1,  412, 3381, 3382,  283,  458,  459,
  460,  461,  462,  463,  464,  465,  276,  277,   -1,  295,
   -1,   -1,   -1,  283,  262,   -1,   -1,   -1,  266,  318,
  276,  277,   -1,  271,   -1,  295,  325,  283,   -1,  277,
   -1,   -1,   -1,  281,  333,   -1,  284,   -1,   -1,   -1,
  458,  459,  460,  461,  462,  463,  464,  465,   -1,   -1,
  291,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,
 3446,   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,
  318,   -1,  371,   -1,   -1,   -1,  317,  325,  364,   -1,
 3466,   -1,   -1,   -1,   -1,  333,   -1,   -1, 3474,   -1,
 3476,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,  385,
   -1,   -1,  350,  344,  352,  391,   -1,  567,  364,   -1,
  741,  742,   -1,  412,  362,  385,  364,  365,  366,   -1,
   -1,  391,   -1,  371,  440,  441,  442,  443,  444,  385,
  446,  447,  448,  593,   -1,  391,   -1,   -1,  424,   -1,
   -1,   -1,  602,   -1,   -1,   -1,   -1,   -1,   -1,  567,
  466,  467,   -1,   -1,  424,  471,  472,   -1,   -1,   -1,
   -1, 3547, 3548,   -1,  412,   -1,   -1,   -1,  424,  410,
   -1,   -1,   -1, 3559,   -1,  593,   41,   -1,  602,   44,
   -1,   -1,   -1,   -1,  602,  426,  276,  277,  504,   -1,
   -1,   -1,   -1,  283,   -1,   60,   61,   62,   -1,  440,
  441,  442,  443,  444,   -1,  446,  447,  448,   -1,   -1,
  458,  459,  460,  461,  462,  463,  464,  465,  300,   -1,
   -1,   -1,   -1,   -1,  306,  466,  467,  468,  469,  470,
  471,  472,  473,  474,  316,   -1,  275,   60,   61,   62,
  481,  482,   -1,   -1,   -1,   -1, 3632,  329,   -1,  490,
   -1, 3637, 3638,   -1,   -1,   -1,   -1,   -1, 3644,   -1,
   -1,  300,   -1,  275,   -1,   -1,   -1,  306,   -1,  555,
   -1,   -1,  311,   -1,  364,   -1,  288,  316,  290,   -1,
  319,  741,  742,   -1,   -1,   -1,   -1,   -1,  300,   -1,
   -1,   -1,   -1,   -1,  306,  385,   -1,   -1,  310,   -1,
   -1,  391,   -1,  602,  316,  387,   -1,  319,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  329,    0,  567,
   -1,   -1,   -1,  741,  742,   -1,   -1,  643,  644,   -1,
   -1,   -1,   -1,   -1,  424,  417,   -1,   -1,  654,  421,
   -1,   -1,   -1,   -1,  426,  593,   -1,   -1,  387,   -1,
  432,   -1,   -1,   -1,  602,   -1,   -1,   -1,   40,   41,
   -1,   43,   44,   45,   46,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  454, 3759,   -1,  387,   58,   59,  417,   -1,
   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  432,   -1,   -1,   -1,  262,   -1,   -1,
  641,   -1,  643,  644,  645,  417,  271,  706,   -1,  421,
   -1,   -1,   -1,   -1,  426,  454,   -1,   -1,   -1,  284,
  432,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  510,   -1,
   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,
   -1,   -1,  454,   -1,   -1,   -1,   -1,   -1,  271,   -1,
   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,
  325,  284,   -1,  704,  705,   -1,   -1,   -1,  333,   -1,
   -1,  510,   -1,   -1,  513,   -1, 3862,   -1,   -1,   -1,
   -1,   -1,  723,   -1,   -1,  350,   -1,  352,   -1,   -1,
   -1,   -1,   -1,  741,  742,  318,   -1,  362,  510,  364,
  365,  366,  325,   -1,   -1,   -1,  371,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,   -1,   -1, 3903,  600,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,
   -1,   -1, 3918,   -1, 3920,   -1,   -1,  619,   -1,  362,
   -1,  364,  365,  366,  556,   -1,   -1,  412,  371,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1, 3950,   -1, 3952, 3953,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,
  619,   -1,  264,  265,   -1,  267,  268,  269,  600,  412,
   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,  280,   -1,
  282,   -1,  284,  285,   -1,  287,   -1,  619,  290,  291,
  292,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
   -1,   -1,  304,   -1,  306,   -1,  308,  309,   -1, 4015,
  312, 4017, 4018,  315,   -1,  317,   -1,  319,  320,   -1,
  322,  323,  324,   -1,  326,  327,  328,   -1,   -1,   -1,
  332, 4037,  334,  335,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,  344,   -1,  346,  347,  348,  349,   -1,  351,
   -1,  353,  354,   -1,  356,  357,  358,   -1,  360,   -1,
 4066,   -1,  364,   -1, 4070,   -1,  368,   -1,  370,   -1,
  372,   -1,  374,  375,  376,  377,  378,   -1,  380,  381,
  382,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,
  402,  403,  404,  405,  736,  407,   -1,  409,  410,  411,
  412,  413,  414,  415,  416,   -1,   -1,  602,  420,   -1,
  422,  423,   -1,   -1,  426,   -1,   -1,   -1,   -1,   -1,
   -1,  433,   -1,  435,   -1,  437,  438,  439,  440,  441,
  442,  443,  444,  445,  446,  447,  448,  449,   -1,  451,
  452,  453,  454,   -1,  456,  457,   -1,   -1,   -1,  602,
   -1,   -1,  464,  465,  466,  467,  468,  469,  470,  471,
  472,  473,  474,  475,  476,   -1,  478,  479,  480,  481,
  482,   -1,  484,  485,  486,  487,  488,  489,  490,  491,
   -1,   -1,  494,  495,  496,  497,  498,  499,  500,   -1,
   -1,  503,  504,  505,  506,  507,  508,  509,  510,  511,
   -1,  513,   -1,  515,  516,  517,   -1,  519,  520,   -1,
  522,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,  540,  541,
  542,  543,   -1,  545,  546,  547,  548,  549,  550,   -1,
  552,  553,  554,  555,   -1,  557,  699,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,  573,  574,  575,  576,   -1,  578,  579,  580,  581,
   -1,  583,  584,  585,  586,  587,   -1,  589,  590,  591,
  592,  593,  594,  595,  596,  597,  598,  599,  600,  601,
   -1,  603,  604,  605,  606,  607,  608,   -1,  610,  611,
  612,  613,  614,  615,  616,  617,   -1,  619,  620,  621,
  622,   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,
  632,  633,  634,  635,  636,  637,  638,  639,  640,  641,
   -1,  643,  644,  645,  646,  647,  648,  649,  650,  651,
  652,  653,   -1,  655,  656,  657,  658,  659,  660,  661,
  662,  663,  664,  665,  666,  667,  668,  669,  670,  671,
  672,  673,   -1,  675,  676,  677,  678,  679,  680,  681,
  682,  683,   -1,  685,  686,  687,  688,  689,  690,  691,
  692,  693,  694,  695,  696,   -1,  698,  699,  700,   -1,
  702,   -1,  704,  705,  706,  707,  708,  709,  710,  711,
  712,  713,  714,  715,  716,  717,  718,    0,  720,  721,
  722,  723,  724,  725,  726,  727,  728,  729,  730,  731,
  732,  733,  734,  735,  736,  737,  738,  739,  740,   -1,
   -1,  743,  744,   -1,   -1,  747,   -1,  749,  750,  751,
  752,  753,  754,  755,  756,  757,   -1,  275,   41,   42,
   43,   44,   45,   -1,   47,   -1,   -1,   -1,   -1,   -1,
   -1,  275,  290,   -1,   -1,   -1,   59,   60,   61,   62,
   -1,   -1,  300,   -1,   -1,   -1,  290,   -1,  306,  275,
   -1,   -1,  310,  311,   -1,   -1,  300,   -1,  316,   -1,
   -1,  319,  306,   -1,  290,   -1,   -1,  311,   -1,   -1,
   93,  329,  316,   -1,  300,  319,   -1,   -1,   -1,   -1,
  306,   -1,   -1,   -1,   -1,  311,   -1,   -1,   -1,   -1,
  316,   -1,   -1,  319,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  379,   -1,   -1,  368,   -1,   -1,   -1,   -1,  387,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  368,  387,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  417,
   -1,  387,   -1,  421,   -1,   -1,   -1,   -1,  426,   -1,
   -1,   -1,   -1,  417,  432,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  432,   -1,
   -1,  417,   -1,   -1,   -1,   -1,  454,  455,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  432,   -1,   -1,   -1,
  454,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  454,   -1,
   -1,   -1,   -1,   -1,  257,  258,  259,   -1,   -1,  262,
   -1,  264,  265,  266,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,  510,  276,  277,  513,  279,  280,  281,  282,
  283,  284,   -1,   -1,  287,   -1,  510,  290,   -1,  513,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,  301,  302,
  303,  304,  305,  306,  510,   -1,  309,  513,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,  619,  385,  386,   -1,  388,  389,   -1,  391,  392,
  393,  394,   -1,   -1,  397,  619,  399,   -1,  401,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,  619,   -1,  418,  419,  420,   -1,  422,
  423,  424,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,   -1,   -1,   -1,
   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,  451,  452,
  453,  454,   -1,  456,   -1,  458,  459,  460,  461,  462,
  463,  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  475,  476,   -1,  478,  479,  480,   -1,   -1,
   -1,   -1,  485,  486,  487,  488,  489,   -1,  491,   -1,
   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,
  503,  504,  505,  506,  507,  508,  509,  510,  511,   -1,
  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,  540,  541,  542,
  543,   -1,  545,  546,  547,  548,  549,  550,   -1,  552,
  553,  554,  555,   -1,  557,   -1,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
  573,  574,  575,  576,   -1,  578,  579,  580,  581,   -1,
  583,  584,  585,  586,  587,   -1,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,   -1,  610,  611,  612,
  613,  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,
   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,  632,
  633,  634,  635,  636,  637,  638,  639,  640,   41,   -1,
   -1,   44,   -1,  646,   -1,  648,  649,  650,  651,  652,
  653,   -1,  655,   -1,   -1,   -1,   -1,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,
  673,   -1,  675,  676,  677,  678,  679,  680,  681,  682,
  683,   -1,  685,  686,  687,  688,  689,  690,  691,  692,
  693,  694,  695,  696,   -1,  698,  699,  700,   -1,  702,
   -1,   -1,   -1,  706,  707,  708,  709,  710,  711,  712,
  713,  714,  715,  716,  717,  718,    0,  720,  721,   -1,
   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,
  733,  734,  735,  736,  737,  738,  739,  740,  741,  742,
  743,  744,   -1,   -1,  747,   -1,  749,  750,  751,  752,
  753,  754,  755,  756,  757,   -1,   -1,   41,   42,   43,
   44,   45,   -1,   47,   -1,   -1,   -1,  275,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   59,   60,   61,   62,   -1,
   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  300,   -1,   -1,   -1,   -1,   -1,  306,   -1,
   -1,   -1,   -1,  311,   -1,   -1,   -1,   -1,  316,   93,
   -1,  319,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  275,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  300,   -1,   -1,
   -1,   -1,   -1,  306,   -1,   -1,   -1,   -1,  311,  262,
   -1,   -1,   -1,  316,   -1,   -1,  319,   -1,  271,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  387,
   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  417,
   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,
   -1,   -1,  325,   -1,  432,   -1,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,  387,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  454,  350,   -1,  352,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,  417,   -1,   -1,   -1,  371,   -1,
   -1,   -1,   -1,  257,  258,  259,   -1,   -1,  262,  432,
  264,  265,  266,   -1,  268,  269,   -1,  271,   -1,   -1,
   -1,   -1,  276,  277,   -1,  279,  280,  281,  282,  283,
  284,  454,  510,  287,   -1,  513,  290,   -1,   -1,  412,
   -1,   -1,   -1,  297,   -1,  299,  300,  301,  302,  303,
  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,
  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,
  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,
  334,  335,  336,   -1,   -1,   -1,  340,  510,   -1,   -1,
  513,   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,
   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,
  364,  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,
  374,  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,
   -1,  385,  386,   -1,  388,  389,   -1,  391,  392,  393,
  394,  619,   -1,  397,   -1,  399,   -1,  401,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,
  424,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
  434,  435,   -1,  437,  438,  439,   -1,   -1,   -1,   -1,
   -1,  445,   -1,   -1,   -1,  449,  619,  451,  452,  453,
  454,   -1,  456,   -1,  458,  459,  460,  461,  462,  463,
  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  475,  476,   -1,  478,  479,  480,   -1,   -1,  602,
   -1,  485,  486,  487,  488,  489,   -1,  491,   -1,   -1,
  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,  503,
  504,  505,  506,  507,  508,  509,  510,  511,   -1,  513,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,  540,  541,  542,  543,
   -1,  545,  546,  547,  548,  549,  550,   -1,  552,  553,
  554,  555,   -1,  557,   -1,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,  573,
  574,  575,  576,   -1,  578,  579,  580,  581,   -1,  583,
  584,  585,  586,  587,   -1,  589,  590,  591,  592,  593,
  594,  595,  596,  597,  598,  599,  600,  601,  602,  603,
  604,  605,  606,  607,  608,   -1,  610,  611,  612,  613,
  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,
  624,  625,  626,  627,  628,  629,   -1,   -1,  632,  633,
  634,  635,  636,  637,  638,  639,  640,   41,   -1,   -1,
   44,   -1,  646,   -1,  648,  649,  650,  651,  652,  653,
   -1,  655,   -1,   -1,   -1,   -1,   60,   61,   62,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,
   -1,  675,  676,  677,  678,  679,  680,  681,  682,  683,
   -1,  685,  686,  687,  688,  689,  690,  691,  692,  693,
  694,  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,
   -1,   -1,  706,  707,  708,  709,  710,  711,  712,  713,
  714,  715,  716,  717,  718,    0,  720,  721,   -1,   -1,
   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,  733,
  734,  735,  736,  737,  738,  739,  740,  741,  742,  743,
  744,   -1,   -1,  747,   -1,  749,  750,  751,  752,  753,
  754,  755,  756,  757,   -1,   40,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,  275,   -1,   -1,   -1,
   -1,   -1,   -1,   58,   59,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  300,   -1,   -1,   -1,   -1,   -1,  306,   -1,   -1,
  261,   -1,  311,   -1,   -1,   -1,   91,  316,   93,   -1,
  319,   -1,   -1,   -1,   -1,   -1,   -1,  278,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  286,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  294,   -1,  296,   -1,   -1,   -1,   -1,
  301,   -1,   -1,   -1,   -1,   -1,  307,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,
  321,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,  330,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  387,   -1,
  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  355,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  417,   -1,
   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,
   -1,  325,   -1,  432,   -1,   -1,   -1,   -1,   -1,  333,
   -1,   -1,   -1,   -1,   -1,  396,   -1,  398,   -1,   -1,
  401,   -1,   -1,   -1,   -1,  454,  350,   -1,  352,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,
  364,  365,  366,   -1,  425,   -1,   -1,  371,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,  437,  262,   -1,  264,
  265,  266,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,  510,  287,   -1,  513,  290,   -1,   -1,  412,   -1,
   -1,   -1,  297,   -1,  299,  300,  477,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,  492,  493,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,  514,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,
  619,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,   -1,   -1,   -1,   -1,   -1,
  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,
   -1,  456,   -1,  458,  459,  460,  461,  462,  463,  464,
  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  475,  476,   -1,  478,  479,  480,   -1,   -1,  602,   -1,
  485,  486,  487,  488,  489,   -1,  491,   -1,   -1,  494,
  495,   -1,   -1,   -1,  499,  500,   -1,   -1,  503,  504,
  505,  506,  507,  508,  509,  510,  511,   -1,  513,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,  540,  541,  542,  543,   -1,
  545,  546,  547,  548,  549,  550,   -1,  552,  553,  554,
  555,   -1,  557,   -1,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,  573,  574,
  575,  576,   -1,  578,  579,  580,  581,   -1,  583,  584,
  585,  586,  587,   -1,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,  614,
  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,
  625,  626,  627,  628,  629,   -1,   -1,  632,  633,  634,
  635,  636,  637,  638,  639,  640,   41,   -1,   -1,   44,
   -1,  646,   -1,  648,  649,  650,  651,  652,  653,   -1,
  655,   -1,   -1,   -1,   -1,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,
  675,  676,  677,  678,  679,  680,  681,  682,  683,   -1,
  685,  686,  687,  688,  689,  690,  691,  692,  693,  694,
  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,   -1,
   -1,  706,  707,  708,  709,  710,  711,  712,  713,  714,
  715,  716,  717,  718,    0,  720,  721,   -1,   -1,   -1,
   -1,   -1,  727,  728,  729,  730,  731,  732,  733,  734,
  735,  736,  737,  738,  739,  740,  741,  742,  743,  744,
   -1,   -1,  747,   -1,  749,  750,  751,  752,  753,  754,
  755,  756,  757,   -1,   40,   41,   42,   43,   44,   45,
   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   58,   59,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,
  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,
   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,
  266,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,
   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,  412,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,  305,
  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,
   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,  325,
  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,
   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,
  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,
  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,
   -1,  437,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,
   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,
  456,   -1,  458,  459,  460,  461,  462,  463,  464,  465,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,
  476,   -1,  478,  479,  480,   -1,   -1,  602,   -1,  485,
  486,  487,  488,  489,   -1,  491,   -1,   -1,  494,  495,
   -1,   -1,   -1,  499,  500,   -1,   -1,  503,  504,  505,
  506,  507,  508,  509,  510,  511,   -1,  513,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,  540,  541,  542,  543,   -1,  545,
  546,  547,  548,  549,  550,   -1,  552,  553,  554,  555,
   -1,  557,   -1,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,  573,  574,  575,
  576,   -1,  578,  579,  580,  581,   -1,  583,  584,  585,
  586,  587,   -1,  589,  590,  591,  592,  593,  594,  595,
  596,  597,  598,  599,  600,  601,  602,  603,  604,  605,
  606,  607,  608,  609,  610,  611,  612,  613,  614,  615,
  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,
  626,  627,  628,  629,   -1,   -1,  632,  633,  634,  635,
  636,  637,  638,  639,  640,   41,   -1,   -1,   44,   -1,
  646,   -1,  648,  649,  650,  651,  652,  653,   -1,  655,
   -1,   -1,   -1,   -1,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,
  676,  677,  678,  679,  680,  681,  682,  683,   -1,  685,
  686,  687,  688,  689,  690,  691,  692,  693,  694,  695,
  696,   -1,  698,  699,  700,   -1,  702,   -1,   -1,   -1,
  706,  707,  708,  709,  710,  711,  712,  713,  714,  715,
  716,  717,  718,    0,  720,  721,   -1,   -1,   -1,   -1,
   -1,  727,  728,  729,  730,  731,  732,  733,  734,  735,
  736,  737,  738,  739,  740,  741,  742,  743,  744,   -1,
   -1,  747,   -1,  749,  750,  751,  752,  753,  754,  755,
  756,  757,   -1,   40,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   58,   59,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,
  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,  266,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,  412,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,
   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,
   -1,  458,  459,  460,  461,  462,  463,  464,  465,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,
   -1,  478,  479,  480,   -1,   -1,  602,   -1,  485,  486,
  487,  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,
   -1,   -1,  499,  500,   -1,   -1,  503,  504,  505,  506,
  507,  508,  509,  510,  511,   -1,  513,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,  540,  541,  542,  543,   -1,  545,  546,
  547,  548,  549,  550,   -1,  552,  553,  554,  555,   -1,
  557,   -1,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,  573,  574,  575,  576,
   -1,  578,  579,  580,  581,   -1,  583,  584,  585,  586,
  587,   -1,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,  614,  615,  616,
  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,
  627,  628,  629,   -1,   -1,  632,  633,  634,  635,  636,
  637,  638,  639,  640,   41,   -1,   -1,   -1,   -1,  646,
   -1,  648,  649,  650,  651,  652,  653,   -1,  655,   -1,
   -1,   -1,   -1,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,
  677,  678,  679,  680,  681,  682,  683,   -1,  685,  686,
  687,  688,  689,  690,  691,  692,  693,  694,  695,  696,
   -1,  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,
  707,  708,  709,  710,  711,  712,  713,  714,  715,  716,
  717,  718,    0,  720,  721,   -1,   -1,   -1,   -1,   -1,
  727,  728,  729,  730,  731,  732,  733,  734,  735,  736,
  737,  738,  739,  740,  741,  742,  743,  744,   -1,   -1,
  747,   -1,  749,  750,  751,  752,  753,  754,  755,  756,
  757,   -1,   40,   41,   42,   43,   44,   45,   46,   47,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   58,   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  312,   -1,   -1,   -1,   -1,
   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,  257,
   -1,  259,   -1,   -1,  262,   -1,  264,  265,  266,   -1,
  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,
   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,  412,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,  302,  303,  304,  305,  306,   -1,
   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,
  318,  319,  320,   -1,  322,  323,  324,  325,  326,  327,
  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,
  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,
  368,   -1,  370,  371,  372,   -1,  374,  375,  376,  377,
  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,
  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,
   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,
  458,  459,  460,  461,  462,  463,  464,  465,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,
  478,  479,  480,   -1,   -1,  602,   -1,  485,  486,  487,
  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,
   -1,  499,  500,   -1,   -1,  503,  504,  505,  506,  507,
  508,  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,  540,  541,  542,  543,   -1,  545,  546,  547,
  548,  549,  550,   -1,  552,  553,  554,  555,   -1,  557,
   -1,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,  573,  574,  575,  576,   -1,
  578,  579,  580,  581,   -1,  583,  584,  585,  586,  587,
   -1,  589,  590,  591,  592,  593,  594,  595,  596,  597,
  598,  599,  600,  601,  602,  603,  604,  605,  606,  607,
  608,  609,  610,  611,  612,  613,  614,  615,  616,  617,
   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,
  628,  629,   -1,   -1,  632,  633,  634,  635,  636,  637,
  638,  639,  640,   41,   -1,   -1,   -1,   -1,  646,   -1,
  648,  649,  650,  651,  652,  653,   -1,  655,   -1,   -1,
   -1,   -1,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,
  678,  679,  680,  681,  682,  683,   -1,  685,  686,  687,
  688,  689,  690,  691,  692,  693,  694,  695,  696,   -1,
  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,
  708,  709,  710,  711,  712,  713,  714,  715,  716,  717,
  718,    0,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,
  728,  729,  730,  731,  732,  733,  734,  735,  736,  737,
  738,  739,  740,  741,  742,  743,  744,   -1,   -1,  747,
   -1,  749,  750,  751,  752,  753,  754,  755,  756,  757,
   -1,   40,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,
   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,
   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,  266,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,  412,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,
  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,  458,
  459,  460,  461,  462,  463,  464,  465,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,
  479,  480,   -1,   -1,  602,   -1,  485,  486,  487,  488,
  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,
  499,  500,   -1,   -1,  503,  504,  505,  506,  507,  508,
  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,  540,  541,  542,  543,   -1,  545,  546,  547,  548,
  549,  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,  573,  574,  575,  576,   -1,  578,
  579,  580,  581,   -1,  583,  584,  585,  586,  587,   -1,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,  614,  615,  616,  617,   -1,
  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,
  629,   -1,   -1,  632,  633,  634,  635,  636,  637,  638,
  639,  640,   41,   -1,   -1,   -1,   -1,  646,   -1,  648,
  649,  650,  651,  652,  653,   -1,  655,   -1,   -1,   -1,
   -1,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,
  679,  680,  681,  682,  683,   -1,  685,  686,  687,  688,
  689,  690,  691,  692,  693,  694,  695,  696,   -1,  698,
  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,
  709,  710,  711,  712,  713,  714,  715,  716,  717,  718,
    0,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,
  729,  730,  731,  732,  733,  734,  735,  736,  737,  738,
  739,  740,  741,  742,  743,  744,   -1,   -1,  747,   -1,
  749,  750,  751,  752,  753,  754,  755,  756,  757,   -1,
   40,   41,   42,   43,   44,   45,   46,   47,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   59,
   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,
   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,
   -1,   -1,  371,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,  262,   -1,  264,  265,  266,   -1,  268,  269,
   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,
  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,   -1,   -1,  412,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,
   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,
  320,   -1,  322,  323,  324,  325,  326,  327,  328,   -1,
   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,
  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,
  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,
  370,  371,  372,   -1,  374,  375,  376,  377,  378,   -1,
  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,  419,
  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,
   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,
   -1,  451,  452,  453,  454,   -1,  456,   -1,  458,  459,
  460,  461,  462,  463,  464,  465,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,
  480,   -1,   -1,  602,   -1,  485,  486,  487,  488,  489,
   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,
  500,   -1,   -1,  503,  504,  505,  506,  507,  508,  509,
  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
  540,  541,  542,  543,   -1,  545,  546,  547,  548,  549,
  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,  573,  574,  575,  576,   -1,  578,  579,
  580,  581,   -1,  583,  584,  585,  586,  587,   -1,  589,
  590,  591,  592,  593,  594,  595,  596,  597,  598,  599,
  600,  601,  602,  603,  604,  605,  606,  607,  608,  609,
  610,  611,  612,  613,  614,  615,  616,  617,   -1,  619,
  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,  629,
   -1,   -1,  632,  633,  634,  635,  636,  637,  638,  639,
  640,   41,   -1,   -1,   -1,   -1,  646,   -1,  648,  649,
  650,  651,  652,  653,   -1,  655,   -1,   -1,   -1,   -1,
   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,  679,
  680,  681,  682,  683,   -1,  685,  686,  687,  688,  689,
  690,  691,  692,  693,  694,  695,  696,   -1,  698,  699,
  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,  709,
  710,  711,  712,  713,  714,  715,  716,  717,  718,    0,
  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,
  730,  731,  732,  733,  734,  735,  736,  737,  738,  739,
  740,  741,  742,  743,  744,   -1,   -1,  747,   -1,  749,
  750,  751,  752,  753,  754,  755,  756,  757,   -1,   40,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   59,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,
   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,
   -1,  371,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,  266,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,  412,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,
   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,
  451,  452,  453,  454,   -1,  456,   -1,  458,  459,  460,
  461,  462,  463,  464,  465,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,  480,
   -1,   -1,  602,   -1,  485,  486,  487,  488,  489,   -1,
  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,  500,
   -1,   -1,  503,  504,  505,  506,  507,  508,  509,  510,
  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,  540,
  541,  542,  543,   -1,  545,  546,  547,  548,  549,  550,
   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,  573,  574,  575,  576,   -1,  578,  579,  580,
  581,   -1,  583,  584,  585,  586,  587,   -1,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,  614,  615,  616,  617,   -1,  619,  620,
   -1,   -1,   -1,  624,  625,  626,  627,  628,  629,   -1,
   -1,  632,  633,  634,  635,  636,  637,  638,  639,  640,
   41,   -1,   -1,   -1,   -1,  646,   -1,  648,  649,  650,
  651,  652,  653,   -1,  655,   -1,   -1,   -1,   -1,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  672,  673,   -1,  675,  676,  677,  678,  679,  680,
  681,  682,  683,   -1,  685,  686,  687,  688,  689,  690,
  691,  692,  693,  694,  695,  696,   -1,  698,  699,  700,
   -1,  702,   -1,   -1,   -1,  706,  707,  708,  709,  710,
  711,  712,  713,  714,  715,  716,  717,  718,    0,  720,
  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,  730,
  731,  732,  733,  734,  735,  736,  737,  738,  739,  740,
  741,  742,  743,  744,   -1,   -1,  747,   -1,  749,  750,
  751,  752,  753,  754,  755,  756,  757,   -1,   40,   41,
   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   58,   59,   60,   61,
   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,
   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,
   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,
   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,
  262,   -1,  264,  265,  266,   -1,  268,  269,   -1,  271,
   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
   -1,  412,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,
  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,
  322,  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,
  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,
  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,
  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,
  372,   -1,  374,  375,  376,  377,  378,   -1,  380,  381,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,
  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,   -1,
   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,  451,
  452,  453,  454,   -1,  456,   -1,  458,  459,  460,  461,
  462,  463,  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  475,  476,   -1,  478,  479,  480,   -1,
   -1,  602,   -1,  485,  486,  487,  488,  489,   -1,  491,
   -1,   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,
   -1,  503,  504,  505,  506,  507,  508,  509,  510,  511,
   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,  540,  541,
  542,  543,   -1,  545,  546,  547,  548,  549,  550,   -1,
  552,  553,  554,  555,   -1,  557,   -1,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,  573,  574,  575,  576,   -1,  578,  579,  580,  581,
   -1,  583,  584,  585,  586,  587,   -1,  589,  590,  591,
  592,  593,  594,  595,  596,  597,  598,  599,  600,  601,
  602,  603,  604,  605,  606,  607,  608,  609,  610,  611,
  612,  613,  614,  615,  616,  617,   -1,  619,  620,   -1,
   -1,   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,
  632,  633,  634,  635,  636,  637,  638,  639,  640,   41,
   -1,   -1,   -1,   -1,  646,   -1,  648,  649,  650,  651,
  652,  653,   -1,  655,   -1,   -1,   -1,   -1,   60,   61,
   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  672,  673,   -1,  675,  676,  677,  678,  679,  680,  681,
  682,  683,   -1,  685,  686,  687,  688,  689,  690,  691,
  692,  693,  694,  695,  696,   -1,  698,  699,  700,   -1,
  702,   -1,   -1,   -1,  706,  707,  708,  709,  710,  711,
  712,  713,  714,  715,  716,  717,  718,    0,  720,  721,
   -1,   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,
  732,  733,  734,  735,  736,  737,  738,  739,  740,  741,
  742,  743,  744,   -1,   -1,  747,   -1,  749,  750,  751,
  752,  753,  754,  755,  756,  757,   -1,   40,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   58,   59,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,
   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,
  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,
   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,  266,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
  412,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,   -1,   -1,   -1,
   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,  451,  452,
  453,  454,   -1,  456,   -1,  458,  459,  460,  461,  462,
  463,  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  475,  476,   -1,  478,  479,  480,   -1,   -1,
  602,   -1,  485,  486,  487,  488,  489,   -1,  491,   -1,
   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,
  503,  504,  505,  506,  507,  508,  509,  510,  511,   -1,
  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,  540,  541,  542,
  543,   -1,  545,  546,  547,  548,  549,  550,   -1,  552,
  553,  554,  555,   -1,  557,   -1,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
  573,  574,  575,  576,   -1,  578,  579,  580,  581,   -1,
  583,  584,  585,  586,  587,   -1,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,
   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,  632,
  633,  634,  635,  636,  637,  638,  639,  640,   41,   -1,
   -1,   -1,   -1,  646,   -1,  648,  649,  650,  651,  652,
  653,   -1,  655,   -1,   -1,   -1,   -1,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,
  673,   -1,  675,  676,  677,  678,  679,  680,  681,  682,
  683,   -1,  685,  686,  687,  688,  689,  690,  691,  692,
  693,  694,  695,  696,   -1,  698,  699,  700,   -1,  702,
   -1,   -1,   -1,  706,  707,  708,  709,  710,  711,  712,
  713,  714,  715,  716,  717,  718,    0,  720,  721,   -1,
   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,
  733,  734,  735,  736,  737,  738,  739,  740,  741,  742,
  743,  744,   -1,   -1,  747,   -1,  749,  750,  751,  752,
  753,  754,  755,  756,  757,   -1,   40,   41,   42,   43,
   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   58,   59,   60,   61,   62,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,
   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,
   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,
  264,  265,  266,   -1,  268,  269,   -1,  271,   -1,   -1,
   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,  412,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,
  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,
  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,
  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,
  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,
   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,
  364,  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,
  374,  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
  434,  435,   -1,  437,  438,  439,   -1,   -1,   -1,   -1,
   -1,  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,
  454,   -1,  456,   -1,  458,  459,  460,  461,  462,  463,
  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  475,  476,   -1,  478,  479,  480,   -1,   -1,  602,
   -1,  485,  486,  487,  488,  489,   -1,  491,   -1,   -1,
  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,  503,
  504,  505,  506,  507,  508,  509,  510,  511,   -1,  513,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,  540,  541,  542,  543,
   -1,  545,  546,  547,  548,  549,  550,   -1,  552,  553,
  554,  555,   -1,  557,   -1,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,  573,
  574,  575,  576,   -1,  578,  579,  580,  581,   -1,  583,
  584,  585,  586,  587,   -1,  589,  590,  591,  592,  593,
  594,  595,  596,  597,  598,  599,  600,  601,  602,  603,
  604,  605,  606,  607,  608,  609,  610,  611,  612,  613,
  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,
  624,  625,  626,  627,  628,  629,   -1,   -1,  632,  633,
  634,  635,  636,  637,  638,  639,  640,   41,   -1,   -1,
   -1,   -1,  646,   -1,  648,  649,  650,  651,  652,  653,
   -1,  655,   -1,   -1,   -1,   -1,   60,   61,   62,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,
   -1,  675,  676,  677,  678,  679,  680,  681,  682,  683,
   -1,  685,  686,  687,  688,  689,  690,  691,  692,  693,
  694,  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,
   -1,   -1,  706,  707,  708,  709,  710,  711,  712,  713,
  714,  715,  716,  717,  718,    0,  720,  721,   -1,   -1,
   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,  733,
  734,  735,  736,  737,  738,  739,  740,  741,  742,  743,
  744,   -1,   -1,  747,   -1,  749,  750,  751,  752,  753,
  754,  755,  756,  757,   -1,   40,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   58,   59,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,
   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,
  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,  266,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,  412,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,   -1,   -1,   -1,   -1,   -1,
  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,
   -1,  456,   -1,  458,  459,  460,  461,  462,  463,  464,
  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  475,  476,   -1,  478,  479,  480,   -1,   -1,  602,   -1,
  485,  486,  487,  488,  489,   -1,  491,   -1,   -1,  494,
  495,   -1,   -1,   -1,  499,  500,   -1,   -1,  503,  504,
  505,  506,  507,  508,  509,  510,  511,   -1,  513,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,  540,  541,  542,  543,   -1,
  545,  546,  547,  548,  549,  550,   -1,  552,  553,  554,
  555,   -1,  557,   -1,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,  573,  574,
  575,  576,   -1,  578,  579,  580,  581,   -1,  583,  584,
  585,  586,  587,   -1,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,  614,
  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,
  625,  626,  627,  628,  629,   -1,   -1,  632,  633,  634,
  635,  636,  637,  638,  639,  640,   41,   -1,   -1,   -1,
   -1,  646,   -1,  648,  649,  650,  651,  652,  653,   -1,
  655,   -1,   -1,   -1,   -1,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,
  675,  676,  677,  678,  679,  680,  681,  682,  683,   -1,
  685,  686,  687,  688,  689,  690,  691,  692,  693,  694,
  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,   -1,
   -1,  706,  707,  708,  709,  710,  711,  712,  713,  714,
  715,  716,  717,  718,    0,  720,  721,   -1,   -1,   -1,
   -1,   -1,  727,  728,  729,  730,  731,  732,  733,  734,
  735,  736,  737,  738,  739,  740,  741,  742,  743,  744,
   -1,   -1,  747,   -1,  749,  750,  751,  752,  753,  754,
  755,  756,  757,   -1,   40,   41,   42,   43,   44,   45,
   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   58,   59,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,
  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,
   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,
  266,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,
   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,  412,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,  305,
  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,
   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,  325,
  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,
   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,
  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,
  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,
   -1,  437,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,
   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,
  456,   -1,  458,  459,  460,  461,  462,  463,  464,  465,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,
  476,   -1,  478,  479,  480,   -1,   -1,  602,   -1,  485,
  486,  487,  488,  489,   -1,  491,   -1,   -1,  494,  495,
   -1,   -1,   -1,  499,  500,   -1,   -1,  503,  504,  505,
  506,  507,  508,  509,  510,  511,   -1,  513,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,  540,  541,  542,  543,   -1,  545,
  546,  547,  548,  549,  550,   -1,  552,  553,  554,  555,
   -1,  557,   -1,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,  573,  574,  575,
  576,   -1,  578,  579,  580,  581,   -1,  583,  584,  585,
  586,  587,   -1,  589,  590,  591,  592,  593,  594,  595,
  596,  597,  598,  599,  600,  601,  602,  603,  604,  605,
  606,  607,  608,  609,  610,  611,  612,  613,  614,  615,
  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,
  626,  627,  628,  629,   -1,   -1,  632,  633,  634,  635,
  636,  637,  638,  639,  640,   41,   -1,   -1,   -1,   -1,
  646,   -1,  648,  649,  650,  651,  652,  653,   -1,  655,
   -1,   -1,   -1,   -1,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,
  676,  677,  678,  679,  680,  681,  682,  683,   -1,  685,
  686,  687,  688,  689,  690,  691,  692,  693,  694,  695,
  696,   -1,  698,  699,  700,   -1,  702,   -1,   -1,   -1,
  706,  707,  708,  709,  710,  711,  712,  713,  714,  715,
  716,  717,  718,    0,  720,  721,   -1,   -1,   -1,   -1,
   -1,  727,  728,  729,  730,  731,  732,  733,  734,  735,
  736,  737,  738,  739,  740,  741,  742,  743,  744,   -1,
   -1,  747,   -1,  749,  750,  751,  752,  753,  754,  755,
  756,  757,   -1,   40,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   58,   59,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,
  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,  266,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,  412,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,
   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,
   -1,  458,  459,  460,  461,  462,  463,  464,  465,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,
   -1,  478,  479,  480,   -1,   -1,  602,   -1,  485,  486,
  487,  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,
   -1,   -1,  499,  500,   -1,   -1,  503,  504,  505,  506,
  507,  508,  509,  510,  511,   -1,  513,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,  540,  541,  542,  543,   -1,  545,  546,
  547,  548,  549,  550,   -1,  552,  553,  554,  555,   -1,
  557,   -1,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,  573,  574,  575,  576,
   -1,  578,  579,  580,  581,   -1,  583,  584,  585,  586,
  587,   -1,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,  614,  615,  616,
  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,
  627,  628,  629,   -1,   -1,  632,  633,  634,  635,  636,
  637,  638,  639,  640,   41,   -1,   -1,   -1,   -1,  646,
   -1,  648,  649,  650,  651,  652,  653,   -1,  655,   -1,
   -1,   -1,   -1,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,
  677,  678,  679,  680,  681,  682,  683,   -1,  685,  686,
  687,  688,  689,  690,  691,  692,  693,  694,  695,  696,
   -1,  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,
  707,  708,  709,  710,  711,  712,  713,  714,  715,  716,
  717,  718,    0,  720,  721,   -1,   -1,   -1,   -1,   -1,
  727,  728,  729,  730,  731,  732,  733,  734,  735,  736,
  737,  738,  739,  740,  741,  742,  743,  744,   -1,   -1,
  747,   -1,  749,  750,  751,  752,  753,  754,  755,  756,
  757,   -1,   40,   41,   42,   43,   44,   45,   46,   47,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   58,   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,  257,
   -1,  259,   -1,   -1,  262,   -1,  264,  265,  266,   -1,
  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,
   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,  412,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,  302,  303,  304,  305,  306,   -1,
   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,
  318,  319,  320,   -1,  322,  323,  324,  325,  326,  327,
  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,
  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,
  368,   -1,  370,  371,  372,   -1,  374,  375,  376,  377,
  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,
  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,
   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,
  458,  459,  460,  461,  462,  463,  464,  465,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,
  478,  479,  480,   -1,   -1,  602,   -1,  485,  486,  487,
  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,
   -1,  499,  500,   -1,   -1,  503,  504,  505,  506,  507,
  508,  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,  540,  541,  542,  543,   -1,  545,  546,  547,
  548,  549,  550,   -1,  552,  553,  554,  555,   -1,  557,
   -1,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,  573,  574,  575,  576,   -1,
  578,  579,  580,  581,   -1,  583,  584,  585,  586,  587,
   -1,  589,  590,  591,  592,  593,  594,  595,  596,  597,
  598,  599,  600,  601,  602,  603,  604,  605,  606,  607,
  608,  609,  610,  611,  612,  613,  614,  615,  616,  617,
   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,
  628,  629,   -1,   -1,  632,  633,  634,  635,  636,  637,
  638,  639,  640,   41,   -1,   -1,   -1,   -1,  646,   -1,
  648,  649,  650,  651,  652,  653,   -1,  655,   -1,   -1,
   -1,   -1,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,
  678,  679,  680,  681,  682,  683,   -1,  685,  686,  687,
  688,  689,  690,  691,  692,  693,  694,  695,  696,   -1,
  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,
  708,  709,  710,  711,  712,  713,  714,  715,  716,  717,
  718,    0,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,
  728,  729,  730,  731,  732,  733,  734,  735,  736,  737,
  738,  739,  740,  741,  742,  743,  744,   -1,   -1,  747,
   -1,  749,  750,  751,  752,  753,  754,  755,  756,  757,
   -1,   40,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,
   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,
   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,  266,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,  412,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,
  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,  458,
  459,  460,  461,  462,  463,  464,  465,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,
  479,  480,   -1,   -1,  602,   -1,  485,  486,  487,  488,
  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,
  499,  500,   -1,   -1,  503,  504,  505,  506,  507,  508,
  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,  540,  541,  542,  543,   -1,  545,  546,  547,  548,
  549,  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,  573,  574,  575,  576,   -1,  578,
  579,  580,  581,   -1,  583,  584,  585,  586,  587,   -1,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,  614,  615,  616,  617,   -1,
  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,
  629,   -1,   -1,  632,  633,  634,  635,  636,  637,  638,
  639,  640,   41,   -1,   -1,   -1,   -1,  646,   -1,  648,
  649,  650,  651,  652,  653,   -1,  655,   -1,   -1,   -1,
   -1,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,
  679,  680,  681,  682,  683,   -1,  685,  686,  687,  688,
  689,  690,  691,  692,  693,  694,  695,  696,   -1,  698,
  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,
  709,  710,  711,  712,  713,  714,  715,  716,  717,  718,
    0,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,
  729,  730,  731,  732,  733,  734,  735,  736,  737,  738,
  739,  740,  741,  742,  743,  744,   -1,   -1,  747,   -1,
  749,  750,  751,  752,  753,  754,  755,  756,  757,   -1,
   40,   41,   42,   43,   44,   45,   46,   47,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   59,
   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,
   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,
   -1,   -1,  371,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,  262,   -1,  264,  265,  266,   -1,  268,  269,
   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,
  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,   -1,   -1,  412,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,
   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,
  320,   -1,  322,  323,  324,  325,  326,  327,  328,   -1,
   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,
  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,
  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,
  370,  371,  372,   -1,  374,  375,  376,  377,  378,   -1,
  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,  419,
  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,
   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,
   -1,  451,  452,  453,  454,   -1,  456,   -1,  458,  459,
  460,  461,  462,  463,  464,  465,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,
  480,   -1,   -1,  602,   -1,  485,  486,  487,  488,  489,
   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,
  500,   -1,   -1,  503,  504,  505,  506,  507,  508,  509,
  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
  540,  541,  542,  543,   -1,  545,  546,  547,  548,  549,
  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,  573,  574,  575,  576,   -1,  578,  579,
  580,  581,   -1,  583,  584,  585,  586,  587,   -1,  589,
  590,  591,  592,  593,  594,  595,  596,  597,  598,  599,
  600,  601,  602,  603,  604,  605,  606,  607,  608,  609,
  610,  611,  612,  613,  614,  615,  616,  617,   -1,  619,
  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,  629,
   -1,   -1,  632,  633,  634,  635,  636,  637,  638,  639,
  640,   41,   -1,   -1,   -1,   -1,  646,   -1,  648,  649,
  650,  651,  652,  653,   -1,  655,   -1,   -1,   -1,   -1,
   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,  679,
  680,  681,  682,  683,   -1,  685,  686,  687,  688,  689,
  690,  691,  692,  693,  694,  695,  696,   -1,  698,  699,
  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,  709,
  710,  711,  712,  713,  714,  715,  716,  717,  718,    0,
  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,
  730,  731,  732,  733,  734,  735,  736,  737,  738,  739,
  740,  741,  742,  743,  744,   -1,   -1,  747,   -1,  749,
  750,  751,  752,  753,  754,  755,  756,  757,   -1,   40,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   59,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,
   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,
   -1,  371,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,  266,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,  412,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,
   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,
  451,  452,  453,  454,   -1,  456,   -1,  458,  459,  460,
  461,  462,  463,  464,  465,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,  480,
   -1,   -1,  602,   -1,  485,  486,  487,  488,  489,   -1,
  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,  500,
   -1,   -1,  503,  504,  505,  506,  507,  508,  509,  510,
  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,  540,
  541,  542,  543,   -1,  545,  546,  547,  548,  549,  550,
   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,  573,  574,  575,  576,   -1,  578,  579,  580,
  581,   -1,  583,  584,  585,  586,  587,   -1,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,  614,  615,  616,  617,   -1,  619,  620,
   -1,   -1,   -1,  624,  625,  626,  627,  628,  629,   -1,
   -1,  632,  633,  634,  635,  636,  637,  638,  639,  640,
   41,   -1,   -1,   -1,   -1,  646,   -1,  648,  649,  650,
  651,  652,  653,   -1,  655,   -1,   -1,   -1,   -1,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  672,  673,   -1,  675,  676,  677,  678,  679,  680,
  681,  682,  683,   -1,  685,  686,  687,  688,  689,  690,
  691,  692,  693,  694,  695,  696,   -1,  698,  699,  700,
   -1,  702,   -1,   -1,   -1,  706,  707,  708,  709,  710,
  711,  712,  713,  714,  715,  716,  717,  718,    0,  720,
  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,  730,
  731,  732,  733,  734,  735,  736,  737,  738,  739,  740,
  741,  742,  743,  744,   -1,   -1,  747,   -1,  749,  750,
  751,  752,  753,  754,  755,  756,  757,   -1,   40,   41,
   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   58,   59,   60,   61,
   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,
   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,
   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,
   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,
  262,   -1,  264,  265,  266,   -1,  268,  269,   -1,  271,
   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
   -1,  412,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,
  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,
  322,  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,
  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,
  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,
  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,
  372,   -1,  374,  375,  376,  377,  378,   -1,  380,  381,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,
  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,   -1,
   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,  451,
  452,  453,  454,   -1,  456,   -1,  458,  459,  460,  461,
  462,  463,  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  475,  476,   -1,  478,  479,  480,   -1,
   -1,  602,   -1,  485,  486,  487,  488,  489,   -1,  491,
   -1,   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,
   -1,  503,  504,  505,  506,  507,  508,  509,  510,  511,
   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,  540,  541,
  542,  543,   -1,  545,  546,  547,  548,  549,  550,   -1,
  552,  553,  554,  555,   -1,  557,   -1,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,  573,  574,  575,  576,   -1,  578,  579,  580,  581,
   -1,  583,  584,  585,  586,  587,   -1,  589,  590,  591,
  592,  593,  594,  595,  596,  597,  598,  599,  600,  601,
  602,  603,  604,  605,  606,  607,  608,  609,  610,  611,
  612,  613,  614,  615,  616,  617,   -1,  619,  620,   -1,
   -1,   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,
  632,  633,  634,  635,  636,  637,  638,  639,  640,   41,
   -1,   -1,   -1,   -1,  646,   -1,  648,  649,  650,  651,
  652,  653,   -1,  655,   -1,   -1,   -1,   -1,   60,   61,
   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  672,  673,   -1,  675,  676,  677,  678,  679,  680,  681,
  682,  683,   -1,  685,  686,  687,  688,  689,  690,  691,
  692,  693,  694,  695,  696,   -1,  698,  699,  700,   -1,
  702,   -1,   -1,   -1,  706,  707,  708,  709,  710,  711,
  712,  713,  714,  715,  716,  717,  718,    0,  720,  721,
   -1,   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,
  732,  733,  734,  735,  736,  737,  738,  739,  740,  741,
  742,  743,  744,   -1,   -1,  747,   -1,  749,  750,  751,
  752,  753,  754,  755,  756,  757,   -1,   40,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   58,   59,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,
   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,
  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,
   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,  266,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
  412,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,   -1,   -1,   -1,
   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,  451,  452,
  453,  454,   -1,  456,   -1,  458,  459,  460,  461,  462,
  463,  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  475,  476,   -1,  478,  479,  480,   -1,   -1,
  602,   -1,  485,  486,  487,  488,  489,   -1,  491,   -1,
   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,
  503,  504,  505,  506,  507,  508,  509,  510,  511,   -1,
  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,  540,  541,  542,
  543,   -1,  545,  546,  547,  548,  549,  550,   -1,  552,
  553,  554,  555,   -1,  557,   -1,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
  573,  574,  575,  576,   -1,  578,  579,  580,  581,   -1,
  583,  584,  585,  586,  587,   -1,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,
   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,  632,
  633,  634,  635,  636,  637,  638,  639,  640,   41,   -1,
   -1,   -1,   -1,  646,   -1,  648,  649,  650,  651,  652,
  653,   -1,  655,   -1,   -1,   -1,   -1,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,
  673,   -1,  675,  676,  677,  678,  679,  680,  681,  682,
  683,   -1,  685,  686,  687,  688,  689,  690,  691,  692,
  693,  694,  695,  696,   -1,  698,  699,  700,   -1,  702,
   -1,   -1,   -1,  706,  707,  708,  709,  710,  711,  712,
  713,  714,  715,  716,  717,  718,    0,  720,  721,   -1,
   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,
  733,  734,  735,  736,  737,  738,  739,  740,  741,  742,
  743,  744,   -1,   -1,  747,   -1,  749,  750,  751,  752,
  753,  754,  755,  756,  757,   -1,   40,   41,   42,   43,
   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   58,   59,   60,   61,   62,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,
   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,
   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,
  264,  265,  266,   -1,  268,  269,   -1,  271,   -1,   -1,
   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,  412,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,
  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,
  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,
  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,
  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,
   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,
  364,  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,
  374,  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
  434,  435,   -1,  437,  438,  439,   -1,   -1,   -1,   -1,
   -1,  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,
  454,   -1,  456,   -1,  458,  459,  460,  461,  462,  463,
  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  475,  476,   -1,  478,  479,  480,   -1,   -1,  602,
   -1,  485,  486,  487,  488,  489,   -1,  491,   -1,   -1,
  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,  503,
  504,  505,  506,  507,  508,  509,  510,  511,   -1,  513,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,  540,  541,  542,  543,
   -1,  545,  546,  547,  548,  549,  550,   -1,  552,  553,
  554,  555,   -1,  557,   -1,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,  573,
  574,  575,  576,   -1,  578,  579,  580,  581,   -1,  583,
  584,  585,  586,  587,   -1,  589,  590,  591,  592,  593,
  594,  595,  596,  597,  598,  599,  600,  601,  602,  603,
  604,  605,  606,  607,  608,  609,  610,  611,  612,  613,
  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,
  624,  625,  626,  627,  628,  629,   -1,   -1,  632,  633,
  634,  635,  636,  637,  638,  639,  640,   41,   -1,   -1,
   -1,   -1,  646,   -1,  648,  649,  650,  651,  652,  653,
   -1,  655,   -1,   -1,   -1,   -1,   60,   61,   62,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,
   -1,  675,  676,  677,  678,  679,  680,  681,  682,  683,
   -1,  685,  686,  687,  688,  689,  690,  691,  692,  693,
  694,  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,
   -1,   -1,  706,  707,  708,  709,  710,  711,  712,  713,
  714,  715,  716,  717,  718,    0,  720,  721,   -1,   -1,
   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,  733,
  734,  735,  736,  737,  738,  739,  740,  741,  742,  743,
  744,   -1,   -1,  747,   -1,  749,  750,  751,  752,  753,
  754,  755,  756,  757,   -1,   40,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   58,   59,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,
   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,
  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,  266,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,  412,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,   -1,   -1,   -1,   -1,   -1,
  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,
   -1,  456,   -1,  458,  459,  460,  461,  462,  463,  464,
  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  475,  476,   -1,  478,  479,  480,   -1,   -1,  602,   -1,
  485,  486,  487,  488,  489,   -1,  491,   -1,   -1,  494,
  495,   -1,   -1,   -1,  499,  500,   -1,   -1,  503,  504,
  505,  506,  507,  508,  509,  510,  511,   -1,  513,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,  540,  541,  542,  543,   -1,
  545,  546,  547,  548,  549,  550,   -1,  552,  553,  554,
  555,   -1,  557,   -1,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,  573,  574,
  575,  576,   -1,  578,  579,  580,  581,   -1,  583,  584,
  585,  586,  587,   -1,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,  614,
  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,
  625,  626,  627,  628,  629,   -1,   -1,  632,  633,  634,
  635,  636,  637,  638,  639,  640,   41,   -1,   -1,   -1,
   -1,  646,   -1,  648,  649,  650,  651,  652,  653,   -1,
  655,   -1,   -1,   -1,   -1,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,
  675,  676,  677,  678,  679,  680,  681,  682,  683,   -1,
  685,  686,  687,  688,  689,  690,  691,  692,  693,  694,
  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,   -1,
   -1,  706,  707,  708,  709,  710,  711,  712,  713,  714,
  715,  716,  717,  718,    0,  720,  721,   -1,   -1,   -1,
   -1,   -1,  727,  728,  729,  730,  731,  732,  733,  734,
  735,  736,  737,  738,  739,  740,  741,  742,  743,  744,
   -1,   -1,  747,   -1,  749,  750,  751,  752,  753,  754,
  755,  756,  757,   -1,   40,   41,   42,   43,   44,   45,
   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   58,   59,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,
  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,
   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,
  266,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,
   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,  412,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,  305,
  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,
   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,  325,
  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,
   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,
  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,
  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,
   -1,  437,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,
   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,
  456,   -1,  458,  459,  460,  461,  462,  463,  464,  465,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,
  476,   -1,  478,  479,  480,   -1,   -1,  602,   -1,  485,
  486,  487,  488,  489,   -1,  491,   -1,   -1,  494,  495,
   -1,   -1,   -1,  499,  500,   -1,   -1,  503,  504,  505,
  506,  507,  508,  509,  510,  511,   -1,  513,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,  540,  541,  542,  543,   -1,  545,
  546,  547,  548,  549,  550,   -1,  552,  553,  554,  555,
   -1,  557,   -1,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,  573,  574,  575,
  576,   -1,  578,  579,  580,  581,   -1,  583,  584,  585,
  586,  587,   -1,  589,  590,  591,  592,  593,  594,  595,
  596,  597,  598,  599,  600,  601,  602,  603,  604,  605,
  606,  607,  608,  609,  610,  611,  612,  613,  614,  615,
  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,
  626,  627,  628,  629,   -1,   -1,  632,  633,  634,  635,
  636,  637,  638,  639,  640,   41,   -1,   -1,   -1,   -1,
  646,   -1,  648,  649,  650,  651,  652,  653,   -1,  655,
   -1,   -1,   -1,   -1,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,
  676,  677,  678,  679,  680,  681,  682,  683,   -1,  685,
  686,  687,  688,  689,  690,  691,  692,  693,  694,  695,
  696,   -1,  698,  699,  700,   -1,  702,   -1,   -1,   -1,
  706,  707,  708,  709,  710,  711,  712,  713,  714,  715,
  716,  717,  718,    0,  720,  721,   -1,   -1,   -1,   -1,
   -1,  727,  728,  729,  730,  731,  732,  733,  734,  735,
  736,  737,  738,  739,  740,  741,  742,  743,  744,   -1,
   -1,  747,   -1,  749,  750,  751,  752,  753,  754,  755,
  756,  757,   -1,   40,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   58,   59,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,
  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,  266,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,  412,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,
   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,
   -1,  458,  459,  460,  461,  462,  463,  464,  465,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,
   -1,  478,  479,  480,   -1,   -1,  602,   -1,  485,  486,
  487,  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,
   -1,   -1,  499,  500,   -1,   -1,  503,  504,  505,  506,
  507,  508,  509,  510,  511,   -1,  513,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,  540,  541,  542,  543,   -1,  545,  546,
  547,  548,  549,  550,   -1,  552,  553,  554,  555,   -1,
  557,   -1,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,  573,  574,  575,  576,
   -1,  578,  579,  580,  581,   -1,  583,  584,  585,  586,
  587,   -1,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,  614,  615,  616,
  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,
  627,  628,  629,   -1,   -1,  632,  633,  634,  635,  636,
  637,  638,  639,  640,   41,   -1,   -1,   -1,   -1,  646,
   -1,  648,  649,  650,  651,  652,  653,   -1,  655,   -1,
   -1,   -1,   -1,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,
  677,  678,  679,  680,  681,  682,  683,   -1,  685,  686,
  687,  688,  689,  690,  691,  692,  693,  694,  695,  696,
   -1,  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,
  707,  708,  709,  710,  711,  712,  713,  714,  715,  716,
  717,  718,    0,  720,  721,   -1,   -1,   -1,   -1,   -1,
  727,  728,  729,  730,  731,  732,  733,  734,  735,  736,
  737,  738,  739,  740,  741,  742,  743,  744,   -1,   -1,
  747,   -1,  749,  750,  751,  752,  753,  754,  755,  756,
  757,   -1,   40,   41,   42,   43,   44,   45,   46,   47,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   58,   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,  257,
   -1,  259,   -1,   -1,  262,   -1,  264,  265,  266,   -1,
  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,
   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,  412,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,  302,  303,  304,  305,  306,   -1,
   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,
  318,  319,  320,   -1,  322,  323,  324,  325,  326,  327,
  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,
  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,
  368,   -1,  370,  371,  372,   -1,  374,  375,  376,  377,
  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,
  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,
   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,
  458,  459,  460,  461,  462,  463,  464,  465,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,
  478,  479,  480,   -1,   -1,  602,   -1,  485,  486,  487,
  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,
   -1,  499,  500,   -1,   -1,  503,  504,  505,  506,  507,
  508,  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,  540,  541,  542,  543,   -1,  545,  546,  547,
  548,  549,  550,   -1,  552,  553,  554,  555,   -1,  557,
   -1,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,  573,  574,  575,  576,   -1,
  578,  579,  580,  581,   -1,  583,  584,  585,  586,  587,
   -1,  589,  590,  591,  592,  593,  594,  595,  596,  597,
  598,  599,  600,  601,  602,  603,  604,  605,  606,  607,
  608,  609,  610,  611,  612,  613,  614,  615,  616,  617,
   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,
  628,  629,   -1,   -1,  632,  633,  634,  635,  636,  637,
  638,  639,  640,   41,   -1,   -1,   -1,   -1,  646,   -1,
  648,  649,  650,  651,  652,  653,   -1,  655,   -1,   -1,
   -1,   -1,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,
  678,  679,  680,  681,  682,  683,   -1,  685,  686,  687,
  688,  689,  690,  691,  692,  693,  694,  695,  696,   -1,
  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,
  708,  709,  710,  711,  712,  713,  714,  715,  716,  717,
  718,    0,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,
  728,  729,  730,  731,  732,  733,  734,  735,  736,  737,
  738,  739,  740,  741,  742,  743,  744,   -1,   -1,  747,
   -1,  749,  750,  751,  752,  753,  754,  755,  756,  757,
   -1,   40,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,
   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,
   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,  266,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,  412,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,
  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,  458,
  459,  460,  461,  462,  463,  464,  465,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,
  479,  480,   -1,   -1,  602,   -1,  485,  486,  487,  488,
  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,
  499,  500,   -1,   -1,  503,  504,  505,  506,  507,  508,
  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,  540,  541,  542,  543,   -1,  545,  546,  547,  548,
  549,  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,  573,  574,  575,  576,   -1,  578,
  579,  580,  581,   -1,  583,  584,  585,  586,  587,   -1,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,  614,  615,  616,  617,   -1,
  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,
  629,   -1,   -1,  632,  633,  634,  635,  636,  637,  638,
  639,  640,   41,   -1,   -1,   -1,   -1,  646,   -1,  648,
  649,  650,  651,  652,  653,   -1,  655,   -1,   -1,   -1,
   -1,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,
  679,  680,  681,  682,  683,   -1,  685,  686,  687,  688,
  689,  690,  691,  692,  693,  694,  695,  696,   -1,  698,
  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,
  709,  710,  711,  712,  713,  714,  715,  716,  717,  718,
    0,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,
  729,  730,  731,  732,  733,  734,  735,  736,  737,  738,
  739,  740,  741,  742,  743,  744,   -1,   -1,  747,   -1,
  749,  750,  751,  752,  753,  754,  755,  756,  757,   -1,
   40,   41,   42,   43,   44,   45,   46,   47,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   59,
   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,
   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,
   -1,   -1,  371,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,  262,   -1,  264,  265,  266,   -1,  268,  269,
   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,
  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,   -1,   -1,  412,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,
   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,
  320,   -1,  322,  323,  324,  325,  326,  327,  328,   -1,
   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,
  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,
  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,
  370,  371,  372,   -1,  374,  375,  376,  377,  378,   -1,
  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,  419,
  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,
   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,
   -1,  451,  452,  453,  454,   -1,  456,   -1,  458,  459,
  460,  461,  462,  463,  464,  465,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,
  480,   -1,   -1,  602,   -1,  485,  486,  487,  488,  489,
   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,
  500,   -1,   -1,  503,  504,  505,  506,  507,  508,  509,
  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
  540,  541,  542,  543,   -1,  545,  546,  547,  548,  549,
  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,  573,  574,  575,  576,   -1,  578,  579,
  580,  581,   -1,  583,  584,  585,  586,  587,   -1,  589,
  590,  591,  592,  593,  594,  595,  596,  597,  598,  599,
  600,  601,  602,  603,  604,  605,  606,  607,  608,  609,
  610,  611,  612,  613,  614,  615,  616,  617,   -1,  619,
  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,  629,
   -1,   -1,  632,  633,  634,  635,  636,  637,  638,  639,
  640,   41,   -1,   -1,   -1,   -1,  646,   -1,  648,  649,
  650,  651,  652,  653,   -1,  655,   -1,   -1,   -1,   -1,
   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,  679,
  680,  681,  682,  683,   -1,  685,  686,  687,  688,  689,
  690,  691,  692,  693,  694,  695,  696,   -1,  698,  699,
  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,  709,
  710,  711,  712,  713,  714,  715,  716,  717,  718,    0,
  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,
  730,  731,  732,  733,  734,  735,  736,  737,  738,  739,
  740,  741,  742,  743,  744,   -1,   -1,  747,   -1,  749,
  750,  751,  752,  753,  754,  755,  756,  757,   -1,   40,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   59,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,
   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,
   -1,  371,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,  266,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,  412,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,
   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,
  451,  452,  453,  454,   -1,  456,   -1,  458,  459,  460,
  461,  462,  463,  464,  465,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,  480,
   -1,   -1,  602,   -1,  485,  486,  487,  488,  489,   -1,
  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,  500,
   -1,   -1,  503,  504,  505,  506,  507,  508,  509,  510,
  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,  540,
  541,  542,  543,   -1,  545,  546,  547,  548,  549,  550,
   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,  573,  574,  575,  576,   -1,  578,  579,  580,
  581,   -1,  583,  584,  585,  586,  587,   -1,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,  614,  615,  616,  617,   -1,  619,  620,
   -1,   -1,   -1,  624,  625,  626,  627,  628,  629,   -1,
   -1,  632,  633,  634,  635,  636,  637,  638,  639,  640,
   41,   -1,   -1,   -1,   -1,  646,   -1,  648,  649,  650,
  651,  652,  653,   -1,  655,   -1,   -1,   -1,   -1,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  672,  673,   -1,  675,  676,  677,  678,  679,  680,
  681,  682,  683,   -1,  685,  686,  687,  688,  689,  690,
  691,  692,  693,  694,  695,  696,   -1,  698,  699,  700,
   -1,  702,   -1,   -1,   -1,  706,  707,  708,  709,  710,
  711,  712,  713,  714,  715,  716,  717,  718,    0,  720,
  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,  730,
  731,  732,  733,  734,  735,  736,  737,  738,  739,  740,
  741,  742,  743,  744,   -1,   -1,  747,   -1,  749,  750,
  751,  752,  753,  754,  755,  756,  757,   -1,   40,   41,
   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   58,   59,   60,   61,
   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,
   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,
   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,
   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,
  262,   -1,  264,  265,  266,   -1,  268,  269,   -1,  271,
   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
   -1,  412,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,
  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,
  322,  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,
  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,
  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,
  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,
  372,   -1,  374,  375,  376,  377,  378,   -1,  380,  381,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,
  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,   -1,
   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,  451,
  452,  453,  454,   -1,  456,   -1,  458,  459,  460,  461,
  462,  463,  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  475,  476,   -1,  478,  479,  480,   -1,
   -1,  602,   -1,  485,  486,  487,  488,  489,   -1,  491,
   -1,   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,
   -1,  503,  504,  505,  506,  507,  508,  509,  510,  511,
   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,  540,  541,
  542,  543,   -1,  545,  546,  547,  548,  549,  550,   -1,
  552,  553,  554,  555,   -1,  557,   -1,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,  573,  574,  575,  576,   -1,  578,  579,  580,  581,
   -1,  583,  584,  585,  586,  587,   -1,  589,  590,  591,
  592,  593,  594,  595,  596,  597,  598,  599,  600,  601,
  602,  603,  604,  605,  606,  607,  608,  609,  610,  611,
  612,  613,  614,  615,  616,  617,   -1,  619,  620,   -1,
   -1,   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,
  632,  633,  634,  635,  636,  637,  638,  639,  640,   41,
   -1,   -1,   -1,   -1,  646,   -1,  648,  649,  650,  651,
  652,  653,   -1,  655,   -1,   -1,   -1,   -1,   60,   61,
   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  672,  673,   -1,  675,  676,  677,  678,  679,  680,  681,
  682,  683,   -1,  685,  686,  687,  688,  689,  690,  691,
  692,  693,  694,  695,  696,   -1,  698,  699,  700,   -1,
  702,   -1,   -1,   -1,  706,  707,  708,  709,  710,  711,
  712,  713,  714,  715,  716,  717,  718,    0,  720,  721,
   -1,   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,
  732,  733,  734,  735,  736,  737,  738,  739,  740,  741,
  742,  743,  744,   -1,   -1,  747,   -1,  749,  750,  751,
  752,  753,  754,  755,  756,  757,   -1,   40,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   58,   59,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,
   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,
  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,
   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,  266,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
  412,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,   -1,   -1,   -1,
   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,  451,  452,
  453,  454,   -1,  456,   -1,  458,  459,  460,  461,  462,
  463,  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  475,  476,   -1,  478,  479,  480,   -1,   -1,
  602,   -1,  485,  486,  487,  488,  489,   -1,  491,   -1,
   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,
  503,  504,  505,  506,  507,  508,  509,  510,  511,   -1,
  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,  540,  541,  542,
  543,   -1,  545,  546,  547,  548,  549,  550,   -1,  552,
  553,  554,  555,   -1,  557,   -1,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
  573,  574,  575,  576,   -1,  578,  579,  580,  581,   -1,
  583,  584,  585,  586,  587,   -1,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,
   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,  632,
  633,  634,  635,  636,  637,  638,  639,  640,   41,   -1,
   -1,   -1,   -1,  646,   -1,  648,  649,  650,  651,  652,
  653,   -1,  655,   -1,   -1,   -1,   -1,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,
  673,   -1,  675,  676,  677,  678,  679,  680,  681,  682,
  683,   -1,  685,  686,  687,  688,  689,  690,  691,  692,
  693,  694,  695,  696,   -1,  698,  699,  700,   -1,  702,
   -1,   -1,   -1,  706,  707,  708,  709,  710,  711,  712,
  713,  714,  715,  716,  717,  718,    0,  720,  721,   -1,
   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,
  733,  734,  735,  736,  737,  738,  739,  740,  741,  742,
  743,  744,   -1,   -1,  747,   -1,  749,  750,  751,  752,
  753,  754,  755,  756,  757,   -1,   40,   41,   42,   43,
   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   58,   59,   60,   61,   62,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,
   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,
   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,
  264,  265,  266,   -1,  268,  269,   -1,  271,   -1,   -1,
   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,  412,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,
  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,
  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,
  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,
  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,
   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,
  364,  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,
  374,  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
  434,  435,   -1,  437,  438,  439,   -1,   -1,   -1,   -1,
   -1,  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,
  454,   -1,  456,   -1,  458,  459,  460,  461,  462,  463,
  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  475,  476,   -1,  478,  479,  480,   -1,   -1,  602,
   -1,  485,  486,  487,  488,  489,   -1,  491,   -1,   -1,
  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,  503,
  504,  505,  506,  507,  508,  509,  510,  511,   -1,  513,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,  540,  541,  542,  543,
   -1,  545,  546,  547,  548,  549,  550,   -1,  552,  553,
  554,  555,   -1,  557,   -1,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,  573,
  574,  575,  576,   -1,  578,  579,  580,  581,   -1,  583,
  584,  585,  586,  587,   -1,  589,  590,  591,  592,  593,
  594,  595,  596,  597,  598,  599,  600,  601,  602,  603,
  604,  605,  606,  607,  608,  609,  610,  611,  612,  613,
  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,
  624,  625,  626,  627,  628,  629,   -1,   -1,  632,  633,
  634,  635,  636,  637,  638,  639,  640,   41,   -1,   -1,
   -1,   -1,  646,   -1,  648,  649,  650,  651,  652,  653,
   -1,  655,   -1,   -1,   -1,   -1,   60,   61,   62,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,
   -1,  675,  676,  677,  678,  679,  680,  681,  682,  683,
   -1,  685,  686,  687,  688,  689,  690,  691,  692,  693,
  694,  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,
   -1,   -1,  706,  707,  708,  709,  710,  711,  712,  713,
  714,  715,  716,  717,  718,    0,  720,  721,   -1,   -1,
   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,  733,
  734,  735,  736,  737,  738,  739,  740,  741,  742,  743,
  744,   -1,   -1,  747,   -1,  749,  750,  751,  752,  753,
  754,  755,  756,  757,   -1,   40,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   58,   59,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,
   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,
  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,  266,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,  412,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,   -1,   -1,   -1,   -1,   -1,
  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,
   -1,  456,   -1,  458,  459,  460,  461,  462,  463,  464,
  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  475,  476,   -1,  478,  479,  480,   -1,   -1,  602,   -1,
  485,  486,  487,  488,  489,   -1,  491,   -1,   -1,  494,
  495,   -1,   -1,   -1,  499,  500,   -1,   -1,  503,  504,
  505,  506,  507,  508,  509,  510,  511,   -1,  513,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,  540,  541,  542,  543,   -1,
  545,  546,  547,  548,  549,  550,   -1,  552,  553,  554,
  555,   -1,  557,   -1,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,  573,  574,
  575,  576,   -1,  578,  579,  580,  581,   -1,  583,  584,
  585,  586,  587,   -1,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,  614,
  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,
  625,  626,  627,  628,  629,   -1,   -1,  632,  633,  634,
  635,  636,  637,  638,  639,  640,   41,   -1,   -1,   -1,
   -1,  646,   -1,  648,  649,  650,  651,  652,  653,   -1,
  655,   -1,   -1,   -1,   -1,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,
  675,  676,  677,  678,  679,  680,  681,  682,  683,   -1,
  685,  686,  687,  688,  689,  690,  691,  692,  693,  694,
  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,   -1,
   -1,  706,  707,  708,  709,  710,  711,  712,  713,  714,
  715,  716,  717,  718,    0,  720,  721,   -1,   -1,   -1,
   -1,   -1,  727,  728,  729,  730,  731,  732,  733,  734,
  735,  736,  737,  738,  739,  740,  741,  742,  743,  744,
   -1,   -1,  747,   -1,  749,  750,  751,  752,  753,  754,
  755,  756,  757,   -1,   40,   41,   42,   43,   44,   45,
   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   58,   59,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,
  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,
   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,
  266,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,
   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,  412,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,  305,
  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,
   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,  325,
  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,
   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,
  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,
  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,
   -1,  437,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,
   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,
  456,   -1,  458,  459,  460,  461,  462,  463,  464,  465,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,
  476,   -1,  478,  479,  480,   -1,   -1,  602,   -1,  485,
  486,  487,  488,  489,   -1,  491,   -1,   -1,  494,  495,
   -1,   -1,   -1,  499,  500,   -1,   -1,  503,  504,  505,
  506,  507,  508,  509,  510,  511,   -1,  513,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,  540,  541,  542,  543,   -1,  545,
  546,  547,  548,  549,  550,   -1,  552,  553,  554,  555,
   -1,  557,   -1,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,  573,  574,  575,
  576,   -1,  578,  579,  580,  581,   -1,  583,  584,  585,
  586,  587,   -1,  589,  590,  591,  592,  593,  594,  595,
  596,  597,  598,  599,  600,  601,  602,  603,  604,  605,
  606,  607,  608,  609,  610,  611,  612,  613,  614,  615,
  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,
  626,  627,  628,  629,   -1,   -1,  632,  633,  634,  635,
  636,  637,  638,  639,  640,   41,   -1,   -1,   -1,   -1,
  646,   -1,  648,  649,  650,  651,  652,  653,   -1,  655,
   -1,   -1,   -1,   -1,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,
  676,  677,  678,  679,  680,  681,  682,  683,   -1,  685,
  686,  687,  688,  689,  690,  691,  692,  693,  694,  695,
  696,   -1,  698,  699,  700,   -1,  702,   -1,   -1,   -1,
  706,  707,  708,  709,  710,  711,  712,  713,  714,  715,
  716,  717,  718,    0,  720,  721,   -1,   -1,   -1,   -1,
   -1,  727,  728,  729,  730,  731,  732,  733,  734,  735,
  736,  737,  738,  739,  740,  741,  742,  743,  744,   -1,
   -1,  747,   -1,  749,  750,  751,  752,  753,  754,  755,
  756,  757,   -1,   40,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   58,   59,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,
  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,  266,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,  412,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,
   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,
   -1,  458,  459,  460,  461,  462,  463,  464,  465,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,
   -1,  478,  479,  480,   -1,   -1,  602,   -1,  485,  486,
  487,  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,
   -1,   -1,  499,  500,   -1,   -1,  503,  504,  505,  506,
  507,  508,  509,  510,  511,   -1,  513,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,  540,  541,  542,  543,   -1,  545,  546,
  547,  548,  549,  550,   -1,  552,  553,  554,  555,   -1,
  557,   -1,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,  573,  574,  575,  576,
   -1,  578,  579,  580,  581,   -1,  583,  584,  585,  586,
  587,   -1,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,  614,  615,  616,
  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,
  627,  628,  629,   -1,   -1,  632,  633,  634,  635,  636,
  637,  638,  639,  640,   41,   -1,   -1,   -1,   -1,  646,
   -1,  648,  649,  650,  651,  652,  653,   -1,  655,   -1,
   -1,   -1,   -1,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,
  677,  678,  679,  680,  681,  682,  683,   -1,  685,  686,
  687,  688,  689,  690,  691,  692,  693,  694,  695,  696,
   -1,  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,
  707,  708,  709,  710,  711,  712,  713,  714,  715,  716,
  717,  718,    0,  720,  721,   -1,   -1,   -1,   -1,   -1,
  727,  728,  729,  730,  731,  732,  733,  734,  735,  736,
  737,  738,  739,  740,  741,  742,  743,  744,   -1,   -1,
  747,   -1,  749,  750,  751,  752,  753,  754,  755,  756,
  757,   -1,   40,   41,   42,   43,   44,   45,   46,   47,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   58,   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,  257,
   -1,  259,   -1,   -1,  262,   -1,  264,  265,  266,   -1,
  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,
   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,  412,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,  302,  303,  304,  305,  306,   -1,
   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,
  318,  319,  320,   -1,  322,  323,  324,  325,  326,  327,
  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,
  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,
  368,   -1,  370,  371,  372,   -1,  374,  375,  376,  377,
  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,
  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,
   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,
  458,  459,  460,  461,  462,  463,  464,  465,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,
  478,  479,  480,   -1,   -1,  602,   -1,  485,  486,  487,
  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,
   -1,  499,  500,   -1,   -1,  503,  504,  505,  506,  507,
  508,  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,  540,  541,  542,  543,   -1,  545,  546,  547,
  548,  549,  550,   -1,  552,  553,  554,  555,   -1,  557,
   -1,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,  573,  574,  575,  576,   -1,
  578,  579,  580,  581,   -1,  583,  584,  585,  586,  587,
   -1,  589,  590,  591,  592,  593,  594,  595,  596,  597,
  598,  599,  600,  601,  602,  603,  604,  605,  606,  607,
  608,  609,  610,  611,  612,  613,  614,  615,  616,  617,
   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,
  628,  629,   -1,   -1,  632,  633,  634,  635,  636,  637,
  638,  639,  640,   41,   -1,   -1,   -1,   -1,  646,   -1,
  648,  649,  650,  651,  652,  653,   -1,  655,   -1,   -1,
   -1,   -1,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,
  678,  679,  680,  681,  682,  683,   -1,  685,  686,  687,
  688,  689,  690,  691,  692,  693,  694,  695,  696,   -1,
  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,
  708,  709,  710,  711,  712,  713,  714,  715,  716,  717,
  718,    0,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,
  728,  729,  730,  731,  732,  733,  734,  735,  736,  737,
  738,  739,  740,  741,  742,  743,  744,   -1,   -1,  747,
   -1,  749,  750,  751,  752,  753,  754,  755,  756,  757,
   -1,   40,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,
   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,
   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,  266,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,  412,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,
  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,  458,
  459,  460,  461,  462,  463,  464,  465,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,
  479,  480,   -1,   -1,  602,   -1,  485,  486,  487,  488,
  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,
  499,  500,   -1,   -1,  503,  504,  505,  506,  507,  508,
  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,  540,  541,  542,  543,   -1,  545,  546,  547,  548,
  549,  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,  573,  574,  575,  576,   -1,  578,
  579,  580,  581,   -1,  583,  584,  585,  586,  587,   -1,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,  614,  615,  616,  617,   -1,
  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,
  629,   -1,   -1,  632,  633,  634,  635,  636,  637,  638,
  639,  640,   41,   -1,   -1,   -1,   -1,  646,   -1,  648,
  649,  650,  651,  652,  653,   -1,  655,   -1,   -1,   -1,
   -1,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,
  679,  680,  681,  682,  683,   -1,  685,  686,  687,  688,
  689,  690,  691,  692,  693,  694,  695,  696,   -1,  698,
  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,
  709,  710,  711,  712,  713,  714,  715,  716,  717,  718,
    0,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,
  729,  730,  731,  732,  733,  734,  735,  736,  737,  738,
  739,  740,  741,  742,  743,  744,   -1,   -1,  747,   -1,
  749,  750,  751,  752,  753,  754,  755,  756,  757,   -1,
   40,   41,   42,   43,   44,   45,   46,   47,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   59,
   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,
   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,
   -1,   -1,  371,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,  262,   -1,  264,  265,  266,   -1,  268,  269,
   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,
  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,   -1,   -1,  412,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,
   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,
  320,   -1,  322,  323,  324,  325,  326,  327,  328,   -1,
   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,
  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,
  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,
  370,  371,  372,   -1,  374,  375,  376,  377,  378,   -1,
  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,  419,
  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,
   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,
   -1,  451,  452,  453,  454,   -1,  456,   -1,  458,  459,
  460,  461,  462,  463,  464,  465,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,
  480,   -1,   -1,  602,   -1,  485,  486,  487,  488,  489,
   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,
  500,   -1,   -1,  503,  504,  505,  506,  507,  508,  509,
  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
  540,  541,  542,  543,   -1,  545,  546,  547,  548,  549,
  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,  573,  574,  575,  576,   -1,  578,  579,
  580,  581,   -1,  583,  584,  585,  586,  587,   -1,  589,
  590,  591,  592,  593,  594,  595,  596,  597,  598,  599,
  600,  601,  602,  603,  604,  605,  606,  607,  608,  609,
  610,  611,  612,  613,  614,  615,  616,  617,   -1,  619,
  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,  629,
   -1,   -1,  632,  633,  634,  635,  636,  637,  638,  639,
  640,   41,   -1,   -1,   -1,   -1,  646,   -1,  648,  649,
  650,  651,  652,  653,   -1,  655,   -1,   -1,   -1,   -1,
   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,  679,
  680,  681,  682,  683,   -1,  685,  686,  687,  688,  689,
  690,  691,  692,  693,  694,  695,  696,   -1,  698,  699,
  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,  709,
  710,  711,  712,  713,  714,  715,  716,  717,  718,    0,
  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,
  730,  731,  732,  733,  734,  735,  736,  737,  738,  739,
  740,  741,  742,  743,  744,   -1,   -1,  747,   -1,  749,
  750,  751,  752,  753,  754,  755,  756,  757,   -1,   40,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   59,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,
   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,
   -1,  371,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,  266,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,  412,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,
   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,
  451,  452,  453,  454,   -1,  456,   -1,  458,  459,  460,
  461,  462,  463,  464,  465,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,  480,
   -1,   -1,  602,   -1,  485,  486,  487,  488,  489,   -1,
  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,  500,
   -1,   -1,  503,  504,  505,  506,  507,  508,  509,  510,
  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,  540,
  541,  542,  543,   -1,  545,  546,  547,  548,  549,  550,
   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,  573,  574,  575,  576,   -1,  578,  579,  580,
  581,   -1,  583,  584,  585,  586,  587,   -1,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,  614,  615,  616,  617,   -1,  619,  620,
   -1,   -1,   -1,  624,  625,  626,  627,  628,  629,   -1,
   -1,  632,  633,  634,  635,  636,  637,  638,  639,  640,
   41,   -1,   -1,   -1,   -1,  646,   -1,  648,  649,  650,
  651,  652,  653,   -1,  655,   -1,   -1,   -1,   -1,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  672,  673,   -1,  675,  676,  677,  678,  679,  680,
  681,  682,  683,   -1,  685,  686,  687,  688,  689,  690,
  691,  692,  693,  694,  695,  696,   -1,  698,  699,  700,
   -1,  702,   -1,   -1,   -1,  706,  707,  708,  709,  710,
  711,  712,  713,  714,  715,  716,  717,  718,    0,  720,
  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,  730,
  731,  732,  733,  734,  735,  736,  737,  738,  739,  740,
  741,  742,  743,  744,   -1,   -1,  747,   -1,  749,  750,
  751,  752,  753,  754,  755,  756,  757,   -1,   40,   41,
   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   58,   59,   60,   61,
   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,
   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,
   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,
   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,
  262,   -1,  264,  265,  266,   -1,  268,  269,   -1,  271,
   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
   -1,  412,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,
  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,
  322,  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,
  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,
  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,
  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,
  372,   -1,  374,  375,  376,  377,  378,   -1,  380,  381,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,
  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,   -1,
   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,  451,
  452,  453,  454,   -1,  456,   -1,  458,  459,  460,  461,
  462,  463,  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  475,  476,   -1,  478,  479,  480,   -1,
   -1,  602,   -1,  485,  486,  487,  488,  489,   -1,  491,
   -1,   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,
   -1,  503,  504,  505,  506,  507,  508,  509,  510,  511,
   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,  540,  541,
  542,  543,   -1,  545,  546,  547,  548,  549,  550,   -1,
  552,  553,  554,  555,   -1,  557,   -1,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,  573,  574,  575,  576,   -1,  578,  579,  580,  581,
   -1,  583,  584,  585,  586,  587,   -1,  589,  590,  591,
  592,  593,  594,  595,  596,  597,  598,  599,  600,  601,
  602,  603,  604,  605,  606,  607,  608,  609,  610,  611,
  612,  613,  614,  615,  616,  617,   -1,  619,  620,   -1,
   -1,   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,
  632,  633,  634,  635,  636,  637,  638,  639,  640,   41,
   -1,   -1,   -1,   -1,  646,   -1,  648,  649,  650,  651,
  652,  653,   -1,  655,   -1,   -1,   -1,   -1,   60,   61,
   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  672,  673,   -1,  675,  676,  677,  678,  679,  680,  681,
  682,  683,   -1,  685,  686,  687,  688,  689,  690,  691,
  692,  693,  694,  695,  696,   -1,  698,  699,  700,   -1,
  702,   -1,   -1,   -1,  706,  707,  708,  709,  710,  711,
  712,  713,  714,  715,  716,  717,  718,    0,  720,  721,
   -1,   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,
  732,  733,  734,  735,  736,  737,  738,  739,  740,  741,
  742,  743,  744,   -1,   -1,  747,   -1,  749,  750,  751,
  752,  753,  754,  755,  756,  757,   -1,   40,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   58,   59,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,
   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,
  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,
   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,  266,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
  412,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,   -1,   -1,   -1,
   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,  451,  452,
  453,  454,   -1,  456,   -1,  458,  459,  460,  461,  462,
  463,  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  475,  476,   -1,  478,  479,  480,   -1,   -1,
  602,   -1,  485,  486,  487,  488,  489,   -1,  491,   -1,
   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,
  503,  504,  505,  506,  507,  508,  509,  510,  511,   -1,
  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,  540,  541,  542,
  543,   -1,  545,  546,  547,  548,  549,  550,   -1,  552,
  553,  554,  555,   -1,  557,   -1,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
  573,  574,  575,  576,   -1,  578,  579,  580,  581,   -1,
  583,  584,  585,  586,  587,   -1,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,
   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,  632,
  633,  634,  635,  636,  637,  638,  639,  640,   41,   -1,
   -1,   -1,   -1,  646,   -1,  648,  649,  650,  651,  652,
  653,   -1,  655,   -1,   -1,   -1,   -1,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,
  673,   -1,  675,  676,  677,  678,  679,  680,  681,  682,
  683,   -1,  685,  686,  687,  688,  689,  690,  691,  692,
  693,  694,  695,  696,   -1,  698,  699,  700,   -1,  702,
   -1,   -1,   -1,  706,  707,  708,  709,  710,  711,  712,
  713,  714,  715,  716,  717,  718,    0,  720,  721,   -1,
   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,
  733,  734,  735,  736,  737,  738,  739,  740,  741,  742,
  743,  744,   -1,   -1,  747,   -1,  749,  750,  751,  752,
  753,  754,  755,  756,  757,   -1,   40,   41,   42,   43,
   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   58,   59,   60,   61,   62,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,
   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,
   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,
  264,  265,  266,   -1,  268,  269,   -1,  271,   -1,   -1,
   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,  412,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,
  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,
  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,
  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,
  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,
   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,
  364,  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,
  374,  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
  434,  435,   -1,  437,  438,  439,   -1,   -1,   -1,   -1,
   -1,  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,
  454,   -1,  456,   -1,  458,  459,  460,  461,  462,  463,
  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  475,  476,   -1,  478,  479,  480,   -1,   -1,  602,
   -1,  485,  486,  487,  488,  489,   -1,  491,   -1,   -1,
  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,  503,
  504,  505,  506,  507,  508,  509,  510,  511,   -1,  513,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,  540,  541,  542,  543,
   -1,  545,  546,  547,  548,  549,  550,   -1,  552,  553,
  554,  555,   -1,  557,   -1,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,  573,
  574,  575,  576,   -1,  578,  579,  580,  581,   -1,  583,
  584,  585,  586,  587,   -1,  589,  590,  591,  592,  593,
  594,  595,  596,  597,  598,  599,  600,  601,  602,  603,
  604,  605,  606,  607,  608,  609,  610,  611,  612,  613,
  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,
  624,  625,  626,  627,  628,  629,   -1,   -1,  632,  633,
  634,  635,  636,  637,  638,  639,  640,   41,   -1,   -1,
   -1,   -1,  646,   -1,  648,  649,  650,  651,  652,  653,
   -1,  655,   -1,   -1,   -1,   -1,   60,   61,   62,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,
   -1,  675,  676,  677,  678,  679,  680,  681,  682,  683,
   -1,  685,  686,  687,  688,  689,  690,  691,  692,  693,
  694,  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,
   -1,   -1,  706,  707,  708,  709,  710,  711,  712,  713,
  714,  715,  716,  717,  718,    0,  720,  721,   -1,   -1,
   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,  733,
  734,  735,  736,  737,  738,  739,  740,  741,  742,  743,
  744,   -1,   -1,  747,   -1,  749,  750,  751,  752,  753,
  754,  755,  756,  757,   -1,   40,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   58,   59,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,
   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,
  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,  266,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,  412,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,   -1,   -1,   -1,   -1,   -1,
  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,
   -1,  456,   -1,  458,  459,  460,  461,  462,  463,  464,
  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  475,  476,   -1,  478,  479,  480,   -1,   -1,  602,   -1,
  485,  486,  487,  488,  489,   -1,  491,   -1,   -1,  494,
  495,   -1,   -1,   -1,  499,  500,   -1,   -1,  503,  504,
  505,  506,  507,  508,  509,  510,  511,   -1,  513,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,  540,  541,  542,  543,   -1,
  545,  546,  547,  548,  549,  550,   -1,  552,  553,  554,
  555,   -1,  557,   -1,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,  573,  574,
  575,  576,   -1,  578,  579,  580,  581,   -1,  583,  584,
  585,  586,  587,   -1,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,  614,
  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,
  625,  626,  627,  628,  629,   -1,   -1,  632,  633,  634,
  635,  636,  637,  638,  639,  640,   41,   -1,   -1,   -1,
   -1,  646,   -1,  648,  649,  650,  651,  652,  653,   -1,
  655,   -1,   -1,   -1,   -1,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,
  675,  676,  677,  678,  679,  680,  681,  682,  683,   -1,
  685,  686,  687,  688,  689,  690,  691,  692,  693,  694,
  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,   -1,
   -1,  706,  707,  708,  709,  710,  711,  712,  713,  714,
  715,  716,  717,  718,    0,  720,  721,   -1,   -1,   -1,
   -1,   -1,  727,  728,  729,  730,  731,  732,  733,  734,
  735,  736,  737,  738,  739,  740,  741,  742,  743,  744,
   -1,   -1,  747,   -1,  749,  750,  751,  752,  753,  754,
  755,  756,  757,   -1,   40,   41,   42,   43,   44,   45,
   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   58,   59,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,
  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,
   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,
  266,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,
   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,  412,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,  305,
  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,
   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,  325,
  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,
   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,
  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,
  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,
   -1,  437,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,
   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,
  456,   -1,  458,  459,  460,  461,  462,  463,  464,  465,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,
  476,   -1,  478,  479,  480,   -1,   -1,  602,   -1,  485,
  486,  487,  488,  489,   -1,  491,   -1,   -1,  494,  495,
   -1,   -1,   -1,  499,  500,   -1,   -1,  503,  504,  505,
  506,  507,  508,  509,  510,  511,   -1,  513,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,  540,  541,  542,  543,   -1,  545,
  546,  547,  548,  549,  550,   -1,  552,  553,  554,  555,
   -1,  557,   -1,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,  573,  574,  575,
  576,   -1,  578,  579,  580,  581,   -1,  583,  584,  585,
  586,  587,   -1,  589,  590,  591,  592,  593,  594,  595,
  596,  597,  598,  599,  600,  601,  602,  603,  604,  605,
  606,  607,  608,  609,  610,  611,  612,  613,  614,  615,
  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,
  626,  627,  628,  629,   -1,   -1,  632,  633,  634,  635,
  636,  637,  638,  639,  640,   41,   -1,   -1,   -1,   -1,
  646,   -1,  648,  649,  650,  651,  652,  653,   -1,  655,
   -1,   -1,   -1,   -1,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,
  676,  677,  678,  679,  680,  681,  682,  683,   -1,  685,
  686,  687,  688,  689,  690,  691,  692,  693,  694,  695,
  696,   -1,  698,  699,  700,   -1,  702,   -1,   -1,   -1,
  706,  707,  708,  709,  710,  711,  712,  713,  714,  715,
  716,  717,  718,    0,  720,  721,   -1,   -1,   -1,   -1,
   -1,  727,  728,  729,  730,  731,  732,  733,  734,  735,
  736,  737,  738,  739,  740,  741,  742,  743,  744,   -1,
   -1,  747,   -1,  749,  750,  751,  752,  753,  754,  755,
  756,  757,   -1,   40,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   58,   59,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,
  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,  266,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,  412,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,
   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,
   -1,  458,  459,  460,  461,  462,  463,  464,  465,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,
   -1,  478,  479,  480,   -1,   -1,  602,   -1,  485,  486,
  487,  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,
   -1,   -1,  499,  500,   -1,   -1,  503,  504,  505,  506,
  507,  508,  509,  510,  511,   -1,  513,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,  540,  541,  542,  543,   -1,  545,  546,
  547,  548,  549,  550,   -1,  552,  553,  554,  555,   -1,
  557,   -1,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,  573,  574,  575,  576,
   -1,  578,  579,  580,  581,   -1,  583,  584,  585,  586,
  587,   -1,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,  614,  615,  616,
  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,
  627,  628,  629,   -1,   -1,  632,  633,  634,  635,  636,
  637,  638,  639,  640,   41,   -1,   -1,   -1,   -1,  646,
   -1,  648,  649,  650,  651,  652,  653,   -1,  655,   -1,
   -1,   -1,   -1,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,
  677,  678,  679,  680,  681,  682,  683,   -1,  685,  686,
  687,  688,  689,  690,  691,  692,  693,  694,  695,  696,
   -1,  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,
  707,  708,  709,  710,  711,  712,  713,  714,  715,  716,
  717,  718,    0,  720,  721,   -1,   -1,   -1,   -1,   -1,
  727,  728,  729,  730,  731,  732,  733,  734,  735,  736,
  737,  738,  739,  740,  741,  742,  743,  744,   -1,   -1,
  747,   -1,  749,  750,  751,  752,  753,  754,  755,  756,
  757,   -1,   40,   41,   42,   43,   44,   45,   46,   47,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   58,   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,  257,
   -1,  259,   -1,   -1,  262,   -1,  264,  265,  266,   -1,
  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,
   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,  412,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,  302,  303,  304,  305,  306,   -1,
   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,
  318,  319,  320,   -1,  322,  323,  324,  325,  326,  327,
  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,
  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,
  368,   -1,  370,  371,  372,   -1,  374,  375,  376,  377,
  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,
  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,
   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,
  458,  459,  460,  461,  462,  463,  464,  465,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,
  478,  479,  480,   -1,   -1,  602,   -1,  485,  486,  487,
  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,
   -1,  499,  500,   -1,   -1,  503,  504,  505,  506,  507,
  508,  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,  540,  541,  542,  543,   -1,  545,  546,  547,
  548,  549,  550,   -1,  552,  553,  554,  555,   -1,  557,
   -1,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,  573,  574,  575,  576,   -1,
  578,  579,  580,  581,   -1,  583,  584,  585,  586,  587,
   -1,  589,  590,  591,  592,  593,  594,  595,  596,  597,
  598,  599,  600,  601,  602,  603,  604,  605,  606,  607,
  608,  609,  610,  611,  612,  613,  614,  615,  616,  617,
   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,
  628,  629,   -1,   -1,  632,  633,  634,  635,  636,  637,
  638,  639,  640,   41,   -1,   -1,   -1,   -1,  646,   -1,
  648,  649,  650,  651,  652,  653,   -1,  655,   -1,   -1,
   -1,   -1,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,
  678,  679,  680,  681,  682,  683,   -1,  685,  686,  687,
  688,  689,  690,  691,  692,  693,  694,  695,  696,   -1,
  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,
  708,  709,  710,  711,  712,  713,  714,  715,  716,  717,
  718,    0,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,
  728,  729,  730,  731,  732,  733,  734,  735,  736,  737,
  738,  739,  740,  741,  742,  743,  744,   -1,   -1,  747,
   -1,  749,  750,  751,  752,  753,  754,  755,  756,  757,
   -1,   40,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,
   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,
   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,  266,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,  412,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,
  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,  458,
  459,  460,  461,  462,  463,  464,  465,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,
  479,  480,   -1,   -1,  602,   -1,  485,  486,  487,  488,
  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,
  499,  500,   -1,   -1,  503,  504,  505,  506,  507,  508,
  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,  540,  541,  542,  543,   -1,  545,  546,  547,  548,
  549,  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,  573,  574,  575,  576,   -1,  578,
  579,  580,  581,   -1,  583,  584,  585,  586,  587,   -1,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,  614,  615,  616,  617,   -1,
  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,
  629,   -1,   -1,  632,  633,  634,  635,  636,  637,  638,
  639,  640,   41,   -1,   -1,   -1,   -1,  646,   -1,  648,
  649,  650,  651,  652,  653,   -1,  655,   -1,   -1,   -1,
   -1,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,
  679,  680,  681,  682,  683,   -1,  685,  686,  687,  688,
  689,  690,  691,  692,  693,  694,  695,  696,   -1,  698,
  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,
  709,  710,  711,  712,  713,  714,  715,  716,  717,  718,
    0,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,
  729,  730,  731,  732,  733,  734,  735,  736,  737,  738,
  739,  740,  741,  742,  743,  744,   -1,   -1,  747,   -1,
  749,  750,  751,  752,  753,  754,  755,  756,  757,   -1,
   40,   41,   42,   43,   44,   45,   46,   47,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   59,
   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,
   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,
   -1,   -1,  371,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,  262,   -1,  264,  265,  266,   -1,  268,  269,
   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,
  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,   -1,   -1,  412,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,
   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,
  320,   -1,  322,  323,  324,  325,  326,  327,  328,   -1,
   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,
  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,
  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,
  370,  371,  372,   -1,  374,  375,  376,  377,  378,   -1,
  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,  419,
  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,
   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,
   -1,  451,  452,  453,  454,   -1,  456,   -1,  458,  459,
  460,  461,  462,  463,  464,  465,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,
  480,   -1,   -1,  602,   -1,  485,  486,  487,  488,  489,
   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,
  500,   -1,   -1,  503,  504,  505,  506,  507,  508,  509,
  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
  540,  541,  542,  543,   -1,  545,  546,  547,  548,  549,
  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,  573,  574,  575,  576,   -1,  578,  579,
  580,  581,   -1,  583,  584,  585,  586,  587,   -1,  589,
  590,  591,  592,  593,  594,  595,  596,  597,  598,  599,
  600,  601,  602,  603,  604,  605,  606,  607,  608,  609,
  610,  611,  612,  613,  614,  615,  616,  617,   -1,  619,
  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,  629,
   -1,   -1,  632,  633,  634,  635,  636,  637,  638,  639,
  640,   41,   -1,   -1,   -1,   -1,  646,   -1,  648,  649,
  650,  651,  652,  653,   -1,  655,   -1,   -1,   -1,   -1,
   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,  679,
  680,  681,  682,  683,   -1,  685,  686,  687,  688,  689,
  690,  691,  692,  693,  694,  695,  696,   -1,  698,  699,
  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,  709,
  710,  711,  712,  713,  714,  715,  716,  717,  718,    0,
  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,
  730,  731,  732,  733,  734,  735,  736,  737,  738,  739,
  740,  741,  742,  743,  744,   -1,   -1,  747,   -1,  749,
  750,  751,  752,  753,  754,  755,  756,  757,   -1,   40,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   59,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,
   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,
   -1,  371,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,  266,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,  412,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,
   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,
  451,  452,  453,  454,   -1,  456,   -1,  458,  459,  460,
  461,  462,  463,  464,  465,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,  480,
   -1,   -1,  602,   -1,  485,  486,  487,  488,  489,   -1,
  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,  500,
   -1,   -1,  503,  504,  505,  506,  507,  508,  509,  510,
  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,  540,
  541,  542,  543,   -1,  545,  546,  547,  548,  549,  550,
   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,  573,  574,  575,  576,   -1,  578,  579,  580,
  581,   -1,  583,  584,  585,  586,  587,   -1,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,  614,  615,  616,  617,   -1,  619,  620,
   -1,   -1,   -1,  624,  625,  626,  627,  628,  629,   -1,
   -1,  632,  633,  634,  635,  636,  637,  638,  639,  640,
   41,   -1,   -1,   -1,   -1,  646,   -1,  648,  649,  650,
  651,  652,  653,   -1,  655,   -1,   -1,   -1,   -1,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  672,  673,   -1,  675,  676,  677,  678,  679,  680,
  681,  682,  683,   -1,  685,  686,  687,  688,  689,  690,
  691,  692,  693,  694,  695,  696,   -1,  698,  699,  700,
   -1,  702,   -1,   -1,   -1,  706,  707,  708,  709,  710,
  711,  712,  713,  714,  715,  716,  717,  718,    0,  720,
  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,  730,
  731,  732,  733,  734,  735,  736,  737,  738,  739,  740,
  741,  742,  743,  744,   -1,   -1,  747,   -1,  749,  750,
  751,  752,  753,  754,  755,  756,  757,   -1,   40,   41,
   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   58,   59,   60,   61,
   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,
   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,
   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,
   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,
  262,   -1,  264,  265,  266,   -1,  268,  269,   -1,  271,
   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
   -1,  412,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,
  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,
  322,  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,
  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,
  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,
  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,
  372,   -1,  374,  375,  376,  377,  378,   -1,  380,  381,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,
  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,   -1,
   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,  451,
  452,  453,  454,   -1,  456,   -1,  458,  459,  460,  461,
  462,  463,  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  475,  476,   -1,  478,  479,  480,   -1,
   -1,  602,   -1,  485,  486,  487,  488,  489,   -1,  491,
   -1,   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,
   -1,  503,  504,  505,  506,  507,  508,  509,  510,  511,
   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,  540,  541,
  542,  543,   -1,  545,  546,  547,  548,  549,  550,   -1,
  552,  553,  554,  555,   -1,  557,   -1,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,  573,  574,  575,  576,   -1,  578,  579,  580,  581,
   -1,  583,  584,  585,  586,  587,   -1,  589,  590,  591,
  592,  593,  594,  595,  596,  597,  598,  599,  600,  601,
  602,  603,  604,  605,  606,  607,  608,  609,  610,  611,
  612,  613,  614,  615,  616,  617,   -1,  619,  620,   -1,
   -1,   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,
  632,  633,  634,  635,  636,  637,  638,  639,  640,   41,
   -1,   -1,   -1,   -1,  646,   -1,  648,  649,  650,  651,
  652,  653,   -1,  655,   -1,   -1,   -1,   -1,   60,   61,
   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  672,  673,   -1,  675,  676,  677,  678,  679,  680,  681,
  682,  683,   -1,  685,  686,  687,  688,  689,  690,  691,
  692,  693,  694,  695,  696,   -1,  698,  699,  700,   -1,
  702,   -1,   -1,   -1,  706,  707,  708,  709,  710,  711,
  712,  713,  714,  715,  716,  717,  718,    0,  720,  721,
   -1,   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,
  732,  733,  734,  735,  736,  737,  738,  739,  740,  741,
  742,  743,  744,   -1,   -1,  747,   -1,  749,  750,  751,
  752,  753,  754,  755,  756,  757,   -1,   40,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   58,   59,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,
   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,
  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,
   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,  266,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
  412,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,   -1,   -1,   -1,
   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,  451,  452,
  453,  454,   -1,  456,   -1,  458,  459,  460,  461,  462,
  463,  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  475,  476,   -1,  478,  479,  480,   -1,   -1,
  602,   -1,  485,  486,  487,  488,  489,   -1,  491,   -1,
   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,
  503,  504,  505,  506,  507,  508,  509,  510,  511,   -1,
  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,  540,  541,  542,
  543,   -1,  545,  546,  547,  548,  549,  550,   -1,  552,
  553,  554,  555,   -1,  557,   -1,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
  573,  574,  575,  576,   -1,  578,  579,  580,  581,   -1,
  583,  584,  585,  586,  587,   -1,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,
   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,  632,
  633,  634,  635,  636,  637,  638,  639,  640,   41,   -1,
   -1,   -1,   -1,  646,   -1,  648,  649,  650,  651,  652,
  653,   -1,  655,   -1,   -1,   -1,   -1,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,
  673,   -1,  675,  676,  677,  678,  679,  680,  681,  682,
  683,   -1,  685,  686,  687,  688,  689,  690,  691,  692,
  693,  694,  695,  696,   -1,  698,  699,  700,   -1,  702,
   -1,   -1,   -1,  706,  707,  708,  709,  710,  711,  712,
  713,  714,  715,  716,  717,  718,    0,  720,  721,   -1,
   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,
  733,  734,  735,  736,  737,  738,  739,  740,  741,  742,
  743,  744,   -1,   -1,  747,   -1,  749,  750,  751,  752,
  753,  754,  755,  756,  757,   -1,   40,   41,   42,   43,
   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   58,   59,   60,   61,   62,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,
   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,
   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,
  264,  265,  266,   -1,  268,  269,   -1,  271,   -1,   -1,
   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,  412,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,
  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,
  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,
  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,
  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,
   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,
  364,  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,
  374,  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
  434,  435,   -1,  437,  438,  439,   -1,   -1,   -1,   -1,
   -1,  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,
  454,   -1,  456,   -1,  458,  459,  460,  461,  462,  463,
  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  475,  476,   -1,  478,  479,  480,   -1,   -1,  602,
   -1,  485,  486,  487,  488,  489,   -1,  491,   -1,   -1,
  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,  503,
  504,  505,  506,  507,  508,  509,  510,  511,   -1,  513,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,  540,  541,  542,  543,
   -1,  545,  546,  547,  548,  549,  550,   -1,  552,  553,
  554,  555,   -1,  557,   -1,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,  573,
  574,  575,  576,   -1,  578,  579,  580,  581,   -1,  583,
  584,  585,  586,  587,   -1,  589,  590,  591,  592,  593,
  594,  595,  596,  597,  598,  599,  600,  601,  602,  603,
  604,  605,  606,  607,  608,  609,  610,  611,  612,  613,
  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,
  624,  625,  626,  627,  628,  629,   -1,   -1,  632,  633,
  634,  635,  636,  637,  638,  639,  640,   41,   -1,   -1,
   -1,   -1,  646,   -1,  648,  649,  650,  651,  652,  653,
   -1,  655,   -1,   -1,   -1,   -1,   60,   61,   62,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,
   -1,  675,  676,  677,  678,  679,  680,  681,  682,  683,
   -1,  685,  686,  687,  688,  689,  690,  691,  692,  693,
  694,  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,
   -1,   -1,  706,  707,  708,  709,  710,  711,  712,  713,
  714,  715,  716,  717,  718,    0,  720,  721,   -1,   -1,
   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,  733,
  734,  735,  736,  737,  738,  739,  740,  741,  742,  743,
  744,   -1,   -1,  747,   -1,  749,  750,  751,  752,  753,
  754,  755,  756,  757,   -1,   40,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   58,   59,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,
   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,
  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,  266,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,  412,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,   -1,   -1,   -1,   -1,   -1,
  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,
   -1,  456,   -1,  458,  459,  460,  461,  462,  463,  464,
  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  475,  476,   -1,  478,  479,  480,   -1,   -1,  602,   -1,
  485,  486,  487,  488,  489,   -1,  491,   -1,   -1,  494,
  495,   -1,   -1,   -1,  499,  500,   -1,   -1,  503,  504,
  505,  506,  507,  508,  509,  510,  511,   -1,  513,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,  540,  541,  542,  543,   -1,
  545,  546,  547,  548,  549,  550,   -1,  552,  553,  554,
  555,   -1,  557,   -1,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,  573,  574,
  575,  576,   -1,  578,  579,  580,  581,   -1,  583,  584,
  585,  586,  587,   -1,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,  614,
  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,
  625,  626,  627,  628,  629,   -1,   -1,  632,  633,  634,
  635,  636,  637,  638,  639,  640,   41,   -1,   -1,   -1,
   -1,  646,   -1,  648,  649,  650,  651,  652,  653,   -1,
  655,   -1,   -1,   -1,   -1,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,
  675,  676,  677,  678,  679,  680,  681,  682,  683,   -1,
  685,  686,  687,  688,  689,  690,  691,  692,  693,  694,
  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,   -1,
   -1,  706,  707,  708,  709,  710,  711,  712,  713,  714,
  715,  716,  717,  718,    0,  720,  721,   -1,   -1,   -1,
   -1,   -1,  727,  728,  729,  730,  731,  732,  733,  734,
  735,  736,  737,  738,  739,  740,  741,  742,  743,  744,
   -1,   -1,  747,   -1,  749,  750,  751,  752,  753,  754,
  755,  756,  757,   -1,   40,   41,   42,   43,   44,   45,
   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   58,   59,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,
  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,
   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,
  266,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,
   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,  412,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,  305,
  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,
   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,  325,
  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,
   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,
  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,
  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,
   -1,  437,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,
   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,
  456,   -1,  458,  459,  460,  461,  462,  463,  464,  465,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,
  476,   -1,  478,  479,  480,   -1,   -1,  602,   -1,  485,
  486,  487,  488,  489,   -1,  491,   -1,   -1,  494,  495,
   -1,   -1,   -1,  499,  500,   -1,   -1,  503,  504,  505,
  506,  507,  508,  509,  510,  511,   -1,  513,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,  540,  541,  542,  543,   -1,  545,
  546,  547,  548,  549,  550,   -1,  552,  553,  554,  555,
   -1,  557,   -1,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,  573,  574,  575,
  576,   -1,  578,  579,  580,  581,   -1,  583,  584,  585,
  586,  587,   -1,  589,  590,  591,  592,  593,  594,  595,
  596,  597,  598,  599,  600,  601,  602,  603,  604,  605,
  606,  607,  608,  609,  610,  611,  612,  613,  614,  615,
  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,
  626,  627,  628,  629,   -1,   -1,  632,  633,  634,  635,
  636,  637,  638,  639,  640,   41,   -1,   -1,   -1,   -1,
  646,   -1,  648,  649,  650,  651,  652,  653,   -1,  655,
   -1,   -1,   -1,   -1,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,
  676,  677,  678,  679,  680,  681,  682,  683,   -1,  685,
  686,  687,  688,  689,  690,  691,  692,  693,  694,  695,
  696,   -1,  698,  699,  700,   -1,  702,   -1,   -1,   -1,
  706,  707,  708,  709,  710,  711,  712,  713,  714,  715,
  716,  717,  718,    0,  720,  721,   -1,   -1,   -1,   -1,
   -1,  727,  728,  729,  730,  731,  732,  733,  734,  735,
  736,  737,  738,  739,  740,  741,  742,  743,  744,   -1,
   -1,  747,   -1,  749,  750,  751,  752,  753,  754,  755,
  756,  757,   -1,   40,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   58,   59,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,
  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,  266,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,  412,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,
   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,
   -1,  458,  459,  460,  461,  462,  463,  464,  465,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,
   -1,  478,  479,  480,   -1,   -1,  602,   -1,  485,  486,
  487,  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,
   -1,   -1,  499,  500,   -1,   -1,  503,  504,  505,  506,
  507,  508,  509,  510,  511,   -1,  513,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,  540,  541,  542,  543,   -1,  545,  546,
  547,  548,  549,  550,   -1,  552,  553,  554,  555,   -1,
  557,   -1,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,  573,  574,  575,  576,
   -1,  578,  579,  580,  581,   -1,  583,  584,  585,  586,
  587,   -1,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,  614,  615,  616,
  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,
  627,  628,  629,   -1,   -1,  632,  633,  634,  635,  636,
  637,  638,  639,  640,   41,   -1,   -1,   -1,   -1,  646,
   -1,  648,  649,  650,  651,  652,  653,   -1,  655,   -1,
   -1,   -1,   -1,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,
  677,  678,  679,  680,  681,  682,  683,   -1,  685,  686,
  687,  688,  689,  690,  691,  692,  693,  694,  695,  696,
   -1,  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,
  707,  708,  709,  710,  711,  712,  713,  714,  715,  716,
  717,  718,    0,  720,  721,   -1,   -1,   -1,   -1,   -1,
  727,  728,  729,  730,  731,  732,  733,  734,  735,  736,
  737,  738,  739,  740,  741,  742,  743,  744,   -1,   -1,
  747,   -1,  749,  750,  751,  752,  753,  754,  755,  756,
  757,   -1,   40,   41,   42,   43,   44,   45,   46,   47,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   58,   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,  257,
   -1,  259,   -1,   -1,  262,   -1,  264,  265,  266,   -1,
  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,
   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,  412,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,  302,  303,  304,  305,  306,   -1,
   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,
  318,  319,  320,   -1,  322,  323,  324,  325,  326,  327,
  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,
  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,
  368,   -1,  370,  371,  372,   -1,  374,  375,  376,  377,
  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,
  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,
   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,
  458,  459,  460,  461,  462,  463,  464,  465,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,
  478,  479,  480,   -1,   -1,  602,   -1,  485,  486,  487,
  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,
   -1,  499,  500,   -1,   -1,  503,  504,  505,  506,  507,
  508,  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,  540,  541,  542,  543,   -1,  545,  546,  547,
  548,  549,  550,   -1,  552,  553,  554,  555,   -1,  557,
   -1,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,  573,  574,  575,  576,   -1,
  578,  579,  580,  581,   -1,  583,  584,  585,  586,  587,
   -1,  589,  590,  591,  592,  593,  594,  595,  596,  597,
  598,  599,  600,  601,  602,  603,  604,  605,  606,  607,
  608,  609,  610,  611,  612,  613,  614,  615,  616,  617,
   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,
  628,  629,   -1,   -1,  632,  633,  634,  635,  636,  637,
  638,  639,  640,   41,   -1,   -1,   -1,   -1,  646,   -1,
  648,  649,  650,  651,  652,  653,   -1,  655,   -1,   -1,
   -1,   -1,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,
  678,  679,  680,  681,  682,  683,   -1,  685,  686,  687,
  688,  689,  690,  691,  692,  693,  694,  695,  696,   -1,
  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,
  708,  709,  710,  711,  712,  713,  714,  715,  716,  717,
  718,    0,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,
  728,  729,  730,  731,  732,  733,  734,  735,  736,  737,
  738,  739,  740,  741,  742,  743,  744,   -1,   -1,  747,
   -1,  749,  750,  751,  752,  753,  754,  755,  756,  757,
   -1,   40,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,
   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,
   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,  266,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,  412,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,
  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,  458,
  459,  460,  461,  462,  463,  464,  465,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,
  479,  480,   -1,   -1,  602,   -1,  485,  486,  487,  488,
  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,
  499,  500,   -1,   -1,  503,  504,  505,  506,  507,  508,
  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,  540,  541,  542,  543,   -1,  545,  546,  547,  548,
  549,  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,  573,  574,  575,  576,   -1,  578,
  579,  580,  581,   -1,  583,  584,  585,  586,  587,   -1,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,  614,  615,  616,  617,   -1,
  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,
  629,   -1,   -1,  632,  633,  634,  635,  636,  637,  638,
  639,  640,   41,   -1,   -1,   -1,   -1,  646,   -1,  648,
  649,  650,  651,  652,  653,   -1,  655,   -1,   -1,   -1,
   -1,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,
  679,  680,  681,  682,  683,   -1,  685,  686,  687,  688,
  689,  690,  691,  692,  693,  694,  695,  696,   -1,  698,
  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,
  709,  710,  711,  712,  713,  714,  715,  716,  717,  718,
    0,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,
  729,  730,  731,  732,  733,  734,  735,  736,  737,  738,
  739,  740,  741,  742,  743,  744,   -1,   -1,  747,   -1,
  749,  750,  751,  752,  753,  754,  755,  756,  757,   -1,
   40,   41,   42,   43,   44,   45,   46,   47,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   59,
   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,
   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,
   -1,   -1,  371,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,  262,   -1,  264,  265,  266,   -1,  268,  269,
   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,
  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,   -1,   -1,  412,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,
   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,
  320,   -1,  322,  323,  324,  325,  326,  327,  328,   -1,
   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,
  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,
  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,
  370,  371,  372,   -1,  374,  375,  376,  377,  378,   -1,
  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,  419,
  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,
   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,
   -1,  451,  452,  453,  454,   -1,  456,   -1,  458,  459,
  460,  461,  462,  463,  464,  465,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,
  480,   -1,   -1,  602,   -1,  485,  486,  487,  488,  489,
   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,
  500,   -1,   -1,  503,  504,  505,  506,  507,  508,  509,
  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
  540,  541,  542,  543,   -1,  545,  546,  547,  548,  549,
  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,  573,  574,  575,  576,   -1,  578,  579,
  580,  581,   -1,  583,  584,  585,  586,  587,   -1,  589,
  590,  591,  592,  593,  594,  595,  596,  597,  598,  599,
  600,  601,  602,  603,  604,  605,  606,  607,  608,  609,
  610,  611,  612,  613,  614,  615,  616,  617,   -1,  619,
  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,  629,
   -1,   -1,  632,  633,  634,  635,  636,  637,  638,  639,
  640,   41,   -1,   -1,   -1,   -1,  646,   -1,  648,  649,
  650,  651,  652,  653,   -1,  655,   -1,   -1,   -1,   -1,
   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,  679,
  680,  681,  682,  683,   -1,  685,  686,  687,  688,  689,
  690,  691,  692,  693,  694,  695,  696,   -1,  698,  699,
  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,  709,
  710,  711,  712,  713,  714,  715,  716,  717,  718,    0,
  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,
  730,  731,  732,  733,  734,  735,  736,  737,  738,  739,
  740,  741,  742,  743,  744,   -1,   -1,  747,   -1,  749,
  750,  751,  752,  753,  754,  755,  756,  757,   -1,   40,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   59,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,
   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,
   -1,  371,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,  266,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,  412,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,
   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,
  451,  452,  453,  454,   -1,  456,   -1,  458,  459,  460,
  461,  462,  463,  464,  465,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,  480,
   -1,   -1,  602,   -1,  485,  486,  487,  488,  489,   -1,
  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,  500,
   -1,   -1,  503,  504,  505,  506,  507,  508,  509,  510,
  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,  540,
  541,  542,  543,   -1,  545,  546,  547,  548,  549,  550,
   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,  573,  574,  575,  576,   -1,  578,  579,  580,
  581,   -1,  583,  584,  585,  586,  587,   -1,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,  614,  615,  616,  617,   -1,  619,  620,
   -1,   -1,   -1,  624,  625,  626,  627,  628,  629,   -1,
   -1,  632,  633,  634,  635,  636,  637,  638,  639,  640,
   41,   -1,   -1,   -1,   -1,  646,   -1,  648,  649,  650,
  651,  652,  653,   -1,  655,   -1,   -1,   -1,   -1,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  672,  673,   -1,  675,  676,  677,  678,  679,  680,
  681,  682,  683,   -1,  685,  686,  687,  688,  689,  690,
  691,  692,  693,  694,  695,  696,   -1,  698,  699,  700,
   -1,  702,   -1,   -1,   -1,  706,  707,  708,  709,  710,
  711,  712,  713,  714,  715,  716,  717,  718,    0,  720,
  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,  730,
  731,  732,  733,  734,  735,  736,  737,  738,  739,  740,
  741,  742,  743,  744,   -1,   -1,  747,   -1,  749,  750,
  751,  752,  753,  754,  755,  756,  757,   -1,   40,   41,
   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   58,   59,   60,   61,
   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,
   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,
   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,
   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,
  262,   -1,  264,  265,  266,   -1,  268,  269,   -1,  271,
   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
   -1,  412,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,
  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,
  322,  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,
  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,
  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,
  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,
  372,   -1,  374,  375,  376,  377,  378,   -1,  380,  381,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,
  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,   -1,
   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,  451,
  452,  453,  454,   -1,  456,   -1,  458,  459,  460,  461,
  462,  463,  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  475,  476,   -1,  478,  479,  480,   -1,
   -1,  602,   -1,  485,  486,  487,  488,  489,   -1,  491,
   -1,   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,
   -1,  503,  504,  505,  506,  507,  508,  509,  510,  511,
   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,  540,  541,
  542,  543,   -1,  545,  546,  547,  548,  549,  550,   -1,
  552,  553,  554,  555,   -1,  557,   -1,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,  573,  574,  575,  576,   -1,  578,  579,  580,  581,
   -1,  583,  584,  585,  586,  587,   -1,  589,  590,  591,
  592,  593,  594,  595,  596,  597,  598,  599,  600,  601,
  602,  603,  604,  605,  606,  607,  608,  609,  610,  611,
  612,  613,  614,  615,  616,  617,   -1,  619,  620,   -1,
   -1,   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,
  632,  633,  634,  635,  636,  637,  638,  639,  640,   41,
   -1,   -1,   -1,   -1,  646,   -1,  648,  649,  650,  651,
  652,  653,   -1,  655,   -1,   -1,   -1,   -1,   60,   61,
   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  672,  673,   -1,  675,  676,  677,  678,  679,  680,  681,
  682,  683,   -1,  685,  686,  687,  688,  689,  690,  691,
  692,  693,  694,  695,  696,   -1,  698,  699,  700,   -1,
  702,   -1,   -1,   -1,  706,  707,  708,  709,  710,  711,
  712,  713,  714,  715,  716,  717,  718,    0,  720,  721,
   -1,   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,
  732,  733,  734,  735,  736,  737,  738,  739,  740,  741,
  742,  743,  744,   -1,   -1,  747,   -1,  749,  750,  751,
  752,  753,  754,  755,  756,  757,   -1,   40,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   58,   59,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,
   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,
  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,
   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,  266,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
  412,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,   -1,   -1,   -1,
   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,  451,  452,
  453,  454,   -1,  456,   -1,  458,  459,  460,  461,  462,
  463,  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  475,  476,   -1,  478,  479,  480,   -1,   -1,
  602,   -1,  485,  486,  487,  488,  489,   -1,  491,   -1,
   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,
  503,  504,  505,  506,  507,  508,  509,  510,  511,   -1,
  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,  540,  541,  542,
  543,   -1,  545,  546,  547,  548,  549,  550,   -1,  552,
  553,  554,  555,   -1,  557,   -1,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
  573,  574,  575,  576,   -1,  578,  579,  580,  581,   -1,
  583,  584,  585,  586,  587,   -1,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,
   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,  632,
  633,  634,  635,  636,  637,  638,  639,  640,   41,   -1,
   -1,   -1,   -1,  646,   -1,  648,  649,  650,  651,  652,
  653,   -1,  655,   -1,   -1,   -1,   -1,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,
  673,   -1,  675,  676,  677,  678,  679,  680,  681,  682,
  683,   -1,  685,  686,  687,  688,  689,  690,  691,  692,
  693,  694,  695,  696,   -1,  698,  699,  700,   -1,  702,
   -1,   -1,   -1,  706,  707,  708,  709,  710,  711,  712,
  713,  714,  715,  716,  717,  718,    0,  720,  721,   -1,
   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,
  733,  734,  735,  736,  737,  738,  739,  740,  741,  742,
  743,  744,   -1,   -1,  747,   -1,  749,  750,  751,  752,
  753,  754,  755,  756,  757,   -1,   40,   41,   42,   43,
   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   58,   59,   60,   61,   62,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,
   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,
   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,
  264,  265,  266,   -1,  268,  269,   -1,  271,   -1,   -1,
   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,  412,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,
  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,
  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,
  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,
  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,
   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,
  364,  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,
  374,  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
  434,  435,   -1,  437,  438,  439,   -1,   -1,   -1,   -1,
   -1,  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,
  454,   -1,  456,   -1,  458,  459,  460,  461,  462,  463,
  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  475,  476,   -1,  478,  479,  480,   -1,   -1,  602,
   -1,  485,  486,  487,  488,  489,   -1,  491,   -1,   -1,
  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,  503,
  504,  505,  506,  507,  508,  509,  510,  511,   -1,  513,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,  540,  541,  542,  543,
   -1,  545,  546,  547,  548,  549,  550,   -1,  552,  553,
  554,  555,   -1,  557,   -1,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,  573,
  574,  575,  576,   -1,  578,  579,  580,  581,   -1,  583,
  584,  585,  586,  587,   -1,  589,  590,  591,  592,  593,
  594,  595,  596,  597,  598,  599,  600,  601,  602,  603,
  604,  605,  606,  607,  608,  609,  610,  611,  612,  613,
  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,
  624,  625,  626,  627,  628,  629,   -1,   -1,  632,  633,
  634,  635,  636,  637,  638,  639,  640,   41,   -1,   -1,
   -1,   -1,  646,   -1,  648,  649,  650,  651,  652,  653,
   -1,  655,   -1,   -1,   -1,   -1,   60,   61,   62,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,
   -1,  675,  676,  677,  678,  679,  680,  681,  682,  683,
   -1,  685,  686,  687,  688,  689,  690,  691,  692,  693,
  694,  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,
   -1,   -1,  706,  707,  708,  709,  710,  711,  712,  713,
  714,  715,  716,  717,  718,    0,  720,  721,   -1,   -1,
   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,  733,
  734,  735,  736,  737,  738,  739,  740,  741,  742,  743,
  744,   -1,   -1,  747,   -1,  749,  750,  751,  752,  753,
  754,  755,  756,  757,   -1,   40,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   58,   59,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,
   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,
  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,  266,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,  412,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,   -1,   -1,   -1,   -1,   -1,
  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,
   -1,  456,   -1,  458,  459,  460,  461,  462,  463,  464,
  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  475,  476,   -1,  478,  479,  480,   -1,   -1,  602,   -1,
  485,  486,  487,  488,  489,   -1,  491,   -1,   -1,  494,
  495,   -1,   -1,   -1,  499,  500,   -1,   -1,  503,  504,
  505,  506,  507,  508,  509,  510,  511,   -1,  513,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,  540,  541,  542,  543,   -1,
  545,  546,  547,  548,  549,  550,   -1,  552,  553,  554,
  555,   -1,  557,   -1,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,  573,  574,
  575,  576,   -1,  578,  579,  580,  581,   -1,  583,  584,
  585,  586,  587,   -1,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,  614,
  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,
  625,  626,  627,  628,  629,   -1,   -1,  632,  633,  634,
  635,  636,  637,  638,  639,  640,   41,   -1,   -1,   -1,
   -1,  646,   -1,  648,  649,  650,  651,  652,  653,   -1,
  655,   -1,   -1,   -1,   -1,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,
  675,  676,  677,  678,  679,  680,  681,  682,  683,   -1,
  685,  686,  687,  688,  689,  690,  691,  692,  693,  694,
  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,   -1,
   -1,  706,  707,  708,  709,  710,  711,  712,  713,  714,
  715,  716,  717,  718,    0,  720,  721,   -1,   -1,   -1,
   -1,   -1,  727,  728,  729,  730,  731,  732,  733,  734,
  735,  736,  737,  738,  739,  740,  741,  742,  743,  744,
   -1,   -1,  747,   -1,  749,  750,  751,  752,  753,  754,
  755,  756,  757,   -1,   40,   41,   42,   43,   44,   45,
   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   58,   59,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,
  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,
   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,
  266,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,
   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,  412,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,  305,
  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,
   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,  325,
  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,
   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,
  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,
  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,
   -1,  437,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,
   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,
  456,   -1,  458,  459,  460,  461,  462,  463,  464,  465,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,
  476,   -1,  478,  479,  480,   -1,   -1,  602,   -1,  485,
  486,  487,  488,  489,   -1,  491,   -1,   -1,  494,  495,
   -1,   -1,   -1,  499,  500,   -1,   -1,  503,  504,  505,
  506,  507,  508,  509,  510,  511,   -1,  513,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,  540,  541,  542,  543,   -1,  545,
  546,  547,  548,  549,  550,   -1,  552,  553,  554,  555,
   -1,  557,   -1,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,  573,  574,  575,
  576,   -1,  578,  579,  580,  581,   -1,  583,  584,  585,
  586,  587,   -1,  589,  590,  591,  592,  593,  594,  595,
  596,  597,  598,  599,  600,  601,  602,  603,  604,  605,
  606,  607,  608,  609,  610,  611,  612,  613,  614,  615,
  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,
  626,  627,  628,  629,   -1,   -1,  632,  633,  634,  635,
  636,  637,  638,  639,  640,   41,   -1,   -1,   -1,   -1,
  646,   -1,  648,  649,  650,  651,  652,  653,   -1,  655,
   -1,   -1,   -1,   -1,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,
  676,  677,  678,  679,  680,  681,  682,  683,   -1,  685,
  686,  687,  688,  689,  690,  691,  692,  693,  694,  695,
  696,   -1,  698,  699,  700,   -1,  702,   -1,   -1,   -1,
  706,  707,  708,  709,  710,  711,  712,  713,  714,  715,
  716,  717,  718,    0,  720,  721,   -1,   -1,   -1,   -1,
   -1,  727,  728,  729,  730,  731,  732,  733,  734,  735,
  736,  737,  738,  739,  740,  741,  742,  743,  744,   -1,
   -1,  747,   -1,  749,  750,  751,  752,  753,  754,  755,
  756,  757,   -1,   40,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   58,   59,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,
  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,  266,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,  412,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,
   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,
   -1,  458,  459,  460,  461,  462,  463,  464,  465,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,
   -1,  478,  479,  480,   -1,   -1,  602,   -1,  485,  486,
  487,  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,
   -1,   -1,  499,  500,   -1,   -1,  503,  504,  505,  506,
  507,  508,  509,  510,  511,   -1,  513,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,  540,  541,  542,  543,   -1,  545,  546,
  547,  548,  549,  550,   -1,  552,  553,  554,  555,   -1,
  557,   -1,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,  573,  574,  575,  576,
   -1,  578,  579,  580,  581,   -1,  583,  584,  585,  586,
  587,   -1,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,  614,  615,  616,
  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,
  627,  628,  629,   -1,   -1,  632,  633,  634,  635,  636,
  637,  638,  639,  640,   -1,   42,   43,   44,   45,  646,
   47,  648,  649,  650,  651,  652,  653,   -1,  655,   -1,
   -1,   -1,   -1,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,
  677,  678,  679,  680,  681,  682,  683,   -1,  685,  686,
  687,  688,  689,  690,  691,  692,  693,  694,  695,  696,
   -1,  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,
  707,  708,  709,  710,  711,  712,  713,  714,  715,  716,
  717,  718,    0,  720,  721,   -1,   -1,   -1,   -1,   -1,
  727,  728,  729,  730,  731,  732,  733,  734,  735,  736,
  737,  738,  739,  740,  741,  742,  743,  744,   -1,   -1,
  747,   -1,  749,  750,  751,  752,  753,  754,  755,  756,
  757,   -1,   40,   41,   42,   43,   44,   45,   46,   47,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   58,   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,  266,
   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,   -1,   -1,  281,   -1,   -1,  284,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,  257,
   -1,  259,   -1,   -1,  262,   -1,  264,  265,  266,   -1,
  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,
   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,  412,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,  302,  303,  304,  305,  306,   -1,
   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,
  318,  319,  320,   -1,  322,  323,  324,  325,  326,  327,
  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,
  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,
  368,   -1,  370,  371,  372,   -1,  374,  375,  376,  377,
  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,
  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,
   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,
  458,  459,  460,  461,  462,  463,  464,  465,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,
  478,  479,  480,   -1,   -1,  602,   -1,  485,  486,  487,
  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,
   -1,  499,  500,   -1,   -1,  503,  504,  505,  506,  507,
  508,  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,  540,  541,  542,  543,   -1,  545,  546,  547,
  548,  549,  550,   -1,  552,  553,  554,  555,   -1,  557,
   -1,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,  573,  574,  575,  576,   -1,
  578,  579,  580,  581,   -1,  583,  584,  585,  586,  587,
   -1,  589,  590,  591,  592,  593,  594,  595,  596,  597,
  598,  599,  600,  601,  602,  603,  604,  605,  606,  607,
  608,  609,  610,  611,  612,  613,  614,  615,  616,  617,
   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,
  628,  629,   -1,   -1,  632,  633,  634,  635,  636,  637,
  638,  639,  640,   -1,   44,   -1,   -1,   -1,  646,   -1,
  648,  649,  650,  651,  652,  653,   -1,  655,   -1,   -1,
   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,
  678,  679,  680,  681,  682,  683,   -1,  685,  686,  687,
  688,  689,  690,  691,  692,  693,  694,  695,  696,   -1,
  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,
  708,  709,  710,  711,  712,  713,  714,  715,  716,  717,
  718,    0,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,
  728,  729,  730,  731,  732,  733,  734,  735,  736,  737,
  738,  739,  740,  741,  742,  743,  744,   -1,   -1,  747,
   -1,  749,  750,  751,  752,  753,  754,  755,  756,  757,
   -1,   -1,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,
   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  300,   -1,   -1,   -1,   -1,   -1,  306,
   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,  316,
   -1,   -1,  319,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  271,   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,
  387,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  402,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,
  417,   -1,   -1,   -1,  421,  325,   -1,  424,   -1,  426,
   -1,   -1,   -1,  333,   -1,  432,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  350,   -1,  352,   -1,   -1,   -1,   -1,  454,   -1,   -1,
   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,
   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,  266,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,  412,  510,   -1,   -1,  513,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,  556,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,  600,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,  619,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,
  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,  458,
  459,  460,  461,  462,  463,  464,  465,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,
  479,  480,  602,   -1,   -1,   -1,  485,  486,  487,  488,
  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,
  499,  500,   -1,   -1,  503,  504,  505,  506,  507,  508,
  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,  540,  541,  542,  543,   -1,  545,  546,  547,  548,
  549,  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,  573,  574,  575,  576,   -1,  578,
  579,  580,  581,   -1,  583,  584,  585,  586,  587,   -1,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,  614,  615,  616,  617,   -1,
  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,
  629,   -1,   -1,  632,  633,  634,  635,  636,  637,  638,
  639,  640,   -1,   44,   -1,   -1,   -1,  646,   -1,  648,
  649,  650,  651,  652,  653,   -1,  655,   -1,   -1,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,
  679,  680,  681,  682,  683,   -1,  685,  686,  687,  688,
  689,  690,  691,  692,  693,  694,  695,  696,   -1,  698,
  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,
  709,  710,  711,  712,  713,  714,  715,  716,  717,  718,
    0,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,
  729,  730,  731,  732,  733,  734,  735,  736,  737,  738,
  739,  740,  741,  742,  743,  744,   -1,   -1,  747,   -1,
  749,  750,  751,  752,  753,  754,  755,  756,  757,   -1,
   -1,   41,   42,   43,   44,   45,   46,   47,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   59,
   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,  300,   -1,
   -1,   -1,   -1,   -1,  306,   -1,   -1,   -1,  310,  311,
   -1,   -1,   -1,   -1,  316,   -1,   -1,  319,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  329,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  387,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,
  402,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  333,   -1,   -1,  417,   -1,   -1,   -1,  421,
   -1,   -1,   -1,   -1,  426,   -1,   -1,   -1,   -1,  350,
  432,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,  454,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,  262,   -1,  264,  265,  266,   -1,  268,  269,
   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,
  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,  412,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,  302,  303,  304,  305,  306,   -1,  510,  309,
   -1,  513,  312,   -1,  314,  315,   -1,   -1,  318,  319,
  320,   -1,  322,  323,  324,  325,  326,  327,  328,   -1,
   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,
  350,  351,  352,  353,  556,   -1,   -1,  357,  358,   -1,
  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,
  370,  371,  372,   -1,  374,  375,  376,  377,  378,   -1,
  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,  394,   -1,   -1,  397,  600,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,  619,  418,  419,
  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,
   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,
   -1,  451,  452,  453,  454,   -1,  456,   -1,  458,  459,
  460,  461,  462,  463,  464,  465,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,
  480,  602,   -1,   -1,   -1,  485,  486,  487,  488,  489,
   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,
  500,   -1,   -1,  503,  504,  505,  506,  507,  508,  509,
  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
  540,  541,  542,  543,   -1,  545,  546,  547,  548,  549,
  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,  573,  574,  575,  576,   -1,  578,  579,
  580,  581,   -1,  583,  584,  585,  586,  587,   -1,  589,
  590,  591,  592,  593,  594,  595,  596,  597,  598,  599,
  600,  601,  602,  603,  604,  605,  606,  607,  608,  609,
  610,  611,  612,  613,  614,  615,  616,  617,   -1,  619,
  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,  629,
   -1,   -1,  632,  633,  634,  635,  636,  637,  638,  639,
  640,   -1,   44,   -1,   -1,   -1,  646,   -1,  648,  649,
  650,  651,  652,  653,   -1,  655,   -1,   -1,   60,   61,
   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,  679,
  680,  681,  682,  683,   -1,  685,  686,  687,  688,  689,
  690,  691,  692,  693,  694,  695,  696,   -1,  698,  699,
  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,  709,
  710,  711,  712,  713,  714,  715,  716,  717,  718,    0,
  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,
  730,  731,  732,  733,  734,  735,  736,  737,  738,  739,
  740,  741,  742,  743,  744,   -1,   -1,  747,   -1,  749,
  750,  751,  752,  753,  754,  755,  756,  757,   -1,   -1,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   59,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,
   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,
  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,
   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,  266,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
  412,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,
   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,
  451,  452,  453,  454,   -1,  456,   -1,  458,  459,  460,
  461,  462,  463,  464,  465,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,  480,
  602,   -1,   -1,   -1,  485,  486,  487,  488,  489,   -1,
  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,  500,
   -1,   -1,  503,  504,  505,  506,  507,  508,  509,  510,
  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,  540,
  541,  542,  543,   -1,  545,  546,  547,  548,  549,  550,
   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,  573,  574,  575,  576,   -1,  578,  579,  580,
  581,   -1,  583,  584,  585,  586,  587,   -1,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,  614,  615,  616,  617,   -1,  619,  620,
   -1,   -1,   -1,  624,  625,  626,  627,  628,  629,   -1,
   -1,  632,  633,  634,  635,  636,  637,  638,  639,  640,
   -1,   44,   -1,   -1,   -1,  646,   -1,  648,  649,  650,
  651,  652,  653,   -1,  655,   -1,   -1,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  672,  673,   -1,  675,  676,  677,  678,  679,  680,
  681,  682,  683,   -1,  685,  686,  687,  688,  689,  690,
  691,  692,  693,  694,  695,  696,   -1,  698,  699,  700,
   -1,  702,   -1,   -1,   -1,  706,  707,  708,  709,  710,
  711,  712,  713,  714,  715,  716,  717,  718,    0,  720,
  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,  730,
  731,  732,  733,  734,  735,  736,  737,  738,  739,  740,
  741,  742,  743,  744,   -1,   -1,  747,   -1,  749,  750,
  751,  752,  753,  754,  755,  756,  757,   -1,   -1,   41,
   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   58,   59,   60,   61,
   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,
   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,
   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,
   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,
  262,   -1,  264,  265,  266,   -1,  268,  269,   -1,  271,
   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,  412,
   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,
  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,
  322,  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,
  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,
  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,
  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,
  372,   -1,  374,  375,  376,  377,  378,   -1,  380,  381,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,
  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,   -1,
   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,  451,
  452,  453,  454,   -1,  456,   -1,  458,  459,  460,  461,
  462,  463,  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  475,  476,   -1,  478,  479,  480,  602,
   -1,   -1,   -1,  485,  486,  487,  488,  489,   -1,  491,
   -1,   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,
   -1,  503,  504,  505,  506,  507,  508,  509,  510,  511,
   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,  540,  541,
  542,  543,   -1,  545,  546,  547,  548,  549,  550,   -1,
  552,  553,  554,  555,   -1,  557,   -1,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,  573,  574,  575,  576,   -1,  578,  579,  580,  581,
   -1,  583,  584,  585,  586,  587,   -1,  589,  590,  591,
  592,  593,  594,  595,  596,  597,  598,  599,  600,  601,
  602,  603,  604,  605,  606,  607,  608,  609,  610,  611,
  612,  613,  614,  615,  616,  617,   -1,  619,  620,   -1,
   -1,   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,
  632,  633,  634,  635,  636,  637,  638,  639,  640,   -1,
   44,   -1,   -1,   -1,  646,   -1,  648,  649,  650,  651,
  652,  653,   -1,  655,   -1,   -1,   60,   61,   62,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  672,  673,   -1,  675,  676,  677,  678,  679,  680,  681,
  682,  683,   -1,  685,  686,  687,  688,  689,  690,  691,
  692,  693,  694,  695,  696,   -1,  698,  699,  700,   -1,
  702,   -1,   -1,   -1,  706,  707,  708,  709,  710,  711,
  712,  713,  714,  715,  716,  717,  718,    0,  720,  721,
   -1,   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,
  732,  733,  734,  735,  736,  737,  738,  739,  740,  741,
  742,  743,  744,   -1,   -1,  747,   -1,  749,  750,  751,
  752,  753,  754,  755,  756,  757,   -1,   -1,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   58,   59,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,
   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,
  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,
   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,  266,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,  412,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,   -1,   -1,   -1,
   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,  451,  452,
  453,  454,   -1,  456,   -1,  458,  459,  460,  461,  462,
  463,  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  475,  476,   -1,  478,  479,  480,  602,   -1,
   -1,   -1,  485,  486,  487,  488,  489,   -1,  491,   -1,
   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,
  503,  504,  505,  506,  507,  508,  509,  510,  511,   -1,
  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,  540,  541,  542,
  543,   -1,  545,  546,  547,  548,  549,  550,   -1,  552,
  553,  554,  555,   -1,  557,   -1,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
  573,  574,  575,  576,   -1,  578,  579,  580,  581,   -1,
  583,  584,  585,  586,  587,   -1,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,
   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,  632,
  633,  634,  635,  636,  637,  638,  639,  640,   -1,   44,
   -1,   -1,   -1,  646,   -1,  648,  649,  650,  651,  652,
  653,   -1,  655,   -1,   -1,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,
  673,   -1,  675,  676,  677,  678,  679,  680,  681,  682,
  683,   -1,  685,  686,  687,  688,  689,  690,  691,  692,
  693,  694,  695,  696,   -1,  698,  699,  700,   -1,  702,
   -1,   -1,   -1,  706,  707,  708,  709,  710,  711,  712,
  713,  714,  715,  716,  717,  718,    0,  720,  721,   -1,
   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,
  733,  734,  735,  736,  737,  738,  739,  740,  741,  742,
  743,  744,   -1,   -1,  747,   -1,  749,  750,  751,  752,
  753,  754,  755,  756,  757,   -1,   -1,   41,   42,   43,
   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   58,   59,   60,   61,   62,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,
  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,
   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,
  264,  265,  266,   -1,  268,  269,   -1,  271,   -1,   -1,
   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,  412,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,
  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,
  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,
  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,
  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,
   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,
  364,  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,
  374,  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
  434,  435,   -1,  437,  438,  439,   -1,   -1,   -1,   -1,
   -1,  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,
  454,   -1,  456,   -1,  458,  459,  460,  461,  462,  463,
  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  475,  476,   -1,  478,  479,  480,  602,   -1,   -1,
   -1,  485,  486,  487,  488,  489,   -1,  491,   -1,   -1,
  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,  503,
  504,  505,  506,  507,  508,  509,  510,  511,   -1,  513,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,  540,  541,  542,  543,
   -1,  545,  546,  547,  548,  549,  550,   -1,  552,  553,
  554,  555,   -1,  557,   -1,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,  573,
  574,  575,  576,   -1,  578,  579,  580,  581,   -1,  583,
  584,  585,  586,  587,   -1,  589,  590,  591,  592,  593,
  594,  595,  596,  597,  598,  599,  600,  601,  602,  603,
  604,  605,  606,  607,  608,  609,  610,  611,  612,  613,
  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,
  624,  625,  626,  627,  628,  629,   -1,   -1,  632,  633,
  634,  635,  636,  637,  638,  639,  640,   -1,   44,   -1,
   -1,   -1,  646,   -1,  648,  649,  650,  651,  652,  653,
   -1,  655,   -1,   -1,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,
   -1,  675,  676,  677,  678,  679,  680,  681,  682,  683,
   -1,  685,  686,  687,  688,  689,  690,  691,  692,  693,
  694,  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,
   -1,   -1,  706,  707,  708,  709,  710,  711,  712,  713,
  714,  715,  716,  717,  718,    0,  720,  721,   -1,   -1,
   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,  733,
  734,  735,  736,  737,  738,  739,  740,  741,  742,  743,
  744,   -1,   -1,  747,   -1,  749,  750,  751,  752,  753,
  754,  755,  756,  757,   -1,   -1,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   58,   59,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,
  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,  266,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,  412,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,   -1,   -1,   -1,   -1,   -1,
  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,
   -1,  456,   -1,  458,  459,  460,  461,  462,  463,  464,
  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  475,  476,   -1,  478,  479,  480,  602,   -1,   -1,   -1,
  485,  486,  487,  488,  489,   -1,  491,   -1,   -1,  494,
  495,   -1,   -1,   -1,  499,  500,   -1,   -1,  503,  504,
  505,  506,  507,  508,  509,  510,  511,   -1,  513,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,  540,  541,  542,  543,   -1,
  545,  546,  547,  548,  549,  550,   -1,  552,  553,  554,
  555,   -1,  557,   -1,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,  573,  574,
  575,  576,   -1,  578,  579,  580,  581,   -1,  583,  584,
  585,  586,  587,   -1,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,  614,
  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,
  625,  626,  627,  628,  629,   -1,   -1,  632,  633,  634,
  635,  636,  637,  638,  639,  640,   -1,   44,   -1,   -1,
   -1,  646,   -1,  648,  649,  650,  651,  652,  653,   -1,
  655,   -1,   -1,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,
  675,  676,  677,  678,  679,  680,  681,  682,  683,   -1,
  685,  686,  687,  688,  689,  690,  691,  692,  693,  694,
  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,   -1,
   -1,  706,  707,  708,  709,  710,  711,  712,  713,  714,
  715,  716,  717,  718,    0,  720,  721,   -1,   -1,   -1,
   -1,   -1,  727,  728,  729,  730,  731,  732,  733,  734,
  735,  736,  737,  738,  739,  740,  741,  742,  743,  744,
   -1,   -1,  747,   -1,  749,  750,  751,  752,  753,  754,
  755,  756,  757,   -1,   -1,   41,   42,   43,   44,   45,
   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   58,   59,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,
   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,
  266,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,
   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,  412,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,  305,
  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,
   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,  325,
  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,
   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,
  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,
  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,
   -1,  437,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,
   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,
  456,   -1,  458,  459,  460,  461,  462,  463,  464,  465,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,
  476,   -1,  478,  479,  480,  602,   -1,   -1,   -1,  485,
  486,  487,  488,  489,   -1,  491,   -1,   -1,  494,  495,
   -1,   -1,   -1,  499,  500,   -1,   -1,  503,  504,  505,
  506,  507,  508,  509,  510,  511,   -1,  513,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,  540,  541,  542,  543,   -1,  545,
  546,  547,  548,  549,  550,   -1,  552,  553,  554,  555,
   -1,  557,   -1,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,  573,  574,  575,
  576,   -1,  578,  579,  580,  581,   -1,  583,  584,  585,
  586,  587,   -1,  589,  590,  591,  592,  593,  594,  595,
  596,  597,  598,  599,  600,  601,  602,  603,  604,  605,
  606,  607,  608,  609,  610,  611,  612,  613,  614,  615,
  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,
  626,  627,  628,  629,   -1,   -1,  632,  633,  634,  635,
  636,  637,  638,  639,  640,   -1,   44,   -1,   -1,   -1,
  646,   -1,  648,  649,  650,  651,  652,  653,   -1,  655,
   -1,   -1,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,
  676,  677,  678,  679,  680,  681,  682,  683,   -1,  685,
  686,  687,  688,  689,  690,  691,  692,  693,  694,  695,
  696,   -1,  698,  699,  700,   -1,  702,   -1,   -1,   -1,
  706,  707,  708,  709,  710,  711,  712,  713,  714,  715,
  716,  717,  718,    0,  720,  721,   -1,   -1,   -1,   -1,
   -1,  727,  728,  729,  730,  731,  732,  733,  734,  735,
  736,  737,  738,  739,  740,  741,  742,  743,  744,   -1,
   -1,  747,   -1,  749,  750,  751,  752,  753,  754,  755,
  756,  757,   -1,   -1,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   58,   59,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,
   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,  266,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,  412,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,
   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,
   -1,  458,  459,  460,  461,  462,  463,  464,  465,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,
   -1,  478,  479,  480,  602,   -1,   -1,   -1,  485,  486,
  487,  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,
   -1,   -1,  499,  500,   -1,   -1,  503,  504,  505,  506,
  507,  508,  509,  510,  511,   -1,  513,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,  540,  541,  542,  543,   -1,  545,  546,
  547,  548,  549,  550,   -1,  552,  553,  554,  555,   -1,
  557,   -1,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,  573,  574,  575,  576,
   -1,  578,  579,  580,  581,   -1,  583,  584,  585,  586,
  587,   -1,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,  614,  615,  616,
  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,
  627,  628,  629,   -1,   -1,  632,  633,  634,  635,  636,
  637,  638,  639,  640,   -1,   44,   -1,   -1,   -1,  646,
   -1,  648,  649,  650,  651,  652,  653,   -1,  655,   -1,
   -1,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,
  677,  678,  679,  680,  681,  682,  683,   -1,  685,  686,
  687,  688,  689,  690,  691,  692,  693,  694,  695,  696,
   -1,  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,
  707,  708,  709,  710,  711,  712,  713,  714,  715,  716,
  717,  718,    0,  720,  721,   -1,   -1,   -1,   -1,   -1,
  727,  728,  729,  730,  731,  732,  733,  734,  735,  736,
  737,  738,  739,  740,  741,  742,  743,  744,   -1,   -1,
  747,   -1,  749,  750,  751,  752,  753,  754,  755,  756,
  757,   -1,   -1,   41,   42,   43,   44,   45,   46,   47,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,
   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,
   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,  257,
   -1,  259,   -1,   -1,  262,   -1,  264,  265,  266,   -1,
  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,
   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,  412,   -1,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,  302,  303,  304,  305,  306,   -1,
   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,
  318,  319,  320,   -1,  322,  323,  324,  325,  326,  327,
  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,
  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,
  368,   -1,  370,  371,  372,   -1,  374,  375,  376,  377,
  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,
  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,
   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,
  458,  459,  460,  461,  462,  463,  464,  465,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,
  478,  479,  480,  602,   -1,   -1,   -1,  485,  486,  487,
  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,
   -1,  499,  500,   -1,   -1,  503,  504,  505,  506,  507,
  508,  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,  540,  541,  542,  543,   -1,  545,  546,  547,
  548,  549,  550,   -1,  552,  553,  554,  555,   -1,  557,
   -1,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,  573,  574,  575,  576,   -1,
  578,  579,  580,  581,   -1,  583,  584,  585,  586,  587,
   -1,  589,  590,  591,  592,  593,  594,  595,  596,  597,
  598,  599,  600,  601,  602,  603,  604,  605,  606,  607,
  608,  609,  610,  611,  612,  613,  614,  615,  616,  617,
   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,
  628,  629,   -1,   -1,  632,  633,  634,  635,  636,  637,
  638,  639,  640,   -1,   44,   -1,   -1,   -1,  646,   -1,
  648,  649,  650,  651,  652,  653,   -1,  655,   -1,   -1,
   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,
  678,  679,  680,  681,  682,  683,   -1,  685,  686,  687,
  688,  689,  690,  691,  692,  693,  694,  695,  696,   -1,
  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,
  708,  709,  710,  711,  712,  713,  714,  715,  716,  717,
  718,    0,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,
  728,  729,  730,  731,  732,  733,  734,  735,  736,  737,
  738,  739,  740,  741,  742,  743,  744,   -1,   -1,  747,
   -1,  749,  750,  751,  752,  753,  754,  755,  756,  757,
   -1,   -1,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,
   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,
   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,  266,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,  412,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,
  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,  458,
  459,  460,  461,  462,  463,  464,  465,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,
  479,  480,  602,   -1,   -1,   -1,  485,  486,  487,  488,
  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,
  499,  500,   -1,   -1,  503,  504,  505,  506,  507,  508,
  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,  540,  541,  542,  543,   -1,  545,  546,  547,  548,
  549,  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,  573,  574,  575,  576,   -1,  578,
  579,  580,  581,   -1,  583,  584,  585,  586,  587,   -1,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,  614,  615,  616,  617,   -1,
  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,
  629,   -1,   -1,  632,  633,  634,  635,  636,  637,  638,
  639,  640,   -1,   44,   -1,   -1,   -1,  646,   -1,  648,
  649,  650,  651,  652,  653,   -1,  655,   -1,   -1,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,
  679,  680,  681,  682,  683,   -1,  685,  686,  687,  688,
  689,  690,  691,  692,  693,  694,  695,  696,   -1,  698,
  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,
  709,  710,  711,  712,  713,  714,  715,  716,  717,  718,
    0,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,
  729,  730,  731,  732,  733,  734,  735,  736,  737,  738,
  739,  740,  741,  742,  743,  744,   -1,   -1,  747,   -1,
  749,  750,  751,  752,  753,  754,  755,  756,  757,   -1,
   -1,   41,   42,   43,   44,   45,   46,   47,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,
   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,
   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,
   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,  262,   -1,  264,  265,  266,   -1,  268,  269,
   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,
  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,  412,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,
   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,
  320,   -1,  322,  323,  324,  325,  326,  327,  328,   -1,
   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,
  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,
  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,
  370,  371,  372,   -1,  374,  375,  376,  377,  378,   -1,
  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,  419,
  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,
   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,
   -1,  451,  452,  453,  454,   -1,  456,   -1,  458,  459,
  460,  461,  462,  463,  464,  465,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,
  480,  602,   -1,   -1,   -1,  485,  486,  487,  488,  489,
   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,
  500,   -1,   -1,  503,  504,  505,  506,  507,  508,  509,
  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
  540,  541,  542,  543,   -1,  545,  546,  547,  548,  549,
  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,  573,  574,  575,  576,   -1,  578,  579,
  580,  581,   -1,  583,  584,  585,  586,  587,   -1,  589,
  590,  591,  592,  593,  594,  595,  596,  597,  598,  599,
  600,  601,  602,  603,  604,  605,  606,  607,  608,  609,
  610,  611,  612,  613,  614,  615,  616,  617,   -1,  619,
  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,  629,
   -1,   -1,  632,  633,  634,  635,  636,  637,  638,  639,
  640,   -1,   44,   -1,   -1,   -1,  646,   -1,  648,  649,
  650,  651,  652,  653,   -1,  655,   -1,   -1,   60,   61,
   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,  679,
  680,  681,  682,  683,   -1,  685,  686,  687,  688,  689,
  690,  691,  692,  693,  694,  695,  696,   -1,  698,  699,
  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,  709,
  710,  711,  712,  713,  714,  715,  716,  717,  718,    0,
  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,
  730,  731,  732,  733,  734,  735,  736,  737,  738,  739,
  740,  741,  742,  743,  744,   -1,   -1,  747,   -1,  749,
  750,  751,  752,  753,  754,  755,  756,  757,   -1,   -1,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,
   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,
  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,
   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,  266,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
  412,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,
   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,
  451,  452,  453,  454,   -1,  456,   -1,  458,  459,  460,
  461,  462,  463,  464,  465,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,  480,
  602,   -1,   -1,   -1,  485,  486,  487,  488,  489,   -1,
  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,  500,
   -1,   -1,  503,  504,  505,  506,  507,  508,  509,  510,
  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,  540,
  541,  542,  543,   -1,  545,  546,  547,  548,  549,  550,
   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,  573,  574,  575,  576,   -1,  578,  579,  580,
  581,   -1,  583,  584,  585,  586,  587,   -1,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,  614,  615,  616,  617,   -1,  619,  620,
   -1,   -1,   -1,  624,  625,  626,  627,  628,  629,   -1,
   -1,  632,  633,  634,  635,  636,  637,  638,  639,  640,
   -1,   44,   -1,   -1,   -1,  646,   -1,  648,  649,  650,
  651,  652,  653,   -1,  655,   -1,   -1,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  672,  673,   -1,  675,  676,  677,  678,  679,  680,
  681,  682,  683,   -1,  685,  686,  687,  688,  689,  690,
  691,  692,  693,  694,  695,  696,   -1,  698,  699,  700,
   -1,  702,   -1,   -1,   -1,  706,  707,  708,  709,  710,
  711,  712,  713,  714,  715,  716,  717,  718,    0,  720,
  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,  730,
  731,  732,  733,  734,  735,  736,  737,  738,  739,  740,
  741,  742,  743,  744,   -1,   -1,  747,   -1,  749,  750,
  751,  752,  753,  754,  755,  756,  757,   -1,   -1,   41,
   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,   60,   61,
   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,
   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,
   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,
   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,
  262,   -1,  264,  265,  266,   -1,  268,  269,   -1,  271,
   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,  412,
   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,
  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,
  322,  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,
  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,
  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,
  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,
  372,   -1,  374,  375,  376,  377,  378,   -1,  380,  381,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,
  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,   -1,
   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,  451,
  452,  453,  454,   -1,  456,   -1,  458,  459,  460,  461,
  462,  463,  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  475,  476,   -1,  478,  479,  480,  602,
   -1,   -1,   -1,  485,  486,  487,  488,  489,   -1,  491,
   -1,   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,
   -1,  503,  504,  505,  506,  507,  508,  509,  510,  511,
   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,  540,  541,
  542,  543,   -1,  545,  546,  547,  548,  549,  550,   -1,
  552,  553,  554,  555,   -1,  557,   -1,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,  573,  574,  575,  576,   -1,  578,  579,  580,  581,
   -1,  583,  584,  585,  586,  587,   -1,  589,  590,  591,
  592,  593,  594,  595,  596,  597,  598,  599,  600,  601,
  602,  603,  604,  605,  606,  607,  608,  609,  610,  611,
  612,  613,  614,  615,  616,  617,   -1,  619,  620,   -1,
   -1,   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,
  632,  633,  634,  635,  636,  637,  638,  639,  640,   -1,
   44,   -1,   -1,   -1,  646,   -1,  648,  649,  650,  651,
  652,  653,   -1,  655,   -1,   -1,   60,   61,   62,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  672,  673,   -1,  675,  676,  677,  678,  679,  680,  681,
  682,  683,   -1,  685,  686,  687,  688,  689,  690,  691,
  692,  693,  694,  695,  696,   -1,  698,  699,  700,   -1,
  702,   -1,   -1,   -1,  706,  707,  708,  709,  710,  711,
  712,  713,  714,  715,  716,  717,  718,    0,  720,  721,
   -1,   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,
  732,  733,  734,  735,  736,  737,  738,  739,  740,  741,
  742,  743,  744,   -1,   -1,  747,   -1,  749,  750,  751,
  752,  753,  754,  755,  756,  757,   -1,   -1,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   59,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,
   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,
  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,
   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,  266,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,  412,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,   -1,   -1,   -1,
   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,  451,  452,
  453,  454,   -1,  456,   -1,  458,  459,  460,  461,  462,
  463,  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  475,  476,   -1,  478,  479,  480,  602,   -1,
   -1,   -1,  485,  486,  487,  488,  489,   -1,  491,   -1,
   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,
  503,  504,  505,  506,  507,  508,  509,  510,  511,   -1,
  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,  540,  541,  542,
  543,   -1,  545,  546,  547,  548,  549,  550,   -1,  552,
  553,  554,  555,   -1,  557,   -1,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
  573,  574,  575,  576,   -1,  578,  579,  580,  581,   -1,
  583,  584,  585,  586,  587,   -1,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,
   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,  632,
  633,  634,  635,  636,  637,  638,  639,  640,   -1,   44,
   -1,   -1,   -1,  646,   -1,  648,  649,  650,  651,  652,
  653,   -1,  655,   -1,   -1,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,
  673,   -1,  675,  676,  677,  678,  679,  680,  681,  682,
  683,   -1,  685,  686,  687,  688,  689,  690,  691,  692,
  693,  694,  695,  696,   -1,  698,  699,  700,   -1,  702,
   -1,   -1,   -1,  706,  707,  708,  709,  710,  711,  712,
  713,  714,  715,  716,  717,  718,    0,  720,  721,   -1,
   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,
  733,  734,  735,  736,  737,  738,  739,  740,  741,  742,
  743,  744,   -1,   -1,  747,   -1,  749,  750,  751,  752,
  753,  754,  755,  756,  757,   -1,   -1,   41,   42,   43,
   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   59,   60,   61,   62,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,
  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,
   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,
  264,  265,  266,   -1,  268,  269,   -1,  271,   -1,   -1,
   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,  412,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,
  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,
  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,
  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,
  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,
   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,
  364,  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,
  374,  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
  434,  435,   -1,  437,  438,  439,   -1,   -1,   -1,   -1,
   -1,  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,
  454,   -1,  456,   -1,  458,  459,  460,  461,  462,  463,
  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  475,  476,   -1,  478,  479,  480,  602,   -1,   -1,
   -1,  485,  486,  487,  488,  489,   -1,  491,   -1,   -1,
  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,  503,
  504,  505,  506,  507,  508,  509,  510,  511,   -1,  513,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,  540,  541,  542,  543,
   -1,  545,  546,  547,  548,  549,  550,   -1,  552,  553,
  554,  555,   -1,  557,   -1,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,  573,
  574,  575,  576,   -1,  578,  579,  580,  581,   -1,  583,
  584,  585,  586,  587,   -1,  589,  590,  591,  592,  593,
  594,  595,  596,  597,  598,  599,  600,  601,  602,  603,
  604,  605,  606,  607,  608,  609,  610,  611,  612,  613,
  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,
  624,  625,  626,  627,  628,  629,   -1,   -1,  632,  633,
  634,  635,  636,  637,  638,  639,  640,   -1,   44,   -1,
   -1,   -1,  646,   -1,  648,  649,  650,  651,  652,  653,
   -1,  655,   -1,   -1,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,
   -1,  675,  676,  677,  678,  679,  680,  681,  682,  683,
   -1,  685,  686,  687,  688,  689,  690,  691,  692,  693,
  694,  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,
   -1,   -1,  706,  707,  708,  709,  710,  711,  712,  713,
  714,  715,  716,  717,  718,    0,  720,  721,   -1,   -1,
   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,  733,
  734,  735,  736,  737,  738,  739,  740,  741,  742,  743,
  744,   -1,   -1,  747,   -1,  749,  750,  751,  752,  753,
  754,  755,  756,  757,   -1,   -1,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   59,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,
  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,  266,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,  412,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,   -1,   -1,   -1,   -1,   -1,
  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,
   -1,  456,   -1,  458,  459,  460,  461,  462,  463,  464,
  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  475,  476,   -1,  478,  479,  480,  602,   -1,   -1,   -1,
  485,  486,  487,  488,  489,   -1,  491,   -1,   -1,  494,
  495,   -1,   -1,   -1,  499,  500,   -1,   -1,  503,  504,
  505,  506,  507,  508,  509,  510,  511,   -1,  513,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,  540,  541,  542,  543,   -1,
  545,  546,  547,  548,  549,  550,   -1,  552,  553,  554,
  555,   -1,  557,   -1,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,  573,  574,
  575,  576,   -1,  578,  579,  580,  581,   -1,  583,  584,
  585,  586,  587,   -1,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,  614,
  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,
  625,  626,  627,  628,  629,   -1,   -1,  632,  633,  634,
  635,  636,  637,  638,  639,  640,   -1,   44,   -1,   -1,
   -1,  646,   -1,  648,  649,  650,  651,  652,  653,   -1,
  655,   -1,   -1,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,
  675,  676,  677,  678,  679,  680,  681,  682,  683,   -1,
  685,  686,  687,  688,  689,  690,  691,  692,  693,  694,
  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,   -1,
   -1,  706,  707,  708,  709,  710,  711,  712,  713,  714,
  715,  716,  717,  718,    0,  720,  721,   -1,   -1,   -1,
   -1,   -1,  727,  728,  729,  730,  731,  732,  733,  734,
  735,  736,  737,  738,  739,  740,  741,  742,  743,  744,
   -1,   -1,  747,   -1,  749,  750,  751,  752,  753,  754,
  755,  756,  757,   -1,   -1,   41,   42,   43,   44,   45,
   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   59,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,
   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,
  266,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,
   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,  412,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,  305,
  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,
   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,  325,
  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,
   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,
  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,
  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,
   -1,  437,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,
   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,
  456,   -1,  458,  459,  460,  461,  462,  463,  464,  465,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,
  476,   -1,  478,  479,  480,  602,   -1,   -1,   -1,  485,
  486,  487,  488,  489,   -1,  491,   -1,   -1,  494,  495,
   -1,   -1,   -1,  499,  500,   -1,   -1,  503,  504,  505,
  506,  507,  508,  509,  510,  511,   -1,  513,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,  540,  541,  542,  543,   -1,  545,
  546,  547,  548,  549,  550,   -1,  552,  553,  554,  555,
   -1,  557,   -1,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,  573,  574,  575,
  576,   -1,  578,  579,  580,  581,   -1,  583,  584,  585,
  586,  587,   -1,  589,  590,  591,  592,  593,  594,  595,
  596,  597,  598,  599,  600,  601,  602,  603,  604,  605,
  606,  607,  608,  609,  610,  611,  612,  613,  614,  615,
  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,
  626,  627,  628,  629,   -1,   -1,  632,  633,  634,  635,
  636,  637,  638,  639,  640,   -1,   44,   -1,   -1,   -1,
  646,   -1,  648,  649,  650,  651,  652,  653,   -1,  655,
   -1,   -1,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,
  676,  677,  678,  679,  680,  681,  682,  683,   -1,  685,
  686,  687,  688,  689,  690,  691,  692,  693,  694,  695,
  696,   -1,  698,  699,  700,   -1,  702,   -1,   -1,   -1,
  706,  707,  708,  709,  710,  711,  712,  713,  714,  715,
  716,  717,  718,    0,  720,  721,   -1,   -1,   -1,   -1,
   -1,  727,  728,  729,  730,  731,  732,  733,  734,  735,
  736,  737,  738,  739,  740,  741,  742,  743,  744,   -1,
   -1,  747,   -1,  749,  750,  751,  752,  753,  754,  755,
  756,  757,   -1,   -1,   41,   42,   43,   44,   45,   46,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   59,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,
   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,  266,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,  412,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,
   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,
   -1,  458,  459,  460,  461,  462,  463,  464,  465,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,
   -1,  478,  479,  480,  602,   -1,   -1,   -1,  485,  486,
  487,  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,
   -1,   -1,  499,  500,   -1,   -1,  503,  504,  505,  506,
  507,  508,  509,  510,  511,   -1,  513,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,  540,  541,  542,  543,   -1,  545,  546,
  547,  548,  549,  550,   -1,  552,  553,  554,  555,   -1,
  557,   -1,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,  573,  574,  575,  576,
   -1,  578,  579,  580,  581,   -1,  583,  584,  585,  586,
  587,   -1,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,  609,  610,  611,  612,  613,  614,  615,  616,
  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,
  627,  628,  629,   -1,   -1,  632,  633,  634,  635,  636,
  637,  638,  639,  640,   -1,   44,   -1,   -1,   -1,  646,
   -1,  648,  649,  650,  651,  652,  653,   -1,  655,   -1,
   -1,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,
  677,  678,  679,  680,  681,  682,  683,   -1,  685,  686,
  687,  688,  689,  690,  691,  692,  693,  694,  695,  696,
   -1,  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,
  707,  708,  709,  710,  711,  712,  713,  714,  715,  716,
  717,  718,    0,  720,  721,   -1,   -1,   -1,   -1,   -1,
  727,  728,  729,  730,  731,  732,  733,  734,  735,  736,
  737,  738,  739,  740,  741,  742,  743,  744,   -1,   -1,
  747,   -1,  749,  750,  751,  752,  753,  754,  755,  756,
  757,   -1,   -1,   41,   42,   43,   44,   45,   46,   47,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,
   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,
   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,  257,
   -1,  259,   -1,   -1,  262,   -1,  264,  265,  266,   -1,
  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,
   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,  412,   -1,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,  302,  303,  304,  305,  306,   -1,
   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,
  318,  319,  320,   -1,  322,  323,  324,  325,  326,  327,
  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,
  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,
  368,   -1,  370,  371,  372,   -1,  374,  375,  376,  377,
  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,
  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,
   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,
  458,  459,  460,  461,  462,  463,  464,  465,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,
  478,  479,  480,  602,   -1,   -1,   -1,  485,  486,  487,
  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,
   -1,  499,  500,   -1,   -1,  503,  504,  505,  506,  507,
  508,  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,  540,  541,  542,  543,   -1,  545,  546,  547,
  548,  549,  550,   -1,  552,  553,  554,  555,   -1,  557,
   -1,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,  573,  574,  575,  576,   -1,
  578,  579,  580,  581,   -1,  583,  584,  585,  586,  587,
   -1,  589,  590,  591,  592,  593,  594,  595,  596,  597,
  598,  599,  600,  601,  602,  603,  604,  605,  606,  607,
  608,  609,  610,  611,  612,  613,  614,  615,  616,  617,
   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,
  628,  629,   -1,   -1,  632,  633,  634,  635,  636,  637,
  638,  639,  640,   -1,   44,   -1,   -1,   -1,  646,   -1,
  648,  649,  650,  651,  652,  653,   -1,  655,   -1,   -1,
   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,
  678,  679,  680,  681,  682,  683,   -1,  685,  686,  687,
  688,  689,  690,  691,  692,  693,  694,  695,  696,   -1,
  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,
  708,  709,  710,  711,  712,  713,  714,  715,  716,  717,
  718,    0,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,
  728,  729,  730,  731,  732,  733,  734,  735,  736,  737,
  738,  739,  740,  741,  742,  743,  744,   -1,   -1,  747,
   -1,  749,  750,  751,  752,  753,  754,  755,  756,  757,
   -1,   -1,   41,   42,   43,   44,   45,   46,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,
   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,
   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,  266,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,  412,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,
  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,  458,
  459,  460,  461,  462,  463,  464,  465,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,
  479,  480,  602,   -1,   -1,   -1,  485,  486,  487,  488,
  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,
  499,  500,   -1,   -1,  503,  504,  505,  506,  507,  508,
  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,  540,  541,  542,  543,   -1,  545,  546,  547,  548,
  549,  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,  573,  574,  575,  576,   -1,  578,
  579,  580,  581,   -1,  583,  584,  585,  586,  587,   -1,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
  609,  610,  611,  612,  613,  614,  615,  616,  617,   -1,
  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,
  629,   -1,   -1,  632,  633,  634,  635,  636,  637,  638,
  639,  640,   -1,   44,   -1,   -1,   -1,  646,   -1,  648,
  649,  650,  651,  652,  653,   -1,  655,   -1,   -1,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,
  679,  680,  681,  682,  683,   -1,  685,  686,  687,  688,
  689,  690,  691,  692,  693,  694,  695,  696,   -1,  698,
  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,
  709,  710,  711,  712,  713,  714,  715,  716,  717,  718,
    0,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,
  729,  730,  731,  732,  733,  734,  735,  736,  737,  738,
  739,  740,  741,  742,  743,  744,   -1,   -1,  747,   -1,
  749,  750,  751,  752,  753,  754,  755,  756,  757,   -1,
   -1,   41,   42,   43,   44,   45,   46,   47,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,
   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,
   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,
   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,  262,   -1,  264,  265,  266,   -1,  268,  269,
   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,
  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,  412,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,
   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,
  320,   -1,  322,  323,  324,  325,  326,  327,  328,   -1,
   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,
  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,
  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,
  370,  371,  372,   -1,  374,  375,  376,  377,  378,   -1,
  380,  381,   -1,   -1,    0,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,  419,
  420,   -1,  422,  423,   -1,   41,   -1,   -1,   44,   -1,
   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,
   -1,   -1,   -1,   59,   -1,  445,   -1,   -1,   -1,  449,
   -1,  451,  452,  453,  454,   -1,  456,   -1,  458,  459,
  460,  461,  462,  463,  464,  465,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,
  480,  602,   -1,   -1,   -1,  485,  486,  487,  488,  489,
   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,
  500,   -1,   -1,  503,  504,  505,  506,  507,  508,  509,
  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
  540,  541,  542,  543,   -1,  545,  546,  547,  548,  549,
  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,  573,  574,  575,  576,   -1,  578,  579,
  580,  581,   -1,  583,  584,  585,  586,  587,   -1,  589,
  590,  591,  592,  593,  594,  595,  596,  597,  598,  599,
  600,  601,  602,  603,  604,  605,  606,  607,  608,  609,
  610,  611,  612,  613,  614,  615,  616,  617,   -1,  619,
  620,   60,   61,   62,  624,  625,  626,  627,  628,  629,
   -1,   -1,  632,  633,  634,  635,  636,  637,  638,  639,
  640,   -1,   -1,   -1,   -1,   -1,  646,   -1,  648,  649,
  650,  651,  652,  653,   -1,  655,   -1,   -1,   -1,   -1,
  276,  277,   -1,   -1,   -1,   -1,   -1,  283,   -1,   -1,
   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,  679,
  680,  681,  682,  683,   -1,  685,  686,  687,  688,  689,
  690,  691,  692,  693,  694,  695,  696,   -1,  698,  699,
  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,  709,
  710,  711,  712,  713,  714,  715,  716,  717,  718,    0,
  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,
  730,  731,  732,  733,  734,  735,  736,  737,  738,  739,
  740,  741,  742,  743,  744,   -1,   -1,  747,  364,  749,
  750,  751,  752,  753,  754,  755,  756,  757,   -1,   -1,
   41,   42,   43,   44,   45,   46,   47,   -1,   -1,  385,
   -1,   -1,   -1,   -1,   -1,  391,   -1,   -1,   59,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  424,   -1,
   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  262,   -1,   -1,  265,   -1,   -1,   -1,
   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  487,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,
   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,
   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  412,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,  266,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,
   -1,   -1,   -1,  602,  445,   -1,   -1,   -1,  449,   -1,
  451,  452,  453,  454,   -1,  456,   -1,  458,  459,  460,
  461,  462,  463,  464,  465,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,  480,
   -1,   -1,   -1,   -1,  485,  486,  487,  488,  489,   -1,
  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,  500,
   -1,   -1,  503,  504,  505,  506,  507,  508,  509,  510,
  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,  540,
  541,  542,  543,   -1,  545,  546,  547,  548,  549,  550,
   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,  573,  574,  575,  576,   -1,  578,  579,  580,
  581,   -1,  583,  584,  585,  586,  587,   -1,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,  609,  610,
  611,  612,  613,  614,  615,  616,  617,   -1,  619,  620,
   60,   61,   62,  624,  625,  626,  627,  628,  629,   -1,
   -1,  632,  633,  634,  635,  636,  637,  638,  639,  640,
   -1,   -1,   -1,   -1,   -1,  646,   -1,  648,  649,  650,
  651,  652,  653,   -1,  655,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  672,  673,   -1,  675,  676,  677,  678,  679,  680,
  681,  682,  683,   -1,  685,  686,  687,  688,  689,  690,
  691,  692,  693,  694,  695,  696,   -1,  698,  699,  700,
   -1,  702,   -1,   -1,   -1,  706,  707,  708,  709,  710,
  711,  712,  713,  714,  715,  716,  717,  718,    0,  720,
  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,  730,
  731,  732,  733,  734,  735,  736,  737,  738,  739,  740,
  741,  742,  743,  744,   -1,   -1,  747,   -1,  749,  750,
  751,  752,  753,  754,  755,  756,  757,   -1,   -1,   41,
   42,   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,   60,   61,
   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,
   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,
   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,
   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  412,   -1,   -1,  257,   -1,  259,   -1,  419,
  262,   -1,  264,  265,  266,   -1,  268,  269,   -1,  271,
   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,
  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,
  322,  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,
  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,
  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,
  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,
  372,   -1,  374,  375,  376,  377,  378,   -1,  380,  381,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,
  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,   -1,
   -1,   -1,  602,  445,   -1,   -1,   -1,  449,   -1,  451,
  452,  453,  454,   -1,  456,   -1,  458,  459,  460,  461,
  462,  463,  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  475,  476,   -1,  478,  479,  480,   -1,
   -1,   -1,   -1,  485,  486,  487,  488,  489,   -1,  491,
   -1,   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,
   -1,  503,  504,  505,  506,  507,  508,  509,  510,  511,
   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,  540,  541,
  542,  543,   -1,  545,  546,  547,  548,  549,  550,   -1,
  552,  553,  554,  555,   -1,  557,   -1,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,  573,  574,  575,  576,   -1,  578,  579,  580,  581,
   -1,  583,  584,  585,  586,  587,   -1,  589,  590,  591,
  592,  593,  594,  595,  596,  597,  598,  599,  600,  601,
  602,  603,  604,  605,  606,  607,  608,  609,  610,  611,
  612,  613,  614,  615,  616,  617,   -1,  619,  620,   60,
   61,   62,  624,  625,  626,  627,  628,  629,   -1,   -1,
  632,  633,  634,  635,  636,  637,  638,  639,  640,   -1,
   -1,   -1,   -1,   -1,  646,   -1,  648,  649,  650,  651,
  652,  653,   -1,  655,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  672,  673,   -1,  675,  676,  677,  678,  679,  680,  681,
  682,  683,   -1,  685,  686,  687,  688,  689,  690,  691,
  692,  693,  694,  695,  696,   -1,  698,  699,  700,   -1,
  702,   -1,   -1,   -1,  706,  707,  708,  709,  710,  711,
  712,  713,  714,  715,  716,  717,  718,    0,  720,  721,
   -1,   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,
  732,  733,  734,  735,  736,  737,  738,  739,  740,  741,
  742,  743,  744,   -1,   -1,  747,   -1,  749,  750,  751,
  752,  753,  754,  755,  756,  757,   -1,   -1,   41,   42,
   43,   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   59,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  262,   -1,  264,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,
   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,
   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  412,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,  266,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,   -1,   -1,   -1,
   -1,  602,  445,   -1,   -1,   -1,  449,   -1,  451,  452,
  453,  454,   -1,  456,   -1,  458,  459,  460,  461,  462,
  463,  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  475,  476,   -1,  478,  479,  480,   -1,   -1,
   -1,   -1,  485,  486,  487,  488,  489,   -1,  491,   -1,
   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,
  503,  504,  505,  506,  507,  508,  509,  510,  511,   -1,
  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,  540,  541,  542,
  543,   -1,  545,  546,  547,  548,  549,  550,   -1,  552,
  553,  554,  555,   -1,  557,   -1,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
  573,  574,  575,  576,   -1,  578,  579,  580,  581,   -1,
  583,  584,  585,  586,  587,   -1,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,  609,  610,  611,  612,
  613,  614,  615,  616,  617,   -1,  619,  620,   60,   61,
   62,  624,  625,  626,  627,  628,  629,   -1,   -1,  632,
  633,  634,  635,  636,  637,  638,  639,  640,   -1,   -1,
   -1,   -1,   -1,  646,   -1,  648,  649,  650,  651,  652,
  653,   -1,  655,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,
  673,   -1,  675,  676,  677,  678,  679,  680,  681,  682,
  683,   -1,  685,  686,  687,  688,  689,  690,  691,  692,
  693,  694,  695,  696,   -1,  698,  699,  700,   -1,  702,
   -1,   -1,   -1,  706,  707,  708,  709,  710,  711,  712,
  713,  714,  715,  716,  717,  718,    0,  720,  721,   -1,
   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,
  733,  734,  735,  736,  737,  738,  739,  740,  741,  742,
  743,  744,   -1,   -1,  747,   -1,  749,  750,  751,  752,
  753,  754,  755,  756,  757,   -1,   -1,   41,   42,   43,
   44,   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   59,   60,   61,   62,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  314,   -1,   -1,   -1,  318,   -1,   -1,   -1,
   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,
  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  412,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,
  264,  265,  266,   -1,  268,  269,   -1,  271,   -1,   -1,
   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,
  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,
  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,
  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,
  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,
   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,
  364,  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,
  374,  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
  434,  435,   -1,  437,  438,  439,   -1,   -1,   -1,   -1,
  602,  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,
  454,   -1,  456,   -1,  458,  459,  460,  461,  462,  463,
  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  475,  476,   -1,  478,  479,  480,   -1,   -1,   -1,
   -1,  485,  486,  487,  488,  489,   -1,  491,   -1,   -1,
  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,  503,
  504,  505,  506,  507,  508,  509,  510,  511,   -1,  513,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,  540,  541,  542,  543,
   -1,  545,  546,  547,  548,  549,  550,   -1,  552,  553,
  554,  555,   -1,  557,   -1,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,  573,
  574,  575,  576,   -1,  578,  579,  580,  581,   -1,  583,
  584,  585,  586,  587,   -1,  589,  590,  591,  592,  593,
  594,  595,  596,  597,  598,  599,  600,  601,  602,  603,
  604,  605,  606,  607,  608,  609,  610,  611,  612,  613,
  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,
  624,  625,  626,  627,  628,  629,   -1,   -1,  632,  633,
  634,  635,  636,  637,  638,  639,  640,   -1,   -1,   60,
   61,   62,  646,   -1,  648,  649,  650,  651,  652,  653,
   -1,  655,   -1,   -1,   -1,   -1,   -1,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,
   -1,  675,  676,  677,  678,  679,  680,  681,  682,  683,
   -1,  685,  686,  687,  688,  689,  690,  691,  692,  693,
  694,  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,
   -1,   -1,  706,  707,  708,  709,  710,  711,  712,  713,
  714,  715,  716,  717,  718,    0,  720,  721,   -1,   -1,
   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,  733,
  734,  735,  736,  737,  738,  739,  740,  741,  742,  743,
  744,   -1,   -1,  747,   -1,  749,  750,  751,  752,  753,
  754,  755,  756,  757,   -1,   -1,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   59,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,
   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,  271,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  314,   -1,   -1,   -1,  318,   -1,   -1,
   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  333,   -1,   -1,  318,   -1,   -1,   -1,   -1,
   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,  350,
  333,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,  350,   -1,  352,
  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,  266,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,  412,  277,   -1,  279,  280,  281,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,  412,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,   -1,   -1,   -1,   -1,   -1,
  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,
  573,  456,   -1,  458,  459,  460,  461,  462,  463,  464,
  465,  602,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  475,  476,   -1,  478,  479,  480,   -1,   -1,   -1,  602,
  485,  486,  487,  488,  489,   -1,  491,   -1,   -1,  494,
  495,   -1,   -1,   -1,  499,  500,   -1,   -1,  503,  504,
  505,  506,  507,  508,  509,  510,  511,   -1,  513,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,  540,  541,  542,  543,   -1,
  545,  546,  547,  548,  549,  550,   -1,  552,  553,  554,
  555,   -1,  557,   -1,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,  573,  574,
  575,  576,   -1,  578,  579,  580,  581,   -1,  583,  584,
  585,  586,  587,   -1,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,  609,  610,  611,  612,  613,  614,
  615,  616,  617,   -1,  619,  620,   60,   61,   62,  624,
  625,  626,  627,  628,  629,   -1,   -1,  632,  633,  634,
  635,  636,  637,  638,  639,  640,   -1,   -1,   -1,   -1,
   -1,  646,   -1,  648,  649,  650,  651,  652,  653,   -1,
  655,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,
  675,  676,  677,  678,  679,  680,  681,  682,  683,   -1,
  685,  686,  687,  688,  689,  690,  691,  692,  693,  694,
  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,   -1,
   -1,  706,  707,  708,  709,  710,  711,  712,  713,  714,
  715,  716,  717,  718,    0,  720,  721,   -1,   -1,   -1,
   -1,   -1,  727,  728,  729,  730,  731,  732,  733,  734,
  735,  736,  737,  738,  739,  740,  741,  742,  743,  744,
   -1,   -1,  747,   -1,  749,  750,  751,  752,  753,  754,
  755,  756,  757,   -1,   -1,   41,   42,   43,   44,   45,
   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   59,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   91,   -1,   93,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,
   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,
   -1,   -1,  336,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,
  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,
   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,
  266,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,
   -1,  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,  305,
  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,
   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,  325,
  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,
   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,
  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,
  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,
   -1,  437,  438,  439,   -1,   -1,   -1,   -1,  602,  445,
   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,
  456,   -1,  458,  459,  460,  461,  462,  463,  464,  465,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,
  476,   -1,  478,  479,  480,   -1,   -1,   -1,   -1,  485,
  486,  487,  488,  489,   -1,  491,   -1,   -1,  494,  495,
   -1,   -1,   -1,  499,  500,   -1,   -1,  503,  504,  505,
  506,  507,  508,  509,  510,  511,   -1,  513,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,  540,  541,  542,  543,   -1,  545,
  546,  547,  548,  549,  550,   -1,  552,  553,  554,  555,
   -1,  557,   -1,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,  573,  574,  575,
  576,   -1,  578,  579,  580,  581,   -1,  583,  584,  585,
  586,  587,   -1,  589,  590,  591,  592,  593,  594,  595,
  596,  597,  598,  599,  600,  601,  602,  603,  604,  605,
  606,  607,  608,  609,  610,  611,  612,  613,  614,  615,
  616,  617,   -1,  619,  620,   60,   61,   62,  624,  625,
  626,  627,  628,  629,   -1,   -1,  632,  633,  634,  635,
  636,  637,  638,  639,  640,   -1,   -1,   -1,   -1,   -1,
  646,   -1,  648,  649,  650,  651,  652,  653,   -1,  655,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,
  676,  677,  678,  679,  680,  681,  682,  683,   -1,  685,
  686,  687,  688,  689,  690,  691,  692,  693,  694,  695,
  696,   -1,  698,  699,  700,   -1,  702,   -1,   -1,   -1,
  706,  707,  708,  709,  710,  711,  712,  713,  714,  715,
  716,  717,  718,    0,  720,  721,   -1,   -1,   -1,   -1,
   -1,  727,  728,  729,  730,  731,  732,  733,  734,  735,
  736,  737,  738,  739,  740,  741,  742,  743,  744,   -1,
   -1,  747,   -1,  749,  750,  751,  752,  753,  754,  755,
  756,  757,   -1,   -1,   41,   42,   43,   44,   45,   -1,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   59,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,
  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,  266,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
  277,   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,  487,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,   -1,   -1,   -1,   -1,  602,  445,   -1,
   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,
   -1,  458,  459,  460,  461,  462,  463,  464,  465,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,
   -1,  478,  479,  480,   -1,   -1,   -1,   -1,  485,  486,
  487,  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,
   -1,   -1,  499,  500,   -1,   -1,  503,  504,  505,  506,
  507,  508,  509,  510,  511,   -1,  513,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,  540,  541,  542,  543,   -1,  545,  546,
  547,  548,  549,  550,   -1,  552,  553,  554,  555,   -1,
  557,   -1,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,  573,  574,  575,  576,
   -1,  578,  579,  580,  581,   -1,  583,  584,  585,  586,
  587,   -1,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,   -1,  610,  611,  612,  613,  614,  615,  616,
  617,  618,  619,  620,   60,   61,   62,  624,  625,  626,
  627,  628,  629,   -1,   -1,  632,  633,  634,  635,  636,
  637,  638,  639,  640,   -1,   -1,   -1,   -1,   -1,  646,
   -1,  648,  649,  650,  651,  652,  653,   -1,  655,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,
  677,  678,  679,  680,  681,  682,  683,   -1,  685,  686,
  687,  688,  689,  690,  691,  692,  693,  694,  695,  696,
   -1,  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,
  707,  708,  709,  710,  711,  712,  713,  714,  715,  716,
  717,  718,    0,  720,  721,   -1,   -1,   -1,   -1,   -1,
  727,  728,  729,  730,  731,  732,  733,  734,  735,  736,
  737,  738,  739,  740,  741,  742,  743,  744,   -1,   -1,
  747,   -1,  749,  750,  751,  752,  753,  754,  755,  756,
  757,   -1,   -1,   41,   42,   43,   44,   45,   -1,   47,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   93,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,
  336,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,
  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,  257,
   -1,  259,   -1,   -1,  262,   -1,  264,  265,  266,   -1,
  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,
   -1,  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,  302,  303,  304,  305,  306,   -1,
   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,
  318,  319,  320,   -1,  322,  323,  324,  325,  326,  327,
  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,
  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,
  368,   -1,  370,  371,  372,   -1,  374,  375,  376,  377,
  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,
  438,  439,   -1,   -1,   -1,   -1,  602,  445,   -1,   -1,
   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,
  458,  459,  460,  461,  462,  463,  464,  465,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,
  478,  479,  480,   -1,   -1,   -1,   -1,  485,  486,  487,
  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,
   -1,  499,  500,   -1,   -1,  503,  504,  505,  506,  507,
  508,  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,  540,  541,  542,  543,   -1,  545,  546,  547,
  548,  549,  550,   -1,  552,  553,  554,  555,   -1,  557,
   -1,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,  573,  574,  575,  576,   -1,
  578,  579,  580,  581,   -1,  583,  584,  585,  586,  587,
   -1,  589,  590,  591,  592,  593,  594,  595,  596,  597,
  598,  599,  600,  601,  602,  603,  604,  605,  606,  607,
  608,   -1,  610,  611,  612,  613,  614,  615,  616,  617,
  618,  619,  620,   60,   61,   62,  624,  625,  626,  627,
  628,  629,   -1,   -1,  632,  633,  634,  635,  636,  637,
  638,  639,  640,   -1,   -1,   -1,   -1,   -1,  646,   -1,
  648,  649,  650,  651,  652,  653,   -1,  655,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,
  678,  679,  680,  681,  682,  683,   -1,  685,  686,  687,
  688,  689,  690,  691,  692,  693,  694,  695,  696,   -1,
  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,
  708,  709,  710,  711,  712,  713,  714,  715,  716,  717,
  718,    0,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,
  728,  729,  730,  731,  732,  733,  734,  735,  736,  737,
  738,  739,  740,  741,  742,  743,  744,   -1,   -1,  747,
   -1,  749,  750,  751,  752,  753,  754,  755,  756,  757,
   -1,   -1,   41,   42,   43,   44,   45,   -1,   47,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   91,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,
   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,  266,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,
  279,  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
  487,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,   -1,   -1,   -1,   -1,  602,  445,   -1,   -1,   -1,
  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,  458,
  459,  460,  461,  462,  463,  464,  465,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,
  479,  480,   -1,   -1,   -1,   -1,  485,  486,  487,  488,
  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,
  499,  500,   -1,   -1,  503,  504,  505,  506,  507,  508,
  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,  540,  541,  542,  543,   -1,  545,  546,  547,  548,
  549,  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,  573,  574,  575,  576,   -1,  578,
  579,  580,  581,   -1,  583,  584,  585,  586,  587,   -1,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
   -1,  610,  611,  612,  613,  614,  615,  616,  617,   -1,
  619,  620,   60,   61,   62,  624,  625,  626,  627,  628,
  629,   -1,   -1,  632,  633,  634,  635,  636,  637,  638,
  639,  640,   -1,   -1,   -1,   -1,   -1,  646,   -1,  648,
  649,  650,  651,  652,  653,   -1,  655,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,
  679,  680,  681,  682,  683,   -1,  685,  686,  687,  688,
  689,  690,  691,  692,  693,  694,  695,  696,   -1,  698,
  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,
  709,  710,  711,  712,  713,  714,  715,  716,  717,  718,
    0,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,
  729,  730,  731,  732,  733,  734,  735,  736,  737,  738,
  739,  740,  741,  742,  743,  744,   -1,   -1,  747,   -1,
  749,  750,  751,  752,  753,  754,  755,  756,  757,   -1,
   -1,   41,   42,   43,   44,   45,   46,   47,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,
   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  312,   -1,   -1,   -1,   -1,   -1,
  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,
   -1,   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  412,   -1,   -1,  257,   -1,  259,
   -1,   -1,  262,   -1,  264,  265,  266,   -1,  268,  269,
   -1,  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,
  280,  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,
   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,
  320,   -1,  322,  323,  324,  325,  326,  327,  328,   -1,
   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,
  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,
  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,
  370,  371,  372,   -1,  374,  375,  376,  377,  378,   -1,
  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,  419,
  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,
   -1,   -1,   -1,   -1,  602,  445,   -1,   -1,   -1,  449,
   -1,  451,  452,  453,  454,   -1,  456,   -1,  458,  459,
  460,  461,  462,  463,  464,  465,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,
  480,   -1,   -1,   -1,   -1,  485,  486,  487,  488,  489,
   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,
  500,   -1,   -1,  503,  504,  505,  506,  507,  508,  509,
  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
  540,  541,  542,  543,   -1,  545,  546,  547,  548,  549,
  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,  573,  574,  575,  576,   -1,  578,  579,
  580,  581,   -1,  583,  584,  585,  586,  587,   -1,  589,
  590,  591,  592,  593,  594,  595,  596,  597,  598,  599,
  600,  601,  602,  603,  604,  605,  606,  607,  608,   -1,
  610,  611,  612,  613,  614,  615,  616,  617,   -1,  619,
  620,   60,   61,   62,  624,  625,  626,  627,  628,  629,
   -1,   -1,  632,  633,  634,  635,  636,  637,  638,  639,
  640,   -1,   -1,   -1,   -1,   -1,  646,   -1,  648,  649,
  650,  651,  652,  653,   -1,  655,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,  679,
  680,  681,  682,  683,   -1,  685,  686,  687,  688,  689,
  690,  691,  692,  693,  694,  695,  696,   -1,  698,  699,
  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,  709,
  710,  711,  712,  713,  714,  715,  716,  717,  718,    0,
  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,
  730,  731,  732,  733,  734,  735,  736,  737,  738,  739,
  740,  741,  742,  743,  744,   -1,   -1,  747,   -1,  749,
  750,  751,  752,  753,  754,  755,  756,  757,   -1,   -1,
   41,   42,   43,   44,   45,   -1,   47,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,   60,
   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  305,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,
   -1,   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,
   -1,   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  412,   -1,   -1,  257,   -1,  259,   -1,
   -1,  262,   -1,  264,  265,  266,   -1,  268,  269,   -1,
  271,   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,
  281,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,
   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,
   -1,  322,  323,  324,  325,  326,  327,  328,   -1,   -1,
   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,
  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,
   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,
  371,  372,   -1,  374,  375,  376,  377,  378,   -1,  380,
  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,  418,  419,  420,
   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,
   -1,   -1,   -1,  602,  445,   -1,   -1,   -1,  449,   -1,
  451,  452,  453,  454,   -1,  456,   -1,  458,  459,  460,
  461,  462,  463,  464,  465,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,  480,
   -1,   -1,   -1,   -1,  485,  486,  487,  488,  489,   -1,
  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,  500,
   -1,   -1,  503,  504,  505,  506,  507,  508,  509,  510,
  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,  540,
  541,  542,  543,   -1,  545,  546,  547,  548,  549,  550,
   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,  573,  574,  575,  576,   -1,  578,  579,  580,
  581,   -1,  583,  584,  585,  586,  587,   -1,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,  602,  603,  604,  605,  606,  607,  608,   -1,  610,
  611,  612,  613,  614,  615,  616,  617,   -1,  619,  620,
   60,   61,   62,  624,  625,  626,  627,  628,  629,   -1,
   -1,  632,  633,  634,  635,  636,  637,  638,  639,  640,
   -1,   -1,   -1,   -1,   -1,  646,   -1,  648,  649,  650,
  651,  652,  653,   -1,  655,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  672,  673,   -1,  675,  676,  677,  678,  679,  680,
  681,  682,  683,   -1,  685,  686,  687,  688,  689,  690,
  691,  692,  693,  694,  695,  696,   -1,  698,  699,  700,
   -1,  702,   -1,   -1,   -1,  706,  707,  708,  709,  710,
  711,  712,  713,  714,  715,  716,  717,  718,    0,  720,
  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,  730,
  731,  732,  733,  734,  735,  736,  737,  738,  739,  740,
  741,  742,  743,  744,   -1,   -1,  747,   -1,  749,  750,
  751,  752,  753,  754,  755,  756,  757,   -1,   -1,   41,
   42,   43,   44,   45,   -1,   47,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,   60,   61,
   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,
   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  350,   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,
   -1,  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  412,   -1,   -1,  257,   -1,  259,   -1,  419,
  262,   -1,  264,  265,  266,   -1,  268,  269,   -1,  271,
   -1,   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,
  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,
  322,  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,
  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,
  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,
  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,
  372,   -1,  374,  375,  376,  377,  378,   -1,  380,  381,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,
  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,   -1,
   -1,   -1,  602,  445,   -1,   -1,   -1,  449,   -1,  451,
  452,  453,  454,   -1,  456,   -1,  458,  459,  460,  461,
  462,  463,  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  475,  476,   -1,  478,  479,  480,   -1,
   -1,   -1,   -1,  485,  486,  487,  488,  489,   -1,  491,
   -1,   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,
   -1,  503,  504,  505,  506,  507,  508,  509,  510,  511,
   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,  540,  541,
  542,  543,   -1,  545,  546,  547,  548,  549,  550,   -1,
  552,  553,  554,  555,   -1,  557,   -1,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,  573,  574,  575,  576,   -1,  578,  579,  580,  581,
   -1,  583,  584,  585,  586,  587,   -1,  589,  590,  591,
  592,  593,  594,  595,  596,  597,  598,  599,  600,  601,
  602,  603,  604,  605,  606,  607,  608,   -1,  610,  611,
  612,  613,  614,  615,  616,  617,   -1,  619,  620,   60,
   61,   62,  624,  625,  626,  627,  628,  629,   -1,   -1,
  632,  633,  634,  635,  636,  637,  638,  639,  640,   -1,
   -1,   -1,   -1,   -1,  646,   -1,  648,  649,  650,  651,
  652,  653,   -1,  655,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  672,  673,   -1,  675,  676,  677,  678,  679,  680,  681,
  682,  683,   -1,  685,  686,  687,  688,  689,  690,  691,
  692,  693,  694,  695,  696,   -1,  698,  699,  700,   -1,
  702,   -1,   -1,   -1,  706,  707,  708,  709,  710,  711,
  712,  713,  714,  715,  716,  717,  718,    0,  720,  721,
   -1,   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,
  732,  733,  734,  735,  736,  737,  738,  739,  740,  741,
  742,  743,  744,   -1,   -1,  747,   -1,  749,  750,  751,
  752,  753,  754,  755,  756,  757,   -1,   -1,   41,   42,
   43,   44,   45,   -1,   47,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   59,   60,   61,   62,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  314,   -1,   -1,   -1,  318,   -1,   -1,
   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,
   -1,  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,
  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  412,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,
   -1,  264,  265,  266,   -1,  268,  269,   -1,  271,   -1,
   -1,   -1,   -1,   -1,  277,   -1,  279,  280,  281,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,
  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,
   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,
  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,
  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,
   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,  381,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,
  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,  434,  435,   -1,  437,  438,  439,   -1,   -1,   -1,
   -1,  602,  445,   -1,   -1,   -1,  449,   -1,  451,  452,
  453,  454,   -1,  456,   -1,  458,  459,  460,  461,  462,
  463,  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  475,  476,   -1,  478,  479,  480,   -1,   -1,
   -1,   -1,  485,  486,  487,  488,  489,   -1,  491,   -1,
   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,
  503,  504,  505,  506,  507,  508,  509,  510,  511,   -1,
  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,  540,  541,  542,
  543,   -1,  545,  546,  547,  548,  549,  550,   -1,  552,
  553,  554,  555,   -1,  557,   -1,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
  573,  574,  575,  576,   -1,  578,  579,  580,  581,   -1,
  583,  584,  585,  586,  587,   -1,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,  602,
  603,  604,  605,  606,  607,  608,   -1,  610,  611,  612,
  613,  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,
   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,  632,
  633,  634,  635,  636,  637,  638,  639,  640,   -1,   -1,
   60,   61,   62,  646,   -1,  648,  649,  650,  651,  652,
  653,   -1,  655,   -1,   -1,   -1,   -1,   -1,   60,   61,
   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,
  673,   -1,  675,  676,  677,  678,  679,  680,  681,  682,
  683,   -1,  685,  686,  687,  688,  689,  690,  691,  692,
  693,  694,  695,  696,   -1,  698,  699,  700,   -1,  702,
   -1,   -1,   -1,  706,  707,  708,  709,  710,  711,  712,
  713,  714,  715,  716,  717,  718,    0,  720,  721,   -1,
   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,
  733,  734,  735,  736,  737,  738,  739,  740,  741,  742,
  743,  744,   -1,   -1,  747,   -1,  749,  750,  751,  752,
  753,  754,  755,  756,  757,   -1,   -1,   41,   42,   43,
   44,   45,   -1,   47,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   59,   60,   61,   62,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   93,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  262,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  262,   -1,   -1,   -1,  284,   -1,   -1,   -1,   -1,  271,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  318,   -1,
   -1,   -1,   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  333,   -1,   -1,  318,   -1,   -1,   -1,
   -1,   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,
  350,  333,  352,   -1,  336,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  362,   -1,  364,  365,  366,   -1,  350,   -1,
  352,  371,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,
   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,
  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,
   -1,   -1,  412,   -1,   -1,  279,  280,  281,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,
  412,   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,
  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,
  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,
  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,
  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,
   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,
  364,  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,
  374,  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,  418,  419,  420,  557,  422,  423,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
  434,  435,   -1,  437,  438,  439,   -1,   -1,   -1,   -1,
   -1,  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,
  454,   -1,  456,   -1,  458,  459,  460,  461,  462,  463,
  464,  465,  602,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  475,  476,   -1,  478,  479,  480,   -1,   -1,   -1,
  602,  485,  486,  487,  488,  489,   -1,  491,   -1,   -1,
  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,  503,
  504,  505,  506,  507,  508,  509,  510,  511,   -1,  513,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,  540,  541,  542,  543,
   -1,  545,  546,  547,  548,  549,  550,   -1,  552,  553,
  554,  555,   -1,  557,   -1,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,  573,
  574,  575,  576,   -1,  578,  579,  580,  581,   -1,  583,
  584,  585,  586,  587,   -1,  589,  590,  591,  592,  593,
  594,  595,  596,  597,  598,  599,  600,  601,  602,  603,
  604,  605,  606,  607,  608,   -1,  610,  611,  612,  613,
  614,  615,  616,  617,   -1,  619,  620,   60,   61,   62,
  624,  625,  626,  627,  628,  629,   -1,   -1,  632,  633,
  634,  635,  636,  637,  638,  639,  640,   -1,   -1,   -1,
   -1,   -1,  646,   -1,  648,  649,  650,  651,  652,  653,
   -1,  655,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,
   -1,  675,  676,  677,  678,  679,  680,  681,  682,  683,
   -1,  685,  686,  687,  688,  689,  690,  691,  692,  693,
  694,  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,
   -1,   -1,  706,  707,  708,  709,  710,  711,  712,  713,
  714,  715,  716,  717,  718,    0,  720,  721,   -1,   -1,
   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,  733,
  734,  735,  736,  737,  738,  739,  740,  741,  742,  743,
  744,   -1,   -1,  747,   -1,  749,  750,  751,  752,  753,
  754,  755,  756,  757,   -1,   -1,   41,   42,   43,   44,
   45,   -1,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   59,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   93,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,
   -1,   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  333,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,
   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,
   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,
  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,
  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,
  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,
  325,  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,
  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,
  435,   -1,  437,  438,  439,   -1,   -1,   -1,   -1,  602,
  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,
   -1,  456,   -1,  458,  459,  460,  461,  462,  463,  464,
  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  475,  476,   -1,  478,  479,  480,   -1,   -1,   -1,   -1,
  485,  486,  487,  488,  489,   -1,  491,   -1,   -1,  494,
  495,   -1,   -1,   -1,  499,  500,   -1,   -1,  503,  504,
  505,  506,  507,  508,  509,  510,  511,   -1,  513,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,  540,  541,  542,  543,   -1,
  545,  546,  547,  548,  549,  550,   -1,  552,  553,  554,
  555,   -1,  557,   -1,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,  573,  574,
  575,  576,   -1,  578,  579,  580,  581,   -1,  583,  584,
  585,  586,  587,   -1,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,  602,  603,  604,
  605,  606,  607,  608,   -1,  610,  611,  612,  613,  614,
  615,  616,  617,   -1,  619,  620,   60,   61,   62,  624,
  625,  626,  627,  628,  629,   -1,   -1,  632,  633,  634,
  635,  636,  637,  638,  639,  640,   -1,   -1,   -1,   -1,
   -1,  646,   -1,  648,  649,  650,  651,  652,  653,   -1,
  655,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,
  675,  676,  677,  678,  679,  680,  681,  682,  683,   -1,
  685,  686,  687,  688,  689,  690,  691,  692,  693,  694,
  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,   -1,
   -1,  706,  707,  708,  709,  710,  711,  712,  713,  714,
  715,  716,  717,  718,    0,  720,  721,   -1,   -1,   -1,
   -1,   -1,  727,  728,  729,  730,  731,  732,  733,  734,
  735,  736,  737,  738,  739,  740,  741,  742,  743,  744,
   -1,   -1,  747,   -1,  749,  750,  751,  752,  753,  754,
  755,  756,  757,   -1,   -1,   41,   42,   43,   44,   45,
   -1,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   59,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   93,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,
   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,
  364,  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,
   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,
   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,  305,
  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,
   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,  325,
  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,
   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,
  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,
  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,
   -1,  437,  438,  439,   -1,   -1,   -1,   -1,  602,  445,
   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,
  456,   -1,  458,  459,  460,  461,  462,  463,  464,  465,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,
  476,   -1,  478,  479,  480,   -1,   -1,   -1,   -1,  485,
  486,  487,  488,  489,   -1,  491,   -1,   -1,  494,  495,
   -1,   -1,   -1,  499,  500,   -1,   -1,  503,  504,  505,
  506,  507,  508,  509,  510,  511,   -1,  513,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,  540,  541,  542,  543,   -1,  545,
  546,  547,  548,  549,  550,   -1,  552,  553,  554,  555,
   -1,  557,   -1,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,  573,  574,  575,
  576,   -1,  578,  579,  580,  581,   -1,  583,  584,  585,
  586,  587,   -1,  589,  590,  591,  592,  593,  594,  595,
  596,  597,  598,  599,  600,  601,  602,  603,  604,  605,
  606,  607,  608,   -1,  610,  611,  612,  613,  614,  615,
  616,  617,   -1,  619,  620,   60,   61,   62,  624,  625,
  626,  627,  628,  629,   -1,   -1,  632,  633,  634,  635,
  636,  637,  638,  639,  640,   -1,   -1,   -1,   -1,   -1,
  646,   -1,  648,  649,  650,  651,  652,  653,   -1,  655,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,
  676,  677,  678,  679,  680,  681,  682,  683,   -1,  685,
  686,  687,  688,  689,  690,  691,  692,  693,  694,  695,
  696,   -1,  698,  699,  700,   -1,  702,   -1,   -1,   -1,
  706,  707,  708,  709,  710,  711,  712,  713,  714,  715,
  716,  717,  718,    0,  720,  721,   -1,   -1,   -1,   -1,
   -1,  727,  728,  729,  730,  731,  732,  733,  734,  735,
  736,  737,  738,  739,  740,  741,  742,  743,  744,   -1,
   -1,  747,   -1,  749,  750,  751,  752,  753,  754,  755,
  756,  757,   -1,   -1,   41,   42,   43,   44,   45,   -1,
   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   59,   60,   61,   62,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   93,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  284,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,
  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,   -1,   -1,
  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,
   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,  302,  303,  304,  305,  306,
   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,
   -1,  318,  319,  320,   -1,  322,  323,  324,  325,  326,
  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,
  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,
   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,
  437,  438,  439,   -1,   -1,   -1,   -1,  602,  445,   -1,
   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,
   -1,  458,  459,  460,  461,  462,  463,  464,  465,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,
   -1,  478,  479,  480,   -1,   -1,   -1,   -1,  485,  486,
  487,  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,
   -1,   -1,  499,  500,   -1,   -1,  503,  504,  505,  506,
  507,  508,  509,  510,  511,   -1,  513,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,  540,  541,  542,  543,   -1,  545,  546,
  547,  548,  549,  550,   -1,  552,  553,  554,  555,   -1,
  557,   -1,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,  573,  574,  575,  576,
   -1,  578,  579,  580,  581,   -1,  583,  584,  585,  586,
  587,   -1,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,   -1,  610,  611,  612,  613,  614,  615,  616,
  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,
  627,  628,  629,   -1,   -1,  632,  633,  634,  635,  636,
  637,  638,  639,  640,   -1,   -1,   -1,   -1,   -1,  646,
   -1,  648,  649,  650,  651,  652,  653,   -1,  655,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,
  677,  678,  679,  680,  681,  682,  683,   -1,  685,  686,
  687,  688,  689,  690,  691,  692,  693,  694,  695,  696,
   -1,  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,
  707,  708,  709,  710,  711,  712,  713,  714,  715,  716,
  717,  718,    0,  720,  721,   -1,   -1,   -1,   -1,   -1,
  727,  728,  729,  730,  731,  732,  733,  734,  735,  736,
  737,  738,  739,  740,  741,  742,  743,  744,   -1,   -1,
  747,   -1,  749,  750,  751,  752,  753,  754,  755,  756,
  757,   -1,   -1,   41,   42,   43,   44,   45,   -1,   47,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   93,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,
   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,
  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,  302,  303,  304,  305,  306,   -1,
   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,
  318,  319,  320,   -1,  322,  323,  324,  325,  326,  327,
  328,   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,
  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,
  368,   -1,  370,  371,  372,   -1,  374,  375,  376,  377,
  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,
  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,
   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,
  458,  459,  460,  461,  462,  463,  464,  465,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,
  478,  479,  480,   -1,   -1,   -1,   -1,  485,  486,  487,
  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,
   -1,  499,  500,   -1,   -1,  503,  504,  505,  506,  507,
  508,  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,  540,  541,  542,  543,   -1,  545,  546,  547,
  548,  549,  550,   -1,  552,  553,  554,  555,   -1,  557,
   -1,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,  573,  574,  575,  576,   -1,
  578,  579,  580,  581,   -1,  583,  584,  585,  586,  587,
   -1,  589,  590,  591,  592,  593,  594,  595,  596,  597,
  598,  599,  600,  601,  602,  603,  604,  605,  606,  607,
  608,   -1,  610,  611,  612,  613,  614,  615,  616,  617,
   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,
  628,  629,   -1,   -1,  632,  633,  634,  635,  636,  637,
  638,  639,  640,   -1,   -1,   -1,   -1,   -1,  646,   -1,
  648,  649,  650,  651,  652,  653,   -1,  655,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,
  678,  679,  680,  681,  682,  683,   -1,  685,  686,  687,
  688,  689,  690,  691,  692,  693,  694,  695,  696,   -1,
  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,
  708,  709,  710,  711,  712,  713,  714,  715,  716,  717,
  718,    0,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,
  728,  729,  730,  731,  732,  733,  734,  735,  736,  737,
  738,  739,  740,  741,  742,  743,  744,   -1,   -1,  747,
   -1,  749,  750,  751,  752,  753,  754,  755,  756,  757,
   -1,   -1,   41,   -1,   43,   44,   45,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   93,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,
  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,
  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,
  319,  320,   -1,  322,  323,  324,  325,  326,  327,  328,
   -1,   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,
   -1,  370,  371,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,
  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,
  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,
  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,  458,
  459,  460,  461,  462,  463,  464,  465,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,
  479,  480,   -1,   -1,   -1,   -1,  485,  486,  487,  488,
  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,
  499,  500,   -1,   -1,  503,  504,  505,  506,  507,  508,
  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,  540,  541,  542,  543,   -1,  545,  546,  547,  548,
  549,  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,  573,  574,  575,  576,   -1,  578,
  579,  580,  581,   -1,  583,  584,  585,  586,  587,   -1,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,  602,  603,  604,  605,  606,  607,  608,
   -1,  610,  611,  612,  613,  614,  615,  616,  617,   -1,
  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,
  629,   -1,   -1,  632,  633,  634,  635,  636,  637,  638,
  639,  640,   -1,   -1,   -1,   -1,   -1,  646,   -1,  648,
  649,  650,  651,  652,  653,   -1,  655,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,
  679,  680,  681,  682,  683,   -1,  685,  686,  687,  688,
  689,  690,  691,  692,  693,  694,  695,  696,   -1,  698,
  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,
  709,  710,  711,  712,  713,  714,  715,  716,  717,  718,
    0,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,
  729,  730,  731,  732,  733,  734,  735,  736,  737,  738,
  739,  740,  741,  742,  743,  744,   -1,   -1,  747,   -1,
  749,  750,  751,  752,  753,  754,  755,  756,  757,   -1,
   -1,   41,   -1,   43,   44,   45,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   59,
   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,
   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,
   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,
  320,   -1,  322,  323,  324,  325,  326,  327,  328,   -1,
   -1,   -1,  332,  333,  334,  335,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,
  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,
  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,
  370,  371,  372,   -1,  374,  375,  376,  377,  378,   -1,
  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,  419,
  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,
   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,
   -1,  451,  452,  453,  454,   -1,  456,   -1,  458,  459,
  460,  461,  462,  463,  464,  465,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,
  480,   -1,   -1,   -1,   -1,  485,  486,  487,  488,  489,
   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,
  500,   -1,   -1,  503,  504,  505,  506,  507,  508,  509,
  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
  540,  541,  542,  543,   -1,  545,  546,  547,  548,  549,
  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,  573,  574,  575,  576,   -1,  578,  579,
  580,  581,   -1,  583,  584,  585,  586,  587,   -1,  589,
  590,  591,  592,  593,  594,  595,  596,  597,  598,  599,
  600,  601,  602,  603,  604,  605,  606,  607,  608,   -1,
  610,  611,  612,  613,  614,  615,  616,  617,   -1,  619,
  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,  629,
   -1,   -1,  632,  633,  634,  635,  636,  637,  638,  639,
  640,   -1,   -1,   -1,   -1,   -1,  646,   -1,  648,  649,
  650,  651,  652,  653,   -1,  655,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,  679,
  680,  681,  682,  683,   -1,  685,  686,  687,  688,  689,
  690,  691,  692,  693,  694,  695,  696,   -1,  698,  699,
  700,   -1,  702,   -1,    0,   -1,  706,  707,  708,  709,
  710,  711,  712,  713,  714,  715,  716,  717,  718,   -1,
  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,
  730,  731,  732,  733,  734,  735,  736,  737,  738,  739,
  740,  741,  742,  743,  744,   41,   -1,  747,   44,  749,
  750,  751,  752,  753,  754,  755,  756,  757,   -1,   -1,
   -1,   -1,   -1,   59,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   93,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,
   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,  305,
  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,
   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,  325,
  326,  327,  328,   -1,   -1,   -1,  332,  333,  334,  335,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,
   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,
  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,
  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,
   -1,  437,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,
   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,
  456,   -1,  458,  459,  460,  461,  462,  463,  464,  465,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,
  476,   -1,  478,  479,  480,   -1,   -1,   -1,   -1,  485,
  486,  487,  488,  489,   -1,  491,   -1,   -1,  494,  495,
   -1,   -1,   -1,  499,  500,   -1,   -1,  503,  504,  505,
  506,  507,  508,  509,  510,  511,   -1,  513,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,  540,  541,  542,  543,   -1,  545,
  546,  547,  548,  549,  550,   -1,  552,  553,  554,  555,
   -1,  557,   -1,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,  573,  574,  575,
  576,   -1,  578,  579,  580,  581,   -1,  583,  584,  585,
  586,  587,   -1,  589,  590,  591,  592,  593,  594,  595,
  596,  597,  598,  599,  600,  601,  602,  603,  604,  605,
  606,  607,  608,   -1,  610,  611,  612,  613,  614,  615,
  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,
  626,  627,  628,  629,   -1,   -1,  632,  633,  634,  635,
  636,  637,  638,  639,  640,   -1,   -1,   -1,   -1,   -1,
  646,   -1,  648,  649,  650,  651,  652,  653,   -1,  655,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,
  676,  677,  678,  679,  680,  681,  682,  683,   -1,  685,
  686,  687,  688,  689,  690,  691,  692,  693,  694,  695,
  696,   -1,  698,  699,  700,   -1,  702,   -1,    0,   -1,
  706,  707,  708,  709,  710,  711,  712,  713,  714,  715,
  716,  717,  718,   -1,  720,  721,   -1,   -1,   -1,   -1,
   -1,  727,  728,  729,  730,  731,  732,  733,  734,  735,
  736,  737,  738,  739,  740,  741,  742,  743,  744,   41,
   -1,  747,   44,  749,  750,  751,  752,  753,  754,  755,
  756,  757,   -1,   -1,   -1,   -1,   -1,   59,   60,   61,
   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,
  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,
  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,
  322,  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,
  332,  333,  334,  335,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,
  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,
  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,
  372,   -1,  374,  375,  376,  377,  378,   -1,  380,  381,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,
  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,   -1,
   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,  451,
  452,  453,  454,   -1,  456,   -1,  458,  459,  460,  461,
  462,  463,  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  475,  476,   -1,  478,  479,  480,   -1,
   -1,   -1,   -1,  485,  486,  487,  488,  489,   -1,  491,
   -1,   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,
   -1,  503,  504,  505,  506,  507,  508,  509,  510,  511,
   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,  540,  541,
  542,  543,   -1,  545,  546,  547,  548,  549,  550,   -1,
  552,  553,  554,  555,   -1,  557,   -1,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,  573,  574,  575,  576,   -1,  578,  579,  580,  581,
   -1,  583,  584,  585,  586,  587,   -1,  589,  590,  591,
  592,  593,  594,  595,  596,  597,  598,  599,  600,  601,
  602,  603,  604,  605,  606,  607,  608,   -1,  610,  611,
  612,  613,  614,  615,  616,  617,   -1,  619,  620,   -1,
   -1,   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,
  632,  633,  634,  635,  636,  637,  638,  639,  640,   -1,
   -1,   -1,   -1,   -1,  646,   -1,  648,  649,  650,  651,
  652,  653,   -1,  655,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  672,  673,   -1,  675,  676,  677,  678,  679,  680,  681,
  682,  683,   -1,  685,  686,  687,  688,  689,  690,  691,
  692,  693,  694,  695,  696,   -1,  698,  699,  700,   -1,
  702,   -1,    0,   -1,  706,  707,  708,  709,  710,  711,
  712,  713,  714,  715,  716,  717,  718,   -1,  720,  721,
   -1,   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,
  732,  733,  734,  735,  736,  737,  738,  739,  740,  741,
  742,  743,  744,   41,   -1,  747,   44,  749,  750,  751,
  752,  753,  754,  755,  756,  757,   -1,   -1,   -1,   -1,
   -1,   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   93,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,
   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,
  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,  302,  303,  304,  305,  306,   -1,
   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,
  318,  319,  320,   -1,  322,  323,  324,  325,  326,  327,
  328,   -1,   -1,   -1,  332,   -1,  334,  335,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,
  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,
  368,   -1,  370,  371,  372,   -1,  374,  375,  376,  377,
  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,
  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,
   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,
  458,  459,  460,  461,  462,  463,  464,  465,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,
  478,  479,  480,   -1,   -1,   -1,   -1,  485,  486,  487,
  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,
   -1,  499,  500,   -1,   -1,  503,  504,  505,  506,  507,
  508,  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,  540,  541,  542,  543,   -1,  545,  546,  547,
  548,  549,  550,   -1,  552,  553,  554,  555,   -1,  557,
   -1,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,  573,  574,  575,  576,   -1,
  578,  579,  580,  581,   -1,  583,  584,  585,  586,  587,
   -1,  589,  590,  591,  592,  593,  594,  595,  596,  597,
  598,  599,  600,  601,  602,  603,  604,  605,  606,  607,
  608,   -1,  610,  611,  612,  613,  614,  615,  616,  617,
   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,
  628,  629,   -1,   -1,  632,  633,  634,  635,  636,  637,
  638,  639,  640,   -1,   -1,   -1,   -1,   -1,  646,   -1,
  648,  649,  650,  651,  652,  653,   -1,  655,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,
  678,  679,  680,  681,  682,  683,   -1,  685,  686,  687,
  688,  689,  690,  691,  692,  693,  694,  695,  696,   -1,
  698,  699,  700,   -1,  702,   -1,    0,   -1,  706,  707,
  708,  709,  710,  711,  712,  713,  714,  715,  716,  717,
  718,   -1,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,
  728,  729,  730,  731,  732,  733,  734,  735,  736,  737,
  738,  739,  740,  741,  742,  743,  744,   41,   -1,  747,
   44,  749,  750,  751,  752,  753,  754,  755,  756,  757,
   -1,   -1,   -1,   -1,   -1,   59,   60,   61,   62,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   93,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,
  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,
  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,
  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,
  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,   -1,
  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,
   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,
  364,  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,
  374,  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
  434,  435,   -1,  437,  438,  439,   -1,   -1,   -1,   -1,
   -1,  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,
  454,   -1,  456,   -1,  458,  459,  460,  461,  462,  463,
  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  475,  476,   -1,  478,  479,  480,   -1,   -1,   -1,
   -1,  485,  486,  487,  488,  489,   -1,  491,   -1,   -1,
  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,  503,
  504,  505,  506,  507,  508,  509,  510,  511,   -1,  513,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,  540,  541,  542,  543,
   -1,  545,  546,  547,  548,  549,  550,   -1,  552,  553,
  554,  555,   -1,  557,   -1,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,  573,
  574,  575,  576,   -1,  578,  579,  580,  581,   -1,  583,
  584,  585,  586,  587,   -1,  589,  590,  591,  592,  593,
  594,  595,  596,  597,  598,  599,  600,  601,  602,  603,
  604,  605,  606,  607,  608,   -1,  610,  611,  612,  613,
  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,
  624,  625,  626,  627,  628,  629,   -1,   -1,  632,  633,
  634,  635,  636,  637,  638,  639,  640,   -1,   -1,   -1,
   -1,   -1,  646,   -1,  648,  649,  650,  651,  652,  653,
   -1,  655,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,
   -1,  675,  676,  677,  678,  679,  680,  681,  682,  683,
   -1,  685,  686,  687,  688,  689,  690,  691,  692,  693,
  694,  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,
    0,   -1,  706,  707,  708,  709,  710,  711,  712,  713,
  714,  715,  716,  717,  718,   -1,  720,  721,   -1,   -1,
   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,  733,
  734,  735,  736,  737,  738,  739,  740,  741,  742,  743,
  744,   41,   -1,  747,   44,  749,  750,  751,  752,  753,
  754,  755,  756,  757,   -1,   -1,   -1,   -1,   -1,   59,
   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,
   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,
   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,
  320,   -1,  322,  323,  324,  325,  326,  327,  328,   -1,
   -1,   -1,  332,   -1,  334,  335,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,
  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,
  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,
  370,  371,  372,   -1,  374,  375,  376,  377,  378,   -1,
  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,  419,
  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,
   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,
   -1,  451,  452,  453,  454,   -1,  456,   -1,  458,  459,
  460,  461,  462,  463,  464,  465,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,
  480,   -1,   -1,   -1,   -1,  485,  486,  487,  488,  489,
   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,
  500,   -1,   -1,  503,  504,  505,  506,  507,  508,  509,
  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
  540,  541,  542,  543,   -1,  545,  546,  547,  548,  549,
  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,  573,  574,  575,  576,   -1,  578,  579,
  580,  581,   -1,  583,  584,  585,  586,  587,   -1,  589,
  590,  591,  592,  593,  594,  595,  596,  597,  598,  599,
  600,  601,  602,  603,  604,  605,  606,  607,  608,   -1,
  610,  611,  612,  613,  614,  615,  616,  617,   -1,  619,
  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,  629,
   -1,   -1,  632,  633,  634,  635,  636,  637,  638,  639,
  640,   -1,   -1,   -1,   -1,   -1,  646,   -1,  648,  649,
  650,  651,  652,  653,   -1,  655,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,  679,
  680,  681,  682,  683,   -1,  685,  686,  687,  688,  689,
  690,  691,  692,  693,  694,  695,  696,   -1,  698,  699,
  700,   -1,  702,   -1,    0,   -1,  706,  707,  708,  709,
  710,  711,  712,  713,  714,  715,  716,  717,  718,   -1,
  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,
  730,  731,  732,  733,  734,  735,  736,  737,  738,  739,
  740,  741,  742,  743,  744,   41,   -1,  747,   44,  749,
  750,  751,  752,  753,  754,  755,  756,  757,   -1,   -1,
   -1,   -1,   -1,   59,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   93,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,
   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,  305,
  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,
   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,  325,
  326,  327,  328,   -1,   -1,   -1,  332,   -1,  334,  335,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,
   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,
  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,
  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,
   -1,  437,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,
   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,
  456,   -1,  458,  459,  460,  461,  462,  463,  464,  465,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,
  476,   -1,  478,  479,  480,   -1,   -1,   -1,   -1,  485,
  486,  487,  488,  489,   -1,  491,   -1,   -1,  494,  495,
   -1,   -1,   -1,  499,  500,   -1,   -1,  503,  504,  505,
  506,  507,  508,  509,  510,  511,   -1,  513,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,  540,  541,  542,  543,   -1,  545,
  546,  547,  548,  549,  550,   -1,  552,  553,  554,  555,
   -1,  557,   -1,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,  573,  574,  575,
  576,   -1,  578,  579,  580,  581,   -1,  583,  584,  585,
  586,  587,   -1,  589,  590,  591,  592,  593,  594,  595,
  596,  597,  598,  599,  600,  601,  602,  603,  604,  605,
  606,  607,  608,   -1,  610,  611,  612,  613,  614,  615,
  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,
  626,  627,  628,  629,   -1,   -1,  632,  633,  634,  635,
  636,  637,  638,  639,  640,   -1,   -1,   -1,   -1,   -1,
  646,   -1,  648,  649,  650,  651,  652,  653,   -1,  655,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,
  676,  677,  678,  679,  680,  681,  682,  683,   -1,  685,
  686,  687,  688,  689,  690,  691,  692,  693,  694,  695,
  696,   -1,  698,  699,  700,   -1,  702,   -1,    0,   -1,
  706,  707,  708,  709,  710,  711,  712,  713,  714,  715,
  716,  717,  718,   -1,  720,  721,   -1,   -1,   -1,   -1,
   -1,  727,  728,  729,  730,  731,  732,  733,  734,  735,
  736,  737,  738,  739,  740,  741,  742,  743,  744,   41,
   -1,  747,   44,  749,  750,  751,  752,  753,  754,  755,
  756,  757,   -1,   -1,   -1,   -1,   -1,   59,   60,   61,
   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,
  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
  302,  303,  304,  305,  306,   -1,   -1,  309,   -1,   -1,
  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,
  322,  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,
  332,   -1,  334,  335,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,
  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,
  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,
  372,   -1,  374,  375,  376,  377,  378,   -1,  380,  381,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,
  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,   -1,
   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,  451,
  452,  453,  454,   -1,  456,   -1,  458,  459,  460,  461,
  462,  463,  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  475,  476,   -1,  478,  479,  480,   -1,
   -1,   -1,   -1,  485,  486,  487,  488,  489,   -1,  491,
   -1,   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,
   -1,  503,  504,  505,  506,  507,  508,  509,  510,  511,
   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,  540,  541,
  542,  543,   -1,  545,  546,  547,  548,  549,  550,   -1,
  552,  553,  554,  555,   -1,  557,   -1,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,  573,  574,  575,  576,   -1,  578,  579,  580,  581,
   -1,  583,  584,  585,  586,  587,   -1,  589,  590,  591,
  592,  593,  594,  595,  596,  597,  598,  599,  600,  601,
  602,  603,  604,  605,  606,  607,  608,   -1,  610,  611,
  612,  613,  614,  615,  616,  617,   -1,  619,  620,   -1,
   -1,   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,
  632,  633,  634,  635,  636,  637,  638,  639,  640,   -1,
   -1,   -1,   -1,   -1,  646,   -1,  648,  649,  650,  651,
  652,  653,   -1,  655,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  672,  673,   -1,  675,  676,  677,  678,  679,  680,  681,
  682,  683,   -1,  685,  686,  687,  688,  689,  690,  691,
  692,  693,  694,  695,  696,   -1,  698,  699,  700,   -1,
  702,   -1,    0,   -1,  706,  707,  708,  709,  710,  711,
  712,  713,  714,  715,  716,  717,  718,   -1,  720,  721,
   -1,   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,
  732,  733,  734,  735,  736,  737,  738,  739,  740,  741,
  742,  743,  744,   41,   -1,  747,   44,  749,  750,  751,
  752,  753,  754,  755,  756,  757,   -1,   -1,   -1,   -1,
   -1,   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   93,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,
   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,
  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,  302,  303,  304,  305,  306,   -1,
   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,
  318,  319,  320,   -1,  322,  323,  324,  325,  326,  327,
  328,   -1,   -1,   -1,  332,   -1,  334,  335,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,
  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,
  368,   -1,  370,  371,  372,   -1,  374,  375,  376,  377,
  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,
  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,
   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,
  458,  459,  460,  461,  462,  463,  464,  465,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,
  478,  479,  480,   -1,   -1,   -1,   -1,  485,  486,  487,
  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,
   -1,  499,  500,   -1,   -1,  503,  504,  505,  506,  507,
  508,  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,  540,  541,  542,  543,   -1,  545,  546,  547,
  548,  549,  550,   -1,  552,  553,  554,  555,   -1,  557,
   -1,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,  573,  574,  575,  576,   -1,
  578,  579,  580,  581,   -1,  583,  584,  585,  586,  587,
   -1,  589,  590,  591,  592,  593,  594,  595,  596,  597,
  598,  599,  600,  601,  602,  603,  604,  605,  606,  607,
  608,   -1,  610,  611,  612,  613,  614,  615,  616,  617,
   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,
  628,  629,   -1,   -1,  632,  633,  634,  635,  636,  637,
  638,  639,  640,   -1,   -1,   -1,   -1,   -1,  646,   -1,
  648,  649,  650,  651,  652,  653,   -1,  655,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,
  678,  679,  680,  681,  682,  683,   -1,  685,  686,  687,
  688,  689,  690,  691,  692,  693,  694,  695,  696,   -1,
  698,  699,  700,   -1,  702,   -1,    0,   -1,  706,  707,
  708,  709,  710,  711,  712,  713,  714,  715,  716,  717,
  718,   -1,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,
  728,  729,  730,  731,  732,  733,  734,  735,  736,  737,
  738,  739,  740,  741,  742,  743,  744,   41,   -1,  747,
   44,  749,  750,  751,  752,  753,  754,  755,  756,  757,
   -1,   -1,   -1,   -1,   -1,   59,   60,   61,   62,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   93,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,
  264,  265,   -1,   -1,  268,  269,   -1,  271,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,
  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,
  314,  315,   -1,   -1,  318,  319,  320,   -1,  322,  323,
  324,  325,  326,  327,  328,   -1,   -1,   -1,  332,   -1,
  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,  349,  350,  351,  352,  353,
   -1,   -1,   -1,  357,  358,   -1,  360,   -1,  362,   -1,
  364,  365,  366,   -1,  368,   -1,  370,  371,  372,   -1,
  374,  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
  434,  435,   -1,  437,  438,  439,   -1,   -1,   -1,   -1,
   -1,  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,
  454,   -1,  456,   -1,  458,  459,  460,  461,  462,  463,
  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  475,  476,   -1,  478,  479,  480,   -1,   -1,   -1,
   -1,  485,  486,  487,  488,  489,   -1,  491,   -1,   -1,
  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,  503,
  504,  505,  506,  507,  508,  509,  510,  511,   -1,  513,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,  540,  541,  542,  543,
   -1,  545,  546,  547,  548,  549,  550,   -1,  552,  553,
  554,  555,   -1,  557,   -1,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,  573,
  574,  575,  576,   -1,  578,  579,  580,  581,   -1,  583,
  584,  585,  586,  587,   -1,  589,  590,  591,  592,  593,
  594,  595,  596,  597,  598,  599,  600,  601,  602,  603,
  604,  605,  606,  607,  608,   -1,  610,  611,  612,  613,
  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,
  624,  625,  626,  627,  628,  629,   -1,   -1,  632,  633,
  634,  635,  636,  637,  638,  639,  640,   -1,   -1,   -1,
   -1,   -1,  646,   -1,  648,  649,  650,  651,  652,  653,
   -1,  655,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,
   -1,  675,  676,  677,  678,  679,  680,  681,  682,  683,
   -1,  685,  686,  687,  688,  689,  690,  691,  692,  693,
  694,  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,
    0,   -1,  706,  707,  708,  709,  710,  711,  712,  713,
  714,  715,  716,  717,  718,   -1,  720,  721,   -1,   -1,
   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,  733,
  734,  735,  736,  737,  738,  739,  740,  741,  742,  743,
  744,   41,   -1,  747,   44,  749,  750,  751,  752,  753,
  754,  755,  756,  757,   -1,   -1,   -1,   -1,   -1,   59,
   60,   61,   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,
   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,  302,  303,  304,   -1,  306,   -1,   -1,  309,
   -1,   -1,  312,   -1,  314,  315,   -1,   -1,  318,  319,
  320,   -1,  322,  323,  324,  325,  326,  327,  328,   -1,
   -1,   -1,  332,   -1,  334,  335,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,
  350,  351,  352,  353,   -1,   -1,   -1,  357,  358,   -1,
  360,   -1,  362,   -1,  364,  365,  366,   -1,  368,   -1,
  370,  371,  372,   -1,  374,  375,  376,  377,  378,   -1,
  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,  418,  419,
  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,
   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,
   -1,  451,  452,  453,  454,   -1,  456,   -1,  458,  459,
  460,  461,  462,  463,  464,  465,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,
  480,   -1,   -1,   -1,   -1,  485,  486,  487,  488,  489,
   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,
  500,   -1,   -1,  503,  504,  505,  506,  507,  508,  509,
  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
  540,  541,  542,  543,   -1,  545,  546,  547,  548,  549,
  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,  573,  574,  575,  576,   -1,  578,  579,
  580,  581,   -1,  583,  584,  585,  586,  587,   -1,  589,
  590,  591,  592,  593,  594,  595,  596,  597,  598,  599,
  600,  601,  602,  603,  604,  605,  606,  607,  608,   -1,
  610,  611,  612,  613,  614,  615,  616,  617,   -1,  619,
  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,  629,
   -1,   -1,  632,  633,  634,  635,  636,  637,  638,  639,
  640,   -1,   -1,   -1,   -1,   -1,  646,   -1,  648,  649,
  650,  651,  652,  653,   -1,  655,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,  679,
  680,  681,  682,  683,   -1,  685,  686,  687,  688,  689,
  690,  691,  692,  693,  694,  695,  696,   -1,  698,  699,
  700,   -1,  702,   -1,    0,   -1,  706,  707,  708,  709,
  710,  711,  712,  713,  714,  715,  716,  717,  718,   -1,
  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,
  730,  731,  732,  733,  734,  735,  736,  737,  738,  739,
  740,  741,  742,  743,  744,   41,   -1,  747,   44,  749,
  750,  751,  752,  753,  754,  755,  756,  757,   -1,   -1,
   -1,   -1,   -1,   59,   60,   61,   62,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   93,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  257,   -1,  259,   -1,   -1,  262,   -1,  264,  265,
   -1,   -1,  268,  269,   -1,  271,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,   -1,
  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,
   -1,   -1,  318,  319,  320,   -1,  322,  323,  324,  325,
  326,  327,  328,   -1,   -1,   -1,  332,   -1,  334,  335,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,  349,  350,  351,  352,  353,   -1,   -1,
   -1,  357,  358,   -1,  360,   -1,  362,   -1,  364,  365,
  366,   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,
  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,
   -1,  437,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,
   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,
  456,   -1,  458,  459,  460,  461,  462,  463,  464,  465,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,
  476,   -1,  478,  479,  480,   -1,   -1,   -1,   -1,  485,
  486,  487,  488,  489,   -1,  491,   -1,   -1,  494,  495,
   -1,   -1,   -1,  499,  500,   -1,   -1,  503,  504,  505,
  506,  507,  508,  509,  510,  511,   -1,  513,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,  540,  541,  542,  543,   -1,  545,
  546,  547,  548,  549,  550,   -1,  552,  553,  554,  555,
   -1,  557,   -1,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,  573,  574,  575,
  576,   -1,  578,  579,  580,  581,   -1,  583,  584,  585,
  586,  587,   -1,  589,  590,  591,  592,  593,  594,  595,
  596,  597,  598,  599,  600,  601,  602,  603,  604,  605,
  606,  607,  608,   -1,  610,  611,  612,  613,  614,  615,
  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,
  626,  627,  628,  629,   -1,   -1,  632,  633,  634,  635,
  636,  637,  638,  639,  640,   -1,   -1,   -1,   -1,   -1,
  646,   -1,  648,  649,  650,  651,  652,  653,   -1,  655,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,
  676,  677,  678,  679,  680,  681,  682,  683,   -1,  685,
  686,  687,  688,  689,  690,  691,  692,  693,  694,  695,
  696,   -1,  698,  699,  700,   -1,  702,   -1,    0,   -1,
  706,  707,  708,  709,  710,  711,  712,  713,  714,  715,
  716,  717,  718,   -1,  720,  721,   -1,   -1,   -1,   -1,
   -1,  727,  728,  729,  730,  731,  732,  733,  734,  735,
  736,  737,  738,  739,  740,  741,  742,  743,  744,   41,
   -1,  747,   44,  749,  750,  751,  752,  753,  754,  755,
  756,  757,   -1,   -1,   -1,   -1,   -1,   59,   60,   61,
   62,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,
  262,   -1,  264,  265,   -1,   -1,  268,  269,   -1,  271,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
  302,  303,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,
  312,   -1,  314,  315,   -1,   -1,  318,  319,  320,   -1,
  322,  323,  324,  325,  326,  327,  328,   -1,   -1,   -1,
  332,   -1,  334,  335,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,  350,  351,
  352,  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,
  362,   -1,  364,  365,  366,   -1,  368,   -1,  370,  371,
  372,   -1,  374,  375,  376,  377,  378,   -1,  380,  381,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,  394,   -1,   -1,  397,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,  418,  419,  420,   -1,
  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,  434,  435,   -1,  437,  438,  439,   -1,   -1,
   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,  451,
  452,  453,  454,   -1,  456,   -1,  458,  459,  460,  461,
  462,  463,  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  475,  476,   -1,  478,  479,  480,   -1,
   -1,   -1,   -1,  485,  486,  487,  488,  489,   -1,  491,
   -1,   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,
   -1,  503,  504,  505,  506,  507,  508,  509,  510,  511,
   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,  540,  541,
  542,  543,   -1,  545,  546,  547,  548,  549,  550,   -1,
  552,  553,  554,  555,   -1,  557,   -1,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,  573,  574,  575,  576,   -1,  578,  579,  580,  581,
   -1,  583,  584,  585,  586,  587,   -1,  589,  590,  591,
  592,  593,  594,  595,  596,  597,  598,  599,  600,  601,
  602,  603,  604,  605,  606,  607,  608,   -1,  610,  611,
  612,  613,  614,  615,  616,  617,   -1,  619,  620,   -1,
   -1,   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,
  632,  633,  634,  635,  636,  637,  638,  639,  640,   -1,
   -1,   -1,   -1,   -1,  646,   -1,  648,  649,  650,  651,
  652,  653,   -1,  655,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  672,  673,   -1,  675,  676,  677,  678,  679,  680,  681,
  682,  683,   -1,  685,  686,  687,  688,  689,  690,  691,
  692,  693,  694,  695,  696,   -1,  698,  699,  700,   -1,
  702,   -1,    0,   -1,  706,  707,  708,  709,  710,  711,
  712,  713,  714,  715,  716,  717,  718,   -1,  720,  721,
   -1,   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,
  732,  733,  734,  735,  736,  737,  738,  739,  740,  741,
  742,  743,  744,   41,   -1,  747,   44,  749,  750,  751,
  752,  753,  754,  755,  756,  757,   -1,   -1,   -1,   -1,
   -1,   59,   60,   61,   62,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   93,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,
   -1,  259,   -1,   -1,  262,   -1,  264,  265,   -1,   -1,
  268,  269,   -1,  271,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,  302,  303,  304,   -1,  306,   -1,
   -1,  309,   -1,   -1,  312,   -1,  314,  315,   -1,   -1,
  318,  319,  320,   -1,  322,  323,  324,  325,  326,  327,
  328,   -1,   -1,   -1,  332,   -1,  334,  335,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,  349,  350,  351,  352,  353,   -1,   -1,   -1,  357,
  358,   -1,  360,   -1,  362,   -1,  364,  365,  366,   -1,
  368,   -1,  370,  371,  372,   -1,  374,  375,  376,  377,
  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,  394,   -1,   -1,  397,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
  418,  419,  420,   -1,  422,  423,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,  434,  435,   -1,  437,
  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,
   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,
  458,  459,  460,  461,  462,  463,  464,  465,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,
  478,  479,  480,   -1,   -1,   -1,   -1,  485,  486,  487,
  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,
   -1,  499,  500,   -1,   -1,  503,  504,  505,  506,  507,
  508,  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,  540,  541,  542,  543,   -1,  545,  546,  547,
  548,  549,  550,   -1,  552,  553,  554,  555,   -1,  557,
   -1,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,  573,  574,  575,  576,   -1,
  578,  579,  580,  581,   -1,  583,  584,  585,  586,  587,
   -1,  589,  590,  591,  592,  593,  594,  595,  596,  597,
  598,  599,  600,  601,  602,  603,  604,  605,  606,  607,
  608,   -1,  610,  611,  612,  613,  614,  615,  616,  617,
   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,
  628,  629,   -1,   -1,  632,  633,  634,  635,  636,  637,
  638,  639,  640,   -1,   -1,   -1,   -1,   -1,  646,   -1,
  648,  649,  650,  651,  652,  653,   -1,  655,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,
  678,  679,  680,  681,  682,  683,   -1,  685,  686,  687,
  688,  689,  690,  691,  692,  693,  694,  695,  696,   -1,
  698,  699,  700,   -1,  702,   -1,    0,   -1,  706,  707,
  708,  709,  710,  711,  712,  713,  714,  715,  716,  717,
  718,   -1,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,
  728,  729,  730,  731,  732,  733,  734,  735,  736,  737,
  738,  739,  740,  741,  742,  743,  744,   41,   -1,  747,
   44,  749,  750,  751,  752,  753,  754,  755,  756,  757,
   -1,   -1,   -1,   -1,   -1,   59,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   93,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,  262,   -1,
  264,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
   -1,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,  302,  303,
  304,  305,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,
  314,  315,   -1,   -1,   -1,  319,  320,   -1,  322,  323,
  324,   -1,  326,  327,  328,   -1,   -1,   -1,  332,   -1,
  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,  349,   -1,  351,   -1,  353,
   -1,   -1,   -1,  357,  358,   -1,  360,   -1,   -1,   -1,
  364,   -1,   -1,   -1,  368,   -1,  370,  371,  372,   -1,
  374,  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
  394,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,   -1,  413,
  414,  415,   -1,   -1,  418,  419,  420,   -1,  422,  423,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
  434,  435,   -1,  437,  438,  439,   -1,   -1,   -1,   -1,
   -1,  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,
  454,   -1,  456,   -1,  458,  459,  460,  461,  462,  463,
  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  475,  476,   -1,  478,  479,  480,   -1,   -1,   -1,
   -1,  485,  486,  487,  488,  489,   -1,  491,   -1,   -1,
  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,  503,
  504,  505,  506,  507,  508,  509,  510,  511,   -1,  513,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,  540,  541,  542,  543,
   -1,  545,  546,  547,  548,  549,  550,   -1,  552,  553,
  554,  555,   -1,  557,   -1,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,  573,
  574,  575,  576,   -1,  578,  579,  580,  581,   -1,  583,
  584,  585,  586,  587,   -1,  589,  590,  591,  592,  593,
  594,  595,  596,  597,  598,  599,  600,  601,   -1,  603,
  604,  605,  606,  607,  608,   -1,  610,  611,  612,  613,
  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,
  624,  625,  626,  627,  628,  629,   -1,   -1,  632,  633,
  634,  635,  636,  637,  638,  639,  640,   -1,   -1,   -1,
   -1,   -1,  646,   -1,  648,  649,  650,  651,  652,  653,
   -1,  655,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,
   -1,  675,  676,  677,  678,  679,  680,  681,  682,  683,
   -1,  685,  686,  687,  688,  689,  690,  691,  692,  693,
  694,  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,
    0,   -1,  706,  707,  708,  709,  710,  711,  712,  713,
  714,  715,  716,  717,  718,   -1,  720,  721,   -1,   -1,
   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,  733,
  734,  735,  736,  737,  738,  739,  740,  741,  742,  743,
  744,   41,   -1,  747,   44,  749,  750,  751,  752,  753,
  754,  755,  756,  757,   -1,   -1,   -1,   -1,   -1,   59,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   93,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,  262,   -1,  264,  265,   -1,   -1,  268,  269,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,   -1,   -1,   -1,  287,   -1,   -1,
  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,  302,  303,  304,  305,  306,   -1,   -1,  309,
   -1,   -1,  312,   -1,  314,  315,   -1,   -1,   -1,  319,
  320,   -1,  322,  323,  324,   -1,  326,  327,  328,   -1,
   -1,   -1,  332,   -1,  334,  335,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,  349,
   -1,  351,   -1,  353,   -1,   -1,   -1,  357,  358,   -1,
  360,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  368,   -1,
  370,  371,  372,   -1,  374,  375,  376,  377,  378,   -1,
  380,  381,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,  394,   -1,   -1,  397,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,   -1,  413,  414,  415,   -1,   -1,  418,  419,
  420,   -1,  422,  423,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,  434,  435,   -1,  437,  438,  439,
   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,
   -1,  451,  452,  453,  454,   -1,  456,   -1,  458,  459,
  460,  461,  462,  463,  464,  465,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,
  480,   -1,   -1,   -1,   -1,  485,  486,  487,  488,  489,
   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,
  500,   -1,   -1,  503,  504,  505,  506,  507,  508,  509,
  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
  540,  541,  542,  543,   -1,  545,  546,  547,  548,  549,
  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,  573,  574,  575,  576,   -1,  578,  579,
  580,  581,   -1,  583,  584,  585,  586,  587,   -1,  589,
  590,  591,  592,  593,  594,  595,  596,  597,  598,  599,
  600,  601,   -1,  603,  604,  605,  606,  607,  608,   -1,
  610,  611,  612,  613,  614,  615,  616,  617,   -1,  619,
  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,  629,
   -1,   -1,  632,  633,  634,  635,  636,  637,  638,  639,
  640,   -1,   -1,   -1,   -1,   -1,  646,   -1,  648,  649,
  650,  651,  652,  653,   -1,  655,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,  679,
  680,  681,  682,  683,   -1,  685,  686,  687,  688,  689,
  690,  691,  692,  693,  694,  695,  696,   -1,  698,  699,
  700,   -1,  702,   -1,    0,   -1,  706,  707,  708,  709,
  710,  711,  712,  713,  714,  715,  716,  717,  718,   -1,
  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,
  730,  731,  732,  733,  734,  735,  736,  737,  738,  739,
  740,  741,  742,  743,  744,   41,   -1,  747,   44,  749,
  750,  751,  752,  753,  754,  755,  756,  757,   -1,   -1,
   -1,   -1,   -1,   59,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   93,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,  264,  265,
   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,   -1,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,  302,  303,  304,  305,
  306,   -1,   -1,  309,   -1,   -1,  312,   -1,  314,  315,
   -1,   -1,   -1,  319,  320,   -1,  322,  323,  324,   -1,
  326,  327,  328,   -1,   -1,   -1,  332,   -1,  334,  335,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,  349,   -1,  351,   -1,  353,   -1,   -1,
   -1,  357,  358,   -1,  360,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  368,   -1,  370,  371,  372,   -1,  374,  375,
  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,  394,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,   -1,  413,  414,  415,
   -1,   -1,  418,  419,  420,   -1,  422,  423,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,  435,
   -1,  437,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,
   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,
  456,   -1,  458,  459,  460,  461,  462,  463,  464,  465,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,
  476,   -1,  478,  479,  480,   -1,   -1,   -1,   -1,  485,
  486,  487,  488,  489,   -1,  491,   -1,   -1,  494,  495,
   -1,   -1,   -1,  499,  500,   -1,   -1,  503,  504,  505,
  506,  507,  508,  509,  510,  511,   -1,  513,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,  540,  541,  542,  543,   -1,  545,
  546,  547,  548,  549,  550,   -1,  552,  553,  554,  555,
   -1,  557,   -1,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,  573,  574,  575,
  576,   -1,  578,  579,  580,  581,   -1,  583,  584,  585,
  586,  587,   -1,  589,  590,  591,  592,  593,  594,  595,
  596,  597,  598,  599,  600,  601,   -1,  603,  604,  605,
  606,  607,  608,   -1,  610,  611,  612,  613,  614,  615,
  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,
  626,  627,  628,  629,   -1,   -1,  632,  633,  634,  635,
  636,  637,  638,  639,  640,   -1,   -1,   -1,   -1,   -1,
  646,   -1,  648,  649,  650,  651,  652,  653,   -1,  655,
   -1,   -1,   -1,   -1,    0,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,
  676,  677,  678,  679,  680,  681,  682,  683,   -1,  685,
  686,  687,  688,  689,  690,  691,  692,  693,  694,  695,
  696,   -1,  698,  699,  700,   41,  702,   -1,   44,   -1,
  706,  707,  708,  709,  710,  711,  712,  713,  714,  715,
  716,  717,  718,   59,  720,  721,   -1,   -1,   -1,   -1,
   -1,  727,  728,  729,  730,  731,  732,  733,  734,  735,
  736,  737,  738,  739,  740,  741,  742,  743,  744,   -1,
   -1,  747,   -1,  749,  750,  751,  752,  753,  754,  755,
  756,  757,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,  264,  265,
   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,
  306,   -1,   -1,  309,   -1,   -1,  312,   -1,   -1,  315,
   -1,   -1,   -1,  319,  320,   -1,  322,  323,  324,   -1,
  326,  327,  328,   -1,   -1,   -1,  332,   -1,  334,  335,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,  349,   -1,  351,   -1,  353,   -1,   -1,
   -1,  357,  358,   -1,  360,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  368,   -1,  370,   -1,  372,   -1,  374,  375,
  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,
   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,   -1,   -1,  420,   -1,  422,  423,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,  435,
   -1,  437,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,
   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,
  456,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  464,  465,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,
  476,   -1,  478,  479,  480,   -1,   -1,   -1,   -1,  485,
  486,  487,  488,  489,   -1,  491,   -1,   -1,  494,  495,
   -1,   -1,   -1,  499,  500,   -1,   -1,  503,  504,  505,
  506,  507,  508,  509,  510,  511,   -1,  513,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,  540,  541,  542,  543,   -1,  545,
  546,  547,  548,  549,  550,   -1,  552,  553,  554,  555,
   -1,  557,   -1,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,  573,  574,  575,
  576,   -1,  578,  579,  580,  581,   -1,  583,  584,  585,
  586,  587,   -1,  589,  590,  591,  592,  593,  594,  595,
  596,  597,  598,  599,  600,  601,   -1,  603,  604,  605,
  606,  607,  608,   -1,  610,  611,  612,  613,  614,  615,
  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,
  626,  627,  628,  629,   -1,   -1,  632,  633,  634,  635,
  636,  637,  638,  639,  640,   -1,   -1,   -1,   -1,   -1,
  646,   -1,  648,  649,  650,  651,  652,  653,   -1,  655,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,
  676,  677,  678,  679,  680,  681,  682,  683,   -1,  685,
  686,  687,  688,  689,  690,  691,  692,  693,  694,  695,
  696,   -1,  698,  699,  700,    0,  702,   -1,   -1,   -1,
  706,  707,  708,  709,  710,  711,  712,  713,  714,  715,
  716,  717,  718,   -1,  720,  721,   -1,   -1,   -1,   -1,
   -1,  727,  728,  729,  730,  731,  732,  733,  734,  735,
  736,  737,  738,  739,  740,   40,   41,  743,  744,   44,
   -1,  747,   -1,  749,  750,  751,  752,  753,  754,  755,
  756,  757,   -1,   -1,   59,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,
  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,
   -1,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,   -1,
  315,   -1,   -1,   -1,  319,  320,   -1,  322,  323,  324,
   -1,  326,  327,  328,   -1,   -1,   -1,  332,   -1,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,   -1,  351,   -1,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  368,   -1,  370,   -1,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,   -1,   -1,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,
  435,   -1,  437,  438,  439,   -1,   -1,   -1,   -1,   -1,
  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,
   -1,  456,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  464,
  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  475,  476,   -1,  478,  479,  480,   -1,   -1,   -1,   -1,
  485,  486,  487,  488,  489,   -1,  491,   -1,   -1,  494,
  495,   -1,   -1,   -1,  499,  500,   -1,   -1,  503,  504,
  505,  506,  507,  508,  509,  510,  511,   -1,  513,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,  540,  541,  542,  543,   -1,
  545,  546,  547,  548,  549,  550,   -1,  552,  553,  554,
  555,   -1,  557,   -1,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,  573,  574,
  575,  576,   -1,  578,  579,  580,  581,   -1,  583,  584,
  585,  586,  587,   -1,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,   -1,  603,  604,
  605,  606,  607,  608,   -1,  610,  611,  612,  613,  614,
  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,
  625,  626,  627,  628,  629,   -1,   -1,  632,  633,  634,
  635,  636,  637,  638,  639,  640,   -1,   -1,   -1,   -1,
   -1,  646,   -1,  648,  649,  650,  651,  652,  653,   -1,
  655,   -1,   -1,   -1,   -1,    0,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,
  675,  676,  677,  678,  679,  680,  681,  682,  683,   -1,
  685,  686,  687,  688,  689,  690,  691,  692,  693,  694,
  695,  696,   -1,  698,  699,  700,   41,  702,   -1,   44,
   -1,  706,  707,  708,  709,  710,  711,  712,  713,  714,
  715,  716,  717,  718,   59,  720,  721,   -1,   -1,   -1,
   -1,   -1,  727,  728,  729,  730,  731,  732,  733,  734,
  735,  736,  737,  738,  739,  740,   -1,   -1,  743,  744,
   -1,   -1,  747,   -1,  749,  750,  751,  752,  753,  754,
  755,  756,  757,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,
  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,
   -1,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,   -1,
  315,   -1,   -1,   -1,  319,  320,   -1,  322,  323,  324,
   -1,  326,  327,  328,   -1,   -1,   -1,  332,   -1,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,   -1,  351,   -1,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  368,   -1,  370,   -1,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,   -1,   -1,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,
  435,   -1,  437,  438,  439,   -1,   -1,   -1,   -1,   -1,
  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,
   -1,  456,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  464,
  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  475,  476,   -1,  478,  479,  480,   -1,   -1,   -1,   -1,
  485,  486,  487,  488,  489,   -1,  491,   -1,   -1,  494,
  495,   -1,   -1,   -1,  499,  500,   -1,   -1,  503,  504,
  505,  506,  507,  508,  509,  510,  511,   -1,  513,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,  540,  541,  542,  543,   -1,
  545,  546,  547,  548,  549,  550,   -1,  552,  553,  554,
  555,   -1,  557,   -1,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,  573,  574,
  575,  576,   -1,  578,  579,  580,  581,   -1,  583,  584,
  585,  586,  587,   -1,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,   -1,  603,  604,
  605,  606,  607,  608,   -1,  610,  611,  612,  613,  614,
  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,
  625,  626,  627,  628,  629,   -1,   -1,  632,  633,  634,
  635,  636,  637,  638,  639,  640,   -1,   -1,   -1,   -1,
   -1,  646,   -1,  648,  649,  650,  651,  652,  653,   -1,
  655,   -1,   -1,   -1,   -1,    0,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,
  675,  676,  677,  678,  679,  680,  681,  682,  683,   -1,
  685,  686,  687,  688,  689,  690,  691,  692,  693,  694,
  695,  696,   -1,  698,  699,  700,   41,  702,   -1,   44,
   -1,  706,  707,  708,  709,  710,  711,  712,  713,  714,
  715,  716,  717,  718,   59,  720,  721,   -1,   -1,   -1,
   -1,   -1,  727,  728,  729,  730,  731,  732,  733,  734,
  735,  736,  737,  738,  739,  740,   -1,   -1,  743,  744,
   -1,   -1,  747,   -1,  749,  750,  751,  752,  753,  754,
  755,  756,  757,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,
  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,
   -1,  306,   -1,   -1,  309,   -1,   -1,  312,   -1,   -1,
  315,   -1,   -1,   -1,  319,  320,   -1,  322,  323,  324,
   -1,  326,  327,  328,   -1,   -1,   -1,  332,   -1,  334,
  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,  349,   -1,  351,   -1,  353,   -1,
   -1,   -1,  357,  358,   -1,  360,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  368,   -1,  370,   -1,  372,   -1,  374,
  375,  376,  377,  378,   -1,  380,  381,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,   -1,   -1,  420,   -1,  422,  423,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,
  435,   -1,  437,  438,  439,   -1,   -1,   -1,   -1,   -1,
  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,
   -1,  456,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  464,
  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  475,  476,   -1,  478,  479,  480,   -1,   -1,   -1,   -1,
  485,  486,  487,  488,  489,   -1,  491,   -1,   -1,  494,
  495,   -1,   -1,   -1,  499,  500,   -1,   -1,  503,  504,
  505,  506,  507,  508,  509,  510,  511,   -1,  513,   -1,
   -1,   -1,   -1,    0,   -1,   -1,   -1,   -1,   -1,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,  540,  541,  542,  543,   -1,
  545,  546,  547,  548,  549,  550,   -1,  552,  553,  554,
  555,   -1,  557,   -1,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,  573,  574,
  575,  576,   59,  578,  579,  580,  581,   -1,  583,  584,
  585,  586,  587,   -1,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,   -1,  603,  604,
  605,  606,  607,  608,   -1,  610,  611,  612,  613,  614,
  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,
  625,  626,  627,  628,  629,   -1,   -1,  632,  633,  634,
  635,  636,  637,  638,  639,  640,   -1,   -1,   -1,   -1,
   -1,  646,   -1,  648,  649,  650,  651,  652,  653,   -1,
  655,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,
  675,  676,  677,  678,  679,  680,  681,  682,  683,   -1,
  685,  686,  687,  688,  689,  690,  691,  692,  693,  694,
  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,   -1,
   -1,  706,  707,  708,  709,  710,  711,  712,  713,  714,
  715,  716,  717,  718,   -1,  720,  721,   -1,   -1,   -1,
   -1,   -1,  727,  728,  729,  730,  731,  732,  733,  734,
  735,  736,  737,  738,  739,  740,   -1,   -1,  743,  744,
   -1,   -1,  747,   -1,  749,  750,  751,  752,  753,  754,
  755,  756,  757,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,
   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,
   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,
   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,
  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  370,   -1,  372,   -1,  374,  375,  376,
  377,  378,   -1,  380,  381,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,
   -1,   -1,  399,   -1,  401,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,  435,   -1,
   -1,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,
   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  464,  465,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,
   -1,  478,  479,  480,   -1,   -1,   -1,   -1,  485,  486,
  487,  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,
   -1,   -1,  499,  500,   -1,   -1,   -1,  504,  505,  506,
  507,   -1,  509,  510,  511,   -1,  513,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,  540,  541,  542,  543,   -1,  545,  546,
  547,  548,  549,  550,   -1,  552,  553,  554,  555,   -1,
  557,   -1,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,  573,  574,  575,  576,
   -1,  578,  579,  580,  581,   -1,  583,  584,  585,  586,
  587,   -1,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,   -1,  603,  604,  605,  606,
  607,  608,   -1,  610,  611,  612,  613,  614,  615,  616,
  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,
  627,  628,  629,   -1,   -1,  632,  633,  634,  635,  636,
  637,  638,  639,  640,   -1,   -1,   -1,   -1,   -1,  646,
   -1,  648,  649,  650,  651,  652,  653,   -1,   -1,   -1,
   -1,   -1,   -1,    0,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,
  677,  678,  679,  680,  681,  682,  683,   -1,  685,  686,
  687,  688,  689,  690,  691,  692,  693,  694,  695,  696,
   -1,  698,  699,  700,   -1,  702,   -1,   44,   -1,  706,
  707,  708,  709,  710,  711,  712,  713,  714,  715,  716,
  717,  718,   59,  720,  721,   -1,   -1,   -1,   -1,   -1,
  727,  728,  729,  730,  731,  732,  733,  734,  735,  736,
  737,  738,  739,  740,   -1,   -1,  743,  744,   -1,   -1,
   -1,   -1,  749,  750,  751,  752,  753,  754,  755,  756,
  757,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,
   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  279,  280,   -1,  282,   -1,   -1,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,
   -1,   -1,  309,   -1,   -1,   -1,   -1,  314,   -1,   -1,
   -1,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,
   -1,  328,   -1,   -1,   -1,  332,   -1,  334,   -1,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,
  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,
  377,  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,
   -1,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,   -1,  413,  414,  415,   -1,
   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,
   -1,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,
   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  464,  465,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,
   -1,  478,  479,  480,   -1,   -1,   -1,   -1,  485,  486,
   -1,  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,
   -1,   -1,  499,  500,   -1,   -1,   -1,   -1,  505,  506,
  507,   -1,  509,  510,  511,   -1,  513,   -1,   -1,   -1,
   -1,    0,   -1,   -1,   -1,   -1,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,  540,  541,  542,  543,   -1,  545,  546,
  547,  548,  549,  550,   -1,  552,  553,  554,  555,   -1,
  557,   -1,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,  573,  574,  575,  576,
   59,  578,  579,  580,  581,   -1,  583,  584,  585,  586,
  587,   -1,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,   -1,  603,  604,  605,  606,
  607,  608,   -1,  610,  611,  612,  613,  614,  615,  616,
  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,
  627,  628,  629,   -1,   -1,  632,  633,  634,  635,  636,
  637,  638,  639,  640,   -1,   -1,   -1,   -1,   -1,  646,
   -1,  648,  649,  650,  651,  652,  653,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,
  677,  678,  679,  680,  681,  682,  683,   -1,  685,  686,
  687,  688,  689,  690,  691,  692,  693,  694,  695,  696,
   -1,  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,
  707,  708,  709,  710,  711,  712,  713,  714,  715,  716,
  717,  718,   -1,  720,  721,   -1,   -1,   -1,   -1,   -1,
  727,  728,  729,  730,  731,  732,  733,  734,  735,  736,
  737,  738,  739,  740,   -1,   -1,  743,  744,   -1,   -1,
   -1,   -1,  749,  750,  751,  752,  753,  754,  755,  756,
  757,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,
  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,
  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,
   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,  357,  358,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,
   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,   -1,
   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,
  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,
  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  464,  465,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,
  479,  480,   -1,   -1,   -1,   -1,  485,  486,   -1,  488,
  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,
  499,  500,   -1,   -1,   -1,   -1,  505,  506,  507,   -1,
  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,  540,  541,  542,  543,   -1,  545,  546,  547,  548,
  549,  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,  573,  574,  575,  576,   -1,  578,
  579,  580,  581,   -1,  583,  584,  585,  586,  587,   -1,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,   -1,  603,  604,  605,  606,  607,  608,
   -1,  610,  611,  612,  613,  614,  615,  616,  617,   -1,
  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,
  629,   -1,   -1,  632,  633,  634,  635,  636,  637,  638,
  639,  640,   -1,   40,   -1,   -1,   43,  646,   45,  648,
  649,  650,  651,  652,  653,   -1,   -1,   -1,   -1,   -1,
   -1,   58,   -1,   -1,   -1,   -1,   63,   -1,   -1,   -1,
   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,
  679,  680,  681,  682,  683,   -1,  685,  686,  687,  688,
  689,  690,  691,  692,  693,  694,  695,  696,   -1,  698,
  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,
  709,  710,  711,  712,  713,  714,  715,  716,  717,  718,
   -1,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,
  729,  730,  731,  732,  733,  734,  735,  736,  737,  738,
  739,  740,   -1,   -1,  743,  744,   -1,   -1,   -1,   -1,
  749,  750,  751,  752,  753,  754,  755,  756,  757,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,
  267,  268,  269,   -1,   -1,   -1,   -1,  274,   -1,   -1,
   -1,   -1,  279,  280,   -1,  282,   -1,  284,  285,   -1,
  287,   -1,   -1,  290,  291,  292,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,
   -1,  308,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  317,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,
   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,  344,   -1,  346,
  347,  348,  349,   -1,  351,   -1,  353,  354,   -1,  356,
  357,  358,   -1,   -1,   -1,   -1,   -1,  364,   -1,   -1,
   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,
  377,  378,   -1,  380,   -1,  382,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,  410,  411,  412,  413,  414,  415,  416,
   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,  426,
   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,
   -1,  438,  439,  440,  441,  442,  443,  444,  445,  446,
  447,  448,  449,   -1,  451,  452,  453,  454,   -1,  456,
  457,  458,  459,  460,  461,  462,  463,  464,  465,  466,
  467,  468,  469,  470,  471,  472,  473,  474,  475,  476,
   -1,  478,  479,  480,  481,  482,   -1,  484,  485,  486,
   -1,  488,  489,  490,  491,   -1,   -1,  494,  495,  496,
  497,  498,  499,  500,   -1,   -1,   -1,   -1,  505,  506,
  507,   -1,  509,  510,  511,   -1,  513,   -1,  515,  516,
  517,   -1,  519,  520,   -1,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,  540,  541,  542,  543,   -1,  545,  546,
  547,  548,  549,  550,   -1,  552,  553,  554,  555,   -1,
  557,   -1,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,  573,  574,  575,  576,
   -1,  578,  579,  580,  581,   -1,  583,  584,  585,  586,
  587,   -1,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,   -1,  603,  604,  605,  606,
  607,  608,   -1,  610,  611,  612,  613,  614,  615,  616,
  617,   -1,  619,  620,  621,  622,   -1,  624,  625,  626,
  627,  628,  629,   -1,   -1,  632,  633,  634,  635,  636,
  637,  638,  639,  640,  641,   -1,  643,  644,  645,  646,
  647,  648,  649,  650,  651,  652,  653,   -1,   -1,  656,
  657,  658,  659,  660,  661,  662,  663,  664,  665,  666,
  667,  668,  669,  670,  671,  672,  673,   -1,  675,  676,
  677,  678,  679,  680,  681,  682,  683,   -1,  685,  686,
  687,  688,  689,  690,  691,  692,  693,  694,  695,  696,
   -1,  698,  699,  700,   -1,  702,   -1,  704,  705,  706,
  707,  708,  709,  710,  711,  712,  713,  714,  715,  716,
  717,  718,   -1,  720,  721,  722,  723,  724,  725,  726,
  727,  728,  729,  730,  731,  732,  733,  734,  735,  736,
  737,  738,  739,  740,  741,  742,  743,  744,   -1,   -1,
   -1,   -1,  749,  750,  751,  752,  753,  754,  755,  756,
  757,   40,   -1,   -1,   43,   -1,   45,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,
   -1,   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,
  269,   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,
  279,  280,   -1,  282,   -1,  284,  285,   -1,  287,   -1,
   -1,  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,  308,
  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,
  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,
   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,
  349,   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,
   -1,   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,
   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,
   -1,  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,  410,  411,  412,  413,  414,  415,  416,   -1,   -1,
   -1,  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,
   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,
  439,  440,  441,  442,  443,  444,  445,  446,  447,  448,
  449,   -1,  451,  452,  453,  454,   -1,  456,  457,   -1,
   -1,   -1,   -1,   -1,   -1,  464,  465,  466,  467,  468,
  469,  470,  471,  472,  473,  474,  475,  476,   -1,  478,
  479,  480,  481,  482,   -1,  484,  485,  486,   -1,  488,
  489,  490,  491,   -1,   -1,  494,  495,  496,  497,  498,
  499,  500,   -1,   -1,   -1,   -1,  505,  506,  507,   -1,
  509,  510,  511,  512,  513,   -1,  515,  516,  517,  518,
  519,  520,  521,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,  540,  541,  542,  543,   -1,  545,  546,  547,  548,
  549,  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,  573,  574,  575,  576,   -1,  578,
  579,  580,  581,   -1,  583,  584,  585,  586,  587,   -1,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,   -1,  603,  604,  605,  606,  607,  608,
   -1,  610,  611,  612,  613,  614,  615,  616,  617,   -1,
  619,  620,  621,  622,   -1,  624,  625,  626,  627,  628,
  629,   -1,   -1,  632,  633,  634,  635,  636,  637,  638,
  639,  640,  641,   -1,  643,  644,  645,  646,  647,  648,
  649,  650,  651,  652,  653,   -1,   -1,  656,  657,  658,
  659,  660,  661,  662,  663,  664,  665,  666,  667,  668,
  669,  670,  671,  672,  673,   -1,  675,  676,  677,  678,
  679,  680,  681,  682,  683,   -1,  685,  686,  687,  688,
  689,  690,  691,  692,  693,  694,  695,  696,   -1,  698,
  699,  700,   -1,  702,   -1,  704,  705,  706,  707,  708,
  709,  710,  711,  712,  713,  714,  715,  716,  717,  718,
   -1,  720,  721,  722,  723,  724,  725,  726,  727,  728,
  729,  730,  731,  732,  733,  734,  735,  736,  737,  738,
  739,  740,   -1,   40,  743,  744,   43,   -1,   45,   -1,
  749,  750,  751,  752,  753,  754,  755,  756,  757,   -1,
   -1,   58,   -1,   -1,   -1,   -1,   63,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  257,   -1,  259,  260,   -1,   -1,  263,   -1,  265,   -1,
  267,  268,  269,   -1,   -1,   -1,   -1,  274,   -1,   -1,
   -1,   -1,  279,  280,   -1,  282,   -1,  284,  285,   -1,
  287,   -1,   -1,  290,  291,  292,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,
   -1,  308,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  317,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,
   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,  344,   -1,  346,
  347,  348,  349,   -1,  351,   -1,  353,  354,   -1,  356,
  357,  358,   -1,   -1,   -1,   -1,   -1,  364,   -1,   -1,
   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,
  377,  378,   -1,  380,   -1,  382,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,  408,  409,  410,  411,  412,  413,  414,  415,  416,
   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,  426,
   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,
   -1,  438,  439,  440,  441,  442,  443,  444,  445,  446,
  447,  448,  449,   -1,  451,  452,  453,  454,   -1,  456,
  457,   -1,   -1,   -1,   -1,   -1,   -1,  464,  465,  466,
  467,  468,  469,  470,  471,  472,  473,  474,  475,  476,
   -1,  478,  479,  480,  481,  482,   -1,  484,  485,  486,
   -1,  488,  489,  490,  491,   -1,   -1,  494,  495,  496,
  497,  498,  499,  500,   -1,   -1,   -1,   -1,  505,  506,
  507,   -1,  509,  510,  511,   -1,  513,   -1,  515,  516,
  517,   -1,  519,  520,   -1,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,  540,  541,  542,  543,   -1,  545,  546,
  547,  548,  549,  550,   -1,  552,  553,  554,  555,   -1,
  557,   -1,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,  573,  574,  575,  576,
   -1,  578,  579,  580,  581,   -1,  583,  584,  585,  586,
  587,   -1,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,   -1,  603,  604,  605,  606,
  607,  608,   -1,  610,  611,  612,  613,  614,  615,  616,
  617,   -1,  619,  620,  621,  622,   -1,  624,  625,  626,
  627,  628,  629,   -1,   -1,  632,  633,  634,  635,  636,
  637,  638,  639,  640,  641,   -1,  643,  644,  645,  646,
  647,  648,  649,  650,  651,  652,  653,   -1,   -1,  656,
  657,  658,  659,  660,  661,  662,  663,  664,  665,  666,
  667,  668,  669,  670,  671,  672,  673,   -1,  675,  676,
  677,  678,  679,  680,  681,  682,  683,   -1,  685,  686,
  687,  688,  689,  690,  691,  692,  693,  694,  695,  696,
   -1,  698,  699,  700,   -1,  702,   -1,  704,  705,  706,
  707,  708,  709,  710,  711,  712,  713,  714,  715,  716,
  717,  718,   -1,  720,  721,  722,  723,  724,  725,  726,
  727,  728,  729,  730,  731,  732,  733,  734,  735,  736,
  737,  738,  739,  740,   -1,   40,  743,  744,   43,   -1,
   45,   -1,  749,  750,  751,  752,  753,  754,  755,  756,
  757,   -1,   -1,   58,   -1,   -1,   -1,   -1,   63,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,
  265,   -1,  267,  268,  269,   -1,  271,   -1,   -1,  274,
   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,
  285,   -1,  287,  288,   -1,  290,  291,  292,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,
   -1,  306,   -1,  308,  309,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  317,   -1,  319,  320,   -1,   -1,   -1,  324,
   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,
   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,  344,
   -1,  346,  347,  348,  349,   -1,  351,   -1,  353,  354,
   -1,  356,  357,  358,   -1,   -1,   -1,   -1,   -1,  364,
   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,
  375,  376,  377,  378,   -1,  380,   -1,  382,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,  410,  411,  412,  413,  414,
  415,  416,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,
   -1,  426,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,
   -1,   -1,   -1,  438,  439,  440,  441,  442,  443,  444,
  445,  446,  447,  448,  449,   -1,  451,  452,  453,  454,
   -1,  456,  457,   -1,   -1,   -1,   -1,   -1,   -1,  464,
  465,  466,  467,  468,  469,  470,  471,  472,  473,  474,
  475,  476,   -1,  478,  479,  480,  481,  482,   -1,  484,
  485,  486,   -1,  488,  489,  490,  491,   -1,   -1,  494,
  495,  496,  497,  498,  499,  500,   -1,   -1,   -1,   -1,
  505,  506,  507,   -1,  509,  510,  511,   -1,  513,   -1,
  515,  516,  517,   -1,  519,  520,   -1,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,  540,  541,  542,  543,   -1,
  545,  546,  547,  548,  549,  550,   -1,  552,  553,  554,
  555,   -1,  557,   -1,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,  573,  574,
  575,  576,   -1,  578,  579,  580,  581,   -1,  583,  584,
  585,  586,  587,   -1,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,   -1,  603,  604,
  605,  606,  607,  608,   -1,  610,  611,  612,  613,  614,
  615,  616,  617,   -1,  619,  620,  621,  622,   -1,  624,
  625,  626,  627,  628,  629,   -1,   -1,  632,  633,  634,
  635,  636,  637,  638,  639,  640,  641,   -1,  643,  644,
  645,  646,  647,  648,  649,  650,  651,  652,  653,   -1,
   -1,  656,  657,  658,  659,  660,  661,  662,  663,  664,
  665,  666,  667,  668,  669,  670,  671,  672,  673,   -1,
  675,  676,  677,  678,  679,  680,  681,  682,  683,   -1,
  685,  686,  687,  688,  689,  690,  691,  692,  693,  694,
  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,  704,
  705,  706,  707,  708,  709,  710,  711,  712,  713,  714,
  715,  716,  717,  718,   -1,  720,  721,  722,  723,  724,
  725,  726,  727,  728,  729,  730,  731,  732,  733,  734,
  735,  736,  737,  738,  739,  740,   -1,   -1,  743,  744,
  745,   -1,   -1,   -1,  749,  750,  751,  752,  753,  754,
  755,  756,  757,   40,   -1,   -1,   43,   -1,   45,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   58,   -1,   -1,   -1,   -1,   63,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,
  267,  268,  269,   -1,   -1,   -1,   -1,  274,   -1,   -1,
   -1,   -1,  279,  280,   -1,  282,   -1,  284,  285,   -1,
  287,  288,   -1,  290,  291,  292,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,
   -1,  308,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  317,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,
   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,  344,   -1,  346,
  347,  348,  349,   -1,  351,   -1,  353,  354,   -1,  356,
  357,  358,   -1,   -1,   -1,   -1,   -1,  364,   -1,   -1,
   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,
  377,  378,   -1,  380,   -1,  382,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,  410,  411,  412,  413,  414,  415,  416,
   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,  426,
   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,
   -1,  438,  439,  440,  441,  442,  443,  444,  445,  446,
  447,  448,  449,   -1,  451,  452,  453,  454,   -1,  456,
  457,   -1,   -1,   -1,   -1,   -1,   -1,  464,  465,  466,
  467,  468,  469,  470,  471,  472,  473,  474,  475,  476,
   -1,  478,  479,  480,  481,  482,   -1,  484,  485,  486,
   -1,  488,  489,  490,  491,   -1,   -1,  494,  495,  496,
  497,  498,  499,  500,   -1,   -1,   -1,   -1,  505,  506,
  507,   -1,  509,  510,  511,   -1,  513,   -1,  515,  516,
  517,   -1,  519,  520,   -1,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,  540,  541,  542,  543,   -1,  545,  546,
  547,  548,  549,  550,   -1,  552,  553,  554,  555,   -1,
  557,   -1,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,  573,  574,  575,  576,
   -1,  578,  579,  580,  581,   -1,  583,  584,  585,  586,
  587,   -1,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,   -1,  603,  604,  605,  606,
  607,  608,   -1,  610,  611,  612,  613,  614,  615,  616,
  617,   -1,  619,  620,  621,  622,   -1,  624,  625,  626,
  627,  628,  629,   -1,   -1,  632,  633,  634,  635,  636,
  637,  638,  639,  640,  641,   -1,  643,  644,  645,  646,
  647,  648,  649,  650,  651,  652,  653,   -1,   -1,  656,
  657,  658,  659,  660,  661,  662,  663,  664,  665,  666,
  667,  668,  669,  670,  671,  672,  673,   -1,  675,  676,
  677,  678,  679,  680,  681,  682,  683,   -1,  685,  686,
  687,  688,  689,  690,  691,  692,  693,  694,  695,  696,
   -1,  698,  699,  700,   -1,  702,   -1,  704,  705,  706,
  707,  708,  709,  710,  711,  712,  713,  714,  715,  716,
  717,  718,   -1,  720,  721,  722,  723,  724,  725,  726,
  727,  728,  729,  730,  731,  732,  733,  734,  735,  736,
  737,  738,  739,  740,   -1,   -1,  743,  744,  745,   -1,
   -1,   -1,  749,  750,  751,  752,  753,  754,  755,  756,
  757,   40,   -1,   -1,   43,   -1,   45,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,
   -1,   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,
  269,   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,
  279,  280,   -1,  282,   -1,  284,  285,   -1,  287,  288,
   -1,  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,  308,
  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,
  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,
   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,
  349,   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,
   -1,   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,
   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,
   -1,  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,  410,  411,  412,  413,  414,  415,  416,   -1,   -1,
   -1,  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,
   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,
  439,  440,  441,  442,  443,  444,  445,  446,  447,  448,
  449,   -1,  451,  452,  453,  454,   -1,  456,  457,   -1,
   -1,   -1,   -1,   -1,   -1,  464,  465,  466,  467,  468,
  469,  470,  471,  472,  473,  474,  475,  476,   -1,  478,
  479,  480,  481,  482,   -1,  484,  485,  486,   -1,  488,
  489,  490,  491,   -1,   -1,  494,  495,  496,  497,  498,
  499,  500,   -1,   -1,   -1,   -1,  505,  506,  507,   -1,
  509,  510,  511,   -1,  513,   -1,  515,  516,  517,   -1,
  519,  520,   -1,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,  540,  541,  542,  543,   -1,  545,  546,  547,  548,
  549,  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,  573,  574,  575,  576,   -1,  578,
  579,  580,  581,   -1,  583,  584,  585,  586,  587,   -1,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,   -1,  603,  604,  605,  606,  607,  608,
   -1,  610,  611,  612,  613,  614,  615,  616,  617,   -1,
  619,  620,  621,  622,   -1,  624,  625,  626,  627,  628,
  629,   -1,   -1,  632,  633,  634,  635,  636,  637,  638,
  639,  640,  641,   -1,  643,  644,  645,  646,  647,  648,
  649,  650,  651,  652,  653,   -1,   -1,  656,  657,  658,
  659,  660,  661,  662,  663,  664,  665,  666,  667,  668,
  669,  670,  671,  672,  673,   -1,  675,  676,  677,  678,
  679,  680,  681,  682,  683,   -1,  685,  686,  687,  688,
  689,  690,  691,  692,  693,  694,  695,  696,   -1,  698,
  699,  700,   -1,  702,   -1,  704,  705,  706,  707,  708,
  709,  710,  711,  712,  713,  714,  715,  716,  717,  718,
   -1,  720,  721,  722,  723,  724,  725,  726,  727,  728,
  729,  730,  731,  732,  733,  734,  735,  736,  737,  738,
  739,  740,   -1,   -1,  743,  744,  745,   -1,   -1,   -1,
  749,  750,  751,  752,  753,  754,  755,  756,  757,   40,
   -1,   42,   43,   -1,   45,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,   -1,   -1,
   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,  260,
   -1,   -1,   -1,   -1,  265,   -1,  267,  268,  269,   -1,
   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,  280,
   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,  290,
  291,  292,   -1,   -1,   -1,   -1,  297,  298,  299,  300,
   -1,   -1,   -1,  304,   -1,  306,   -1,  308,  309,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,  320,
   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,
   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,   -1,
  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,   -1,
   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,  370,
   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,
   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,  410,
  411,  412,  413,  414,  415,  416,   -1,   -1,   -1,  420,
   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,   -1,
   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,  440,
  441,  442,  443,  444,  445,  446,  447,  448,  449,   -1,
  451,  452,  453,  454,   -1,  456,  457,   -1,   -1,   -1,
   -1,   -1,   -1,  464,  465,  466,  467,  468,  469,  470,
  471,  472,  473,  474,  475,  476,   -1,  478,  479,   -1,
  481,  482,   -1,  484,  485,  486,   -1,  488,  489,  490,
  491,   -1,   -1,  494,  495,  496,  497,  498,  499,  500,
   -1,   -1,   -1,   -1,  505,  506,  507,   -1,  509,  510,
  511,   -1,  513,   -1,  515,  516,  517,   -1,  519,  520,
   -1,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,  540,
  541,  542,  543,   -1,  545,  546,  547,  548,  549,  550,
   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,  573,  574,  575,  576,   -1,  578,  579,  580,
  581,   -1,  583,  584,  585,  586,  587,   -1,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,   -1,  603,  604,  605,  606,  607,  608,   -1,  610,
  611,  612,  613,  614,  615,  616,  617,   -1,  619,  620,
  621,  622,   -1,  624,  625,  626,  627,  628,  629,   -1,
   -1,  632,  633,  634,  635,  636,  637,  638,  639,  640,
  641,   -1,  643,  644,  645,  646,  647,  648,  649,  650,
  651,  652,  653,   -1,   -1,  656,  657,  658,  659,  660,
  661,  662,  663,  664,  665,  666,  667,  668,  669,  670,
  671,  672,  673,   -1,  675,  676,  677,  678,  679,  680,
  681,  682,  683,   -1,  685,  686,  687,  688,  689,  690,
  691,  692,  693,  694,  695,  696,   -1,  698,  699,  700,
   -1,  702,   -1,  704,  705,  706,  707,  708,  709,  710,
  711,  712,  713,  714,  715,  716,  717,  718,   -1,  720,
  721,  722,  723,  724,  725,  726,  727,  728,  729,  730,
  731,  732,  733,  734,  735,  736,  737,  738,  739,  740,
   -1,   40,  743,  744,   43,   -1,   45,   -1,  749,  750,
  751,  752,  753,  754,  755,  756,  757,   -1,   -1,   58,
   -1,   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,
  269,   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,
  279,  280,   -1,  282,   -1,  284,  285,   -1,  287,  288,
   -1,  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,  308,
  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,
  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,
   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,
  349,   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,
   -1,   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,
   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,
   -1,  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,  410,  411,  412,  413,  414,  415,  416,   -1,   -1,
   -1,  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,
   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,
  439,  440,  441,  442,  443,  444,  445,  446,  447,  448,
  449,   -1,  451,  452,  453,  454,   -1,  456,  457,   -1,
   -1,   -1,   -1,   -1,   -1,  464,  465,  466,  467,  468,
  469,  470,  471,  472,  473,  474,  475,  476,   -1,  478,
  479,  480,  481,  482,   -1,  484,  485,  486,   -1,  488,
  489,  490,  491,   -1,   -1,  494,  495,  496,  497,  498,
  499,  500,   -1,   -1,   -1,   -1,  505,  506,  507,   -1,
  509,  510,  511,   -1,  513,   -1,  515,  516,  517,   -1,
  519,  520,   -1,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,  540,  541,  542,  543,   -1,  545,  546,  547,  548,
  549,  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,  573,  574,  575,  576,   -1,  578,
  579,  580,  581,   -1,  583,  584,  585,  586,  587,   -1,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,   -1,  603,  604,  605,  606,  607,  608,
   -1,  610,  611,  612,  613,  614,  615,  616,  617,   -1,
  619,  620,  621,  622,   -1,  624,  625,  626,  627,  628,
  629,   -1,   -1,  632,  633,  634,  635,  636,  637,  638,
  639,  640,  641,   -1,  643,  644,  645,  646,  647,  648,
  649,  650,  651,  652,  653,   -1,   -1,  656,  657,  658,
  659,  660,  661,  662,  663,  664,  665,  666,  667,  668,
  669,  670,  671,  672,  673,   -1,  675,  676,  677,  678,
  679,  680,  681,  682,  683,   -1,  685,  686,  687,  688,
  689,  690,  691,  692,  693,  694,  695,  696,   -1,  698,
  699,  700,   -1,  702,   -1,  704,  705,  706,  707,  708,
  709,  710,  711,  712,  713,  714,  715,  716,  717,  718,
   -1,  720,  721,  722,  723,  724,  725,  726,  727,  728,
  729,  730,  731,  732,  733,  734,  735,  736,  737,  738,
  739,  740,   -1,   40,  743,  744,   43,   -1,   45,   -1,
  749,  750,  751,  752,  753,  754,  755,  756,  757,   -1,
   -1,   58,   -1,   -1,   -1,   -1,   63,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,
  267,  268,  269,   -1,   -1,   -1,   -1,  274,   -1,   -1,
   -1,   -1,  279,  280,   -1,  282,   -1,  284,  285,   -1,
  287,   -1,   -1,  290,  291,  292,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,
   -1,  308,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  317,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,
   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,  344,   -1,  346,
  347,  348,  349,   -1,  351,   -1,  353,  354,   -1,  356,
  357,  358,   -1,   -1,   -1,   -1,   -1,  364,   -1,   -1,
   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,
  377,  378,   -1,  380,   -1,  382,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,  410,  411,  412,  413,  414,  415,  416,
   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,  426,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,   -1,   -1,
   -1,  438,  439,  440,  441,  442,  443,  444,  445,  446,
  447,  448,  449,   -1,  451,  452,  453,  454,   -1,  456,
  457,   -1,   -1,   -1,   -1,   -1,   -1,  464,  465,  466,
  467,  468,  469,  470,  471,  472,  473,  474,  475,  476,
   -1,  478,  479,  480,  481,  482,   -1,  484,  485,  486,
   -1,  488,  489,  490,  491,   -1,   -1,  494,  495,  496,
  497,  498,  499,  500,   -1,   -1,   -1,   -1,  505,  506,
  507,   -1,  509,  510,  511,   -1,  513,   -1,  515,  516,
  517,   -1,  519,  520,   -1,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,  540,  541,  542,  543,   -1,  545,  546,
  547,  548,  549,  550,   -1,  552,  553,  554,  555,   -1,
  557,   -1,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,  573,  574,  575,  576,
   -1,  578,  579,  580,  581,   -1,  583,  584,  585,  586,
  587,   -1,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,   -1,  603,  604,  605,  606,
  607,  608,   -1,  610,  611,  612,  613,  614,  615,  616,
  617,   -1,  619,  620,  621,  622,   -1,  624,  625,  626,
  627,  628,  629,   -1,   -1,  632,  633,  634,  635,  636,
  637,  638,  639,  640,  641,   -1,  643,  644,  645,  646,
  647,  648,  649,  650,  651,  652,  653,   -1,   -1,  656,
  657,  658,  659,  660,  661,  662,  663,  664,  665,  666,
  667,  668,  669,  670,  671,  672,  673,   -1,  675,  676,
  677,  678,  679,  680,  681,  682,  683,   -1,  685,  686,
  687,  688,  689,  690,  691,  692,  693,  694,  695,  696,
   -1,  698,  699,  700,   -1,  702,   -1,  704,  705,  706,
  707,  708,  709,  710,  711,  712,  713,  714,  715,  716,
  717,  718,   -1,  720,  721,  722,  723,  724,  725,  726,
  727,  728,  729,  730,  731,  732,  733,  734,  735,  736,
  737,  738,  739,  740,   -1,   40,  743,  744,   43,   -1,
   45,   -1,  749,  750,  751,  752,  753,  754,  755,  756,
  757,   -1,   -1,   58,   -1,   -1,   -1,   -1,   63,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,
  265,   -1,  267,  268,  269,   -1,   -1,   -1,   -1,  274,
   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,
  285,   -1,  287,   -1,   -1,  290,  291,  292,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,
   -1,  306,   -1,  308,  309,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  317,   -1,  319,  320,   -1,   -1,   -1,  324,
   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,
   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,  344,
   -1,  346,  347,  348,  349,   -1,  351,   -1,  353,  354,
   -1,  356,  357,  358,   -1,   -1,   -1,   -1,   -1,  364,
   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,
  375,  376,  377,  378,   -1,  380,   -1,  382,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,  410,  411,  412,  413,  414,
  415,  416,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,
   -1,  426,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,
   -1,   -1,  437,  438,  439,  440,  441,  442,  443,  444,
  445,  446,  447,  448,  449,   -1,  451,  452,  453,  454,
   -1,  456,  457,   -1,   -1,   -1,   -1,   -1,   -1,  464,
  465,  466,  467,  468,  469,  470,  471,  472,  473,  474,
  475,  476,   -1,  478,  479,  480,  481,  482,   -1,  484,
  485,  486,   -1,  488,  489,  490,  491,   -1,   -1,  494,
  495,  496,  497,  498,  499,  500,   -1,   -1,   -1,   -1,
  505,  506,  507,   -1,  509,  510,  511,   -1,  513,   -1,
  515,  516,  517,   -1,  519,  520,   -1,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,  540,  541,  542,  543,   -1,
  545,  546,  547,  548,  549,  550,   -1,  552,  553,  554,
  555,   -1,  557,   -1,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,  573,  574,
  575,  576,   -1,  578,  579,  580,  581,   -1,  583,  584,
  585,  586,  587,   -1,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,   -1,  603,  604,
  605,  606,  607,  608,   -1,  610,  611,  612,  613,  614,
  615,  616,  617,   -1,  619,  620,  621,  622,   -1,  624,
  625,  626,  627,  628,  629,   -1,   -1,  632,  633,  634,
  635,  636,  637,  638,  639,  640,  641,   -1,  643,  644,
  645,  646,  647,  648,  649,  650,  651,  652,  653,   -1,
   -1,  656,  657,  658,  659,  660,  661,  662,  663,  664,
  665,  666,  667,  668,  669,  670,  671,  672,  673,   -1,
  675,  676,  677,  678,  679,  680,  681,  682,  683,   -1,
  685,  686,  687,  688,  689,  690,  691,  692,  693,  694,
  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,  704,
  705,  706,  707,  708,  709,  710,  711,  712,  713,  714,
  715,  716,  717,  718,   -1,  720,  721,  722,  723,  724,
  725,  726,  727,  728,  729,  730,  731,  732,  733,  734,
  735,  736,  737,  738,  739,  740,   -1,   -1,  743,  744,
   -1,   -1,   -1,   -1,  749,  750,  751,  752,  753,  754,
  755,  756,  757,   40,   -1,   42,   43,   -1,   45,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   58,   -1,   -1,   -1,   -1,   63,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,
  267,  268,  269,   -1,   -1,   -1,   -1,  274,   -1,   -1,
   -1,   -1,  279,  280,   -1,  282,   -1,  284,  285,   -1,
  287,   -1,   -1,  290,  291,  292,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,
   -1,  308,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  317,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,
   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,  344,   -1,  346,
  347,  348,  349,   -1,  351,   -1,  353,  354,   -1,  356,
  357,  358,   -1,   -1,   -1,   -1,   -1,  364,   -1,   -1,
   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,
  377,  378,   -1,  380,   -1,  382,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,  410,  411,  412,  413,  414,  415,  416,
   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,  426,
   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,
   -1,  438,  439,  440,  441,  442,  443,  444,  445,  446,
  447,  448,  449,   -1,  451,  452,  453,  454,   -1,  456,
  457,   -1,   -1,   -1,   -1,   -1,   -1,  464,  465,  466,
  467,  468,  469,  470,  471,  472,  473,  474,  475,  476,
   -1,  478,  479,  480,  481,  482,   -1,  484,  485,  486,
   -1,  488,  489,  490,  491,   -1,   -1,  494,  495,  496,
  497,  498,  499,  500,   -1,   -1,   -1,   -1,  505,  506,
  507,   -1,  509,  510,  511,   -1,  513,   -1,  515,  516,
  517,   -1,  519,  520,   -1,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,  540,  541,  542,  543,   -1,  545,  546,
  547,  548,  549,  550,   -1,  552,  553,  554,  555,   -1,
  557,   -1,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,  573,  574,  575,  576,
   -1,  578,  579,  580,  581,   -1,  583,  584,  585,  586,
  587,   -1,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,   -1,  603,  604,  605,  606,
  607,  608,   -1,  610,  611,  612,  613,  614,  615,  616,
  617,   -1,  619,  620,  621,  622,   -1,  624,  625,  626,
  627,  628,  629,   -1,   -1,  632,  633,  634,  635,  636,
  637,  638,  639,  640,  641,   -1,  643,  644,  645,  646,
  647,  648,  649,  650,  651,  652,  653,   -1,   -1,  656,
  657,  658,  659,  660,  661,  662,  663,  664,  665,  666,
  667,  668,  669,  670,  671,  672,  673,   -1,  675,  676,
  677,  678,  679,  680,  681,  682,  683,   -1,  685,  686,
  687,  688,  689,  690,  691,  692,  693,  694,  695,  696,
   -1,  698,  699,  700,   -1,  702,   -1,  704,  705,  706,
  707,  708,  709,  710,  711,  712,  713,  714,  715,  716,
  717,  718,   -1,  720,  721,  722,  723,  724,  725,  726,
  727,  728,  729,  730,  731,  732,  733,  734,  735,  736,
  737,  738,  739,  740,   -1,   -1,  743,  744,   -1,   -1,
   -1,   -1,  749,  750,  751,  752,  753,  754,  755,  756,
  757,   40,   41,   -1,   43,   -1,   45,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   58,
   -1,   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,
  269,   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,
  279,  280,   -1,  282,   -1,  284,  285,   -1,  287,   -1,
   -1,  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,  308,
  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,
  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,
   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,
  349,   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,
   -1,   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,
   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,
   -1,  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,  410,  411,  412,  413,  414,  415,  416,   -1,   -1,
   -1,  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,
   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,
  439,  440,  441,  442,  443,  444,  445,  446,  447,  448,
  449,   -1,  451,  452,  453,  454,   -1,  456,  457,   -1,
   -1,   -1,   -1,   -1,   -1,  464,  465,  466,  467,  468,
  469,  470,  471,  472,  473,  474,  475,  476,   -1,  478,
  479,  480,  481,  482,   -1,  484,  485,  486,   -1,  488,
  489,  490,  491,   -1,   -1,  494,  495,  496,  497,  498,
  499,  500,   -1,   -1,   -1,   -1,  505,  506,  507,   -1,
  509,  510,  511,   -1,  513,   -1,  515,  516,  517,   -1,
  519,  520,   -1,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,  540,  541,  542,  543,   -1,  545,  546,  547,  548,
  549,  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,  573,  574,  575,  576,   -1,  578,
  579,  580,  581,   -1,  583,  584,  585,  586,  587,   -1,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,   -1,  603,  604,  605,  606,  607,  608,
   -1,  610,  611,  612,  613,  614,  615,  616,  617,   -1,
  619,  620,  621,  622,   -1,  624,  625,  626,  627,  628,
  629,   -1,   -1,  632,  633,  634,  635,  636,  637,  638,
  639,  640,  641,   -1,  643,  644,  645,  646,  647,  648,
  649,  650,  651,  652,  653,   -1,   -1,  656,  657,  658,
  659,  660,  661,  662,  663,  664,  665,  666,  667,  668,
  669,  670,  671,  672,  673,   -1,  675,  676,  677,  678,
  679,  680,  681,  682,  683,   -1,  685,  686,  687,  688,
  689,  690,  691,  692,  693,  694,  695,  696,   -1,  698,
  699,  700,   -1,  702,   -1,  704,  705,  706,  707,  708,
  709,  710,  711,  712,  713,  714,  715,  716,  717,  718,
   -1,  720,  721,  722,  723,  724,  725,  726,  727,  728,
  729,  730,  731,  732,  733,  734,  735,  736,  737,  738,
  739,  740,   -1,   40,  743,  744,   43,   -1,   45,   -1,
  749,  750,  751,  752,  753,  754,  755,  756,  757,   -1,
   -1,   58,   -1,   -1,   -1,   -1,   63,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,
  267,  268,  269,   -1,   -1,   -1,   -1,  274,   -1,   -1,
   -1,   -1,  279,  280,   -1,  282,   -1,  284,  285,   -1,
  287,   -1,   -1,  290,  291,  292,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,
   -1,  308,  309,   -1,   -1,   -1,   -1,  314,   -1,   -1,
  317,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,
   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,  344,   -1,  346,
  347,  348,  349,   -1,  351,   -1,  353,  354,   -1,  356,
  357,  358,   -1,   -1,   -1,   -1,   -1,  364,   -1,   -1,
   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,
  377,  378,   -1,  380,   -1,  382,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,  410,  411,  412,  413,  414,  415,  416,
   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,  426,
   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,
   -1,  438,  439,  440,  441,  442,  443,  444,  445,  446,
  447,  448,  449,   -1,  451,  452,  453,  454,   -1,  456,
  457,   -1,   -1,   -1,   -1,   -1,   -1,  464,  465,  466,
  467,  468,  469,  470,  471,  472,  473,  474,  475,  476,
   -1,  478,  479,  480,  481,  482,   -1,  484,  485,  486,
   -1,  488,  489,  490,  491,   -1,   -1,  494,  495,  496,
  497,  498,  499,  500,   -1,   -1,   -1,   -1,  505,  506,
  507,   -1,  509,  510,  511,   -1,  513,   -1,  515,  516,
  517,   -1,  519,  520,   -1,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,  540,  541,  542,  543,   -1,  545,  546,
  547,  548,  549,  550,   -1,  552,  553,  554,  555,   -1,
  557,   -1,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,  573,  574,  575,  576,
   -1,  578,  579,  580,  581,   -1,  583,  584,  585,  586,
  587,   -1,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,   -1,  603,  604,  605,  606,
  607,  608,   -1,  610,  611,  612,  613,  614,  615,  616,
  617,   -1,  619,  620,  621,  622,   -1,  624,  625,  626,
  627,  628,  629,   -1,   -1,  632,  633,  634,  635,  636,
  637,  638,  639,  640,  641,   -1,  643,  644,  645,  646,
  647,  648,  649,  650,  651,  652,  653,   -1,   -1,  656,
  657,  658,  659,  660,  661,  662,  663,  664,  665,  666,
  667,  668,  669,  670,  671,  672,  673,   -1,  675,  676,
  677,  678,  679,  680,  681,  682,  683,   -1,  685,  686,
  687,  688,  689,  690,  691,  692,  693,  694,  695,  696,
   -1,  698,  699,  700,   -1,  702,   -1,  704,  705,  706,
  707,  708,  709,  710,  711,  712,  713,  714,  715,  716,
  717,  718,   -1,  720,  721,  722,  723,  724,  725,  726,
  727,  728,  729,  730,  731,  732,  733,  734,  735,  736,
  737,  738,  739,  740,   -1,   40,  743,  744,   43,   -1,
   45,   -1,  749,  750,  751,  752,  753,  754,  755,  756,
  757,   -1,   -1,   58,   -1,   -1,   -1,   -1,   63,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,
  265,   -1,  267,  268,  269,   -1,   -1,   -1,   -1,  274,
   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,
  285,   -1,  287,   -1,   -1,  290,  291,  292,   -1,   -1,
  295,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,
   -1,  306,   -1,  308,  309,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  317,   -1,  319,  320,   -1,   -1,   -1,  324,
   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,
   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,  344,
   -1,  346,  347,  348,  349,   -1,  351,   -1,  353,  354,
   -1,  356,  357,  358,   -1,   -1,   -1,   -1,   -1,  364,
   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,
  375,  376,  377,  378,   -1,  380,   -1,  382,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,  410,  411,  412,  413,  414,
  415,  416,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,
   -1,  426,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,
   -1,   -1,   -1,  438,  439,  440,  441,  442,  443,  444,
  445,  446,  447,  448,  449,   -1,  451,  452,  453,  454,
   -1,  456,  457,   -1,   -1,   -1,   -1,   -1,   -1,  464,
  465,  466,  467,  468,  469,  470,  471,  472,  473,  474,
  475,  476,   -1,  478,  479,  480,  481,  482,   -1,  484,
  485,  486,   -1,  488,  489,  490,  491,   -1,   -1,  494,
  495,  496,  497,  498,  499,  500,   -1,   -1,   -1,   -1,
  505,  506,  507,   -1,  509,  510,  511,   -1,  513,   -1,
  515,  516,  517,   -1,  519,  520,   -1,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,  540,  541,  542,  543,   -1,
  545,  546,  547,  548,  549,  550,   -1,  552,  553,  554,
  555,   -1,  557,   -1,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,  573,  574,
  575,  576,   -1,  578,  579,  580,  581,   -1,  583,  584,
  585,  586,  587,   -1,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,   -1,  603,  604,
  605,  606,  607,  608,   -1,  610,  611,  612,  613,  614,
  615,  616,  617,   -1,  619,  620,  621,  622,   -1,  624,
  625,  626,  627,  628,  629,   -1,   -1,  632,  633,  634,
  635,  636,  637,  638,  639,  640,  641,   -1,  643,  644,
  645,  646,  647,  648,  649,  650,  651,  652,  653,   -1,
   -1,  656,  657,  658,  659,  660,  661,  662,  663,  664,
  665,  666,  667,  668,  669,  670,  671,  672,  673,   -1,
  675,  676,  677,  678,  679,  680,  681,  682,  683,   -1,
  685,  686,  687,  688,  689,  690,  691,  692,  693,  694,
  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,  704,
  705,  706,  707,  708,  709,  710,  711,  712,  713,  714,
  715,  716,  717,  718,   -1,  720,  721,  722,  723,  724,
  725,  726,  727,  728,  729,  730,  731,  732,  733,  734,
  735,  736,  737,  738,  739,  740,   -1,   40,  743,  744,
   43,   -1,   45,   -1,  749,  750,  751,  752,  753,  754,
  755,  756,  757,   -1,   -1,   58,   -1,   -1,   -1,   -1,
   63,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,   -1,
   -1,   -1,  265,   -1,  267,  268,  269,   -1,   -1,   -1,
   -1,  274,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,
   -1,  284,  285,   -1,  287,   -1,   -1,  290,  291,  292,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,
   -1,  304,   -1,  306,   -1,  308,  309,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  317,   -1,  319,  320,   -1,   -1,
   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,
   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,  344,   -1,  346,  347,  348,  349,   -1,  351,   -1,
  353,  354,   -1,  356,  357,  358,   -1,   -1,   -1,   -1,
   -1,  364,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,
   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,  382,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,   -1,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,  410,  411,  412,
  413,  414,  415,  416,   -1,   -1,  419,  420,   -1,  422,
   -1,   -1,   -1,  426,   -1,   -1,   -1,   -1,   -1,   -1,
  433,   -1,   -1,   -1,   -1,  438,  439,  440,  441,  442,
  443,  444,  445,  446,  447,  448,  449,   -1,  451,  452,
  453,  454,   -1,  456,  457,   -1,   -1,   -1,   -1,   -1,
   -1,  464,  465,  466,  467,  468,  469,  470,  471,  472,
  473,  474,  475,  476,   -1,  478,  479,  480,  481,  482,
   -1,  484,  485,  486,   -1,  488,  489,  490,  491,   -1,
   -1,  494,  495,  496,  497,  498,  499,  500,   -1,   -1,
   -1,   -1,  505,  506,  507,   -1,  509,  510,  511,   -1,
  513,   -1,  515,  516,  517,   -1,  519,  520,   -1,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,  540,  541,  542,
  543,   -1,  545,  546,  547,  548,  549,  550,   -1,  552,
  553,  554,  555,   -1,  557,   -1,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
  573,  574,  575,  576,   -1,  578,  579,  580,  581,   -1,
  583,  584,  585,  586,  587,   -1,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,   -1,
  603,  604,  605,  606,  607,  608,   -1,  610,  611,  612,
  613,  614,  615,  616,  617,   -1,  619,  620,  621,  622,
   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,  632,
  633,  634,  635,  636,  637,  638,  639,  640,  641,   -1,
  643,  644,  645,  646,  647,  648,  649,  650,  651,  652,
  653,   -1,   -1,  656,  657,  658,  659,  660,  661,  662,
  663,  664,  665,  666,  667,  668,  669,  670,  671,  672,
  673,   -1,  675,  676,  677,  678,  679,  680,  681,  682,
  683,   -1,  685,  686,  687,  688,  689,  690,  691,  692,
  693,  694,  695,  696,   -1,  698,  699,  700,   -1,  702,
   -1,  704,  705,  706,  707,  708,  709,  710,  711,  712,
  713,  714,  715,  716,  717,  718,   -1,  720,  721,  722,
  723,  724,  725,  726,  727,  728,  729,  730,  731,  732,
  733,  734,  735,  736,  737,  738,  739,  740,   -1,   -1,
  743,  744,   -1,   -1,   -1,   -1,  749,  750,  751,  752,
  753,  754,  755,  756,  757,   40,   41,   -1,   43,   -1,
   45,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   58,   -1,   -1,   -1,   -1,   63,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,
  265,   -1,  267,  268,  269,   -1,   -1,   -1,   -1,  274,
   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,
  285,   -1,  287,   -1,   -1,  290,  291,  292,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,
   -1,  306,   -1,  308,  309,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  317,   -1,  319,  320,   -1,   -1,   -1,  324,
   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,
   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,  344,
   -1,  346,  347,  348,  349,   -1,  351,   -1,  353,  354,
   -1,  356,  357,  358,   -1,   -1,   -1,   -1,   -1,  364,
   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,
  375,  376,  377,  378,   -1,  380,   -1,  382,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,  410,  411,  412,  413,  414,
  415,  416,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,
   -1,  426,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,
   -1,   -1,   -1,  438,  439,  440,  441,  442,  443,  444,
  445,  446,  447,  448,  449,   -1,  451,  452,  453,  454,
   -1,  456,  457,   -1,   -1,   -1,   -1,   -1,   -1,  464,
  465,  466,  467,  468,  469,  470,  471,  472,  473,  474,
  475,  476,   -1,  478,  479,  480,  481,  482,   -1,  484,
  485,  486,   -1,  488,  489,  490,  491,   -1,   -1,  494,
  495,  496,  497,  498,  499,  500,   -1,   -1,   -1,   -1,
  505,  506,  507,   -1,  509,  510,  511,   -1,  513,   -1,
  515,  516,  517,   -1,  519,  520,   -1,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,  540,  541,  542,  543,   -1,
  545,  546,  547,  548,  549,  550,   -1,  552,  553,  554,
  555,   -1,  557,   -1,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,  573,  574,
  575,  576,   -1,  578,  579,  580,  581,   -1,  583,  584,
  585,  586,  587,   -1,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,   -1,  603,  604,
  605,  606,  607,  608,   -1,  610,  611,  612,  613,  614,
  615,  616,  617,   -1,  619,  620,  621,  622,   -1,  624,
  625,  626,  627,  628,  629,   -1,   -1,  632,  633,  634,
  635,  636,  637,  638,  639,  640,  641,   -1,  643,  644,
  645,  646,  647,  648,  649,  650,  651,  652,  653,   -1,
   -1,  656,  657,  658,  659,  660,  661,  662,  663,  664,
  665,  666,  667,  668,  669,  670,  671,  672,  673,   -1,
  675,  676,  677,  678,  679,  680,  681,  682,  683,   -1,
  685,  686,  687,  688,  689,  690,  691,  692,  693,  694,
  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,  704,
  705,  706,  707,  708,  709,  710,  711,  712,  713,  714,
  715,  716,  717,  718,   -1,  720,  721,  722,  723,  724,
  725,  726,  727,  728,  729,  730,  731,  732,  733,  734,
  735,  736,  737,  738,  739,  740,   -1,   40,  743,  744,
   43,   -1,   45,   -1,  749,  750,  751,  752,  753,  754,
  755,  756,  757,   -1,   -1,   58,   -1,   -1,   -1,   -1,
   63,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,   -1,
   -1,   -1,  265,   -1,  267,  268,  269,   -1,   -1,   -1,
   -1,  274,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,
   -1,  284,  285,   -1,  287,   -1,   -1,  290,  291,  292,
   -1,   -1,  295,   -1,  297,   -1,  299,  300,   -1,   -1,
   -1,  304,   -1,  306,   -1,  308,  309,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  317,   -1,  319,  320,   -1,   -1,
   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,
   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,  344,   -1,  346,  347,  348,  349,   -1,  351,   -1,
  353,  354,   -1,  356,  357,  358,   -1,   -1,   -1,   -1,
   -1,  364,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,
   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,  382,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,   -1,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,  410,  411,  412,
  413,  414,  415,  416,   -1,   -1,   -1,  420,   -1,  422,
   -1,   -1,   -1,  426,   -1,   -1,   -1,   -1,   -1,   -1,
  433,   -1,   -1,   -1,   -1,  438,  439,  440,  441,  442,
  443,  444,  445,  446,  447,  448,  449,   -1,  451,  452,
  453,  454,   -1,  456,  457,   -1,   -1,   -1,   -1,   -1,
   -1,  464,  465,  466,  467,  468,  469,  470,  471,  472,
  473,  474,  475,  476,   -1,  478,  479,  480,  481,  482,
   -1,  484,  485,  486,   -1,  488,  489,  490,  491,   -1,
   -1,  494,  495,  496,  497,  498,  499,  500,   -1,   -1,
   -1,   -1,  505,  506,  507,   -1,  509,  510,  511,   -1,
  513,   -1,  515,  516,  517,   -1,  519,  520,   -1,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,  540,  541,  542,
  543,   -1,  545,  546,  547,  548,  549,  550,   -1,  552,
  553,  554,  555,   -1,  557,   -1,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
  573,  574,  575,  576,   -1,  578,  579,  580,  581,   -1,
  583,  584,  585,  586,  587,   -1,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,   -1,
  603,  604,  605,  606,  607,  608,   -1,  610,  611,  612,
  613,  614,  615,  616,  617,   -1,  619,  620,  621,  622,
   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,  632,
  633,  634,  635,  636,  637,  638,  639,  640,  641,   -1,
  643,  644,  645,  646,  647,  648,  649,  650,  651,  652,
  653,   -1,   -1,  656,  657,  658,  659,  660,  661,  662,
  663,  664,  665,  666,  667,  668,  669,  670,  671,  672,
  673,   -1,  675,  676,  677,  678,  679,  680,  681,  682,
  683,   -1,  685,  686,  687,  688,  689,  690,  691,  692,
  693,  694,  695,  696,   -1,  698,  699,  700,   -1,  702,
   -1,  704,  705,  706,  707,  708,  709,  710,  711,  712,
  713,  714,  715,  716,  717,  718,   -1,  720,  721,  722,
  723,  724,  725,  726,  727,  728,  729,  730,  731,  732,
  733,  734,  735,  736,  737,  738,  739,  740,   -1,   40,
  743,  744,   43,   -1,   45,   -1,  749,  750,  751,  752,
  753,  754,  755,  756,  757,   -1,   -1,   58,   -1,   -1,
   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,
   -1,   -1,   -1,   -1,  265,   -1,  267,  268,  269,   -1,
   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,  280,
   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,  290,
  291,  292,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,   -1,   -1,  304,   -1,  306,   -1,  308,  309,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,  320,
   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,
   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,   -1,
  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,   -1,
   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,  370,
   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,
   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,  410,
  411,  412,  413,  414,  415,  416,   -1,   -1,   -1,  420,
   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,   -1,
   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,  440,
  441,  442,  443,  444,  445,  446,  447,  448,  449,   -1,
  451,  452,  453,  454,   -1,  456,  457,   -1,   -1,   -1,
   -1,   -1,   -1,  464,  465,  466,  467,  468,  469,  470,
  471,  472,  473,  474,  475,  476,   -1,  478,  479,  480,
  481,  482,   -1,  484,  485,  486,  487,  488,  489,  490,
  491,   -1,   -1,  494,  495,  496,  497,  498,  499,  500,
   -1,   -1,   -1,   -1,  505,  506,  507,   -1,  509,  510,
  511,   -1,  513,   -1,  515,  516,  517,   -1,  519,  520,
   -1,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,  540,
  541,  542,  543,   -1,  545,  546,  547,  548,  549,  550,
   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,  573,  574,  575,  576,   -1,  578,  579,  580,
  581,   -1,  583,  584,  585,  586,  587,   -1,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,   -1,  603,  604,  605,  606,  607,  608,   -1,  610,
  611,  612,  613,  614,  615,  616,  617,   -1,  619,  620,
  621,  622,   -1,  624,  625,  626,  627,  628,  629,   -1,
   -1,  632,  633,  634,  635,  636,  637,  638,  639,  640,
  641,   -1,  643,  644,  645,  646,  647,  648,  649,  650,
  651,  652,  653,   -1,   -1,  656,  657,  658,  659,  660,
  661,  662,  663,  664,  665,  666,  667,  668,  669,  670,
  671,  672,  673,   -1,  675,  676,  677,  678,  679,  680,
  681,  682,  683,   -1,  685,  686,  687,  688,  689,  690,
  691,  692,  693,  694,  695,  696,   -1,  698,  699,  700,
   -1,  702,   -1,  704,  705,  706,  707,  708,  709,  710,
  711,  712,  713,  714,  715,  716,  717,  718,   -1,  720,
  721,  722,  723,  724,  725,  726,  727,  728,  729,  730,
  731,  732,  733,  734,  735,  736,  737,  738,  739,  740,
   -1,   -1,  743,  744,   -1,   -1,   -1,   -1,  749,  750,
  751,  752,  753,  754,  755,  756,  757,   40,   -1,   42,
   43,   -1,   45,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   58,   -1,   -1,   -1,   -1,
   63,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  257,   -1,  259,  260,   -1,   -1,
   -1,   -1,  265,   -1,  267,  268,  269,   -1,   -1,   -1,
   -1,  274,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,
   -1,  284,  285,   -1,  287,   -1,   -1,  290,  291,  292,
   -1,   -1,   -1,   -1,  297,  298,  299,  300,   -1,   -1,
   -1,  304,   -1,  306,   -1,  308,  309,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  317,   -1,  319,  320,   -1,   -1,
   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,
   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,  344,   -1,  346,  347,  348,  349,   -1,  351,   -1,
  353,  354,   -1,  356,  357,  358,   -1,   -1,   -1,   -1,
   -1,  364,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,
   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,  382,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,   -1,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,  410,  411,  412,
  413,  414,  415,  416,   -1,   -1,   -1,  420,   -1,  422,
   -1,   -1,   -1,  426,   -1,   -1,   -1,   -1,   -1,   -1,
  433,   -1,   -1,   -1,   -1,  438,  439,  440,  441,  442,
  443,  444,  445,  446,  447,  448,  449,   -1,  451,  452,
  453,  454,   -1,  456,  457,   -1,   -1,   -1,   -1,   -1,
   -1,  464,  465,  466,  467,  468,  469,  470,  471,  472,
  473,  474,  475,  476,   -1,  478,   -1,   -1,  481,  482,
   -1,  484,  485,  486,   -1,  488,  489,  490,  491,   -1,
   -1,  494,  495,  496,  497,  498,  499,  500,   -1,   -1,
   -1,   -1,  505,  506,  507,   -1,  509,  510,  511,   -1,
  513,   -1,  515,  516,  517,   -1,  519,  520,   -1,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,  540,  541,  542,
  543,   -1,  545,  546,  547,  548,  549,  550,   -1,  552,
  553,  554,  555,   -1,  557,   -1,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
  573,  574,  575,  576,   -1,  578,  579,  580,  581,   -1,
  583,  584,  585,  586,  587,   -1,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,   -1,
  603,  604,  605,  606,  607,  608,   -1,  610,  611,  612,
  613,  614,  615,  616,  617,   -1,  619,  620,  621,  622,
   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,  632,
  633,  634,  635,  636,  637,  638,  639,  640,  641,   -1,
  643,  644,  645,  646,  647,  648,  649,  650,  651,  652,
  653,   -1,   -1,  656,  657,  658,  659,  660,  661,  662,
  663,  664,  665,  666,  667,  668,  669,  670,  671,  672,
  673,   -1,  675,  676,  677,  678,  679,  680,  681,  682,
  683,   -1,  685,  686,  687,  688,  689,  690,  691,  692,
  693,  694,  695,  696,   -1,  698,  699,  700,   -1,  702,
   -1,  704,  705,  706,  707,  708,  709,  710,  711,  712,
  713,  714,  715,  716,  717,  718,   -1,  720,  721,  722,
  723,  724,  725,  726,  727,  728,  729,  730,  731,  732,
  733,  734,  735,  736,  737,  738,  739,  740,   -1,   -1,
  743,  744,   -1,   -1,   -1,   -1,  749,  750,  751,  752,
  753,  754,  755,  756,  757,   40,   -1,   42,   43,   -1,
   45,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   58,   -1,   -1,   -1,   -1,   63,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,
  265,   -1,  267,  268,  269,   -1,   -1,   -1,   -1,  274,
   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,
  285,   -1,  287,   -1,   -1,  290,  291,  292,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,
   -1,  306,   -1,  308,  309,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  317,   -1,  319,  320,   -1,   -1,   -1,  324,
   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,
   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,  344,
   -1,  346,  347,  348,  349,   -1,  351,   -1,  353,  354,
   -1,  356,  357,  358,   -1,   -1,   -1,   -1,   -1,  364,
   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,
  375,  376,  377,  378,   -1,  380,   -1,  382,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,  410,  411,  412,  413,  414,
  415,  416,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,
   -1,  426,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,
   -1,   -1,   -1,  438,  439,  440,  441,  442,  443,  444,
  445,  446,  447,  448,  449,   -1,  451,  452,  453,  454,
   -1,  456,  457,   -1,   -1,   -1,   -1,   -1,   -1,  464,
  465,  466,  467,  468,  469,  470,  471,  472,  473,  474,
  475,  476,   -1,  478,  479,  480,  481,  482,   -1,  484,
  485,  486,   -1,  488,  489,  490,  491,   -1,   -1,  494,
  495,  496,  497,  498,  499,  500,   -1,   -1,   -1,   -1,
  505,  506,  507,   -1,  509,  510,  511,   -1,  513,   -1,
  515,  516,  517,   -1,  519,  520,   -1,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,  540,  541,  542,  543,   -1,
  545,  546,  547,  548,  549,  550,   -1,  552,  553,  554,
  555,   -1,  557,   -1,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,  573,  574,
  575,  576,   -1,  578,  579,  580,  581,   -1,  583,  584,
  585,  586,  587,   -1,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,   -1,  603,  604,
  605,  606,  607,  608,   -1,  610,  611,  612,  613,  614,
  615,  616,  617,   -1,  619,  620,  621,  622,   -1,  624,
  625,  626,  627,  628,  629,   -1,   -1,  632,  633,  634,
  635,  636,  637,  638,  639,  640,  641,   -1,  643,  644,
  645,  646,  647,  648,  649,  650,  651,  652,  653,   -1,
   -1,  656,  657,  658,  659,  660,  661,  662,  663,  664,
  665,  666,  667,  668,  669,  670,  671,  672,  673,   -1,
  675,  676,  677,  678,  679,  680,  681,  682,  683,   -1,
  685,  686,  687,  688,  689,  690,  691,  692,  693,  694,
  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,  704,
  705,  706,  707,  708,  709,  710,  711,  712,  713,  714,
  715,  716,  717,  718,   -1,  720,  721,  722,  723,  724,
  725,  726,  727,  728,  729,  730,  731,  732,  733,  734,
  735,  736,  737,  738,  739,  740,   -1,   40,  743,  744,
   43,   -1,   45,   -1,  749,  750,  751,  752,  753,  754,
  755,  756,  757,   -1,   -1,   58,   -1,   -1,   -1,   -1,
   63,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,   -1,
   -1,   -1,  265,   -1,  267,  268,  269,   -1,   -1,   -1,
   -1,  274,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,
   -1,  284,  285,   -1,  287,   -1,   -1,  290,  291,  292,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,
   -1,  304,   -1,  306,   -1,  308,  309,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  317,   -1,  319,  320,   -1,   -1,
   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,
   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,  344,   -1,  346,  347,  348,  349,   -1,  351,   -1,
  353,  354,   -1,  356,  357,  358,   -1,   -1,   -1,   -1,
   -1,  364,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,
   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,  382,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,   -1,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,  410,  411,  412,
  413,  414,  415,  416,   -1,   -1,   -1,  420,   -1,  422,
   -1,   -1,   -1,  426,   -1,   -1,   -1,   -1,   -1,   -1,
  433,   -1,   -1,   -1,   -1,  438,  439,  440,  441,  442,
  443,  444,  445,  446,  447,  448,  449,   -1,  451,  452,
  453,  454,   -1,  456,  457,   -1,   -1,   -1,   -1,   -1,
   -1,  464,  465,  466,  467,  468,  469,  470,  471,  472,
  473,  474,  475,  476,   -1,  478,  479,  480,  481,  482,
   -1,  484,  485,  486,   -1,  488,  489,  490,  491,   -1,
   -1,  494,  495,  496,  497,  498,  499,  500,   -1,   -1,
   -1,   -1,  505,  506,  507,   -1,  509,  510,  511,   -1,
  513,   -1,  515,  516,  517,   -1,  519,  520,   -1,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,  540,  541,  542,
  543,   -1,  545,  546,  547,  548,  549,  550,   -1,  552,
  553,  554,  555,   -1,  557,   -1,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
  573,  574,  575,  576,   -1,  578,  579,  580,  581,   -1,
  583,  584,  585,  586,  587,   -1,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,   -1,
  603,  604,  605,  606,  607,  608,   -1,  610,  611,  612,
  613,  614,  615,  616,  617,   -1,  619,  620,  621,  622,
   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,  632,
  633,  634,  635,  636,  637,  638,  639,  640,  641,   -1,
  643,  644,  645,  646,  647,  648,  649,  650,  651,  652,
  653,   -1,   -1,  656,  657,  658,  659,  660,  661,  662,
  663,  664,  665,  666,  667,  668,  669,  670,  671,  672,
  673,   -1,  675,  676,  677,  678,  679,  680,  681,  682,
  683,   -1,  685,  686,  687,  688,  689,  690,  691,  692,
  693,  694,  695,  696,   -1,  698,  699,  700,   -1,  702,
   -1,  704,  705,  706,  707,  708,  709,  710,  711,  712,
  713,  714,  715,  716,  717,  718,   -1,  720,  721,  722,
  723,  724,  725,  726,  727,  728,  729,  730,  731,  732,
  733,  734,  735,  736,  737,  738,  739,  740,   -1,   40,
  743,  744,   43,   -1,   45,   -1,  749,  750,  751,  752,
  753,  754,  755,  756,  757,   -1,   -1,   58,   -1,   -1,
   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,
   -1,   -1,   -1,   -1,  265,   -1,  267,  268,  269,   -1,
   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,  280,
   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,  290,
  291,  292,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,   -1,   -1,  304,   -1,  306,   -1,  308,  309,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,  320,
   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,
   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,   -1,
  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,   -1,
   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,  370,
   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,
   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,  410,
  411,  412,  413,  414,  415,  416,   -1,   -1,   -1,  420,
   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,   -1,
   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,  440,
  441,  442,  443,  444,  445,  446,  447,  448,  449,   -1,
  451,  452,  453,  454,   -1,  456,  457,   -1,   -1,   -1,
   -1,   -1,   -1,  464,  465,  466,  467,  468,  469,  470,
  471,  472,  473,  474,  475,  476,   -1,  478,  479,  480,
  481,  482,   -1,  484,  485,  486,   -1,  488,  489,  490,
  491,   -1,   -1,  494,  495,  496,  497,  498,  499,  500,
   -1,   -1,   -1,   -1,  505,  506,  507,   -1,  509,  510,
  511,   -1,  513,   -1,  515,  516,  517,   -1,  519,  520,
   -1,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,  540,
  541,  542,  543,   -1,  545,  546,  547,  548,  549,  550,
   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,  573,  574,  575,  576,   -1,  578,  579,  580,
  581,   -1,  583,  584,  585,  586,  587,   -1,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,   -1,  603,  604,  605,  606,  607,  608,   -1,  610,
  611,  612,  613,  614,  615,  616,  617,   -1,  619,  620,
  621,  622,   -1,  624,  625,  626,  627,  628,  629,   -1,
   -1,  632,  633,  634,  635,  636,  637,  638,  639,  640,
  641,   -1,  643,  644,  645,  646,  647,  648,  649,  650,
  651,  652,  653,   -1,   -1,  656,  657,  658,  659,  660,
  661,  662,  663,  664,  665,  666,  667,  668,  669,  670,
  671,  672,  673,   -1,  675,  676,  677,  678,  679,  680,
  681,  682,  683,   -1,  685,  686,  687,  688,  689,  690,
  691,  692,  693,  694,  695,  696,   -1,  698,  699,  700,
   -1,  702,   -1,  704,  705,  706,  707,  708,  709,  710,
  711,  712,  713,  714,  715,  716,  717,  718,   -1,  720,
  721,  722,  723,  724,  725,  726,  727,  728,  729,  730,
  731,  732,  733,  734,  735,  736,  737,  738,  739,  740,
   -1,   40,  743,  744,   43,   -1,   45,   -1,  749,  750,
  751,  752,  753,  754,  755,  756,  757,   -1,   -1,   58,
   -1,   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,
  269,   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,
  279,  280,   -1,  282,   -1,  284,  285,   -1,  287,   -1,
   -1,  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,  308,
  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,
  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,
   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,
  349,   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,
   -1,   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,
   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,
   -1,  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,  410,  411,  412,  413,  414,  415,  416,   -1,   -1,
   -1,  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,
   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,
  439,  440,  441,  442,  443,  444,  445,  446,  447,  448,
  449,   -1,  451,  452,  453,  454,   -1,  456,  457,   -1,
   -1,   -1,   -1,   -1,   -1,  464,  465,  466,  467,  468,
  469,  470,  471,  472,  473,  474,  475,  476,   -1,  478,
  479,  480,  481,  482,   -1,  484,  485,  486,   -1,  488,
  489,  490,  491,   -1,   -1,  494,  495,  496,  497,  498,
  499,  500,   -1,   -1,   -1,   -1,  505,  506,  507,   -1,
  509,  510,  511,   -1,  513,   -1,  515,  516,  517,   -1,
  519,  520,   -1,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,  540,  541,  542,  543,   -1,  545,  546,  547,  548,
  549,  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,  573,  574,  575,  576,   -1,  578,
  579,  580,  581,   -1,  583,  584,  585,  586,  587,   -1,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,   -1,  603,  604,  605,  606,  607,  608,
   -1,  610,  611,  612,  613,  614,  615,  616,  617,   -1,
  619,  620,  621,  622,   -1,  624,  625,  626,  627,  628,
  629,   -1,   -1,  632,  633,  634,  635,  636,  637,  638,
  639,  640,  641,   -1,  643,  644,  645,  646,  647,  648,
  649,  650,  651,  652,  653,   -1,   -1,  656,  657,  658,
  659,  660,  661,  662,  663,  664,  665,  666,  667,  668,
  669,  670,  671,  672,  673,   -1,  675,  676,  677,  678,
  679,  680,  681,  682,  683,   -1,  685,  686,  687,  688,
  689,  690,  691,  692,  693,  694,  695,  696,   -1,  698,
  699,  700,   -1,  702,   -1,  704,  705,  706,  707,  708,
  709,  710,  711,  712,  713,  714,  715,  716,  717,  718,
   -1,  720,  721,  722,  723,  724,  725,  726,  727,  728,
  729,  730,  731,  732,  733,  734,  735,  736,  737,  738,
  739,  740,   -1,   40,  743,  744,   43,   -1,   45,   -1,
  749,  750,  751,  752,  753,  754,  755,  756,  757,   -1,
   -1,   58,   -1,   -1,   -1,   -1,   63,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,
  267,  268,  269,   -1,   -1,   -1,   -1,  274,   -1,   -1,
   -1,   -1,  279,  280,   -1,  282,   -1,  284,  285,   -1,
  287,   -1,   -1,  290,  291,  292,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,
   -1,  308,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  317,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,
   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,  344,   -1,  346,
  347,  348,  349,   -1,  351,   -1,  353,  354,   -1,  356,
  357,  358,   -1,   -1,   -1,   -1,   -1,  364,   -1,   -1,
   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,
  377,  378,   -1,  380,   -1,  382,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,  410,  411,  412,  413,  414,  415,  416,
   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,  426,
   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,
   -1,  438,  439,  440,  441,  442,  443,  444,  445,  446,
  447,  448,  449,   -1,  451,  452,  453,  454,   -1,  456,
  457,   -1,   -1,   -1,   -1,   -1,   -1,  464,  465,  466,
  467,  468,  469,  470,  471,  472,  473,  474,  475,  476,
   -1,  478,  479,  480,  481,  482,   -1,  484,  485,  486,
   -1,  488,  489,  490,  491,   -1,   -1,  494,  495,  496,
  497,  498,  499,  500,   -1,   -1,   -1,   -1,  505,  506,
  507,   -1,  509,  510,  511,   -1,  513,   -1,  515,  516,
  517,   -1,  519,  520,   -1,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,  540,  541,  542,  543,   -1,  545,  546,
  547,  548,  549,  550,   -1,  552,  553,  554,  555,   -1,
  557,   -1,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,  573,  574,  575,  576,
   -1,  578,  579,  580,  581,   -1,  583,  584,  585,  586,
  587,   -1,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,   -1,  603,  604,  605,  606,
  607,  608,   -1,  610,  611,  612,  613,  614,  615,  616,
  617,   -1,  619,  620,  621,  622,   -1,  624,  625,  626,
  627,  628,  629,   -1,   -1,  632,  633,  634,  635,  636,
  637,  638,  639,  640,  641,   -1,  643,  644,  645,  646,
  647,  648,  649,  650,  651,  652,  653,   -1,   -1,  656,
  657,  658,  659,  660,  661,  662,  663,  664,  665,  666,
  667,  668,  669,  670,  671,  672,  673,   -1,  675,  676,
  677,  678,  679,  680,  681,  682,  683,   -1,  685,  686,
  687,  688,  689,  690,  691,  692,  693,  694,  695,  696,
   -1,  698,  699,  700,   -1,  702,   -1,  704,  705,  706,
  707,  708,  709,  710,  711,  712,  713,  714,  715,  716,
  717,  718,   -1,  720,  721,  722,  723,  724,  725,  726,
  727,  728,  729,  730,  731,  732,  733,  734,  735,  736,
  737,  738,  739,  740,   -1,   40,  743,  744,   43,   -1,
   45,   -1,  749,  750,  751,  752,  753,  754,  755,  756,
  757,   -1,   -1,   58,   -1,   -1,   -1,   -1,   63,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,
  265,   -1,  267,  268,  269,   -1,   -1,   -1,   -1,  274,
   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,
  285,   -1,  287,   -1,   -1,  290,  291,  292,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,
   -1,  306,   -1,  308,  309,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  317,   -1,  319,  320,   -1,   -1,   -1,  324,
   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,
   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,  344,
   -1,  346,  347,  348,  349,   -1,  351,   -1,  353,  354,
   -1,  356,  357,  358,   -1,   -1,   -1,   -1,   -1,  364,
   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,
  375,  376,  377,  378,   -1,  380,   -1,  382,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,
   -1,   -1,  397,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,  410,  411,  412,  413,  414,
  415,  416,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,
   -1,  426,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,
   -1,   -1,   -1,  438,  439,  440,  441,  442,  443,  444,
  445,  446,  447,  448,  449,   -1,  451,  452,  453,  454,
   -1,  456,  457,   -1,   -1,   -1,   -1,   -1,   -1,  464,
  465,  466,  467,  468,  469,  470,  471,  472,  473,  474,
  475,  476,   -1,  478,  479,  480,  481,  482,   -1,  484,
  485,  486,   -1,  488,  489,  490,  491,   -1,   -1,  494,
  495,  496,  497,  498,  499,  500,   -1,   -1,   -1,   -1,
  505,  506,  507,   -1,  509,  510,  511,   -1,  513,   -1,
  515,  516,  517,   -1,  519,  520,   -1,  522,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,  540,  541,  542,  543,   -1,
  545,  546,  547,  548,  549,  550,   -1,  552,  553,  554,
  555,   -1,  557,   -1,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,  573,  574,
  575,  576,   -1,  578,  579,  580,  581,   -1,  583,  584,
  585,  586,  587,   -1,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,   -1,  603,  604,
  605,  606,  607,  608,   -1,  610,  611,  612,  613,  614,
  615,  616,  617,   -1,  619,  620,  621,  622,   -1,  624,
  625,  626,  627,  628,  629,   -1,   -1,  632,  633,  634,
  635,  636,  637,  638,  639,  640,  641,   -1,  643,  644,
  645,  646,  647,  648,  649,  650,  651,  652,  653,   -1,
   -1,  656,  657,  658,  659,  660,  661,  662,  663,  664,
  665,  666,  667,  668,  669,  670,  671,  672,  673,   -1,
  675,  676,  677,  678,  679,  680,  681,  682,  683,   -1,
  685,  686,  687,  688,  689,  690,  691,  692,  693,  694,
  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,  704,
  705,  706,  707,  708,  709,  710,  711,  712,  713,  714,
  715,  716,  717,  718,   -1,  720,  721,  722,  723,  724,
  725,  726,  727,  728,  729,  730,  731,  732,  733,  734,
  735,  736,  737,  738,  739,  740,   -1,   40,  743,  744,
   43,   -1,   45,   -1,  749,  750,  751,  752,  753,  754,
  755,  756,  757,   -1,   -1,   58,   -1,   -1,   -1,   -1,
   63,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,   -1,
   -1,   -1,  265,   -1,  267,  268,  269,   -1,   -1,   -1,
   -1,  274,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,
   -1,  284,  285,   -1,  287,   -1,   -1,  290,  291,  292,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,
   -1,  304,   -1,  306,   -1,  308,  309,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  317,   -1,  319,  320,   -1,   -1,
   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,
   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,  344,   -1,  346,  347,  348,  349,   -1,  351,   -1,
  353,  354,   -1,  356,  357,  358,   -1,   -1,   -1,   -1,
   -1,  364,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,
   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,  382,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,   -1,   -1,   -1,  397,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,  410,  411,  412,
  413,  414,  415,  416,   -1,   -1,   -1,  420,   -1,  422,
   -1,   -1,   -1,  426,   -1,   -1,   -1,   -1,   -1,   -1,
  433,   -1,   -1,   -1,   -1,  438,  439,  440,  441,  442,
  443,  444,  445,  446,  447,  448,  449,   -1,  451,  452,
  453,  454,   -1,  456,  457,   -1,   -1,   -1,   -1,   -1,
   -1,  464,  465,  466,  467,  468,  469,  470,  471,  472,
  473,  474,  475,  476,   -1,  478,  479,  480,  481,  482,
   -1,  484,  485,  486,   -1,  488,  489,  490,  491,   -1,
   -1,  494,  495,  496,  497,  498,  499,  500,   -1,   -1,
   -1,   -1,  505,  506,  507,   -1,  509,  510,  511,   -1,
  513,   -1,  515,  516,  517,   -1,  519,  520,   -1,  522,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,  540,  541,  542,
  543,   -1,  545,  546,  547,  548,  549,  550,   -1,  552,
  553,  554,  555,   -1,  557,   -1,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
  573,  574,  575,  576,   -1,  578,  579,  580,  581,   -1,
  583,  584,  585,  586,  587,   -1,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,   -1,
  603,  604,  605,  606,  607,  608,   -1,  610,  611,  612,
  613,  614,  615,  616,  617,   -1,  619,  620,  621,  622,
   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,  632,
  633,  634,  635,  636,  637,  638,  639,  640,  641,   -1,
  643,  644,  645,  646,  647,  648,  649,  650,  651,  652,
  653,   -1,   -1,  656,  657,  658,  659,  660,  661,  662,
  663,  664,  665,  666,  667,  668,  669,  670,  671,  672,
  673,   -1,  675,  676,  677,  678,  679,  680,  681,  682,
  683,   -1,  685,  686,  687,  688,  689,  690,  691,  692,
  693,  694,  695,  696,   -1,  698,  699,  700,   -1,  702,
   -1,  704,  705,  706,  707,  708,  709,  710,  711,  712,
  713,  714,  715,  716,  717,  718,   -1,  720,  721,  722,
  723,  724,  725,  726,  727,  728,  729,  730,  731,  732,
  733,  734,  735,  736,  737,  738,  739,  740,   -1,   40,
  743,  744,   43,   -1,   45,   -1,  749,  750,  751,  752,
  753,  754,  755,  756,  757,   -1,   -1,   58,   -1,   -1,
   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,
   -1,   -1,   -1,   -1,  265,   -1,  267,  268,  269,   -1,
   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,  279,  280,
   -1,  282,   -1,  284,  285,   -1,  287,   -1,   -1,  290,
  291,  292,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,   -1,   -1,  304,   -1,  306,   -1,  308,  309,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,  319,  320,
   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,
   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,  344,   -1,  346,  347,  348,  349,   -1,
  351,   -1,  353,  354,   -1,  356,  357,  358,   -1,   -1,
   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,   -1,  370,
   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,
   -1,  382,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,   -1,   -1,   -1,  397,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,  410,
  411,  412,  413,  414,  415,  416,   -1,   -1,   -1,  420,
   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,   -1,
   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,  440,
  441,  442,  443,  444,  445,  446,  447,  448,  449,   -1,
  451,  452,  453,  454,   -1,  456,  457,   -1,   -1,   -1,
   -1,   -1,   -1,  464,  465,  466,  467,  468,  469,  470,
  471,  472,  473,  474,  475,  476,   -1,  478,  479,  480,
  481,  482,   -1,  484,  485,  486,   -1,  488,  489,  490,
  491,   -1,   -1,  494,  495,  496,  497,  498,  499,  500,
   -1,   -1,   -1,   -1,  505,  506,  507,   -1,  509,  510,
  511,   -1,  513,   -1,  515,  516,  517,   -1,  519,  520,
   -1,  522,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,  540,
  541,  542,  543,   -1,  545,  546,  547,  548,  549,  550,
   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,  573,  574,  575,  576,   -1,  578,  579,  580,
  581,   -1,  583,  584,  585,  586,  587,   -1,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,   -1,  603,  604,  605,  606,  607,  608,   -1,  610,
  611,  612,  613,  614,  615,  616,  617,   -1,  619,  620,
  621,  622,   -1,  624,  625,  626,  627,  628,  629,   -1,
   -1,  632,  633,  634,  635,  636,  637,  638,  639,  640,
  641,   -1,  643,  644,  645,  646,  647,  648,  649,  650,
  651,  652,  653,   -1,   -1,  656,  657,  658,  659,  660,
  661,  662,  663,  664,  665,  666,  667,  668,  669,  670,
  671,  672,  673,   -1,  675,  676,  677,  678,  679,  680,
  681,  682,  683,   -1,  685,  686,  687,  688,  689,  690,
  691,  692,  693,  694,  695,  696,   -1,  698,  699,  700,
   -1,  702,   -1,  704,  705,  706,  707,  708,  709,  710,
  711,  712,  713,  714,  715,  716,  717,  718,   -1,  720,
  721,  722,  723,  724,  725,  726,  727,  728,  729,  730,
  731,  732,  733,  734,  735,  736,  737,  738,  739,  740,
   -1,   40,  743,  744,   43,   -1,   45,   -1,  749,  750,
  751,  752,  753,  754,  755,  756,  757,   -1,   -1,   58,
   -1,   -1,   -1,   -1,   63,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,  267,  268,
  269,   -1,   -1,   -1,   -1,  274,   -1,   -1,   -1,   -1,
  279,  280,   -1,  282,   -1,  284,  285,   -1,  287,   -1,
   -1,  290,  291,  292,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,  308,
  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  317,   -1,
  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,
   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,  344,   -1,  346,  347,  348,
  349,   -1,  351,   -1,  353,  354,   -1,  356,  357,  358,
   -1,   -1,   -1,   -1,   -1,  364,   -1,   -1,   -1,   -1,
   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,
   -1,  380,   -1,  382,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,  410,  411,  412,  413,  414,  415,  416,   -1,   -1,
   -1,  420,   -1,  422,   -1,   -1,   -1,  426,   -1,   -1,
   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,
  439,  440,  441,  442,  443,  444,  445,  446,  447,  448,
  449,   -1,  451,  452,  453,  454,   -1,  456,  457,   -1,
   -1,   -1,   -1,   -1,   -1,  464,  465,  466,  467,  468,
  469,  470,  471,  472,  473,  474,  475,  476,   -1,  478,
  479,  480,  481,  482,   -1,  484,  485,  486,   -1,  488,
  489,  490,  491,   -1,   -1,  494,  495,  496,  497,  498,
  499,  500,   -1,   -1,   -1,   -1,  505,  506,  507,   -1,
  509,  510,  511,   -1,  513,   -1,  515,  516,  517,   -1,
  519,  520,   -1,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,  540,  541,  542,  543,   -1,  545,  546,  547,  548,
  549,  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,  573,  574,  575,  576,   -1,  578,
  579,  580,  581,   -1,  583,  584,  585,  586,  587,   -1,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,   -1,  603,  604,  605,  606,  607,  608,
   -1,  610,  611,  612,  613,  614,  615,  616,  617,   -1,
  619,  620,  621,  622,   -1,  624,  625,  626,  627,  628,
  629,   -1,   -1,  632,  633,  634,  635,  636,  637,  638,
  639,  640,  641,   -1,  643,  644,  645,  646,  647,  648,
  649,  650,  651,  652,  653,   -1,   -1,  656,  657,  658,
  659,  660,  661,  662,  663,  664,  665,  666,  667,  668,
  669,  670,  671,  672,  673,   -1,  675,  676,  677,  678,
  679,  680,  681,  682,  683,   -1,  685,  686,  687,  688,
  689,  690,  691,  692,  693,  694,  695,  696,   -1,  698,
  699,  700,   -1,  702,   -1,  704,  705,  706,  707,  708,
  709,  710,  711,  712,  713,  714,  715,  716,  717,  718,
   -1,  720,  721,  722,  723,  724,  725,  726,  727,  728,
  729,  730,  731,  732,  733,  734,  735,  736,  737,  738,
  739,  740,   -1,   40,  743,  744,   43,   -1,   45,   -1,
  749,  750,  751,  752,  753,  754,  755,  756,  757,   -1,
   -1,   58,   -1,   -1,   -1,   -1,   63,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,
  267,  268,  269,   -1,   -1,   -1,   -1,  274,   -1,   -1,
   -1,   -1,  279,  280,   -1,  282,   -1,  284,  285,   -1,
  287,   -1,   -1,  290,  291,  292,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,
   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  317,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,
   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,  344,   -1,  346,
  347,  348,  349,   -1,  351,   -1,  353,  354,   -1,  356,
  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,
  377,  378,   -1,  380,   -1,  382,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,
  397,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,  410,  411,  412,  413,  414,  415,  416,
   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,  426,
   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,
   -1,  438,  439,  440,  441,  442,  443,  444,  445,  446,
  447,  448,  449,   -1,  451,  452,  453,  454,   -1,  456,
  457,   -1,   -1,   -1,   -1,   -1,   -1,  464,  465,  466,
  467,  468,  469,  470,  471,  472,  473,  474,  475,  476,
   -1,  478,  479,  480,  481,  482,   -1,  484,  485,  486,
   -1,  488,  489,  490,  491,   -1,   -1,  494,  495,   -1,
   -1,   -1,  499,  500,   -1,   -1,   -1,   -1,  505,  506,
  507,   -1,  509,  510,  511,   -1,  513,   -1,  515,  516,
  517,   -1,  519,  520,   -1,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,  540,  541,  542,  543,   40,  545,  546,
  547,  548,  549,  550,   -1,  552,  553,  554,  555,   -1,
  557,   -1,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,  573,  574,  575,  576,
   -1,  578,  579,  580,  581,   -1,  583,  584,  585,  586,
  587,   -1,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,   -1,  603,  604,  605,  606,
  607,  608,   -1,  610,  611,  612,  613,  614,  615,  616,
  617,   -1,  619,  620,  621,  622,   -1,  624,  625,  626,
  627,  628,  629,   -1,   -1,  632,  633,  634,  635,  636,
  637,  638,  639,  640,  641,   -1,  643,  644,  645,  646,
  647,  648,  649,  650,  651,  652,  653,   -1,   -1,  656,
  657,  658,  659,  660,  661,  662,  663,  664,  665,  666,
  667,  668,  669,  670,  671,  672,  673,   -1,  675,  676,
  677,  678,  679,  680,  681,  682,  683,   -1,  685,  686,
  687,  688,  689,  690,  691,  692,  693,  694,  695,  696,
   -1,  698,  699,  700,   -1,  702,   -1,  704,  705,  706,
  707,  708,  709,  710,  711,  712,  713,  714,  715,  716,
  717,  718,   -1,  720,  721,   -1,  723,  724,  725,  726,
  727,  728,  729,  730,  731,  732,  733,  734,  735,  736,
  737,  738,  739,  740,   -1,   -1,  743,  744,   -1,   -1,
   -1,   -1,  749,  750,  751,  752,  753,  754,  755,  756,
  757,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,   -1,
   -1,   -1,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,
   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,
   -1,  324,   -1,  326,   -1,  328,  329,   -1,   -1,   -1,
   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,
  353,   -1,   -1,   -1,  357,  358,   -1,  360,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,  372,
   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,   -1,   -1,   -1,   -1,  438,  439,   -1,   -1,   -1,
   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,  451,  452,
  453,  454,   -1,  456,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  475,  476,   -1,  478,  479,  480,   -1,   -1,
   -1,   -1,  485,  486,   -1,  488,  489,   -1,  491,   -1,
   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,
   -1,   -1,  505,  506,  507,   -1,  509,  510,  511,   -1,
  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,  540,  541,  542,
  543,   40,  545,  546,  547,  548,  549,  550,   -1,  552,
  553,  554,  555,   -1,  557,   -1,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
  573,  574,  575,  576,   -1,  578,  579,  580,  581,   -1,
  583,  584,  585,  586,  587,   -1,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,   -1,
  603,  604,  605,  606,  607,  608,   -1,  610,  611,  612,
  613,  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,
   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,  632,
  633,  634,  635,  636,  637,  638,  639,  640,   -1,   -1,
   -1,   -1,   -1,  646,   -1,  648,  649,  650,  651,  652,
  653,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,
  673,   -1,  675,  676,  677,  678,  679,  680,  681,  682,
  683,   -1,  685,  686,  687,  688,  689,  690,  691,  692,
  693,  694,  695,  696,   -1,  698,  699,  700,   -1,  702,
   -1,   -1,   -1,  706,  707,  708,  709,  710,  711,  712,
  713,  714,  715,  716,  717,  718,   -1,  720,  721,   -1,
   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,
  733,  734,  735,  736,  737,  738,  739,  740,   -1,   -1,
  743,  744,   -1,   -1,   -1,   -1,  749,  750,  751,  752,
  753,  754,  755,  756,  757,   -1,   -1,   -1,  257,   -1,
  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,
  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,
  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,
  329,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,  357,  358,
   -1,  360,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  370,   -1,  372,   -1,  374,  375,  376,  377,  378,
   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,   -1,
   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,
  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,
  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  464,  465,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,
  479,  480,   -1,   -1,   -1,   -1,  485,  486,   -1,  488,
  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,
  499,  500,   -1,   -1,   -1,   -1,  505,  506,  507,   -1,
  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,  540,  541,  542,  543,   40,  545,  546,  547,  548,
  549,  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,  573,  574,  575,  576,   -1,  578,
  579,  580,  581,   -1,  583,  584,  585,  586,  587,   -1,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,   -1,  603,  604,  605,  606,  607,  608,
   -1,  610,  611,  612,  613,  614,  615,  616,  617,   -1,
  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,
  629,   -1,   -1,  632,  633,  634,  635,  636,  637,  638,
  639,  640,   -1,   -1,   -1,   -1,   -1,  646,   -1,  648,
  649,  650,  651,  652,  653,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,
  679,  680,  681,  682,  683,   -1,  685,  686,  687,  688,
  689,  690,  691,  692,  693,  694,  695,  696,   -1,  698,
  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,
  709,  710,  711,  712,  713,  714,  715,  716,  717,  718,
   -1,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,
  729,  730,  731,  732,  733,  734,  735,  736,  737,  738,
  739,  740,   -1,   -1,  743,  744,   -1,   -1,   -1,   -1,
  749,  750,  751,  752,  753,  754,  755,  756,  757,   -1,
   -1,   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,
  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,
   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,  324,
   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,
   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,   -1,
   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,
  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,
   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,
   -1,   -1,  437,  438,  439,   -1,   -1,   -1,   -1,   -1,
  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,
   -1,  456,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  464,
  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  475,  476,   -1,  478,  479,  480,   -1,   -1,   -1,   -1,
  485,  486,   -1,  488,  489,   -1,  491,   -1,   -1,  494,
  495,   -1,   -1,   -1,  499,  500,   -1,   -1,   -1,   -1,
  505,  506,  507,   -1,  509,  510,  511,   -1,  513,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,  540,  541,  542,  543,   40,
  545,  546,  547,  548,  549,  550,   -1,  552,  553,  554,
  555,   -1,  557,   -1,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,  573,  574,
  575,  576,   -1,  578,  579,  580,  581,   -1,  583,  584,
  585,  586,  587,   -1,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,   -1,  603,  604,
  605,  606,  607,  608,   -1,  610,  611,  612,  613,  614,
  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,
  625,  626,  627,  628,  629,   -1,   -1,  632,  633,  634,
  635,  636,  637,  638,  639,  640,   -1,   -1,   -1,   -1,
   -1,  646,   -1,  648,  649,  650,  651,  652,  653,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,
  675,  676,  677,  678,  679,  680,  681,  682,  683,   -1,
  685,  686,  687,  688,  689,  690,  691,  692,  693,  694,
  695,  696,   -1,  698,  699,  700,  701,  702,   -1,   -1,
   -1,  706,  707,  708,  709,  710,  711,  712,  713,  714,
  715,  716,  717,  718,   -1,  720,  721,   -1,   -1,   -1,
   -1,   -1,  727,  728,  729,  730,  731,  732,  733,  734,
  735,  736,  737,  738,  739,  740,   -1,   -1,  743,  744,
   -1,   -1,   -1,   -1,  749,  750,  751,  752,  753,  754,
  755,  756,  757,   -1,   -1,   -1,  257,   -1,  259,   -1,
   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,  269,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,
   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,  309,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,
   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,
   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,
  351,   -1,  353,   -1,   -1,   -1,  357,  358,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,
   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,
   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,   -1,   -1,  420,
   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,   -1,
   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,
  451,  452,  453,  454,   -1,  456,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  464,  465,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,  480,
   -1,   -1,   -1,   -1,  485,  486,   -1,  488,  489,   -1,
  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,  500,
   -1,   -1,   -1,   -1,  505,  506,  507,   -1,  509,  510,
  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,  540,
  541,  542,  543,   -1,  545,  546,  547,  548,  549,  550,
   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,  573,  574,  575,  576,   -1,  578,  579,  580,
  581,   -1,  583,  584,  585,  586,  587,   -1,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,   -1,  603,  604,  605,  606,  607,  608,   -1,  610,
  611,  612,  613,  614,  615,  616,  617,   -1,  619,  620,
   -1,   -1,   40,  624,  625,  626,  627,  628,  629,   -1,
   -1,  632,  633,  634,  635,  636,  637,  638,  639,  640,
   58,   -1,   -1,   -1,   -1,  646,   -1,  648,  649,  650,
  651,  652,  653,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  672,  673,   -1,  675,  676,  677,  678,  679,  680,
  681,  682,  683,   -1,  685,  686,  687,  688,  689,  690,
  691,  692,  693,  694,  695,  696,   -1,  698,  699,  700,
  701,  702,   -1,   -1,   -1,  706,  707,  708,  709,  710,
  711,  712,  713,  714,  715,  716,  717,  718,   -1,  720,
  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,  730,
  731,  732,  733,  734,  735,  736,  737,  738,  739,  740,
   -1,   -1,  743,  744,   -1,   -1,   -1,   -1,  749,  750,
  751,  752,  753,  754,  755,  756,  757,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,
   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,
  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,
   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,
  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,  357,
  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,
  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,
  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,
   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  464,  465,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,
  478,  479,  480,   -1,   -1,   -1,   -1,  485,  486,   -1,
  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,
   -1,  499,  500,   -1,   -1,   -1,   -1,  505,  506,  507,
   -1,  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,  540,  541,  542,  543,   40,  545,  546,  547,
  548,  549,  550,   -1,  552,  553,  554,  555,   -1,  557,
   -1,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,  573,  574,  575,  576,   -1,
  578,  579,  580,  581,   -1,  583,  584,  585,  586,  587,
   -1,  589,  590,  591,  592,  593,  594,  595,  596,  597,
  598,  599,  600,  601,   -1,  603,  604,  605,  606,  607,
  608,   -1,  610,  611,  612,  613,  614,  615,  616,  617,
   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,
  628,  629,   -1,   -1,  632,  633,  634,  635,  636,  637,
  638,  639,  640,   -1,   -1,   -1,   -1,   -1,  646,   -1,
  648,  649,  650,  651,  652,  653,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,
  678,  679,  680,  681,  682,  683,   -1,  685,  686,  687,
  688,  689,  690,  691,  692,  693,  694,  695,  696,   -1,
  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,
  708,  709,  710,  711,  712,  713,  714,  715,  716,  717,
  718,   -1,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,
  728,  729,  730,  731,  732,  733,  734,  735,  736,  737,
  738,  739,  740,   -1,   -1,  743,  744,   -1,   -1,   -1,
   -1,  749,  750,  751,  752,  753,  754,  755,  756,  757,
   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,   -1,   -1,
   -1,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,
  304,   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,
  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,
  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,
   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,
  374,  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
   -1,   -1,   -1,   -1,  438,  439,   -1,   -1,   -1,   -1,
   -1,  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,
  454,   -1,  456,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  475,  476,   -1,  478,  479,  480,   -1,   -1,   -1,
   -1,  485,  486,   -1,  488,  489,   -1,  491,   -1,   -1,
  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,   -1,
   -1,  505,  506,  507,   -1,  509,  510,  511,   -1,  513,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,  540,  541,  542,  543,
   40,  545,  546,  547,  548,  549,  550,   -1,  552,  553,
  554,  555,   -1,  557,   -1,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,  573,
  574,  575,  576,   -1,  578,  579,  580,  581,   -1,  583,
  584,  585,  586,  587,   -1,  589,  590,  591,  592,  593,
  594,  595,  596,  597,  598,  599,  600,  601,   -1,  603,
  604,  605,  606,  607,  608,   -1,  610,  611,  612,  613,
  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,
  624,  625,  626,  627,  628,  629,   -1,   -1,  632,  633,
  634,  635,  636,  637,  638,  639,  640,   -1,   -1,   -1,
   -1,   -1,  646,   -1,  648,  649,  650,  651,  652,  653,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,
   -1,  675,  676,  677,  678,  679,  680,  681,  682,  683,
   -1,  685,  686,  687,  688,  689,  690,  691,  692,  693,
  694,  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,
   -1,   -1,  706,  707,  708,  709,  710,  711,  712,  713,
  714,  715,  716,  717,  718,   -1,  720,  721,   -1,   -1,
   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,  733,
  734,  735,  736,  737,  738,  739,  740,   -1,   -1,  743,
  744,   -1,   -1,   -1,   -1,  749,  750,  751,  752,  753,
  754,  755,  756,  757,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,  269,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,
   -1,  351,   -1,  353,   -1,   -1,   -1,  357,  358,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,
   -1,  451,  452,  453,  454,   -1,  456,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  464,  465,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,
  480,   -1,   -1,   -1,   -1,  485,  486,   -1,  488,  489,
   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,
  500,   -1,   -1,   -1,   -1,  505,  506,  507,   -1,  509,
  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
  540,  541,  542,  543,   42,  545,  546,  547,  548,  549,
  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,  573,  574,  575,  576,   -1,  578,  579,
  580,  581,   -1,  583,  584,  585,  586,  587,   -1,  589,
  590,  591,  592,  593,  594,  595,  596,  597,  598,  599,
  600,  601,   -1,  603,  604,  605,  606,  607,  608,   -1,
  610,  611,  612,  613,  614,  615,  616,  617,   -1,  619,
  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,  629,
   -1,   -1,  632,  633,  634,  635,  636,  637,  638,  639,
  640,   -1,   -1,   -1,   -1,   -1,  646,   -1,  648,  649,
  650,  651,  652,  653,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,  679,
  680,  681,  682,  683,   -1,  685,  686,  687,  688,  689,
  690,  691,  692,  693,  694,  695,  696,   -1,  698,  699,
  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,  709,
  710,  711,  712,  713,  714,  715,  716,  717,  718,   -1,
  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,
  730,  731,  732,  733,  734,  735,  736,  737,  738,  739,
  740,   -1,   -1,  743,  744,   -1,   -1,   -1,   -1,  749,
  750,  751,  752,  753,  754,  755,  756,  757,   -1,  257,
   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,
  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,  292,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,
   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,
  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,  357,
  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,
  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,
  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,
   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  464,  465,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,
  478,  479,  480,   -1,   -1,   -1,   -1,  485,  486,   -1,
  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,
   -1,  499,  500,   -1,   -1,   -1,   -1,  505,  506,  507,
   -1,  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,  540,  541,  542,  543,   -1,  545,  546,  547,
  548,  549,  550,   45,  552,  553,  554,  555,   -1,  557,
   -1,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,  573,  574,  575,  576,   -1,
  578,  579,  580,  581,   -1,  583,  584,  585,  586,  587,
   -1,  589,  590,  591,  592,  593,  594,  595,  596,  597,
  598,  599,  600,  601,   -1,  603,  604,  605,  606,  607,
  608,   -1,  610,  611,  612,  613,  614,  615,  616,  617,
   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,
  628,  629,   -1,   -1,  632,  633,  634,  635,  636,  637,
  638,  639,  640,   -1,   -1,   -1,   -1,   -1,  646,  647,
  648,  649,  650,  651,  652,  653,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,
  678,  679,  680,  681,  682,  683,   -1,  685,  686,  687,
  688,  689,  690,  691,  692,  693,  694,  695,  696,   -1,
  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,
  708,  709,  710,  711,  712,  713,  714,  715,  716,  717,
  718,   -1,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,
  728,  729,  730,  731,  732,  733,  734,  735,  736,  737,
  738,  739,  740,   -1,   -1,  743,  744,   -1,   -1,   -1,
   -1,  749,  750,  751,  752,  753,  754,  755,  756,  757,
   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,   -1,   -1,
   -1,   -1,   -1,  265,   -1,   -1,  268,  269,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
   -1,   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,
   -1,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,
   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,
   -1,  353,   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,
   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,   -1,   -1,  420,   -1,
  422,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,   -1,   -1,   -1,   -1,  438,  439,   -1,   -1,
   -1,   -1,   -1,  445,  446,   -1,   -1,  449,   -1,  451,
  452,  453,  454,   -1,  456,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  475,  476,   -1,  478,  479,  480,   -1,
   -1,   -1,   -1,  485,  486,   -1,  488,  489,   -1,  491,
   -1,   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,
   -1,   -1,   -1,  505,  506,  507,   -1,  509,  510,  511,
   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,  540,  541,
  542,  543,   -1,  545,  546,  547,  548,  549,  550,   -1,
  552,  553,  554,  555,   -1,  557,   -1,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,  573,  574,  575,  576,   -1,  578,  579,  580,  581,
   -1,  583,  584,  585,  586,  587,   -1,  589,  590,  591,
  592,  593,  594,  595,  596,  597,  598,  599,  600,  601,
   -1,  603,  604,  605,  606,  607,  608,   -1,  610,  611,
  612,  613,  614,  615,  616,  617,   -1,  619,  620,   -1,
   -1,   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,
  632,  633,  634,  635,  636,  637,  638,  639,  640,   -1,
   -1,   -1,   -1,   -1,  646,   -1,  648,  649,  650,  651,
  652,  653,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  672,  673,  674,  675,  676,  677,  678,  679,  680,  681,
  682,  683,   -1,  685,  686,  687,  688,  689,  690,  691,
  692,  693,  694,  695,  696,   -1,  698,  699,  700,   -1,
  702,   -1,   -1,   -1,  706,  707,  708,  709,  710,  711,
  712,  713,  714,  715,  716,  717,  718,   -1,  720,  721,
   -1,   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,
  732,  733,  734,  735,  736,  737,  738,  739,  740,   -1,
   -1,  743,  744,   -1,   -1,   -1,   -1,  749,  750,  751,
  752,  753,  754,  755,  756,  757,   42,   43,   44,   45,
   46,   47,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   60,   61,   62,   -1,   -1,   41,
   42,   43,   44,   45,   -1,   47,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   60,   61,
   62,   -1,   -1,   -1,   -1,   91,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,
  272,   -1,   -1,  275,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  291,
   -1,  293,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  331,
   -1,   -1,   -1,   -1,   -1,  337,  338,  339,   -1,  341,
  342,  343,   -1,  345,   -1,   -1,   41,   42,   43,   44,
   45,   46,   47,   -1,   -1,   -1,   -1,  359,   -1,  361,
   -1,   -1,   -1,   -1,   -1,   60,   61,   62,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  390,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  406,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  262,   -1,   -1,   -1,
  266,   -1,   -1,   -1,   -1,  271,  428,   -1,   -1,   -1,
   -1,  277,   -1,   -1,   -1,  281,   -1,   -1,  284,   -1,
  262,   -1,   -1,   -1,  266,   -1,   -1,   -1,   -1,  271,
   -1,   -1,   -1,   -1,   -1,  277,   -1,   -1,   -1,  281,
   -1,   -1,  284,   -1,  466,  467,   -1,   -1,   -1,   -1,
   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,  325,
   -1,  483,   -1,   -1,   -1,   -1,   -1,  333,   -1,   -1,
   -1,   58,   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,
   -1,   -1,   -1,  325,  350,   -1,  352,   -1,   -1,   -1,
   -1,  333,   -1,   -1,   -1,   -1,  362,   -1,  364,  365,
  366,   -1,   -1,   -1,   -1,  371,   -1,   -1,  350,   -1,
  352,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  362,   -1,  364,  365,  366,   -1,   -1,   -1,   -1,  371,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  412,  262,   -1,   -1,
   -1,  266,   -1,   -1,   -1,   -1,  271,   -1,   -1,   -1,
   -1,   -1,  277,   -1,   -1,   -1,  281,   -1,   -1,   -1,
  412,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  458,  459,  460,  461,  462,  463,  464,  465,
   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,   -1,
  325,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  333,   -1,
  642,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,  364,
  365,  366,  674,   -1,   -1,   -1,  371,   -1,   -1,   -1,
   -1,   -1,  684,   -1,   -1,   -1,   -1,   -1,  690,   -1,
  257,   -1,  259,   -1,  261,  697,   -1,   -1,  265,   -1,
  702,  268,  269,  270,   -1,   -1,   -1,   -1,  710,   -1,
   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,
  287,  567,   -1,  290,   -1,   -1,   -1,   -1,   -1,  296,
  297,   -1,  299,  300,   -1,   -1,  303,  304,   -1,  306,
  307,   -1,  309,   -1,  746,  312,   -1,  593,   -1,   -1,
   -1,   -1,  319,  320,   -1,   -1,  602,  324,  325,  326,
   -1,  328,   -1,  330,   -1,   -1,   -1,  334,   -1,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,  346,
  602,  348,  349,   -1,  351,   -1,  353,  609,  355,   -1,
  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,
  377,  378,   -1,  380,   -1,  382,  383,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,
  397,   -1,  399,  400,  401,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,  425,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,  434,   -1,  436,
  437,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,
   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,
  457,   -1,   -1,   -1,   -1,  741,  742,  464,  465,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  602,  475,  476,
   -1,  478,  479,  480,  609,   -1,   -1,   -1,  485,  486,
   -1,  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,
   -1,   -1,  499,  500,  501,  502,  503,   -1,  505,  506,
  507,   -1,  509,  510,  511,   -1,  513,   -1,  515,  516,
  517,   -1,  519,  520,   -1,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,  540,  541,  542,  543,   -1,  545,  546,
  547,  548,  549,  550,   -1,  552,  553,  554,  555,   -1,
  557,   -1,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,  573,  574,  575,  576,
   58,  578,  579,  580,  581,   -1,  583,  584,  585,  586,
  587,   -1,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,   -1,  603,  604,  605,  606,
  607,  608,   -1,  610,  611,  612,  613,  614,  615,  616,
  617,   -1,  619,  620,  621,  622,   -1,  624,  625,  626,
  627,  628,  629,  630,   -1,  632,  633,  634,  635,  636,
  637,  638,  639,  640,   -1,   -1,   -1,   -1,   -1,  646,
   -1,  648,  649,  650,  651,  652,  653,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,
  677,  678,  679,  680,  681,  682,  683,   -1,  685,  686,
  687,  688,  689,  690,  691,  692,  693,  694,  695,  696,
   -1,  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,
  707,  708,  709,  710,  711,  712,  713,  714,  715,  716,
  717,  718,   -1,  720,  721,   -1,   -1,  724,  725,  726,
  727,  728,  729,  730,  731,  732,  733,  734,  735,  736,
  737,  738,  739,  740,   -1,   -1,  743,  744,   -1,   -1,
   -1,   -1,  749,  750,  751,  752,  753,  754,  755,  756,
  757,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,
   -1,  259,   -1,  261,   -1,   -1,   -1,  265,   -1,   -1,
  268,  269,  270,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,  296,  297,
   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,  307,
   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  319,  320,   -1,   -1,   -1,  324,  325,  326,   -1,
  328,   -1,  330,   -1,   -1,   -1,  334,   -1,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,  346,   -1,
  348,  349,   -1,  351,   -1,  353,   -1,  355,   -1,  357,
  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,
  378,   -1,  380,   -1,  382,  383,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,  397,
   -1,  399,   -1,  401,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
   -1,   -1,  420,   -1,  422,   -1,   -1,  425,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,  434,   -1,   -1,  437,
  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,
   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,  457,
   -1,   -1,   -1,   -1,   -1,   -1,  464,  465,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,
  478,  479,  480,   -1,   -1,   -1,   -1,  485,  486,   -1,
  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,
   -1,  499,  500,  501,  502,  503,   -1,  505,  506,  507,
   -1,  509,  510,  511,   -1,  513,   -1,  515,  516,  517,
   -1,  519,  520,   -1,  522,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,  540,  541,  542,  543,   -1,  545,  546,  547,
  548,  549,  550,   -1,  552,  553,  554,  555,   -1,  557,
   -1,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,  573,  574,  575,  576,   58,
  578,  579,  580,  581,   -1,  583,  584,  585,  586,  587,
   -1,  589,  590,  591,  592,  593,  594,  595,  596,  597,
  598,  599,  600,  601,   -1,  603,  604,  605,  606,  607,
  608,   -1,  610,  611,  612,  613,  614,  615,  616,  617,
   -1,  619,  620,  621,  622,   -1,  624,  625,  626,  627,
  628,  629,  630,   -1,  632,  633,  634,  635,  636,  637,
  638,  639,  640,   -1,   -1,   -1,   -1,   -1,  646,   -1,
  648,  649,  650,  651,  652,  653,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,
  678,  679,  680,  681,  682,  683,   -1,  685,  686,  687,
  688,  689,  690,  691,  692,  693,  694,  695,  696,   -1,
  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,
  708,  709,  710,  711,  712,  713,  714,  715,  716,  717,
  718,   -1,  720,  721,   -1,   -1,  724,  725,  726,  727,
  728,  729,  730,  731,  732,  733,  734,  735,  736,  737,
  738,  739,  740,   -1,   -1,  743,  744,   -1,   -1,   -1,
   -1,  749,  750,  751,  752,  753,  754,  755,  756,  757,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,
  259,   -1,  261,   -1,   -1,   -1,  265,   -1,   -1,  268,
  269,  270,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,  296,  297,   -1,
  299,  300,   -1,   -1,   -1,  304,   -1,  306,  307,   -1,
  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  319,  320,   -1,   -1,   -1,  324,  325,  326,   -1,  328,
   -1,  330,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,  346,   -1,  348,
  349,   -1,  351,   -1,  353,   -1,  355,   -1,  357,  358,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,
   -1,  380,   -1,  382,  383,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,   -1,   -1,   -1,  397,   -1,
  399,   -1,  401,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,   -1,
   -1,  420,   -1,  422,   -1,   -1,  425,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,  437,  438,
  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,
  449,   -1,  451,  452,  453,  454,   -1,  456,  457,   -1,
   -1,   -1,   -1,   -1,   -1,  464,  465,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,
  479,  480,   -1,   -1,   -1,   -1,  485,  486,   -1,  488,
  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,
  499,  500,  501,  502,  503,   -1,  505,  506,  507,   -1,
  509,  510,  511,   -1,  513,   -1,  515,  516,  517,   -1,
  519,  520,   -1,  522,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,  540,  541,  542,  543,   -1,  545,  546,  547,  548,
  549,  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,  573,  574,  575,  576,   58,  578,
  579,  580,  581,   -1,  583,  584,  585,  586,  587,   -1,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,   -1,  603,  604,  605,  606,  607,  608,
   -1,  610,  611,  612,  613,  614,  615,  616,  617,   -1,
  619,  620,  621,  622,   -1,  624,  625,  626,  627,  628,
  629,  630,   -1,  632,  633,  634,  635,  636,  637,  638,
  639,  640,   -1,   -1,   -1,   -1,   -1,  646,   -1,  648,
  649,  650,  651,  652,  653,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,
  679,  680,  681,  682,  683,   -1,  685,  686,  687,  688,
  689,  690,  691,  692,  693,  694,  695,  696,   -1,  698,
  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,
  709,  710,  711,  712,  713,  714,  715,  716,  717,  718,
   -1,  720,  721,   -1,   -1,  724,  725,  726,  727,  728,
  729,  730,  731,  732,  733,  734,  735,  736,  737,  738,
  739,  740,   -1,   -1,  743,  744,   -1,   -1,   -1,   -1,
  749,  750,  751,  752,  753,  754,  755,  756,  757,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,  269,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,
   -1,  351,   -1,  353,   -1,   -1,   -1,  357,  358,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,
   -1,  451,  452,  453,  454,   -1,  456,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  464,  465,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,
  480,   -1,   -1,   -1,   -1,  485,  486,   -1,  488,  489,
   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,
  500,   -1,   -1,   -1,   -1,  505,  506,  507,   -1,  509,
  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
  540,  541,  542,  543,   -1,  545,  546,  547,  548,  549,
  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,  573,  574,  575,  576,   -1,  578,  579,
  580,  581,   -1,  583,  584,  585,  586,  587,   -1,  589,
  590,  591,  592,  593,  594,  595,  596,  597,  598,  599,
  600,  601,   -1,  603,  604,  605,  606,  607,  608,   -1,
  610,  611,  612,  613,  614,  615,  616,  617,   -1,  619,
  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,  629,
   -1,   -1,  632,  633,  634,  635,  636,  637,  638,  639,
  640,   -1,   -1,   -1,   -1,   -1,  646,   -1,  648,  649,
  650,  651,  652,  653,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,  679,
  680,  681,  682,  683,   -1,  685,  686,  687,  688,  689,
  690,  691,  692,  693,  694,  695,  696,   -1,  698,  699,
  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,  709,
  710,  711,  712,  713,  714,  715,  716,  717,  718,   -1,
  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,
  730,  731,  732,  733,  734,  735,  736,  737,  738,  739,
  740,   -1,   -1,  743,  744,   -1,   -1,   -1,   -1,  749,
  750,  751,  752,  753,  754,  755,  756,  757,   42,   43,
   -1,   45,   46,   47,   -1,  272,   -1,   -1,  275,   -1,
   -1,   -1,   -1,   -1,   -1,   59,   60,   61,   62,   -1,
  287,   -1,   -1,   -1,  291,   -1,  293,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   91,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  331,   -1,   -1,   -1,   -1,   -1,
  337,  338,  339,   -1,  341,  342,  343,   -1,  345,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  359,   -1,  361,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  379,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  390,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  406,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  428,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  466,
  467,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  483,   -1,  262,   -1,
  264,   -1,  266,   -1,   -1,   -1,   -1,  271,   -1,   -1,
   -1,   -1,   -1,  277,   -1,   -1,   -1,  281,   -1,   -1,
  284,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  318,   -1,   -1,   -1,   -1,   -1,
   -1,  325,   -1,   -1,   -1,   -1,   -1,   -1,  332,  333,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  350,   -1,  352,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  362,   -1,
  364,  365,  366,   -1,  368,   -1,   -1,  371,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  380,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  412,  257,
   -1,  259,   -1,   -1,   -1,  642,   -1,  265,   -1,   -1,
  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  279,  280,  437,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,   -1,   -1,  674,   -1,  297,
  454,  299,  300,   -1,   -1,   -1,  304,  684,  306,   -1,
   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  697,  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,
  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,  357,
  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  746,
   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,
  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,
  438,  439,   -1,   -1,   -1,   -1,   -1,  445,  602,   -1,
   -1,  449,  450,  451,  452,  453,  454,  455,  456,  457,
  458,  459,  460,  461,  462,  463,  464,  465,  466,  467,
  468,  469,  470,   -1,   -1,  473,  474,  475,  476,  477,
  478,  479,  480,  481,  482,  483,  484,  485,  486,  487,
  488,  489,  490,  491,  492,  493,  494,  495,  496,  497,
  498,  499,  500,  501,  502,  503,  504,  505,  506,  507,
  508,  509,  510,  511,  512,  513,  514,  515,  516,  517,
  518,  519,  520,  521,  522,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,  540,  541,  542,  543,  544,  545,  546,  547,
  548,  549,  550,  551,  552,  553,  554,  555,  556,  557,
  558,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,  573,  574,  575,  576,  577,
  578,  579,  580,  581,  582,  583,  584,  585,  586,  587,
  588,  589,  590,  591,  592,  593,  594,  595,  596,  597,
  598,  599,  600,  601,  602,  603,  604,  605,  606,  607,
  608,   -1,  610,  611,  612,  613,  614,  615,  616,  617,
  618,  619,  620,   -1,   -1,  623,  624,  625,  626,  627,
  628,  629,  630,  631,  632,  633,  634,  635,  636,  637,
  638,  639,  640,  641,  642,  643,  644,  645,  646,   -1,
  648,  649,  650,  651,  652,  653,  654,  655,  656,  657,
  658,  659,  660,  661,  662,  663,  664,  665,  666,  667,
  668,  669,  670,  671,  672,  673,  674,  675,  676,  677,
  678,  679,  680,  681,  682,  683,  684,  685,  686,  687,
  688,  689,  690,  691,  692,  693,  694,  695,  696,  697,
  698,  699,  700,  701,  702,  703,  704,  705,  706,  707,
  708,  709,  710,  711,  712,  713,  714,  715,  716,  717,
  718,  719,  720,  721,  722,   -1,   -1,   -1,   -1,  727,
  728,  729,  730,  731,  732,  733,  734,  735,  736,  737,
  738,  739,  740,  741,  742,  743,  744,  745,  746,  747,
  748,  749,  750,  751,  752,  753,  754,  755,  756,  757,
  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,
   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,
   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,
   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,
  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,
  377,  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,
   -1,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,
   -1,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,
   -1,   -1,  449,  450,  451,  452,  453,  454,   -1,  456,
  457,  458,  459,  460,  461,  462,  463,  464,  465,  466,
  467,  468,  469,  470,   -1,   -1,  473,  474,  475,  476,
  477,  478,  479,  480,  481,  482,  483,  484,  485,  486,
  487,  488,  489,  490,  491,  492,  493,  494,  495,  496,
  497,  498,  499,  500,  501,  502,  503,  504,  505,  506,
  507,  508,  509,  510,  511,  512,  513,  514,  515,  516,
  517,  518,  519,  520,  521,  522,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,  540,  541,  542,  543,  544,  545,  546,
  547,  548,  549,  550,  551,  552,  553,  554,  555,  556,
  557,  558,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,  573,  574,  575,  576,
  577,  578,  579,  580,  581,  582,  583,  584,  585,  586,
  587,  588,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,  602,  603,  604,  605,  606,
  607,  608,   -1,  610,  611,  612,  613,  614,  615,  616,
  617,  618,  619,  620,   -1,   -1,  623,  624,  625,  626,
  627,  628,  629,  630,  631,  632,  633,  634,  635,  636,
  637,  638,  639,  640,  641,  642,  643,  644,  645,  646,
   -1,  648,  649,  650,  651,  652,  653,  654,  655,  656,
  657,  658,  659,  660,  661,  662,  663,  664,  665,  666,
  667,  668,  669,  670,  671,  672,  673,  674,  675,  676,
  677,  678,  679,  680,  681,  682,  683,  684,  685,  686,
  687,  688,  689,  690,  691,  692,  693,  694,  695,  696,
  697,  698,  699,  700,  701,  702,  703,  704,  705,  706,
  707,  708,  709,  710,  711,  712,  713,  714,  715,  716,
  717,  718,  719,  720,  721,  722,   -1,   -1,   -1,   -1,
  727,  728,  729,  730,  731,  732,  733,  734,  735,  736,
  737,   -1,  739,  740,  741,  742,  743,  744,  745,  746,
  747,  748,  749,  750,  751,  752,  753,  754,  755,  756,
  757,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,
   -1,   -1,  268,  269,   -1,   -1,  272,   -1,   -1,  275,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,
   -1,  287,   -1,  289,  290,  291,   -1,  293,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,
  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,
  326,   -1,  328,   -1,   -1,  331,   -1,   -1,  334,   -1,
  336,  337,  338,  339,  340,  341,  342,  343,   -1,  345,
   -1,   -1,  348,   -1,   -1,  351,   -1,  353,   -1,   -1,
   -1,  357,  358,  359,   -1,  361,   -1,  363,   -1,   -1,
   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,
  376,  377,  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,  390,   -1,  392,  393,   -1,   -1,
   -1,   -1,   -1,  399,   -1,   -1,  402,  403,  404,  405,
  406,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,
   -1,   -1,  428,   -1,   -1,   -1,   -1,  433,   -1,   -1,
   -1,   -1,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,
   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,
  456,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  464,  465,
  466,  467,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,
  476,   -1,  478,  479,  480,   -1,   -1,  483,   -1,  485,
  486,   -1,  488,  489,   -1,  491,   -1,   -1,  494,  495,
   -1,   -1,   -1,  499,  500,   -1,   -1,   -1,   -1,  505,
  506,  507,   -1,  509,  510,  511,   -1,  513,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,  540,  541,  542,  543,   -1,  545,
  546,  547,  548,  549,  550,   -1,  552,  553,  554,  555,
   -1,  557,   -1,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,  573,  574,  575,
  576,   -1,  578,  579,  580,  581,   -1,  583,  584,  585,
  586,  587,   -1,  589,  590,  591,  592,  593,  594,  595,
  596,  597,  598,  599,  600,  601,   -1,  603,  604,  605,
  606,  607,  608,   -1,  610,  611,  612,  613,  614,  615,
  616,  617,   -1,  619,  620,   -1,   -1,  623,  624,  625,
  626,  627,  628,  629,   -1,   -1,  632,  633,  634,  635,
  636,  637,  638,  639,  640,   -1,  642,   -1,   -1,   -1,
  646,   -1,  648,  649,  650,  651,  652,  653,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,  674,  675,
  676,  677,  678,  679,  680,  681,  682,  683,  684,  685,
  686,  687,  688,  689,  690,  691,  692,  693,  694,  695,
  696,  697,  698,  699,  700,   -1,  702,   -1,   -1,   -1,
  706,  707,  708,  709,  710,  711,  712,  713,  714,  715,
  716,  717,  718,   -1,  720,  721,   -1,   -1,   -1,   -1,
   -1,  727,  728,  729,  730,  731,  732,  733,  734,  735,
  736,  737,  738,  739,  740,   -1,   -1,  743,  744,   -1,
  746,   -1,   -1,  749,  750,  751,  752,  753,  754,  755,
  756,  757,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,
  265,   -1,   -1,  268,  269,   -1,   -1,  272,   -1,   -1,
  275,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,  291,   -1,  293,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,
   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,  324,
   -1,  326,   -1,  328,   -1,   -1,  331,   -1,   -1,  334,
   -1,  336,  337,  338,  339,  340,  341,  342,  343,   -1,
  345,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,   -1,
   -1,   -1,  357,  358,  359,   -1,  361,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,
  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,  390,   -1,  392,  393,   -1,
   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,  403,  404,
  405,  406,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,
   -1,   -1,   -1,  428,   -1,   -1,   -1,   -1,  433,   -1,
   -1,   -1,   -1,  438,  439,   -1,   -1,   -1,   -1,   -1,
  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,
   -1,  456,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  464,
  465,  466,  467,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  475,  476,   -1,  478,  479,  480,   -1,   -1,  483,   -1,
  485,  486,   -1,  488,  489,   -1,  491,   -1,   -1,  494,
  495,   -1,   -1,   -1,  499,  500,   -1,   -1,   -1,   -1,
  505,  506,  507,   -1,  509,  510,  511,   -1,  513,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,  540,  541,  542,  543,   -1,
  545,  546,  547,  548,  549,  550,   -1,  552,  553,  554,
  555,   -1,  557,   -1,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,  573,  574,
  575,  576,   -1,  578,  579,  580,  581,   -1,  583,  584,
  585,  586,  587,   -1,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,   -1,  603,  604,
  605,  606,  607,  608,   -1,  610,  611,  612,  613,  614,
  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,
  625,  626,  627,  628,  629,   -1,   -1,  632,  633,  634,
  635,  636,  637,  638,  639,  640,   -1,  642,   -1,   -1,
   -1,  646,   -1,  648,  649,  650,  651,  652,  653,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,  674,
  675,  676,  677,  678,  679,  680,  681,  682,  683,  684,
  685,  686,  687,  688,  689,  690,  691,  692,  693,  694,
  695,  696,  697,  698,  699,  700,   -1,  702,   -1,   -1,
   -1,  706,  707,  708,  709,  710,  711,  712,  713,  714,
  715,  716,  717,  718,   -1,  720,  721,   -1,   -1,   -1,
   -1,   -1,  727,  728,  729,  730,  731,  732,  733,  734,
  735,  736,  737,  738,  739,  740,   -1,   -1,  743,  744,
   -1,  746,   -1,   -1,  749,  750,  751,  752,  753,  754,
  755,  756,  757,  257,   -1,  259,   -1,   -1,   -1,   -1,
   -1,  265,   -1,   -1,  268,  269,   -1,   -1,  272,   -1,
   -1,  275,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,  291,   -1,  293,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,
  304,   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,
  324,   -1,  326,   -1,  328,   -1,   -1,  331,   -1,   -1,
  334,   -1,  336,  337,  338,  339,  340,  341,  342,  343,
   -1,  345,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,
   -1,   -1,   -1,  357,  358,  359,   -1,  361,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,
  374,  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,  390,   -1,  392,  393,
   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,  403,
  404,  405,  406,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,
   -1,   -1,   -1,   -1,  428,   -1,   -1,   -1,   -1,  433,
   -1,   -1,   -1,   -1,  438,  439,   -1,   -1,   -1,   -1,
   -1,  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,
  454,   -1,  456,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  464,  465,  466,  467,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  475,  476,   -1,  478,  479,  480,   -1,   -1,  483,
   -1,  485,  486,   -1,  488,  489,   -1,  491,   -1,   -1,
  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,   -1,
   -1,  505,  506,  507,   -1,  509,  510,  511,   -1,  513,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,  540,  541,  542,  543,
   -1,  545,  546,  547,  548,  549,  550,   -1,  552,  553,
  554,  555,   -1,  557,   -1,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,  573,
  574,  575,  576,   -1,  578,  579,  580,  581,   -1,  583,
  584,  585,  586,  587,   -1,  589,  590,  591,  592,  593,
  594,  595,  596,  597,  598,  599,  600,  601,   -1,  603,
  604,  605,  606,  607,  608,   -1,  610,  611,  612,  613,
  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,
  624,  625,  626,  627,  628,  629,   -1,   -1,  632,  633,
  634,  635,  636,  637,  638,  639,  640,   -1,  642,   -1,
   -1,   -1,  646,   -1,  648,  649,  650,  651,  652,  653,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,
  674,  675,  676,  677,  678,  679,  680,  681,  682,  683,
  684,  685,  686,  687,  688,  689,  690,  691,  692,  693,
  694,  695,  696,  697,  698,  699,  700,   -1,  702,   -1,
   -1,   -1,  706,  707,  708,  709,  710,  711,  712,  713,
  714,  715,  716,  717,  718,   -1,  720,  721,   -1,   -1,
   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,  733,
  734,  735,  736,  737,  738,  739,  740,   -1,   -1,  743,
  744,   -1,  746,   -1,   -1,  749,  750,  751,  752,  753,
  754,  755,  756,  757,  257,   -1,  259,   -1,   -1,   -1,
   -1,   -1,  265,   -1,   -1,  268,  269,   -1,   -1,  272,
   -1,   -1,  275,   -1,   -1,   -1,  279,  280,   -1,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,  291,   -1,
  293,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,
   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,
   -1,  324,   -1,  326,   -1,  328,   -1,   -1,  331,   -1,
   -1,  334,   -1,  336,  337,  338,  339,  340,  341,  342,
  343,   -1,  345,   -1,   -1,  348,   -1,   -1,  351,   -1,
  353,   -1,   -1,   -1,  357,  358,  359,   -1,  361,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,
   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,  390,   -1,  392,
  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,
  403,  404,  405,  406,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,
   -1,   -1,   -1,   -1,   -1,  428,   -1,   -1,   -1,   -1,
  433,   -1,   -1,   -1,   -1,  438,  439,   -1,   -1,   -1,
   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,  451,  452,
  453,  454,   -1,  456,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  464,  465,  466,  467,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  475,  476,   -1,  478,  479,  480,   -1,   -1,
  483,   -1,  485,  486,   -1,  488,  489,   -1,  491,   -1,
   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,
   -1,   -1,  505,  506,  507,   -1,  509,  510,  511,   -1,
  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,  540,  541,  542,
  543,   -1,  545,  546,  547,  548,  549,  550,   -1,  552,
  553,  554,  555,   -1,  557,   -1,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
  573,  574,  575,  576,   -1,  578,  579,  580,  581,   -1,
  583,  584,  585,  586,  587,   -1,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,   -1,
  603,  604,  605,  606,  607,  608,   -1,  610,  611,  612,
  613,  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,
   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,  632,
  633,  634,  635,  636,  637,  638,  639,  640,   -1,  642,
   -1,   -1,   -1,  646,   -1,  648,  649,  650,  651,  652,
  653,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,
  673,  674,  675,  676,  677,  678,  679,  680,  681,  682,
  683,  684,  685,  686,  687,  688,  689,  690,  691,  692,
  693,  694,  695,  696,  697,  698,  699,  700,   -1,  702,
   -1,   -1,   -1,  706,  707,  708,  709,  710,  711,  712,
  713,  714,  715,  716,  717,  718,   -1,  720,  721,   -1,
   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,
  733,  734,  735,  736,  737,  738,  739,  740,   -1,   -1,
  743,  744,   -1,  746,   -1,   -1,  749,  750,  751,  752,
  753,  754,  755,  756,  757,  257,   -1,  259,   -1,   -1,
   -1,   -1,   -1,  265,   -1,   -1,  268,  269,   -1,   -1,
  272,   -1,   -1,  275,   -1,   -1,   -1,  279,  280,   -1,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,  291,
   -1,  293,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
   -1,   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,
   -1,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,  331,
   -1,   -1,  334,   -1,  336,  337,  338,  339,  340,  341,
  342,  343,   -1,  345,   -1,   -1,  348,   -1,   -1,  351,
   -1,  353,   -1,   -1,   -1,  357,  358,  359,   -1,  361,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,
   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,  390,   -1,
  392,  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,
  402,  403,  404,  405,  406,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,   -1,   -1,  420,   -1,
  422,   -1,   -1,   -1,   -1,   -1,  428,   -1,   -1,   -1,
   -1,  433,   -1,   -1,   -1,   -1,  438,  439,   -1,   -1,
   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,  451,
  452,  453,  454,   -1,  456,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  464,  465,  466,  467,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  475,  476,   -1,  478,  479,  480,   -1,
   -1,  483,   -1,  485,  486,   -1,  488,  489,   -1,  491,
   -1,   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,
   -1,   -1,   -1,  505,  506,  507,   -1,  509,  510,  511,
   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,  540,  541,
  542,  543,   -1,  545,  546,  547,  548,  549,  550,   -1,
  552,  553,  554,  555,   -1,  557,   -1,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,  573,  574,  575,  576,   -1,  578,  579,  580,  581,
   -1,  583,  584,  585,  586,  587,   -1,  589,  590,  591,
  592,  593,  594,  595,  596,  597,  598,  599,  600,  601,
   -1,  603,  604,  605,  606,  607,  608,   -1,  610,  611,
  612,  613,  614,  615,  616,  617,   -1,  619,  620,   -1,
   -1,   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,
  632,  633,  634,  635,  636,  637,  638,  639,  640,   -1,
  642,   -1,   -1,   -1,  646,   -1,  648,  649,  650,  651,
  652,  653,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  672,  673,  674,  675,  676,  677,  678,  679,  680,  681,
  682,  683,  684,  685,  686,  687,  688,  689,  690,  691,
  692,  693,  694,  695,  696,  697,  698,  699,  700,   -1,
  702,   -1,   -1,   -1,  706,  707,  708,  709,  710,  711,
  712,  713,  714,  715,  716,  717,  718,   -1,  720,  721,
   -1,   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,
  732,  733,  734,  735,  736,  737,  738,  739,  740,   -1,
   -1,  743,  744,   -1,  746,   -1,   -1,  749,  750,  751,
  752,  753,  754,  755,  756,  757,  257,   -1,  259,  260,
  261,   -1,   -1,   -1,  265,   -1,   -1,  268,  269,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,
   -1,  282,   -1,  284,   -1,  286,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,  295,  296,  297,   -1,  299,  300,
  301,   -1,   -1,  304,   -1,  306,  307,   -1,  309,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,
   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,  330,
   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,
  351,   -1,  353,   -1,   -1,   -1,  357,  358,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,
   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,
   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
  391,  392,  393,   -1,   -1,   -1,   -1,   -1,  399,  400,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,   -1,   -1,  420,
   -1,  422,   -1,   -1,  425,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,   -1,
   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,
  451,  452,  453,  454,   -1,  456,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  464,  465,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,  480,
   -1,   -1,   -1,   -1,  485,  486,   -1,  488,  489,   -1,
  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,  500,
   -1,   -1,   -1,   -1,  505,  506,  507,   -1,  509,  510,
  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,  540,
  541,  542,  543,   -1,  545,  546,  547,  548,  549,  550,
   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,  573,  574,  575,  576,   -1,  578,  579,  580,
  581,   -1,  583,  584,  585,  586,  587,   -1,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,   -1,  603,  604,  605,  606,  607,  608,   -1,  610,
  611,  612,  613,  614,  615,  616,  617,   -1,  619,  620,
   -1,   -1,   -1,  624,  625,  626,  627,  628,  629,   -1,
   -1,  632,  633,  634,  635,  636,  637,  638,  639,  640,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  648,  649,  650,
  651,  652,  653,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  672,  673,   -1,  675,  676,  677,  678,  679,  680,
  681,  682,  683,   -1,  685,  686,  687,  688,  689,  690,
  691,  692,  693,  694,  695,  696,   -1,  698,  699,  700,
   -1,  702,   -1,   -1,   -1,  706,  707,  708,  709,  710,
  711,  712,  713,  714,  715,  716,  717,  718,   -1,  720,
  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,  730,
  731,  732,  733,  734,  735,  736,  737,  738,  739,  740,
   -1,   -1,  743,  744,   -1,   -1,   -1,   -1,  749,  750,
  751,  752,  753,  754,  755,  756,  757,  257,   -1,  259,
   -1,  261,   -1,   -1,   -1,  265,   -1,   -1,  268,  269,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,   -1,  286,  287,   -1,   -1,
  290,   -1,   -1,   -1,   -1,  295,  296,  297,   -1,  299,
  300,  301,   -1,   -1,  304,   -1,  306,  307,   -1,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
  330,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,
   -1,  351,   -1,  353,   -1,   -1,   -1,  357,  358,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,  391,  392,  393,   -1,   -1,   -1,   -1,   -1,  399,
  400,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,  425,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,
   -1,  451,  452,  453,  454,   -1,  456,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  464,  465,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,
  480,   -1,   -1,   -1,   -1,  485,  486,   -1,  488,  489,
   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,
  500,   -1,   -1,   -1,   -1,  505,  506,  507,   -1,  509,
  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
  540,  541,  542,  543,   -1,  545,  546,  547,  548,  549,
  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,  573,  574,  575,  576,   -1,  578,  579,
  580,  581,   -1,  583,  584,  585,  586,  587,   -1,  589,
  590,  591,  592,  593,  594,  595,  596,  597,  598,  599,
  600,  601,   -1,  603,  604,  605,  606,  607,  608,   -1,
  610,  611,  612,  613,  614,  615,  616,  617,   -1,  619,
  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,  629,
   -1,   -1,  632,  633,  634,  635,  636,  637,  638,  639,
  640,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  648,  649,
  650,  651,  652,  653,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,  679,
  680,  681,  682,  683,   -1,  685,  686,  687,  688,  689,
  690,  691,  692,  693,  694,  695,  696,   -1,  698,  699,
  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,  709,
  710,  711,  712,  713,  714,  715,  716,  717,  718,   -1,
  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,
  730,  731,  732,  733,  734,  735,  736,  737,  738,  739,
  740,   -1,   -1,  743,  744,   -1,   -1,   -1,   -1,  749,
  750,  751,  752,  753,  754,  755,  756,  757,  257,   -1,
  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,
  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,
  309,   -1,   -1,   -1,   -1,   -1,   -1,  316,   -1,   -1,
  319,  320,   -1,  322,   -1,  324,   -1,  326,   -1,  328,
   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,  357,  358,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,
   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,  387,  388,
  389,   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,   -1,
   -1,  420,  421,  422,   -1,   -1,   -1,  426,   -1,   -1,
   -1,   -1,   -1,  432,  433,   -1,   -1,   -1,   -1,  438,
  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,
  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  464,  465,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,
  479,  480,   -1,   -1,   -1,   -1,  485,  486,   -1,  488,
  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,
  499,  500,   -1,   -1,   -1,   -1,  505,  506,  507,   -1,
  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,  540,  541,  542,  543,   -1,  545,  546,  547,  548,
  549,  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,  573,  574,  575,  576,   -1,  578,
  579,  580,  581,   -1,  583,  584,  585,  586,  587,   -1,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,   -1,  603,  604,  605,  606,  607,  608,
   -1,  610,  611,  612,  613,  614,  615,  616,  617,   -1,
  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,
  629,   -1,   -1,  632,  633,  634,  635,  636,  637,  638,
  639,  640,   -1,   -1,   -1,   -1,   -1,  646,   -1,  648,
  649,  650,  651,  652,  653,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,
  679,  680,  681,  682,  683,   -1,  685,  686,  687,  688,
  689,  690,  691,  692,  693,  694,  695,  696,   -1,  698,
  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,
  709,  710,  711,  712,  713,  714,  715,  716,  717,  718,
   -1,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,
  729,  730,  731,  732,  733,  734,  735,  736,  737,  738,
  739,  740,   -1,   -1,  743,  744,   -1,   -1,   -1,   -1,
  749,  750,  751,  752,  753,  754,  755,  756,  757,  257,
   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,
  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,
   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,
  328,  329,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,  357,
  358,   -1,  360,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  370,   -1,  372,   -1,  374,  375,  376,  377,
  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,
  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,
   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  464,  465,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,
  478,  479,  480,   -1,   -1,   -1,   -1,  485,  486,   -1,
  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,
   -1,  499,  500,   -1,   -1,   -1,   -1,  505,  506,  507,
   -1,  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,  540,  541,  542,  543,   -1,  545,  546,  547,
  548,  549,  550,   -1,  552,  553,  554,  555,   -1,  557,
   -1,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,  573,  574,  575,  576,   -1,
  578,  579,  580,  581,   -1,  583,  584,  585,  586,  587,
   -1,  589,  590,  591,  592,  593,  594,  595,  596,  597,
  598,  599,  600,  601,   -1,  603,  604,  605,  606,  607,
  608,   -1,  610,  611,  612,  613,  614,  615,  616,  617,
   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,
  628,  629,   -1,   -1,  632,  633,  634,  635,  636,  637,
  638,  639,  640,   -1,   -1,   -1,   -1,   -1,  646,   -1,
  648,  649,  650,  651,  652,  653,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,
  678,  679,  680,  681,  682,  683,   -1,  685,  686,  687,
  688,  689,  690,  691,  692,  693,  694,  695,  696,   -1,
  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,
  708,  709,  710,  711,  712,  713,  714,  715,  716,  717,
  718,   -1,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,
  728,  729,  730,  731,  732,  733,  734,  735,  736,  737,
  738,  739,  740,   -1,   -1,  743,  744,   -1,   -1,   -1,
   -1,  749,  750,  751,  752,  753,  754,  755,  756,  757,
  257,   -1,  259,   -1,   -1,   -1,  263,   -1,  265,   -1,
   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,
   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  319,  320,   -1,  322,   -1,  324,   -1,  326,
   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,
  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,
  377,  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,
   -1,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,  426,
   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,
   -1,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,
   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  464,  465,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,
   -1,  478,  479,  480,   -1,   -1,   -1,   -1,  485,  486,
   -1,  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,
   -1,   -1,  499,  500,   -1,   -1,   -1,   -1,  505,  506,
  507,   -1,  509,  510,  511,   -1,  513,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,  540,  541,  542,  543,   -1,  545,  546,
  547,  548,  549,  550,   -1,  552,  553,  554,  555,   -1,
  557,   -1,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,  573,  574,  575,  576,
   -1,  578,  579,  580,  581,   -1,  583,  584,  585,  586,
  587,   -1,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,   -1,  603,  604,  605,  606,
  607,  608,   -1,  610,  611,  612,  613,  614,  615,  616,
  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,
  627,  628,  629,   -1,   -1,  632,  633,  634,  635,  636,
  637,  638,  639,  640,   -1,   -1,   -1,   -1,   -1,  646,
   -1,  648,  649,  650,  651,  652,  653,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,
  677,  678,  679,  680,  681,  682,  683,   -1,  685,  686,
  687,  688,  689,  690,  691,  692,  693,  694,  695,  696,
   -1,  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,
  707,  708,  709,  710,  711,  712,  713,  714,  715,  716,
  717,  718,   -1,  720,  721,   -1,   -1,   -1,   -1,   -1,
  727,  728,  729,  730,  731,  732,  733,  734,  735,  736,
  737,  738,  739,  740,   -1,   -1,  743,  744,   -1,   -1,
   -1,   -1,  749,  750,  751,  752,  753,  754,  755,  756,
  757,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,
   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,  292,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,
  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,
  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,   -1,   -1,  351,   -1,  353,   -1,   -1,
   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,
  376,  377,  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,
   -1,   -1,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,
   -1,   -1,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,
   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,
  456,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  464,  465,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,
  476,   -1,  478,  479,  480,   -1,   -1,   -1,   -1,  485,
  486,   -1,  488,  489,   -1,  491,   -1,   -1,  494,  495,
   -1,   -1,   -1,  499,  500,   -1,   -1,   -1,   -1,  505,
  506,  507,   -1,  509,  510,  511,   -1,  513,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,  540,  541,  542,  543,   -1,  545,
  546,  547,  548,  549,  550,   -1,  552,  553,  554,  555,
   -1,  557,   -1,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,  573,  574,  575,
  576,   -1,  578,  579,  580,  581,   -1,  583,  584,  585,
  586,  587,   -1,  589,  590,  591,  592,  593,  594,  595,
  596,  597,  598,  599,  600,  601,   -1,  603,  604,  605,
  606,  607,  608,   -1,  610,  611,  612,  613,  614,  615,
  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,
  626,  627,  628,  629,   -1,   -1,  632,  633,  634,  635,
  636,  637,  638,  639,  640,   -1,   -1,   -1,   -1,   -1,
  646,  647,  648,  649,  650,  651,  652,  653,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,
  676,  677,  678,  679,  680,  681,  682,  683,   -1,  685,
  686,  687,  688,  689,  690,  691,  692,  693,  694,  695,
  696,   -1,  698,  699,  700,   -1,  702,   -1,   -1,   -1,
  706,  707,  708,  709,  710,  711,  712,  713,  714,  715,
  716,  717,  718,   -1,  720,  721,   -1,   -1,   -1,   -1,
   -1,  727,  728,  729,  730,  731,  732,  733,  734,  735,
  736,  737,  738,  739,  740,   -1,   -1,  743,  744,   -1,
   -1,   -1,   -1,  749,  750,  751,  752,  753,  754,  755,
  756,  757,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,
  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,
   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,  324,
   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,
   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,   -1,
   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,
  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,
   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,
   -1,   -1,   -1,  438,  439,   -1,   -1,   -1,   -1,   -1,
  445,   -1,  447,  448,  449,   -1,  451,  452,  453,  454,
   -1,  456,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  464,
  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  475,  476,   -1,  478,  479,  480,   -1,   -1,   -1,   -1,
  485,  486,   -1,  488,  489,   -1,  491,   -1,   -1,  494,
  495,   -1,   -1,   -1,  499,  500,   -1,   -1,   -1,   -1,
  505,  506,  507,   -1,  509,  510,  511,   -1,  513,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,  540,  541,  542,  543,   -1,
  545,  546,  547,  548,  549,  550,   -1,  552,  553,  554,
  555,   -1,  557,   -1,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,  573,  574,
  575,  576,   -1,  578,  579,  580,  581,   -1,  583,  584,
  585,  586,  587,   -1,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,   -1,  603,  604,
  605,  606,  607,  608,   -1,  610,  611,  612,  613,  614,
  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,
  625,  626,  627,  628,  629,   -1,   -1,  632,  633,  634,
  635,  636,  637,  638,  639,  640,   -1,   -1,   -1,   -1,
   -1,  646,   -1,  648,  649,  650,  651,  652,  653,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,
  675,  676,  677,  678,  679,  680,  681,  682,  683,   -1,
  685,  686,  687,  688,  689,  690,  691,  692,  693,  694,
  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,   -1,
   -1,  706,  707,  708,  709,  710,  711,  712,  713,  714,
  715,  716,  717,  718,   -1,  720,  721,   -1,   -1,   -1,
   -1,   -1,  727,  728,  729,  730,  731,  732,  733,  734,
  735,  736,  737,  738,  739,  740,   -1,   -1,  743,  744,
   -1,   -1,   -1,   -1,  749,  750,  751,  752,  753,  754,
  755,  756,  757,  257,   -1,  259,   -1,   -1,   -1,   -1,
   -1,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,
  304,   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,
  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,
  334,  335,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,
   -1,  355,   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,
  374,  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
   -1,   -1,   -1,   -1,  438,  439,   -1,   -1,   -1,   -1,
   -1,  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,
  454,   -1,  456,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  475,  476,   -1,  478,  479,  480,   -1,   -1,   -1,
   -1,  485,  486,   -1,  488,  489,   -1,  491,   -1,   -1,
  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,   -1,
   -1,  505,  506,  507,   -1,  509,  510,  511,   -1,  513,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,  540,  541,  542,  543,
   -1,  545,  546,  547,  548,  549,  550,   -1,  552,  553,
  554,  555,   -1,  557,   -1,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,  573,
  574,  575,  576,   -1,  578,  579,  580,  581,   -1,  583,
  584,  585,  586,  587,   -1,  589,  590,  591,  592,  593,
  594,  595,  596,  597,  598,  599,  600,  601,   -1,  603,
  604,  605,  606,  607,  608,   -1,  610,  611,  612,  613,
  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,
  624,  625,  626,  627,  628,  629,   -1,   -1,  632,  633,
  634,  635,  636,  637,  638,  639,  640,   -1,   -1,   -1,
   -1,   -1,  646,   -1,  648,  649,  650,  651,  652,  653,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,
   -1,  675,  676,  677,  678,  679,  680,  681,  682,  683,
   -1,  685,  686,  687,  688,  689,  690,  691,  692,  693,
  694,  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,
   -1,   -1,  706,  707,  708,  709,  710,  711,  712,  713,
  714,  715,  716,  717,  718,   -1,  720,  721,   -1,   -1,
   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,  733,
  734,  735,  736,  737,  738,  739,  740,   -1,   -1,  743,
  744,   -1,   -1,   -1,   -1,  749,  750,  751,  752,  753,
  754,  755,  756,  757,  257,   -1,  259,   -1,   -1,   -1,
   -1,   -1,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,
   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,  322,
   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,
   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,
  353,   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,
   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,
   -1,   -1,   -1,  426,   -1,   -1,   -1,   -1,   -1,   -1,
  433,   -1,   -1,   -1,   -1,  438,  439,   -1,   -1,   -1,
   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,  451,  452,
  453,  454,   -1,  456,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  475,  476,   -1,  478,  479,  480,   -1,   -1,
   -1,   -1,  485,  486,   -1,  488,  489,   -1,  491,   -1,
   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,
   -1,   -1,  505,  506,  507,   -1,  509,  510,  511,   -1,
  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,  540,  541,  542,
  543,   -1,  545,  546,  547,  548,  549,  550,   -1,  552,
  553,  554,  555,   -1,  557,   -1,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
  573,  574,  575,  576,   -1,  578,  579,  580,  581,   -1,
  583,  584,  585,  586,  587,   -1,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,   -1,
  603,  604,  605,  606,  607,  608,   -1,  610,  611,  612,
  613,  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,
   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,  632,
  633,  634,  635,  636,  637,  638,  639,  640,   -1,   -1,
   -1,   -1,   -1,  646,   -1,  648,  649,  650,  651,  652,
  653,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,
  673,   -1,  675,  676,  677,  678,  679,  680,  681,  682,
  683,   -1,  685,  686,  687,  688,  689,  690,  691,  692,
  693,  694,  695,  696,   -1,  698,  699,  700,   -1,  702,
   -1,   -1,   -1,  706,  707,  708,  709,  710,  711,  712,
  713,  714,  715,  716,  717,  718,   -1,  720,  721,   -1,
   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,
  733,  734,  735,  736,  737,  738,  739,  740,   -1,   -1,
  743,  744,   -1,   -1,   -1,   -1,  749,  750,  751,  752,
  753,  754,  755,  756,  757,  257,   -1,  259,   -1,   -1,
   -1,   -1,   -1,  265,   -1,   -1,  268,  269,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
   -1,   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,
   -1,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,
   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,
   -1,  353,   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,  371,
   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,   -1,   -1,  420,   -1,
  422,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,   -1,   -1,   -1,   -1,  438,  439,   -1,   -1,
   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,  451,
  452,  453,  454,   -1,  456,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  475,  476,   -1,  478,  479,  480,   -1,
   -1,   -1,   -1,  485,  486,   -1,  488,  489,   -1,  491,
   -1,   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,
   -1,   -1,   -1,  505,  506,  507,   -1,  509,  510,  511,
   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,  540,  541,
  542,  543,   -1,  545,  546,  547,  548,  549,  550,   -1,
  552,  553,  554,  555,   -1,  557,   -1,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,  573,  574,  575,  576,   -1,  578,  579,  580,  581,
   -1,  583,  584,  585,  586,  587,   -1,  589,  590,  591,
  592,  593,  594,  595,  596,  597,  598,  599,  600,  601,
   -1,  603,  604,  605,  606,  607,  608,   -1,  610,  611,
  612,  613,  614,  615,  616,  617,   -1,  619,  620,   -1,
   -1,   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,
  632,  633,  634,  635,  636,  637,  638,  639,  640,   -1,
   -1,   -1,   -1,   -1,  646,   -1,  648,  649,  650,  651,
  652,  653,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  672,  673,   -1,  675,  676,  677,  678,  679,  680,  681,
  682,  683,   -1,  685,  686,  687,  688,  689,  690,  691,
  692,  693,  694,  695,  696,   -1,  698,  699,  700,   -1,
  702,   -1,   -1,   -1,  706,  707,  708,  709,  710,  711,
  712,  713,  714,  715,  716,  717,  718,   -1,  720,  721,
   -1,   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,
  732,  733,  734,  735,  736,  737,  738,  739,  740,   -1,
   -1,  743,  744,   -1,   -1,   -1,   -1,  749,  750,  751,
  752,  753,  754,  755,  756,  757,  257,   -1,  259,   -1,
   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,  269,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,
   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,  309,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,
   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,
   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,
  351,   -1,  353,   -1,   -1,   -1,  357,  358,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,
   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,
   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,   -1,   -1,  420,
   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,   -1,
   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,
  451,  452,  453,  454,   -1,  456,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  464,  465,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,  480,
   -1,   -1,   -1,   -1,  485,  486,   -1,  488,  489,   -1,
  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,  500,
   -1,   -1,   -1,   -1,  505,  506,  507,   -1,  509,  510,
  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,  540,
  541,  542,  543,   -1,  545,  546,  547,  548,  549,  550,
   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,  573,  574,  575,  576,  577,  578,  579,  580,
  581,   -1,  583,  584,  585,  586,  587,   -1,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,   -1,  603,  604,  605,  606,  607,  608,   -1,  610,
  611,  612,  613,  614,  615,  616,  617,   -1,  619,  620,
   -1,   -1,   -1,  624,  625,  626,  627,  628,  629,   -1,
   -1,  632,  633,  634,  635,  636,  637,  638,  639,  640,
   -1,   -1,   -1,   -1,   -1,  646,   -1,  648,  649,  650,
  651,  652,  653,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  672,  673,   -1,  675,  676,  677,  678,  679,  680,
  681,  682,  683,   -1,  685,  686,  687,  688,  689,  690,
  691,  692,  693,  694,  695,  696,   -1,  698,  699,  700,
   -1,  702,   -1,   -1,   -1,  706,  707,  708,  709,  710,
  711,  712,  713,  714,  715,  716,  717,  718,   -1,  720,
  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,  730,
  731,  732,  733,  734,  735,  736,  737,  738,  739,  740,
   -1,   -1,  743,  744,   -1,   -1,   -1,   -1,  749,  750,
  751,  752,  753,  754,  755,  756,  757,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,  269,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,
   -1,  351,   -1,  353,   -1,   -1,   -1,  357,  358,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,
   -1,  451,  452,  453,  454,   -1,  456,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  464,  465,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,
  480,   -1,   -1,   -1,   -1,  485,  486,   -1,  488,  489,
   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,
  500,   -1,   -1,   -1,   -1,  505,  506,  507,   -1,  509,
  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
  540,  541,  542,  543,   -1,  545,  546,  547,  548,  549,
  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,  573,  574,  575,  576,   -1,  578,  579,
  580,  581,   -1,  583,  584,  585,  586,  587,   -1,  589,
  590,  591,  592,  593,  594,  595,  596,  597,  598,  599,
  600,  601,   -1,  603,  604,  605,  606,  607,  608,   -1,
  610,  611,  612,  613,  614,  615,  616,  617,   -1,  619,
  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,  629,
   -1,   -1,  632,  633,  634,  635,  636,  637,  638,  639,
  640,   -1,   -1,   -1,   -1,   -1,  646,   -1,  648,  649,
  650,  651,  652,  653,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  672,  673,  674,  675,  676,  677,  678,  679,
  680,  681,  682,  683,   -1,  685,  686,  687,  688,  689,
  690,  691,  692,  693,  694,  695,  696,   -1,  698,  699,
  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,  709,
  710,  711,  712,  713,  714,  715,  716,  717,  718,   -1,
  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,
  730,  731,  732,  733,  734,  735,  736,  737,  738,  739,
  740,   -1,   -1,  743,  744,   -1,   -1,   -1,   -1,  749,
  750,  751,  752,  753,  754,  755,  756,  757,  257,   -1,
  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,
  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,  295,   -1,  297,   -1,
  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,
  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,
   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,  357,  358,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,
   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,   -1,
   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,
  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,
  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  464,  465,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,
  479,  480,   -1,   -1,   -1,   -1,  485,  486,   -1,  488,
  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,
  499,  500,   -1,   -1,   -1,   -1,  505,  506,  507,   -1,
  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,  540,  541,  542,  543,   -1,  545,  546,  547,  548,
  549,  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,  573,  574,  575,  576,   -1,  578,
  579,  580,  581,   -1,  583,  584,  585,  586,  587,   -1,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,   -1,  603,  604,  605,  606,  607,  608,
   -1,  610,  611,  612,  613,  614,  615,  616,  617,   -1,
  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,
  629,   -1,   -1,  632,  633,  634,  635,  636,  637,  638,
  639,  640,   -1,   -1,   -1,   -1,   -1,  646,   -1,  648,
  649,  650,  651,  652,  653,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,
  679,  680,  681,  682,  683,   -1,  685,  686,  687,  688,
  689,  690,  691,  692,  693,  694,  695,  696,   -1,  698,
  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,
  709,  710,  711,  712,  713,  714,  715,  716,  717,  718,
   -1,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,
  729,  730,  731,  732,  733,  734,  735,  736,  737,  738,
  739,  740,   -1,   -1,  743,  744,   -1,   -1,   -1,   -1,
  749,  750,  751,  752,  753,  754,  755,  756,  757,  257,
   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,
  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  279,  280,   -1,  282,  283,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,
   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,
  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,  357,
  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,
  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,
  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,
   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  464,  465,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,
  478,  479,  480,   -1,   -1,   -1,   -1,  485,  486,   -1,
  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,
   -1,  499,  500,   -1,   -1,   -1,   -1,  505,  506,  507,
   -1,  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,  540,  541,  542,  543,   -1,  545,  546,  547,
  548,  549,  550,   -1,  552,  553,  554,  555,   -1,  557,
   -1,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,  573,  574,  575,  576,   -1,
  578,  579,  580,  581,   -1,  583,  584,  585,  586,  587,
   -1,  589,  590,  591,  592,  593,  594,  595,  596,  597,
  598,  599,  600,  601,   -1,  603,  604,  605,  606,  607,
  608,   -1,  610,  611,  612,  613,  614,  615,  616,  617,
   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,
  628,  629,   -1,   -1,  632,  633,  634,  635,  636,  637,
  638,  639,  640,   -1,   -1,   -1,   -1,   -1,  646,   -1,
  648,  649,  650,  651,  652,  653,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,
  678,  679,  680,  681,  682,  683,   -1,  685,  686,  687,
  688,  689,  690,  691,  692,  693,  694,  695,  696,   -1,
  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,
  708,  709,  710,  711,  712,  713,  714,  715,  716,  717,
  718,   -1,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,
  728,  729,  730,  731,  732,  733,  734,  735,  736,  737,
  738,  739,  740,   -1,   -1,  743,  744,   -1,   -1,   -1,
   -1,  749,  750,  751,  752,  753,  754,  755,  756,  757,
  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,
   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  279,  280,   -1,  282,  283,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,
   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,
   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,
  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,
  377,  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,
   -1,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,
   -1,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,
   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  464,  465,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,
   -1,  478,  479,  480,   -1,   -1,   -1,   -1,  485,  486,
   -1,  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,
   -1,   -1,  499,  500,   -1,   -1,   -1,   -1,  505,  506,
  507,   -1,  509,  510,  511,   -1,  513,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,  540,  541,  542,  543,   -1,  545,  546,
  547,  548,  549,  550,   -1,  552,  553,  554,  555,   -1,
  557,   -1,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,  573,  574,  575,  576,
   -1,  578,  579,  580,  581,   -1,  583,  584,  585,  586,
  587,   -1,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,   -1,  603,  604,  605,  606,
  607,  608,   -1,  610,  611,  612,  613,  614,  615,  616,
  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,
  627,  628,  629,   -1,   -1,  632,  633,  634,  635,  636,
  637,  638,  639,  640,   -1,   -1,   -1,   -1,   -1,  646,
   -1,  648,  649,  650,  651,  652,  653,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,
  677,  678,  679,  680,  681,  682,  683,   -1,  685,  686,
  687,  688,  689,  690,  691,  692,  693,  694,  695,  696,
   -1,  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,
  707,  708,  709,  710,  711,  712,  713,  714,  715,  716,
  717,  718,   -1,  720,  721,   -1,   -1,   -1,   -1,   -1,
  727,  728,  729,  730,  731,  732,  733,  734,  735,  736,
  737,  738,  739,  740,   -1,   -1,  743,  744,   -1,   -1,
   -1,   -1,  749,  750,  751,  752,  753,  754,  755,  756,
  757,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,
   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,
  306,   -1,   -1,  309,  310,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,
  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,   -1,   -1,  351,   -1,  353,   -1,   -1,
   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,
  376,  377,  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,
   -1,   -1,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,
   -1,   -1,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,
   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,
  456,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  464,  465,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,
  476,   -1,  478,  479,  480,   -1,   -1,   -1,   -1,  485,
  486,   -1,  488,  489,   -1,  491,   -1,   -1,  494,  495,
   -1,   -1,   -1,  499,  500,   -1,   -1,   -1,   -1,  505,
  506,  507,   -1,  509,  510,  511,   -1,  513,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,  540,  541,  542,  543,   -1,  545,
  546,  547,  548,  549,  550,   -1,  552,  553,  554,  555,
   -1,  557,   -1,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,  573,  574,  575,
  576,   -1,  578,  579,  580,  581,   -1,  583,  584,  585,
  586,  587,   -1,  589,  590,  591,  592,  593,  594,  595,
  596,  597,  598,  599,  600,  601,   -1,  603,  604,  605,
  606,  607,  608,   -1,  610,  611,  612,  613,  614,  615,
  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,
  626,  627,  628,  629,   -1,   -1,  632,  633,  634,  635,
  636,  637,  638,  639,  640,   -1,   -1,   -1,   -1,   -1,
  646,   -1,  648,  649,  650,  651,  652,  653,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,
  676,  677,  678,  679,  680,  681,  682,  683,   -1,  685,
  686,  687,  688,  689,  690,  691,  692,  693,  694,  695,
  696,   -1,  698,  699,  700,   -1,  702,   -1,   -1,   -1,
  706,  707,  708,  709,  710,  711,  712,  713,  714,  715,
  716,  717,  718,   -1,  720,  721,   -1,   -1,   -1,   -1,
   -1,  727,  728,  729,  730,  731,  732,  733,  734,  735,
  736,  737,  738,  739,  740,   -1,   -1,  743,  744,   -1,
   -1,   -1,   -1,  749,  750,  751,  752,  753,  754,  755,
  756,  757,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,
  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,
   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,  324,
   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,
   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,   -1,
   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,
  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,
   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,
   -1,  426,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,
   -1,   -1,   -1,  438,  439,   -1,   -1,   -1,   -1,   -1,
  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,
   -1,  456,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  464,
  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  475,  476,   -1,  478,  479,  480,   -1,   -1,   -1,   -1,
  485,  486,   -1,  488,  489,   -1,  491,   -1,   -1,  494,
  495,   -1,   -1,   -1,  499,  500,   -1,   -1,   -1,   -1,
  505,  506,  507,   -1,  509,  510,  511,   -1,  513,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,  540,  541,  542,  543,   -1,
  545,  546,  547,  548,  549,  550,   -1,  552,  553,  554,
  555,   -1,  557,   -1,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,  573,  574,
  575,  576,   -1,  578,  579,  580,  581,   -1,  583,  584,
  585,  586,  587,   -1,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,   -1,  603,  604,
  605,  606,  607,  608,   -1,  610,  611,  612,  613,  614,
  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,
  625,  626,  627,  628,  629,   -1,   -1,  632,  633,  634,
  635,  636,  637,  638,  639,  640,   -1,   -1,   -1,   -1,
   -1,  646,   -1,  648,  649,  650,  651,  652,  653,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,
  675,  676,  677,  678,  679,  680,  681,  682,  683,   -1,
  685,  686,  687,  688,  689,  690,  691,  692,  693,  694,
  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,   -1,
   -1,  706,  707,  708,  709,  710,  711,  712,  713,  714,
  715,  716,  717,  718,   -1,  720,  721,   -1,   -1,   -1,
   -1,   -1,  727,  728,  729,  730,  731,  732,  733,  734,
  735,  736,  737,  738,  739,  740,   -1,   -1,  743,  744,
   -1,   -1,   -1,   -1,  749,  750,  751,  752,  753,  754,
  755,  756,  757,  257,   -1,  259,   -1,   -1,   -1,   -1,
   -1,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,
  304,   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,
  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,
  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,
   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,
  374,  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
   -1,   -1,   -1,   -1,  438,  439,   -1,   -1,   -1,   -1,
   -1,  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,
  454,  455,  456,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  475,  476,   -1,  478,  479,  480,   -1,   -1,   -1,
   -1,  485,  486,   -1,  488,  489,   -1,  491,   -1,   -1,
  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,   -1,
   -1,  505,  506,  507,   -1,  509,  510,  511,   -1,  513,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,  540,  541,  542,  543,
   -1,  545,  546,  547,  548,  549,  550,   -1,  552,  553,
  554,  555,   -1,  557,   -1,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,  573,
  574,  575,  576,   -1,  578,  579,  580,  581,   -1,  583,
  584,  585,  586,  587,   -1,  589,  590,  591,  592,  593,
  594,  595,  596,  597,  598,  599,  600,  601,   -1,  603,
  604,  605,  606,  607,  608,   -1,  610,  611,  612,  613,
  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,
  624,  625,  626,  627,  628,  629,   -1,   -1,  632,  633,
  634,  635,  636,  637,  638,  639,  640,   -1,   -1,   -1,
   -1,   -1,  646,   -1,  648,  649,  650,  651,  652,  653,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,
   -1,  675,  676,  677,  678,  679,  680,  681,  682,  683,
   -1,  685,  686,  687,  688,  689,  690,  691,  692,  693,
  694,  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,
   -1,   -1,  706,  707,  708,  709,  710,  711,  712,  713,
  714,  715,  716,  717,  718,   -1,  720,  721,   -1,   -1,
   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,  733,
  734,  735,  736,  737,  738,  739,  740,   -1,   -1,  743,
  744,   -1,   -1,   -1,   -1,  749,  750,  751,  752,  753,
  754,  755,  756,  757,  257,   -1,  259,   -1,   -1,   -1,
   -1,   -1,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,
   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,
   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,
   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,
  353,   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,
   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,   -1,   -1,   -1,   -1,  438,  439,   -1,   -1,   -1,
   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,  451,  452,
  453,  454,  455,  456,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  475,  476,   -1,  478,  479,  480,   -1,   -1,
   -1,   -1,  485,  486,   -1,  488,  489,   -1,  491,   -1,
   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,
   -1,   -1,  505,  506,  507,   -1,  509,  510,  511,   -1,
  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,  540,  541,  542,
  543,   -1,  545,  546,  547,  548,  549,  550,   -1,  552,
  553,  554,  555,   -1,  557,   -1,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
  573,  574,  575,  576,   -1,  578,  579,  580,  581,   -1,
  583,  584,  585,  586,  587,   -1,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,   -1,
  603,  604,  605,  606,  607,  608,   -1,  610,  611,  612,
  613,  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,
   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,  632,
  633,  634,  635,  636,  637,  638,  639,  640,   -1,   -1,
   -1,   -1,   -1,  646,   -1,  648,  649,  650,  651,  652,
  653,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,
  673,   -1,  675,  676,  677,  678,  679,  680,  681,  682,
  683,   -1,  685,  686,  687,  688,  689,  690,  691,  692,
  693,  694,  695,  696,   -1,  698,  699,  700,   -1,  702,
   -1,   -1,   -1,  706,  707,  708,  709,  710,  711,  712,
  713,  714,  715,  716,  717,  718,   -1,  720,  721,   -1,
   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,
  733,  734,  735,  736,  737,  738,  739,  740,   -1,   -1,
  743,  744,   -1,   -1,   -1,   -1,  749,  750,  751,  752,
  753,  754,  755,  756,  757,  257,   -1,  259,   -1,   -1,
   -1,   -1,   -1,  265,   -1,   -1,  268,  269,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
   -1,   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,
   -1,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,
   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,
   -1,  353,   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,
   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,   -1,   -1,  420,   -1,
  422,   -1,   -1,   -1,  426,   -1,   -1,   -1,   -1,   -1,
   -1,  433,   -1,   -1,   -1,   -1,  438,  439,   -1,   -1,
   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,  451,
  452,  453,  454,   -1,  456,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  475,  476,   -1,  478,  479,  480,   -1,
   -1,   -1,   -1,  485,  486,   -1,  488,  489,   -1,  491,
   -1,   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,
   -1,   -1,   -1,  505,  506,  507,   -1,  509,  510,  511,
   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,  540,  541,
  542,  543,   -1,  545,  546,  547,  548,  549,  550,   -1,
  552,  553,  554,  555,   -1,  557,   -1,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,  573,  574,  575,  576,   -1,  578,  579,  580,  581,
   -1,  583,  584,  585,  586,  587,   -1,  589,  590,  591,
  592,  593,  594,  595,  596,  597,  598,  599,  600,  601,
   -1,  603,  604,  605,  606,  607,  608,   -1,  610,  611,
  612,  613,  614,  615,  616,  617,   -1,  619,  620,   -1,
   -1,   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,
  632,  633,  634,  635,  636,  637,  638,  639,  640,   -1,
   -1,   -1,   -1,   -1,  646,   -1,  648,  649,  650,  651,
  652,  653,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  672,  673,   -1,  675,  676,  677,  678,  679,  680,  681,
  682,  683,   -1,  685,  686,  687,  688,  689,  690,  691,
  692,  693,  694,  695,  696,   -1,  698,  699,  700,   -1,
  702,   -1,   -1,   -1,  706,  707,  708,  709,  710,  711,
  712,  713,  714,  715,  716,  717,  718,   -1,  720,  721,
   -1,   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,
  732,  733,  734,  735,  736,  737,  738,  739,  740,   -1,
   -1,  743,  744,   -1,   -1,   -1,   -1,  749,  750,  751,
  752,  753,  754,  755,  756,  757,  257,   -1,  259,   -1,
   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,  269,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,
   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
  301,   -1,   -1,  304,   -1,  306,   -1,   -1,  309,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,
   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,
   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,
  351,   -1,  353,   -1,   -1,   -1,  357,  358,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,
   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,
   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,   -1,   -1,  420,
   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,   -1,
   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,
  451,  452,  453,  454,   -1,  456,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  464,  465,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,  480,
   -1,   -1,   -1,   -1,  485,  486,   -1,  488,  489,   -1,
  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,  500,
   -1,   -1,   -1,   -1,  505,  506,  507,   -1,  509,  510,
  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,  540,
  541,  542,  543,   -1,  545,  546,  547,  548,  549,  550,
   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,  573,  574,  575,  576,   -1,  578,  579,  580,
  581,   -1,  583,  584,  585,  586,  587,   -1,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,   -1,  603,  604,  605,  606,  607,  608,   -1,  610,
  611,  612,  613,  614,  615,  616,  617,   -1,  619,  620,
   -1,   -1,   -1,  624,  625,  626,  627,  628,  629,   -1,
   -1,  632,  633,  634,  635,  636,  637,  638,  639,  640,
   -1,   -1,   -1,   -1,   -1,  646,   -1,  648,  649,  650,
  651,  652,  653,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  672,  673,   -1,  675,  676,  677,  678,  679,  680,
  681,  682,  683,   -1,  685,  686,  687,  688,  689,  690,
  691,  692,  693,  694,  695,  696,   -1,  698,  699,  700,
   -1,  702,   -1,   -1,   -1,  706,  707,  708,  709,  710,
  711,  712,  713,  714,  715,  716,  717,  718,   -1,  720,
  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,  730,
  731,  732,  733,  734,  735,  736,  737,  738,  739,  740,
   -1,   -1,  743,  744,   -1,   -1,   -1,   -1,  749,  750,
  751,  752,  753,  754,  755,  756,  757,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,  269,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,
   -1,  351,   -1,  353,   -1,   -1,   -1,  357,  358,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,
   -1,  451,  452,  453,  454,   -1,  456,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  464,  465,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,
  480,   -1,   -1,   -1,   -1,  485,  486,   -1,  488,  489,
   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,
  500,   -1,   -1,   -1,   -1,  505,  506,  507,   -1,  509,
  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
  540,  541,  542,  543,   -1,  545,  546,  547,  548,  549,
  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,  573,  574,  575,  576,   -1,  578,  579,
  580,  581,   -1,  583,  584,  585,  586,  587,   -1,  589,
  590,  591,  592,  593,  594,  595,  596,  597,  598,  599,
  600,  601,   -1,  603,  604,  605,  606,  607,  608,   -1,
  610,  611,  612,  613,  614,  615,  616,  617,   -1,  619,
  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,  629,
   -1,   -1,  632,  633,  634,  635,  636,  637,  638,  639,
  640,   -1,   -1,   -1,   -1,   -1,  646,   -1,  648,  649,
  650,  651,  652,  653,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,  679,
  680,  681,  682,  683,   -1,  685,  686,  687,  688,  689,
  690,  691,  692,  693,  694,  695,  696,   -1,  698,  699,
  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,  709,
  710,  711,  712,  713,  714,  715,  716,  717,  718,   -1,
  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,
  730,  731,  732,  733,  734,  735,  736,  737,  738,  739,
  740,   -1,   -1,  743,  744,   -1,   -1,   -1,   -1,  749,
  750,  751,  752,  753,  754,  755,  756,  757,  257,   -1,
  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,
  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,
  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,
   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,  357,  358,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,
   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,   -1,
   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,
  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,
  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  464,  465,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,
  479,  480,   -1,   -1,   -1,   -1,  485,  486,   -1,  488,
  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,
  499,  500,   -1,   -1,   -1,   -1,  505,  506,  507,   -1,
  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,  540,  541,  542,  543,   -1,  545,  546,  547,  548,
  549,  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,  573,  574,  575,  576,   -1,  578,
  579,  580,  581,   -1,  583,  584,  585,  586,  587,   -1,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,   -1,  603,  604,  605,  606,  607,  608,
   -1,  610,  611,  612,  613,  614,  615,  616,  617,   -1,
  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,
  629,   -1,   -1,  632,  633,  634,  635,  636,  637,  638,
  639,  640,   -1,   -1,   -1,   -1,   -1,  646,   -1,  648,
  649,  650,  651,  652,  653,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,
  679,  680,  681,  682,  683,   -1,  685,  686,  687,  688,
  689,  690,  691,  692,  693,  694,  695,  696,   -1,  698,
  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,
  709,  710,  711,  712,  713,  714,  715,  716,  717,  718,
   -1,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,
  729,  730,  731,  732,  733,  734,  735,  736,  737,  738,
  739,  740,   -1,   -1,  743,  744,   -1,   -1,   -1,   -1,
  749,  750,  751,  752,  753,  754,  755,  756,  757,  257,
   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,
  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,
   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,
  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,  357,
  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,
  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,
  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,
   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  464,  465,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,
  478,  479,  480,   -1,   -1,   -1,   -1,  485,  486,   -1,
  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,
   -1,  499,  500,   -1,   -1,   -1,   -1,  505,  506,  507,
   -1,  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,  540,  541,  542,  543,   -1,  545,  546,  547,
  548,  549,  550,   -1,  552,  553,  554,  555,   -1,  557,
   -1,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,  573,  574,  575,  576,   -1,
  578,  579,  580,  581,   -1,  583,  584,  585,  586,  587,
   -1,  589,  590,  591,  592,  593,  594,  595,  596,  597,
  598,  599,  600,  601,   -1,  603,  604,  605,  606,  607,
  608,   -1,  610,  611,  612,  613,  614,  615,  616,  617,
   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,
  628,  629,   -1,   -1,  632,  633,  634,  635,  636,  637,
  638,  639,  640,   -1,   -1,   -1,   -1,   -1,  646,   -1,
  648,  649,  650,  651,  652,  653,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,
  678,  679,  680,  681,  682,  683,   -1,  685,  686,  687,
  688,  689,  690,  691,  692,  693,  694,  695,  696,   -1,
  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,
  708,  709,  710,  711,  712,  713,  714,  715,  716,  717,
  718,   -1,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,
  728,  729,  730,  731,  732,  733,  734,  735,  736,  737,
  738,  739,  740,   -1,   -1,  743,  744,   -1,   -1,   -1,
   -1,  749,  750,  751,  752,  753,  754,  755,  756,  757,
  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,
   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,
   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,
   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,
  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,
  377,  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,
   -1,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,
   -1,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,
   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  464,  465,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,
   -1,  478,  479,  480,   -1,   -1,   -1,   -1,  485,  486,
   -1,  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,
   -1,   -1,  499,  500,   -1,   -1,   -1,   -1,  505,  506,
  507,   -1,  509,  510,  511,   -1,  513,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,  540,  541,  542,  543,   -1,  545,  546,
  547,  548,  549,  550,   -1,  552,  553,  554,  555,   -1,
  557,   -1,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,  573,  574,  575,  576,
   -1,  578,  579,  580,  581,   -1,  583,  584,  585,  586,
  587,   -1,  589,  590,  591,  592,  593,  594,  595,  596,
  597,  598,  599,  600,  601,   -1,  603,  604,  605,  606,
  607,  608,   -1,  610,  611,  612,  613,  614,  615,  616,
  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,
  627,  628,  629,   -1,   -1,  632,  633,  634,  635,  636,
  637,  638,  639,  640,   -1,   -1,   -1,   -1,   -1,  646,
   -1,  648,  649,  650,  651,  652,  653,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,
  677,  678,  679,  680,  681,  682,  683,   -1,  685,  686,
  687,  688,  689,  690,  691,  692,  693,  694,  695,  696,
   -1,  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,
  707,  708,  709,  710,  711,  712,  713,  714,  715,  716,
  717,  718,   -1,  720,  721,   -1,   -1,   -1,   -1,   -1,
  727,  728,  729,  730,  731,  732,  733,  734,  735,  736,
  737,  738,  739,  740,   -1,   -1,  743,  744,   -1,   -1,
   -1,   -1,  749,  750,  751,  752,  753,  754,  755,  756,
  757,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,
   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,
  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,
  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,   -1,   -1,  351,   -1,  353,   -1,   -1,
   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,
  376,  377,  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,
   -1,   -1,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,  415,
   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,
   -1,   -1,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,
   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,
  456,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  464,  465,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,
  476,   -1,  478,  479,  480,   -1,   -1,   -1,   -1,  485,
  486,   -1,  488,  489,   -1,  491,   -1,   -1,  494,  495,
   -1,   -1,   -1,  499,  500,   -1,   -1,   -1,   -1,  505,
  506,  507,   -1,  509,  510,  511,   -1,  513,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,  540,  541,  542,  543,   -1,  545,
  546,  547,  548,  549,  550,   -1,  552,  553,  554,  555,
   -1,  557,   -1,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,  573,  574,  575,
  576,   -1,  578,  579,  580,  581,   -1,  583,  584,  585,
  586,  587,   -1,  589,  590,  591,  592,  593,  594,  595,
  596,  597,  598,  599,  600,  601,   -1,  603,  604,  605,
  606,  607,  608,   -1,  610,  611,  612,  613,  614,  615,
  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,
  626,  627,  628,  629,   -1,   -1,  632,  633,  634,  635,
  636,  637,  638,  639,  640,   -1,   -1,   -1,   -1,   -1,
  646,   -1,  648,  649,  650,  651,  652,  653,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,
  676,  677,  678,  679,  680,  681,  682,  683,   -1,  685,
  686,  687,  688,  689,  690,  691,  692,  693,  694,  695,
  696,   -1,  698,  699,  700,   -1,  702,   -1,   -1,   -1,
  706,  707,  708,  709,  710,  711,  712,  713,  714,  715,
  716,  717,  718,   -1,  720,  721,   -1,   -1,   -1,   -1,
   -1,  727,  728,  729,  730,  731,  732,  733,  734,  735,
  736,  737,  738,  739,  740,   -1,   -1,  743,  744,   -1,
   -1,   -1,   -1,  749,  750,  751,  752,  753,  754,  755,
  756,  757,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,
  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,
   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,  324,
   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,
   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,   -1,
   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,
  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,
   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,
   -1,   -1,   -1,  438,  439,   -1,   -1,   -1,   -1,   -1,
  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,
   -1,  456,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  464,
  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  475,  476,   -1,  478,  479,  480,   -1,   -1,   -1,   -1,
  485,  486,   -1,  488,  489,   -1,  491,   -1,   -1,  494,
  495,   -1,   -1,   -1,  499,  500,   -1,   -1,   -1,   -1,
  505,  506,  507,   -1,  509,  510,  511,   -1,  513,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,  540,  541,  542,  543,   -1,
  545,  546,  547,  548,  549,  550,   -1,  552,  553,  554,
  555,   -1,  557,   -1,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,  573,  574,
  575,  576,   -1,  578,  579,  580,  581,   -1,  583,  584,
  585,  586,  587,   -1,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,   -1,  603,  604,
  605,  606,  607,  608,   -1,  610,  611,  612,  613,  614,
  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,
  625,  626,  627,  628,  629,   -1,   -1,  632,  633,  634,
  635,  636,  637,  638,  639,  640,   -1,   -1,   -1,   -1,
   -1,  646,   -1,  648,  649,  650,  651,  652,  653,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,
  675,  676,  677,  678,  679,  680,  681,  682,  683,   -1,
  685,  686,  687,  688,  689,  690,  691,  692,  693,  694,
  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,   -1,
   -1,  706,  707,  708,  709,  710,  711,  712,  713,  714,
  715,  716,  717,  718,   -1,  720,  721,   -1,   -1,   -1,
   -1,   -1,  727,  728,  729,  730,  731,  732,  733,  734,
  735,  736,  737,  738,  739,  740,   -1,   -1,  743,  744,
   -1,   -1,   -1,   -1,  749,  750,  751,  752,  753,  754,
  755,  756,  757,  257,   -1,  259,   -1,   -1,   -1,   -1,
   -1,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,
  304,   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,
  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,
  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,
   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,
  374,  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
   -1,   -1,   -1,   -1,  438,  439,   -1,   -1,   -1,   -1,
   -1,  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,
  454,   -1,  456,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  475,  476,   -1,  478,  479,  480,   -1,   -1,   -1,
   -1,  485,  486,   -1,  488,  489,   -1,  491,   -1,   -1,
  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,   -1,
   -1,  505,  506,  507,   -1,  509,  510,  511,   -1,  513,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,  540,  541,  542,  543,
   -1,  545,  546,  547,  548,  549,  550,   -1,  552,  553,
  554,  555,   -1,  557,   -1,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,  573,
  574,  575,  576,   -1,  578,  579,  580,  581,   -1,  583,
  584,  585,  586,  587,   -1,  589,  590,  591,  592,  593,
  594,  595,  596,  597,  598,  599,  600,  601,   -1,  603,
  604,  605,  606,  607,  608,   -1,  610,  611,  612,  613,
  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,
  624,  625,  626,  627,  628,  629,   -1,   -1,  632,  633,
  634,  635,  636,  637,  638,  639,  640,   -1,   -1,   -1,
   -1,   -1,  646,   -1,  648,  649,  650,  651,  652,  653,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,
   -1,  675,  676,  677,  678,  679,  680,  681,  682,  683,
   -1,  685,  686,  687,  688,  689,  690,  691,  692,  693,
  694,  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,
   -1,   -1,  706,  707,  708,  709,  710,  711,  712,  713,
  714,  715,  716,  717,  718,   -1,  720,  721,   -1,   -1,
   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,  733,
  734,  735,  736,  737,  738,  739,  740,   -1,   -1,  743,
  744,   -1,   -1,   -1,   -1,  749,  750,  751,  752,  753,
  754,  755,  756,  757,  257,   -1,  259,   -1,   -1,   -1,
   -1,   -1,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,
   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,
   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,
   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,
   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,
   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,
  353,   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,
   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,   -1,
   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,
  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,
  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,
  413,  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  433,   -1,   -1,   -1,   -1,  438,  439,   -1,   -1,   -1,
   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,  451,  452,
  453,  454,   -1,  456,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  475,  476,   -1,  478,  479,  480,   -1,   -1,
   -1,   -1,  485,  486,   -1,  488,  489,   -1,  491,   -1,
   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,
   -1,   -1,  505,  506,  507,   -1,  509,  510,  511,   -1,
  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,  540,  541,  542,
  543,   -1,  545,  546,  547,  548,  549,  550,   -1,  552,
  553,  554,  555,   -1,  557,   -1,  559,  560,  561,  562,
  563,  564,  565,  566,  567,  568,  569,  570,  571,  572,
  573,  574,  575,  576,   -1,  578,  579,  580,  581,   -1,
  583,  584,  585,  586,  587,   -1,  589,  590,  591,  592,
  593,  594,  595,  596,  597,  598,  599,  600,  601,   -1,
  603,  604,  605,  606,  607,  608,   -1,  610,  611,  612,
  613,  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,
   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,  632,
  633,  634,  635,  636,  637,  638,  639,  640,   -1,   -1,
   -1,   -1,   -1,  646,   -1,  648,  649,  650,  651,  652,
  653,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,
  673,   -1,  675,  676,  677,  678,  679,  680,  681,  682,
  683,   -1,  685,  686,  687,  688,  689,  690,  691,  692,
  693,  694,  695,  696,   -1,  698,  699,  700,   -1,  702,
   -1,   -1,   -1,  706,  707,  708,  709,  710,  711,  712,
  713,  714,  715,  716,  717,  718,   -1,  720,  721,   -1,
   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,
  733,  734,  735,  736,  737,  738,  739,  740,   -1,   -1,
  743,  744,   -1,   -1,   -1,   -1,  749,  750,  751,  752,
  753,  754,  755,  756,  757,  257,   -1,  259,   -1,   -1,
   -1,   -1,   -1,  265,   -1,   -1,  268,  269,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,
  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,   -1,
   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,   -1,
   -1,   -1,  304,   -1,  306,   -1,   -1,  309,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,
   -1,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,   -1,
   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,
   -1,  353,   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,
   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,   -1,
   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,   -1,
  392,  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,
  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,  411,
  412,  413,  414,  415,   -1,   -1,   -1,   -1,  420,   -1,
  422,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  433,   -1,   -1,   -1,   -1,  438,  439,   -1,   -1,
   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,  451,
  452,  453,  454,   -1,  456,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  475,  476,   -1,  478,  479,  480,   -1,
   -1,   -1,   -1,  485,  486,   -1,  488,  489,   -1,  491,
   -1,   -1,  494,  495,   -1,   -1,   -1,  499,  500,   -1,
   -1,   -1,   -1,  505,  506,  507,   -1,  509,  510,  511,
   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  523,  524,  525,  526,  527,  528,  529,  530,  531,
  532,  533,  534,  535,  536,  537,  538,  539,  540,  541,
  542,  543,   -1,  545,  546,  547,  548,  549,  550,   -1,
  552,  553,  554,  555,   -1,  557,   -1,  559,  560,  561,
  562,  563,  564,  565,  566,  567,  568,  569,  570,  571,
  572,  573,  574,  575,  576,   -1,  578,  579,  580,  581,
   -1,  583,  584,  585,  586,  587,   -1,  589,  590,  591,
  592,  593,  594,  595,  596,  597,  598,  599,  600,  601,
   -1,  603,  604,  605,  606,  607,  608,   -1,  610,  611,
  612,  613,  614,  615,  616,  617,   -1,  619,  620,   -1,
   -1,   -1,  624,  625,  626,  627,  628,  629,   -1,   -1,
  632,  633,  634,  635,  636,  637,  638,  639,  640,   -1,
   -1,   -1,   -1,   -1,  646,   -1,  648,  649,  650,  651,
  652,  653,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  672,  673,   -1,  675,  676,  677,  678,  679,  680,  681,
  682,  683,   -1,  685,  686,  687,  688,  689,  690,  691,
  692,  693,  694,  695,  696,   -1,  698,  699,  700,   -1,
  702,   -1,   -1,   -1,  706,  707,  708,  709,  710,  711,
  712,  713,  714,  715,  716,  717,  718,   -1,  720,  721,
   -1,   -1,   -1,   -1,   -1,  727,  728,  729,  730,  731,
  732,  733,  734,  735,  736,  737,  738,  739,  740,   -1,
   -1,  743,  744,   -1,   -1,   -1,   -1,  749,  750,  751,
  752,  753,  754,  755,  756,  757,  257,   -1,  259,   -1,
   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,  269,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,  280,
   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,  290,
   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,  300,
   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,  309,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,  320,
   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,   -1,
   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,  340,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,   -1,
  351,   -1,  353,   -1,   -1,   -1,  357,  358,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  370,
   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,  380,
   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,   -1,
   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,  399,   -1,
   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,   -1,
  411,  412,  413,  414,  415,   -1,   -1,   -1,   -1,  420,
   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,   -1,
   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,   -1,
  451,  452,  453,  454,   -1,  456,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  464,  465,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,  480,
   -1,   -1,   -1,   -1,  485,  486,   -1,  488,  489,   -1,
  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,  500,
   -1,   -1,   -1,   -1,  505,  506,  507,   -1,  509,  510,
  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  523,  524,  525,  526,  527,  528,  529,  530,
  531,  532,  533,  534,  535,  536,  537,  538,  539,  540,
  541,  542,  543,   -1,  545,  546,  547,  548,  549,  550,
   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,  560,
  561,  562,  563,  564,  565,  566,  567,  568,  569,  570,
  571,  572,  573,  574,  575,  576,   -1,  578,  579,  580,
  581,   -1,  583,  584,  585,  586,  587,   -1,  589,  590,
  591,  592,  593,  594,  595,  596,  597,  598,  599,  600,
  601,   -1,  603,  604,  605,  606,  607,  608,   -1,  610,
  611,  612,  613,  614,  615,  616,  617,   -1,  619,  620,
   -1,   -1,   -1,  624,  625,  626,  627,  628,  629,   -1,
   -1,  632,  633,  634,  635,  636,  637,  638,  639,  640,
   -1,   -1,   -1,   -1,   -1,  646,   -1,  648,  649,  650,
  651,  652,  653,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  672,  673,   -1,  675,  676,  677,  678,  679,  680,
  681,  682,  683,   -1,  685,  686,  687,  688,  689,  690,
  691,  692,  693,  694,  695,  696,   -1,  698,  699,  700,
   -1,  702,   -1,   -1,   -1,  706,  707,  708,  709,  710,
  711,  712,  713,  714,  715,  716,  717,  718,   -1,  720,
  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,  730,
  731,  732,  733,  734,  735,  736,  737,  738,  739,  740,
   -1,   -1,  743,  744,   -1,   -1,   -1,   -1,  749,  750,
  751,  752,  753,  754,  755,  756,  757,  257,   -1,  259,
   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,  269,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  279,
  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,   -1,
  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,  299,
  300,   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,  309,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  319,
  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,   -1,
   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,   -1,
  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,   -1,
   -1,  351,   -1,  353,   -1,   -1,   -1,  357,  358,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,   -1,
  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,  389,
   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,  399,
   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,  409,
   -1,  411,  412,  413,  414,  415,   -1,   -1,   -1,   -1,
  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,  439,
   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,  449,
   -1,  451,  452,  453,  454,   -1,  456,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  464,  465,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,  479,
  480,   -1,   -1,   -1,   -1,  485,  486,   -1,  488,  489,
   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,  499,
  500,   -1,   -1,   -1,   -1,  505,  506,  507,   -1,  509,
  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,  529,
  530,  531,  532,  533,  534,  535,  536,  537,  538,  539,
  540,  541,  542,  543,   -1,  545,  546,  547,  548,  549,
  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,  559,
  560,  561,  562,  563,  564,  565,  566,  567,  568,  569,
  570,  571,  572,  573,  574,  575,  576,   -1,  578,  579,
  580,  581,   -1,  583,  584,  585,  586,  587,   -1,  589,
  590,  591,  592,  593,  594,  595,  596,  597,  598,  599,
  600,  601,   -1,  603,  604,  605,  606,  607,  608,   -1,
  610,  611,  612,  613,  614,  615,  616,  617,   -1,  619,
  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,  629,
   -1,   -1,  632,  633,  634,  635,  636,  637,  638,  639,
  640,   -1,   -1,   -1,   -1,   -1,  646,   -1,  648,  649,
  650,  651,  652,  653,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,  679,
  680,  681,  682,  683,   -1,  685,  686,  687,  688,  689,
  690,  691,  692,  693,  694,  695,  696,   -1,  698,  699,
  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,  709,
  710,  711,  712,  713,  714,  715,  716,  717,  718,   -1,
  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,  729,
  730,  731,  732,  733,  734,  735,  736,  737,  738,  739,
  740,   -1,   -1,  743,  744,   -1,   -1,   -1,   -1,  749,
  750,  751,  752,  753,  754,  755,  756,  757,  257,   -1,
  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,  268,
  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,   -1,
   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,   -1,
  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,   -1,
  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,  328,
   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,   -1,
   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  348,
   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,  357,  358,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,  378,
   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,  388,
  389,   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,   -1,
  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,   -1,
  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,   -1,
   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,  438,
  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,   -1,
  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  464,  465,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,  478,
  479,  480,   -1,   -1,   -1,   -1,  485,  486,   -1,  488,
  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,   -1,
  499,  500,   -1,   -1,   -1,   -1,  505,  506,  507,   -1,
  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  523,  524,  525,  526,  527,  528,
  529,  530,  531,  532,  533,  534,  535,  536,  537,  538,
  539,  540,  541,  542,  543,   -1,  545,  546,  547,  548,
  549,  550,   -1,  552,  553,  554,  555,   -1,  557,   -1,
  559,  560,  561,  562,  563,  564,  565,  566,  567,  568,
  569,  570,  571,  572,  573,  574,  575,  576,   -1,  578,
  579,  580,  581,   -1,  583,  584,  585,  586,  587,   -1,
  589,  590,  591,  592,  593,  594,  595,  596,  597,  598,
  599,  600,  601,   -1,  603,  604,  605,  606,  607,  608,
   -1,  610,  611,  612,  613,  614,  615,  616,  617,   -1,
  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,  628,
  629,   -1,   -1,  632,  633,  634,  635,  636,  637,  638,
  639,  640,   -1,   -1,   -1,   -1,   -1,  646,   -1,  648,
  649,  650,  651,  652,  653,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,  678,
  679,  680,  681,  682,  683,   -1,  685,  686,  687,  688,
  689,  690,  691,  692,  693,  694,  695,  696,   -1,  698,
  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,  708,
  709,  710,  711,  712,  713,  714,  715,  716,  717,  718,
   -1,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,  728,
  729,  730,  731,  732,  733,  734,  735,  736,  737,   -1,
  739,  740,   -1,   -1,  743,  744,   -1,   -1,   -1,   -1,
  749,  750,  751,  752,  753,  754,  755,  756,  757,  257,
   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,   -1,
  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,  287,
   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,  297,
   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,   -1,
   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,   -1,
  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,   -1,
   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  348,   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,  357,
  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,  377,
  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,   -1,
  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,   -1,
   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,  407,
   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,   -1,
   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,   -1,
  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,   -1,
   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  464,  465,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,   -1,
  478,  479,  480,   -1,   -1,   -1,   -1,  485,  486,   -1,
  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,   -1,
   -1,  499,  500,   -1,   -1,   -1,   -1,  505,  506,  507,
   -1,  509,  510,  511,   -1,  513,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,  540,  541,  542,  543,   -1,  545,  546,  547,
  548,  549,  550,   -1,  552,  553,  554,  555,   -1,  557,
   -1,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,  573,  574,  575,  576,   -1,
  578,  579,  580,  581,   -1,  583,  584,  585,  586,  587,
   -1,  589,  590,  591,  592,  593,  594,  595,  596,  597,
  598,  599,  600,  601,   -1,  603,  604,  605,  606,  607,
  608,   -1,  610,  611,  612,  613,  614,  615,  616,  617,
   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,  627,
  628,  629,   -1,   -1,  632,  633,  634,  635,  636,  637,
  638,  639,  640,   -1,   -1,   -1,   -1,   -1,  646,   -1,
  648,  649,  650,  651,  652,  653,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,  677,
  678,  679,  680,  681,  682,  683,   -1,  685,  686,  687,
  688,  689,  690,  691,  692,  693,  694,  695,  696,   -1,
  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,  707,
  708,  709,  710,  711,  712,  713,  714,  715,  716,  717,
  718,   -1,  720,  721,   -1,   -1,   -1,   -1,   -1,  727,
  728,  729,  730,  731,  732,  733,  734,  735,  736,  737,
  738,  739,  740,   -1,   -1,  743,  744,   -1,   -1,   -1,
   -1,  749,  750,  751,  752,  753,  754,  755,  756,  757,
  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,   -1,
   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  279,  280,   -1,  282,   -1,  284,   -1,   -1,
  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,   -1,
  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,  306,
   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,  326,
   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,  336,
   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  348,   -1,   -1,  351,   -1,  353,   -1,   -1,   -1,
  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,  376,
  377,  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,  386,
   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,   -1,
   -1,   -1,  399,   -1,   -1,  402,  403,  404,  405,   -1,
  407,   -1,  409,   -1,  411,  412,  413,  414,  415,   -1,
   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,   -1,
   -1,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,   -1,
   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,  456,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  464,  465,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,  476,
   -1,  478,  479,  480,   -1,   -1,   -1,   -1,  485,  486,
   -1,  488,  489,   -1,  491,   -1,   -1,  494,  495,   -1,
   -1,   -1,  499,  500,   -1,   -1,   -1,   -1,  505,  506,
  507,   -1,  509,  510,  511,   -1,  513,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,  526,
  527,  528,  529,  530,  531,  532,  533,  534,  535,  536,
  537,  538,  539,  540,  541,  542,  543,   -1,  545,  546,
  547,  548,  549,  550,   -1,  552,  553,  554,  555,   -1,
  557,   -1,  559,  560,  561,  562,  563,  564,  565,  566,
  567,  568,  569,  570,  571,  572,  573,  574,  575,  576,
   -1,  578,  579,  580,  581,   -1,  583,  584,  585,  586,
  587,   -1,  589,  590,  591,  592,  593,  594,  595,  596,
   -1,  598,  599,  600,  601,   -1,  603,  604,  605,  606,
  607,  608,   -1,  610,  611,  612,  613,  614,  615,  616,
  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,  626,
  627,  628,  629,   -1,   -1,  632,  633,  634,  635,  636,
  637,  638,  639,  640,   -1,   -1,   -1,   -1,   -1,  646,
   -1,  648,  649,  650,  651,  652,  653,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,  676,
  677,  678,  679,  680,  681,  682,  683,   -1,  685,  686,
  687,  688,  689,  690,  691,  692,  693,  694,  695,  696,
   -1,  698,  699,  700,   -1,  702,   -1,   -1,   -1,  706,
  707,  708,  709,  710,  711,  712,  713,  714,  715,  716,
  717,  718,   -1,  720,  721,   -1,   -1,   -1,   -1,   -1,
  727,  728,  729,  730,  731,  732,  733,  734,  735,  736,
  737,  738,  739,  740,   -1,   -1,  743,  744,   -1,   -1,
   -1,   -1,  749,  750,  751,  752,  753,  754,  755,  756,
  757,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,  265,
   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  279,  280,   -1,  282,   -1,   -1,   -1,
   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,   -1,
   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,   -1,
  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,  324,   -1,
  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,   -1,
  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  348,   -1,   -1,  351,   -1,  353,   -1,   -1,
   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,  375,
  376,  377,  378,   -1,  380,   -1,   -1,   -1,   -1,   -1,
  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,   -1,
   -1,   -1,   -1,  399,   -1,   -1,  402,  403,  404,  405,
   -1,  407,   -1,  409,   -1,  411,   -1,  413,  414,  415,
   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,   -1,
   -1,   -1,  438,  439,   -1,   -1,   -1,   -1,   -1,  445,
   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,   -1,
  456,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  464,  465,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  475,
  476,   -1,  478,  479,  480,   -1,   -1,   -1,   -1,  485,
  486,   -1,  488,  489,   -1,  491,   -1,   -1,  494,  495,
   -1,   -1,   -1,  499,  500,   -1,   -1,   -1,   -1,  505,
  506,  507,   -1,  509,  510,  511,   -1,  513,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,  525,
  526,  527,  528,  529,  530,  531,  532,  533,  534,  535,
  536,  537,  538,  539,  540,  541,  542,  543,   -1,  545,
  546,  547,  548,  549,  550,   -1,  552,  553,  554,  555,
   -1,  557,   -1,  559,  560,  561,  562,  563,  564,  565,
  566,  567,  568,  569,  570,  571,  572,  573,  574,  575,
  576,   -1,  578,  579,  580,  581,   -1,  583,  584,  585,
  586,  587,   -1,  589,  590,  591,  592,  593,  594,  595,
  596,  597,  598,  599,  600,  601,   -1,  603,  604,  605,
  606,  607,  608,   -1,  610,  611,  612,  613,  614,  615,
  616,  617,   -1,  619,  620,   -1,   -1,   -1,  624,  625,
  626,  627,  628,  629,   -1,   -1,  632,  633,  634,  635,
  636,  637,  638,  639,  640,   -1,   -1,   -1,   -1,   -1,
  646,   -1,  648,  649,  650,  651,  652,  653,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,  675,
  676,  677,  678,  679,  680,  681,  682,  683,   -1,  685,
  686,  687,  688,  689,  690,  691,  692,  693,  694,  695,
  696,   -1,  698,  699,  700,   -1,  702,   -1,   -1,   -1,
  706,  707,  708,  709,  710,  711,  712,  713,  714,  715,
  716,  717,  718,   -1,  720,  721,   -1,   -1,   -1,   -1,
   -1,  727,  728,  729,  730,  731,  732,  733,  734,  735,
  736,  737,  738,  739,  740,   -1,   -1,  743,  744,   -1,
   -1,   -1,   -1,  749,  750,  751,  752,  753,  754,  755,
  756,  757,  257,   -1,  259,   -1,   -1,   -1,   -1,   -1,
  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,  284,
   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,   -1,
   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,  304,
   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,  324,
   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,  334,
   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,   -1,
   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,  374,
  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,   -1,
   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,   -1,
   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,  403,  404,
  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,  414,
  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,   -1,
   -1,   -1,   -1,  438,  439,   -1,   -1,   -1,   -1,   -1,
  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,  454,
   -1,  456,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  464,
  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  475,  476,   -1,  478,  479,  480,   -1,   -1,   -1,   -1,
  485,  486,   -1,  488,  489,   -1,  491,   -1,   -1,  494,
  495,   -1,   -1,   -1,  499,  500,   -1,   -1,   -1,   -1,
  505,  506,  507,   -1,  509,  510,  511,   -1,  513,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,  524,
  525,  526,  527,  528,  529,  530,  531,  532,  533,  534,
  535,  536,  537,  538,  539,  540,  541,  542,  543,   -1,
  545,  546,  547,  548,  549,  550,   -1,  552,  553,  554,
  555,   -1,  557,   -1,  559,  560,  561,  562,  563,  564,
  565,  566,  567,  568,  569,  570,  571,  572,  573,  574,
  575,  576,   -1,  578,  579,  580,  581,   -1,  583,  584,
  585,  586,  587,   -1,  589,  590,  591,  592,  593,  594,
  595,  596,  597,  598,  599,  600,  601,   -1,  603,  604,
  605,  606,  607,  608,   -1,  610,  611,  612,  613,  614,
  615,  616,  617,   -1,  619,   -1,   -1,   -1,   -1,  624,
  625,  626,  627,  628,  629,   -1,   -1,  632,  633,  634,
  635,  636,  637,  638,  639,  640,   -1,   -1,   -1,   -1,
   -1,  646,   -1,  648,  649,  650,  651,  652,  653,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,   -1,
  675,  676,  677,  678,  679,  680,  681,  682,  683,   -1,
  685,  686,  687,  688,   -1,  690,  691,  692,  693,  694,
  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,   -1,
   -1,  706,  707,  708,  709,  710,  711,  712,  713,  714,
  715,  716,  717,  718,   -1,  720,   -1,   -1,   -1,   -1,
   -1,   -1,  727,  728,  729,  730,  731,  732,  733,  734,
  735,  736,  737,  738,  739,  740,   -1,   -1,  743,  744,
   -1,   -1,   -1,   -1,  749,  750,  751,  752,  753,  754,
  755,  756,  757,  257,   -1,  259,   -1,   -1,   -1,   -1,
   -1,  265,   -1,   -1,  268,  269,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  279,  280,   -1,  282,   -1,
  284,   -1,   -1,  287,   -1,   -1,  290,   -1,   -1,   -1,
   -1,   -1,   -1,  297,   -1,  299,  300,   -1,   -1,   -1,
  304,   -1,  306,   -1,   -1,  309,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  319,  320,   -1,   -1,   -1,
  324,   -1,  326,   -1,  328,   -1,   -1,   -1,   -1,   -1,
  334,   -1,  336,   -1,   -1,   -1,  340,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  348,   -1,   -1,  351,   -1,  353,
   -1,   -1,   -1,  357,  358,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  370,   -1,   -1,   -1,
  374,  375,  376,  377,  378,   -1,  380,   -1,   -1,   -1,
   -1,   -1,  386,   -1,  388,  389,   -1,   -1,  392,  393,
   -1,   -1,   -1,   -1,   -1,  399,   -1,   -1,  402,  403,
  404,  405,   -1,  407,   -1,  409,   -1,  411,  412,  413,
  414,  415,   -1,   -1,   -1,   -1,  420,   -1,  422,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  433,
   -1,   -1,   -1,   -1,  438,  439,   -1,   -1,   -1,   -1,
   -1,  445,   -1,   -1,   -1,  449,   -1,  451,  452,  453,
  454,   -1,  456,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  464,  465,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  475,  476,   -1,  478,   -1,  480,   -1,   -1,   -1,
   -1,  485,  486,   -1,  488,   -1,   -1,  491,   -1,   -1,
  494,  495,   -1,   -1,   -1,  499,  500,   -1,   -1,   -1,
   -1,  505,  506,  507,   -1,   -1,  510,  511,   -1,  513,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  523,
  524,  525,  526,  527,  528,  529,  530,  531,  532,  533,
  534,  535,  536,  537,  538,  539,  540,  541,  542,  543,
   -1,  545,  546,  547,  548,  549,  550,   -1,  552,  553,
  554,  555,   -1,  557,   -1,  559,  560,  561,  562,  563,
  564,  565,  566,  567,  568,  569,  570,  571,  572,  573,
  574,  575,  576,   -1,  578,  579,  580,  581,   -1,  583,
  584,  585,  586,  587,   -1,  589,  590,  591,  592,  593,
  594,  595,  596,  597,  598,  599,  600,  601,   -1,  603,
  604,  605,  606,  607,  608,   -1,  610,  611,  612,  613,
  614,  615,  616,  617,   -1,  619,  620,   -1,   -1,   -1,
   -1,   -1,   -1,  627,  628,  629,   -1,   -1,  632,  633,
  634,  635,  636,  637,  638,  639,  640,   -1,   -1,   -1,
   -1,   -1,  646,   -1,  648,  649,  650,  651,  652,  653,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  672,  673,
   -1,  675,  676,  677,  678,  679,  680,  681,  682,  683,
   -1,  685,  686,  687,  688,  689,  690,  691,  692,  693,
  694,  695,  696,   -1,  698,  699,  700,   -1,  702,   -1,
   -1,   -1,  706,  707,  708,  709,  710,  711,  712,  713,
  714,  715,  716,  717,  718,   -1,  720,  721,   -1,   -1,
   -1,   -1,   -1,  727,  728,  729,  730,  731,  732,  733,
  734,  735,  736,  737,  738,  739,  740,   -1,   -1,  743,
  744,  272,   -1,   -1,  275,  749,  750,  751,  752,  753,
  754,  755,  756,  757,   -1,   -1,  287,   -1,   -1,   -1,
  291,   -1,  293,   -1,   -1,   -1,  272,   -1,   -1,  275,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  287,   -1,   -1,   -1,  291,   -1,  293,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  331,   -1,   -1,   -1,   -1,   -1,  337,  338,  339,   -1,
  341,  342,  343,   -1,  345,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  272,   -1,  331,  275,   -1,  359,   -1,
  361,  337,  338,  339,   -1,  341,  342,  343,  287,  345,
   -1,   -1,  291,   -1,  293,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  359,   -1,  361,   -1,   -1,  272,  390,
   -1,  275,   -1,   -1,  395,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  379,   -1,  406,   -1,  291,   -1,  293,
   -1,   -1,  331,   -1,  390,   -1,   -1,   -1,  337,  338,
  339,   -1,  341,  342,  343,   -1,  345,  428,   -1,   -1,
  406,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  359,   -1,  361,   -1,   -1,   -1,   -1,  331,   -1,   -1,
   -1,   -1,  428,  337,  338,  339,   -1,  341,  342,  343,
   -1,  345,   -1,   -1,   -1,  466,  467,  272,   -1,   -1,
  275,  390,   -1,   -1,   -1,  359,   -1,  361,   -1,   -1,
   -1,   -1,  483,   -1,   -1,   -1,  291,  406,  293,   -1,
  466,  467,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  272,   -1,   -1,  275,   -1,   -1,  390,  483,   -1,  428,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  291,
   -1,  293,  406,   -1,   -1,   -1,  331,   -1,   -1,   -1,
   -1,   -1,  337,  338,  339,   -1,  341,  342,  343,   -1,
  345,   -1,   -1,   -1,  428,   -1,   -1,  466,  467,   -1,
   -1,   -1,   -1,   -1,  359,   -1,  361,   -1,   -1,  331,
   -1,   -1,   -1,   -1,  483,  337,  338,  339,   -1,  341,
  342,  343,   -1,  345,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  466,  467,   -1,  390,   -1,  359,   -1,  361,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  483,
   -1,  406,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  390,   -1,
   -1,   -1,   -1,  428,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  406,   -1,   -1,   -1,   -1,   -1,
   -1,  642,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,  428,   -1,   -1,   -1,
   -1,  466,  467,   -1,   -1,   -1,  642,   -1,   -1,   -1,
   -1,   -1,   -1,  674,   -1,   -1,   -1,   -1,  483,   -1,
   -1,   -1,   -1,  684,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  466,  467,  697,   -1,  674,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  684,   -1,
   -1,  483,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  697,   -1,  642,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  746,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  674,   -1,   -1,  642,   -1,
   -1,   -1,   -1,   -1,   -1,  684,   -1,   -1,   -1,   -1,
  746,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  697,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  674,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
  684,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,  697,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  746,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,  642,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  746,   -1,   -1,   -1,   -1,   -1,   -1,  674,
  642,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,  684,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  697,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  674,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,  684,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  697,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,  746,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,  746,
};
static int yyctable[] = {                                     -1,
 1360, 1396,   -1,  746, 1340,   -1,  747, 1340,   -1,  791,
  317,   -1,  792,  317,   -1,  407, 2275,   -1,   40,   52,
   -1, 1107,  127,   -1,  127,  129,   -1,  747, 1342,   -1,
 1362, 1977,   -1, 2093, 2100,   -1, 1546, 1314,   -1, 1609,
  574,   -1, 1797, 1688,   -1, 1798, 1687,   -1, 1418, 1360,
   -1, 1429, 1360,   -1, 1609,  575,   -1, 2214, 1599,   -1,
  331, 1418,   -1,  369, 1418,   -1,  395, 1418,   -1,  699,
 1389,   -1, 1360, 1389,   -1, 2289, 1194,   -1, 2462, 1000,
   -1, 2627, 1601,   -1, 2629, 1603,   -1,   90,   97,   -1,
  699, 1360,   -1,  226,  724,   -1,  231,  724,   -1,  240,
  724,   -1,  332,  724,   -1,  333,  724,   -1,  334,  724,
   -1, 2790, 1092,   -1, 2815,  897,   -1,  906, 2079,   -1,
 2968, 1605,   -1,  244, 1373,   -1,  699, 1391,   -1, 1360,
 1391,   -1, 2621, 1334,   -1,  311, 2108,   -1, 3344, 1264,
   -1, 3345, 1264,   -1, 2817, 1090,   -1,  311, 2283,   -1,
 3539, 1276,   -1, 3585,  450,   -1,  419,  430,   -1, 3814,
  652,   -1,  162, 2318,   -1,  205, 2318,   -1,
};
#define YYFINAL 20
#ifndef YYDEBUG
#define YYDEBUG 0
#endif
#define YYMAXTOKEN 759
#if YYDEBUG
static const char *yyname[] = {
"end-of-file",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,"'('","')'","'*'","'+'","','","'-'","'.'","'/'",0,0,0,0,0,0,0,0,0,0,
"':'","';'","'<'","'='","'>'","'?'",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,"'['",0,"']'",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,"ACTIVE","ADD","AFTER","ALL","ALTER","AND","ANY",
"AS","ASC","AT","AVG","AUTO","BEFORE","BEGIN","BETWEEN","BLOB","BY","CAST",
"CHARACTER","CHECK","COLLATE","COMMIT","COMMITTED","COMPUTED","CONCATENATE",
"CONDITIONAL","CONSTRAINT","CONTAINING","COUNT","CREATE","CSTRING","CURRENT",
"CURSOR","DATABASE","DATE","DB_KEY","DECIMAL","DECLARE","DEFAULT","DELETE",
"DESC","DISTINCT","DO","DOMAIN","DROP","ELSE","END","ENTRY_POINT","ESCAPE",
"EXCEPTION","EXECUTE","EXISTS","EXIT","EXTERNAL","FILTER","FOR","FOREIGN",
"FROM","FULL","FUNCTION","GDSCODE","GEQ","GENERATOR","GEN_ID","GRANT","GROUP",
"HAVING","IF","IN","INACTIVE","INNER","INPUT_TYPE","INDEX","INSERT","INTEGER",
"INTO","IS","ISOLATION","JOIN","KEY","CHAR","DEC","DOUBLE","FILE","FLOAT","INT",
"LONG","NULL","NUMERIC","UPPER","VALUE","LENGTH","LEFT","LEQ","LEVEL","LIKE",
"MANUAL","MAXIMUM","MERGE","MINIMUM","MODULE_NAME","NAMES","NATIONAL","NATURAL",
"NCHAR","NEQ","NO","NOT","NOT_GTR","NOT_LSS","OF","ON","ONLY","OPTION","OR",
"ORDER","OUTER","OUTPUT_TYPE","OVERFLOW","PAGE","PAGES","PAGE_SIZE","PARAMETER",
"PASSWORD","PLAN","POSITION","POST_EVENT","PRECISION","PRIMARY","PRIVILEGES",
"PROCEDURE","PROTECTED","READ","REAL","REFERENCES","RESERVING","RETAIN",
"RETURNING_VALUES","RETURNS","REVOKE","RIGHT","ROLLBACK","SEGMENT","SELECT",
"SET","SHADOW","SHARED","SINGULAR","SIZE","SMALLINT","SNAPSHOT","SOME","SORT",
"SQLCODE","STABILITY","STARTING","STATISTICS","SUB_TYPE","SUSPEND","SUM",
"TABLE","THEN","TO","TRANSACTION","TRIGGER","UNCOMMITTED","UNION","UNIQUE",
"UPDATE","USER","VALUES","VARCHAR","VARIABLE","VARYING","VERSION","VIEW","WAIT",
"WHEN","WHERE","WHILE","WITH","WORK","WRITE","FLOAT_NUMBER","DECIMAL_NUMBER",
"LIMIT64_NUMBER","LIMIT64_INT","NUM128","SYMBOL","NUMBER32BIT","STRING",
"INTRODUCER","ACTION","ADMIN","CASCADE","FREE_IT","RESTRICT","ROLE","COLUMN",
"TYPE","EXTRACT","YEAR","MONTH","DAY","HOUR","MINUTE","SECOND","WEEKDAY",
"YEARDAY","TIME","TIMESTAMP","CURRENT_DATE","CURRENT_TIME","CURRENT_TIMESTAMP",
"NUMBER64BIT","SCALEDINT","CURRENT_USER","CURRENT_ROLE","BREAK","SUBSTRING",
"RECREATE","DESCRIPTOR","FIRST","SKIP","CURRENT_CONNECTION",
"CURRENT_TRANSACTION","BIGINT","CASE","NULLIF","COALESCE","USING","NULLS",
"LAST","ROW_COUNT","LOCK","SAVEPOINT","RELEASE","STATEMENT","LEAVE","INSERTING",
"UPDATING","DELETING","BACKUP","DIFFERENCE","OPEN","CLOSE","FETCH","ROWS",
"BLOCK","IIF","SCALAR_ARRAY","CROSS","NEXT","SEQUENCE","RESTART","BOTH",
"COLLATION","COMMENT","BIT_LENGTH","CHAR_LENGTH","CHARACTER_LENGTH","LEADING",
"LOWER","OCTET_LENGTH","TRAILING","TRIM","RETURNING","IGNORE","LIMBO","UNDO",
"REQUESTS","TIMEOUT","ABS","ACCENT","ACOS","ALWAYS","ASCII_CHAR","ASCII_VAL",
"ASIN","ATAN","ATAN2","BIN_AND","BIN_OR","BIN_SHL","BIN_SHR","BIN_XOR","CEIL",
"CONNECT","COS","COSH","COT","DATEADD","DATEDIFF","DECODE","DISCONNECT","EXP",
"FLOOR","GEN_UUID","GENERATED","GLOBAL","HASH","INSENSITIVE","LIST","LN","LOG",
"LOG10","LPAD","MATCHED","MATCHING","MAXVALUE","MILLISECOND","MINVALUE","MOD",
"OVERLAY","PAD","PI","PLACING","POWER","PRESERVE","RAND","RECURSIVE","REPLACE",
"REVERSE","ROUND","RPAD","SENSITIVE","SIGN","SIN","SINH","SPACE","SQRT","START",
"TAN","TANH","TEMPORARY","TRUNC","WEEK","AUTONOMOUS","CHAR_TO_UUID","FIRSTNAME",
"GRANTED","LASTNAME","MIDDLENAME","MAPPING","OS_NAME","SIMILAR","UUID_TO_CHAR",
"CALLER","COMMON","DATA","SOURCE","TWO_PHASE","BIND_PARAM","BIN_NOT","BODY",
"CONTINUE","DDL","DECRYPT","ENCRYPT","ENGINE","NAME","OVER","PACKAGE",
"PARTITION","RDB_GET_CONTEXT","RDB_SET_CONTEXT","SCROLL","PRIOR","ABSOLUTE",
"RELATIVE","ACOSH","ASINH","ATANH","RETURN","DETERMINISTIC","IDENTITY",
"DENSE_RANK","FIRST_VALUE","NTH_VALUE","LAST_VALUE","LAG","LEAD","RANK",
"ROW_NUMBER","SQLSTATE","BOOLEAN","FALSE","TRUE","UNKNOWN","USAGE",
"RDB_RECORD_VERSION","LINGER","TAGS","PLUGIN","SERVERWIDE","INCREMENT",
"TRUSTED","ROW","OFFSET","STDDEV_SAMP","STDDEV_POP","VAR_SAMP","VAR_POP",
"COVAR_SAMP","COVAR_POP","CORR","REGR_AVGX","REGR_AVGY","REGR_COUNT",
"REGR_INTERCEPT","REGR_R2","REGR_SLOPE","REGR_SXX","REGR_SXY","REGR_SYY",
"BASE64_DECODE","BASE64_ENCODE","BINARY","BIND","COMPARE_DECFLOAT",
"CONSISTENCY","COUNTER","CRYPT_HASH","CTR_BIG_ENDIAN","CTR_LENGTH",
"CTR_LITTLE_ENDIAN","CUME_DIST","DECFLOAT","DEFINER","DISABLE","ENABLE",
"EXCESS","EXCLUDE","EXTENDED","FIRST_DAY","FOLLOWING","HEX_DECODE","HEX_ENCODE",
"IDLE","INCLUDE","INT128","INVOKER","IV","LAST_DAY","LATERAL","LEGACY","LOCAL",
"LOCALTIME","LOCALTIMESTAMP","LPARAM","MAKE_DBKEY","MESSAGE","MODE","NATIVE",
"NORMALIZE_DECFLOAT","NTILE","NUMBER","OTHERS","OVERRIDING","PERCENT_RANK",
"PRECEDING","PRIVILEGE","PUBLICATION","QUANTIZE","RANGE","RESETTING",
"RDB_ERROR","RDB_GET_TRANSACTION_CN","RDB_ROLE_IN_USE","RDB_SYSTEM_PRIVILEGE",
"RESET","RSA_DECRYPT","RSA_ENCRYPT","RSA_PRIVATE","RSA_PUBLIC","RSA_SIGN_HASH",
"RSA_VERIFY_HASH","SALT_LENGTH","SECURITY","SESSION","SIGNATURE","SQL","SYSTEM",
"TIES","TIMEZONE_HOUR","TIMEZONE_MINUTE","TOTALORDER","TRAPS","UNBOUNDED",
"VARBINARY","WINDOW","WITHOUT","ZONE","CONNECTIONS","POOL","LIFETIME","CLEAR",
"OLDEST","DEBUG","PKCS_1_5","BLOB_APPEND","UMINUS","UPLUS",
};
static const char *yyrule[] = {
"$accept : top",
"top : statement",
"top : statement ';'",
"statement : dml_statement",
"statement : ddl_statement",
"statement : tra_statement",
"statement : mng_statement",
"dml_statement : delete",
"dml_statement : insert",
"dml_statement : merge",
"dml_statement : exec_procedure",
"dml_statement : exec_block",
"dml_statement : savepoint",
"dml_statement : select",
"dml_statement : update",
"dml_statement : update_or_insert",
"ddl_statement : alter",
"ddl_statement : comment",
"ddl_statement : create",
"ddl_statement : create_or_alter",
"ddl_statement : declare",
"ddl_statement : drop",
"ddl_statement : grant",
"ddl_statement : recreate",
"ddl_statement : revoke",
"ddl_statement : set_statistics",
"tra_statement : set_transaction",
"tra_statement : commit",
"tra_statement : rollback",
"mng_statement : set_debug_option",
"mng_statement : set_decfloat_round",
"mng_statement : set_decfloat_traps",
"mng_statement : session_statement",
"mng_statement : set_role",
"mng_statement : session_reset",
"mng_statement : set_time_zone",
"mng_statement : set_bind",
"$$1 :",
"$$2 :",
"grant : GRANT $$1 $$2 grant0",
"$$3 :",
"$$4 :",
"grant0 : $$3 privileges ON table_noise symbol_table_name TO $$4 non_role_grantee_list grant_option granted_by",
"grant0 : $$3 execute_privilege ON PROCEDURE symbol_procedure_name TO $$4 non_role_grantee_list grant_option granted_by",
"grant0 : $$3 execute_privilege ON FUNCTION symbol_UDF_name TO $$4 non_role_grantee_list grant_option granted_by",
"grant0 : $$3 execute_privilege ON PACKAGE symbol_package_name TO $$4 non_role_grantee_list grant_option granted_by",
"grant0 : $$3 usage_privilege ON EXCEPTION symbol_exception_name TO $$4 non_role_grantee_list grant_option granted_by",
"grant0 : $$3 usage_privilege ON GENERATOR symbol_generator_name TO $$4 non_role_grantee_list grant_option granted_by",
"grant0 : $$3 usage_privilege ON SEQUENCE symbol_generator_name TO $$4 non_role_grantee_list grant_option granted_by",
"$$5 :",
"grant0 : $$3 ddl_privileges object TO $$5 non_role_grantee_list grant_option granted_by",
"grant0 : $$3 db_ddl_privileges DATABASE TO $$5 non_role_grantee_list grant_option granted_by",
"$$6 :",
"$$7 :",
"grant0 : $$6 role_name_list TO $$7 role_grantee_list role_admin_option granted_by",
"object : TABLE",
"object : VIEW",
"object : PROCEDURE",
"object : FUNCTION",
"object : PACKAGE",
"object : GENERATOR",
"object : SEQUENCE",
"object : DOMAIN",
"object : EXCEPTION",
"object : ROLE",
"object : CHARACTER SET",
"object : COLLATION",
"object : FILTER",
"table_noise :",
"table_noise : TABLE",
"privileges : ALL",
"privileges : ALL PRIVILEGES",
"$$8 :",
"privileges : $$8 privilege_list",
"privilege_list : $$8 privilege",
"$$9 :",
"privilege_list : privilege_list ',' $$9 privilege",
"execute_privilege : EXECUTE",
"usage_privilege : USAGE",
"privilege : SELECT",
"privilege : INSERT",
"privilege : DELETE",
"privilege : UPDATE column_parens_opt",
"privilege : REFERENCES column_parens_opt",
"ddl_privileges : ALL privileges_opt",
"ddl_privileges : $$8 ddl_privilege_list",
"privileges_opt :",
"privileges_opt : PRIVILEGES",
"ddl_privilege_list : $$8 ddl_privilege",
"ddl_privilege_list : ddl_privilege_list ',' $$9 ddl_privilege",
"ddl_privilege : CREATE",
"ddl_privilege : ALTER ANY",
"ddl_privilege : DROP ANY",
"db_ddl_privileges : ALL privileges_opt",
"db_ddl_privileges : $$8 db_ddl_privilege_list",
"db_ddl_privilege_list : $$8 db_ddl_privilege",
"db_ddl_privilege_list : db_ddl_privilege_list ',' $$9 db_ddl_privilege",
"db_ddl_privilege : CREATE",
"db_ddl_privilege : ALTER",
"db_ddl_privilege : DROP",
"grant_option :",
"grant_option : WITH GRANT OPTION",
"role_admin_option :",
"role_admin_option : WITH ADMIN OPTION",
"granted_by :",
"granted_by : granted_by_text grantor",
"granted_by_text : GRANTED BY",
"granted_by_text : AS",
"grantor : symbol_user_name",
"grantor : USER symbol_user_name",
"$$10 :",
"revoke : REVOKE $$10 $$2 revoke0",
"$$11 :",
"$$12 :",
"revoke0 : rev_grant_option $$11 privileges ON table_noise symbol_table_name FROM $$12 non_role_grantee_list granted_by",
"revoke0 : rev_grant_option $$11 execute_privilege ON PROCEDURE symbol_procedure_name FROM $$12 non_role_grantee_list granted_by",
"revoke0 : rev_grant_option $$11 execute_privilege ON FUNCTION symbol_UDF_name FROM $$12 non_role_grantee_list granted_by",
"revoke0 : rev_grant_option $$11 execute_privilege ON PACKAGE symbol_package_name FROM $$12 non_role_grantee_list granted_by",
"revoke0 : rev_grant_option $$11 usage_privilege ON EXCEPTION symbol_exception_name FROM $$12 non_role_grantee_list granted_by",
"revoke0 : rev_grant_option $$11 usage_privilege ON GENERATOR symbol_generator_name FROM $$12 non_role_grantee_list granted_by",
"revoke0 : rev_grant_option $$11 usage_privilege ON SEQUENCE symbol_generator_name FROM $$12 non_role_grantee_list granted_by",
"$$13 :",
"revoke0 : rev_grant_option $$11 ddl_privileges object FROM $$13 non_role_grantee_list granted_by",
"revoke0 : rev_grant_option $$11 db_ddl_privileges DATABASE FROM $$13 non_role_grantee_list granted_by",
"$$14 :",
"revoke0 : rev_admin_option $$14 role_name_list FROM $$5 role_grantee_list granted_by",
"revoke0 : ALL ON ALL FROM $$5 non_role_grantee_list",
"rev_grant_option :",
"rev_grant_option : GRANT OPTION FOR",
"rev_admin_option :",
"rev_admin_option : ADMIN OPTION FOR",
"$$15 :",
"non_role_grantee_list : $$15 grantee",
"non_role_grantee_list : $$15 user_grantee",
"$$16 :",
"non_role_grantee_list : non_role_grantee_list ',' $$16 grantee",
"non_role_grantee_list : non_role_grantee_list ',' $$16 user_grantee",
"grantee : PROCEDURE symbol_procedure_name",
"grantee : FUNCTION symbol_UDF_name",
"grantee : PACKAGE symbol_package_name",
"grantee : TRIGGER symbol_trigger_name",
"grantee : VIEW symbol_view_name",
"grantee : ROLE symbol_role_name",
"grantee : SYSTEM PRIVILEGE valid_symbol_name",
"user_grantee : symbol_user_name",
"user_grantee : USER symbol_user_name",
"user_grantee : GROUP symbol_user_name",
"role_name_list : $$2 role_name",
"$$17 :",
"role_name_list : role_name_list ',' $$17 role_name",
"role_name : symbol_role_name",
"role_name : DEFAULT symbol_role_name",
"role_grantee_list : $$15 role_grantee",
"role_grantee_list : role_grantee_list ',' $$16 role_grantee",
"role_grantee : symbol_user_name",
"role_grantee : USER symbol_user_name",
"role_grantee : ROLE symbol_user_name",
"declare : DECLARE declare_clause",
"declare_clause : FILTER filter_decl_clause",
"declare_clause : EXTERNAL FUNCTION udf_decl_clause",
"$$18 :",
"$$19 :",
"$$20 :",
"udf_decl_clause : symbol_UDF_name $$18 $$19 arg_desc_list1 RETURNS $$20 return_value1 ENTRY_POINT utf_string MODULE_NAME utf_string",
"udf_data_type : simple_type",
"udf_data_type : BLOB",
"udf_data_type : CSTRING '(' pos_short_integer ')' charset_clause",
"arg_desc_list1 :",
"$$21 :",
"arg_desc_list1 : $$21 arg_desc_list",
"$$22 :",
"arg_desc_list1 : '(' $$22 arg_desc_list ')'",
"arg_desc_list : $$21 arg_desc",
"$$23 :",
"arg_desc_list : arg_desc_list ',' $$23 arg_desc",
"arg_desc : udf_data_type param_mechanism",
"param_mechanism :",
"param_mechanism : BY DESCRIPTOR",
"param_mechanism : BY SCALAR_ARRAY",
"param_mechanism : NULL",
"$$24 :",
"return_value1 : $$24 return_value",
"$$25 :",
"return_value1 : '(' $$25 return_value ')'",
"return_value : udf_data_type return_mechanism",
"return_value : PARAMETER pos_short_integer",
"return_mechanism :",
"return_mechanism : BY VALUE",
"return_mechanism : BY DESCRIPTOR",
"return_mechanism : FREE_IT",
"return_mechanism : BY DESCRIPTOR FREE_IT",
"filter_decl_clause : symbol_filter_name INPUT_TYPE blob_filter_subtype OUTPUT_TYPE blob_filter_subtype ENTRY_POINT utf_string MODULE_NAME utf_string",
"blob_filter_subtype : symbol_blob_subtype_name",
"blob_filter_subtype : signed_short_integer",
"create : CREATE create_clause",
"create_clause : EXCEPTION exception_clause",
"$$26 :",
"$$27 :",
"create_clause : unique_opt order_direction INDEX symbol_index_name ON simple_table_name $$26 $$27 index_definition",
"create_clause : FUNCTION function_clause",
"create_clause : PROCEDURE procedure_clause",
"create_clause : TABLE table_clause",
"create_clause : GLOBAL TEMPORARY TABLE gtt_table_clause",
"create_clause : TRIGGER trigger_clause",
"create_clause : VIEW view_clause",
"create_clause : GENERATOR generator_clause",
"create_clause : SEQUENCE generator_clause",
"create_clause : DATABASE db_clause",
"create_clause : DOMAIN domain_clause",
"create_clause : SHADOW shadow_clause",
"create_clause : ROLE role_clause",
"create_clause : COLLATION collation_clause",
"create_clause : USER create_user_clause",
"create_clause : PACKAGE package_clause",
"create_clause : PACKAGE BODY package_body_clause",
"$$28 :",
"create_clause : MAPPING $$28 create_map_clause",
"$$29 :",
"create_clause : GLOBAL MAPPING $$29 create_map_clause",
"recreate : RECREATE recreate_clause",
"recreate_clause : PROCEDURE procedure_clause",
"recreate_clause : FUNCTION function_clause",
"recreate_clause : TABLE table_clause",
"recreate_clause : GLOBAL TEMPORARY TABLE gtt_table_clause",
"recreate_clause : VIEW view_clause",
"recreate_clause : TRIGGER trigger_clause",
"recreate_clause : PACKAGE package_clause",
"recreate_clause : PACKAGE BODY package_body_clause",
"recreate_clause : EXCEPTION exception_clause",
"recreate_clause : GENERATOR generator_clause",
"recreate_clause : SEQUENCE generator_clause",
"recreate_clause : USER create_user_clause",
"create_or_alter : CREATE OR ALTER replace_clause",
"replace_clause : PROCEDURE replace_procedure_clause",
"replace_clause : FUNCTION replace_function_clause",
"replace_clause : TRIGGER replace_trigger_clause",
"replace_clause : PACKAGE replace_package_clause",
"replace_clause : VIEW replace_view_clause",
"replace_clause : EXCEPTION replace_exception_clause",
"replace_clause : GENERATOR replace_sequence_clause",
"replace_clause : SEQUENCE replace_sequence_clause",
"replace_clause : USER replace_user_clause",
"replace_clause : MAPPING $$28 replace_map_clause",
"replace_clause : GLOBAL MAPPING $$29 replace_map_clause",
"exception_clause : symbol_exception_name sql_string",
"replace_exception_clause : symbol_exception_name sql_string",
"alter_exception_clause : symbol_exception_name sql_string",
"unique_opt :",
"unique_opt : UNIQUE",
"index_definition : column_list",
"index_definition : column_parens",
"index_definition : computed_by '(' value ')'",
"$$30 :",
"$$31 :",
"shadow_clause : pos_short_integer manual_auto conditional utf_string first_file_length $$30 $$31 sec_shadow_files",
"manual_auto :",
"manual_auto : MANUAL",
"manual_auto : AUTO",
"conditional :",
"conditional : CONDITIONAL",
"first_file_length :",
"first_file_length : LENGTH equals long_integer page_noise",
"sec_shadow_files :",
"$$32 :",
"sec_shadow_files : $$32 db_file_list",
"db_file_list : db_file",
"db_file_list : db_file_list db_file",
"$$33 :",
"$$34 :",
"domain_clause : symbol_column_name as_opt data_type domain_default_opt $$33 $$34 domain_constraints_opt collate_clause",
"domain_constraints_opt :",
"domain_constraints_opt : $$34 domain_constraints",
"domain_constraints : $$34 domain_constraint",
"$$35 :",
"domain_constraints : domain_constraints $$35 domain_constraint",
"domain_constraint : null_constraint",
"domain_constraint : check_constraint",
"as_opt :",
"as_opt : AS",
"domain_default : DEFAULT default_value",
"domain_default_opt :",
"domain_default_opt : domain_default",
"null_constraint : NOT NULL",
"check_constraint : CHECK '(' search_condition ')'",
"$$36 :",
"$$37 :",
"generator_clause : symbol_generator_name $$36 $$37 create_sequence_options",
"create_sequence_options :",
"$$38 :",
"create_sequence_options : $$37 create_seq_option $$38 create_sequence_options",
"create_seq_option : $$37 start_with_opt",
"create_seq_option : $$37 step_option",
"start_with_opt : START WITH sequence_value",
"step_option : INCREMENT by_noise signed_long_integer",
"by_noise :",
"by_noise : BY",
"$$39 :",
"replace_sequence_clause : symbol_generator_name $$39 $$37 replace_sequence_options",
"replace_sequence_options :",
"replace_sequence_options : $$37 replace_seq_option $$38 replace_sequence_options",
"replace_seq_option : RESTART",
"replace_seq_option : $$37 start_with_opt",
"replace_seq_option : $$37 step_option",
"$$40 :",
"alter_sequence_clause : symbol_generator_name $$40 $$37 alter_sequence_options",
"alter_sequence_options :",
"alter_sequence_options : $$37 alter_seq_option $$38 alter_sequence_options",
"alter_seq_option : $$37 restart_option",
"alter_seq_option : $$37 step_option",
"restart_option : RESTART with_opt",
"with_opt :",
"with_opt : WITH sequence_value",
"set_generator_clause : SET GENERATOR symbol_generator_name TO sequence_value",
"sequence_value : signed_long_integer",
"sequence_value : NUMBER64BIT",
"sequence_value : '-' NUMBER64BIT",
"sequence_value : '-' LIMIT64_INT",
"$$41 :",
"$$42 :",
"role_clause : symbol_role_name $$41 $$42 opt_system_privileges",
"opt_system_privileges :",
"opt_system_privileges : $$42 set_system_privileges",
"opt_system_privileges : $$42 drop_system_privileges",
"$$43 :",
"set_system_privileges : SET SYSTEM PRIVILEGES TO $$43 system_privileges_list",
"drop_system_privileges : DROP SYSTEM PRIVILEGES",
"system_privileges_list : $$42 system_privilege",
"$$44 :",
"system_privileges_list : system_privileges_list ',' $$44 system_privilege",
"system_privilege : valid_symbol_name",
"$$45 :",
"$$46 :",
"$$47 :",
"$$48 :",
"collation_clause : symbol_collation_name FOR symbol_character_set_name $$45 $$46 collation_sequence_definition $$47 collation_attribute_list_opt $$48 collation_specific_attribute_opt",
"collation_sequence_definition :",
"collation_sequence_definition : FROM symbol_collation_name",
"collation_sequence_definition : FROM EXTERNAL '(' utf_string ')'",
"collation_attribute_list_opt :",
"collation_attribute_list_opt : $$46 collation_attribute_list",
"collation_attribute_list : $$46 collation_attribute",
"$$49 :",
"collation_attribute_list : collation_attribute_list $$49 collation_attribute",
"collation_attribute : $$46 collation_pad_attribute",
"collation_attribute : $$46 collation_case_attribute",
"collation_attribute : $$46 collation_accent_attribute",
"collation_pad_attribute : NO PAD",
"collation_pad_attribute : PAD SPACE",
"collation_case_attribute : CASE SENSITIVE",
"collation_case_attribute : CASE INSENSITIVE",
"collation_accent_attribute : ACCENT SENSITIVE",
"collation_accent_attribute : ACCENT INSENSITIVE",
"collation_specific_attribute_opt :",
"collation_specific_attribute_opt : utf_string",
"alter_charset_clause : symbol_character_set_name SET DEFAULT COLLATION symbol_collation_name",
"alter_eds_conn_pool_clause : SET SIZE unsigned_short_integer",
"alter_eds_conn_pool_clause : SET LIFETIME unsigned_short_integer eds_pool_lifetime_mult",
"alter_eds_conn_pool_clause : CLEAR sql_string",
"alter_eds_conn_pool_clause : CLEAR ALL",
"alter_eds_conn_pool_clause : CLEAR OLDEST",
"eds_pool_lifetime_mult : HOUR",
"eds_pool_lifetime_mult : MINUTE",
"eds_pool_lifetime_mult : SECOND",
"$$50 :",
"$$51 :",
"$$52 :",
"db_clause : db_name $$50 $$51 db_initial_desc1 $$52 db_rem_desc1",
"equals :",
"equals : '='",
"db_name : utf_string",
"db_initial_desc1 :",
"db_initial_desc1 : $$51 db_initial_desc",
"db_initial_desc : $$51 db_initial_option",
"$$53 :",
"db_initial_desc : db_initial_desc $$53 db_initial_option",
"db_initial_option : PAGE_SIZE equals NUMBER32BIT",
"db_initial_option : USER symbol_user_name",
"db_initial_option : USER utf_string",
"db_initial_option : ROLE valid_symbol_name",
"db_initial_option : ROLE utf_string",
"db_initial_option : PASSWORD utf_string",
"db_initial_option : SET NAMES utf_string",
"db_initial_option : LENGTH equals long_integer page_noise",
"db_rem_desc1 :",
"db_rem_desc1 : $$51 db_rem_desc",
"db_rem_desc : $$51 db_rem_option",
"db_rem_desc : db_rem_desc $$53 db_rem_option",
"db_rem_option : db_file",
"db_rem_option : DEFAULT CHARACTER SET symbol_character_set_name",
"db_rem_option : DEFAULT CHARACTER SET symbol_character_set_name COLLATION symbol_collation_name",
"db_rem_option : DIFFERENCE FILE utf_string",
"$$54 :",
"$$55 :",
"db_file : FILE utf_string $$54 $$55 file_desc1",
"file_desc1 :",
"file_desc1 : $$55 file_desc",
"file_desc : $$55 file_clause",
"$$56 :",
"file_desc : file_desc $$56 file_clause",
"file_clause : STARTING file_clause_noise long_integer",
"file_clause : LENGTH equals long_integer page_noise",
"file_clause_noise :",
"file_clause_noise : AT",
"file_clause_noise : AT PAGE",
"page_noise :",
"page_noise : PAGE",
"page_noise : PAGES",
"$$57 :",
"$$58 :",
"$$59 :",
"table_clause : simple_table_name external_file $$57 '(' $$58 table_elements ')' $$59 table_attributes",
"table_attributes :",
"$$60 :",
"$$61 :",
"table_attributes : $$60 table_attribute $$61 table_attributes",
"table_attribute : sql_security_clause",
"table_attribute : publication_state",
"sql_security_clause : SQL SECURITY DEFINER",
"sql_security_clause : SQL SECURITY INVOKER",
"sql_security_clause_opt :",
"sql_security_clause_opt : sql_security_clause",
"publication_state : ENABLE PUBLICATION",
"publication_state : DISABLE PUBLICATION",
"$$62 :",
"$$63 :",
"gtt_table_clause : simple_table_name $$62 '(' $$58 table_elements ')' $$63 gtt_ops",
"$$64 :",
"gtt_ops : $$64 gtt_op",
"$$65 :",
"gtt_ops : gtt_ops ',' $$65 gtt_op",
"gtt_op :",
"gtt_op : sql_security_clause_opt",
"gtt_op : ON COMMIT DELETE ROWS",
"gtt_op : ON COMMIT PRESERVE ROWS",
"external_file :",
"external_file : EXTERNAL FILE utf_string",
"external_file : EXTERNAL utf_string",
"table_elements : $$64 table_element",
"table_elements : table_elements ',' $$65 table_element",
"$$66 :",
"table_element : $$66 column_def",
"table_element : $$66 table_constraint_definition",
"$$67 :",
"$$68 :",
"column_def : symbol_column_name data_type_or_domain domain_default_opt $$67 $$68 column_constraint_clause collate_clause",
"$$69 :",
"column_def : symbol_column_name data_type_or_domain identity_clause $$69 $$68 column_constraint_clause collate_clause",
"column_def : symbol_column_name non_array_type def_computed",
"column_def : symbol_column_name def_computed",
"$$70 :",
"$$71 :",
"identity_clause : GENERATED identity_clause_type AS IDENTITY $$70 $$71 identity_clause_options_opt",
"identity_clause_type : BY DEFAULT",
"identity_clause_type : ALWAYS",
"identity_clause_options_opt :",
"$$72 :",
"identity_clause_options_opt : '(' $$72 identity_clause_options ')'",
"identity_clause_options : identity_clause_options $$72 identity_clause_option",
"identity_clause_options : $$71 identity_clause_option",
"identity_clause_option : START WITH sequence_value",
"identity_clause_option : INCREMENT by_noise signed_long_integer",
"def_computed : computed_clause '(' value ')'",
"computed_clause : computed_by",
"computed_clause : generated_always_clause",
"generated_always_clause : GENERATED ALWAYS AS",
"computed_by : COMPUTED BY",
"computed_by : COMPUTED",
"data_type_or_domain : data_type",
"data_type_or_domain : symbol_column_name",
"collate_clause :",
"collate_clause : COLLATE symbol_collation_name",
"data_type_descriptor : data_type",
"data_type_descriptor : TYPE OF symbol_column_name",
"data_type_descriptor : TYPE OF COLUMN symbol_column_name '.' symbol_column_name",
"data_type_descriptor : symbol_column_name",
"default_value : constant",
"default_value : current_user",
"default_value : current_role",
"default_value : internal_info",
"default_value : null_value",
"default_value : datetime_value_expression",
"column_constraint_clause :",
"$$73 :",
"column_constraint_clause : $$73 column_constraint_list",
"column_constraint_list : $$73 column_constraint_def",
"$$74 :",
"column_constraint_list : column_constraint_list $$74 column_constraint_def",
"column_constraint_def : constraint_name_opt $$74 column_constraint",
"column_constraint : null_constraint",
"column_constraint : check_constraint",
"column_constraint : REFERENCES symbol_table_name column_parens_opt referential_trigger_action constraint_index_opt",
"column_constraint : UNIQUE constraint_index_opt",
"column_constraint : PRIMARY KEY constraint_index_opt",
"$$75 :",
"table_constraint_definition : constraint_name_opt $$75 table_constraint",
"constraint_name_opt :",
"constraint_name_opt : CONSTRAINT symbol_constraint_name",
"table_constraint : UNIQUE column_parens constraint_index_opt",
"table_constraint : PRIMARY KEY column_parens constraint_index_opt",
"table_constraint : FOREIGN KEY column_parens REFERENCES symbol_table_name column_parens_opt referential_trigger_action constraint_index_opt",
"table_constraint : check_constraint",
"constraint_index_opt :",
"constraint_index_opt : USING order_direction INDEX symbol_index_name",
"referential_trigger_action :",
"referential_trigger_action : update_rule",
"referential_trigger_action : delete_rule",
"referential_trigger_action : delete_rule update_rule",
"referential_trigger_action : update_rule delete_rule",
"update_rule : ON UPDATE referential_action",
"delete_rule : ON DELETE referential_action",
"referential_action : CASCADE",
"referential_action : SET DEFAULT",
"referential_action : SET NULL",
"referential_action : NO ACTION",
"procedure_clause : psql_procedure_clause",
"procedure_clause : external_procedure_clause",
"psql_procedure_clause : procedure_clause_start sql_security_clause_opt AS local_declarations_opt full_proc_block",
"external_procedure_clause : procedure_clause_start external_clause external_body_clause_opt",
"$$76 :",
"$$77 :",
"$$78 :",
"procedure_clause_start : symbol_procedure_name $$76 $$77 input_parameters $$78 output_parameters",
"alter_procedure_clause : procedure_clause",
"replace_procedure_clause : procedure_clause",
"input_parameters :",
"input_parameters : '(' ')'",
"input_parameters : '(' $$22 input_proc_parameters ')'",
"output_parameters :",
"output_parameters : RETURNS '(' $$23 output_proc_parameters ')'",
"input_proc_parameters : $$21 input_proc_parameter",
"input_proc_parameters : input_proc_parameters ',' $$23 input_proc_parameter",
"input_proc_parameter : column_domain_or_non_array_type collate_clause default_par_opt",
"output_proc_parameters : output_proc_parameter",
"output_proc_parameters : output_proc_parameters ',' $$23 output_proc_parameter",
"output_proc_parameter : column_domain_or_non_array_type collate_clause",
"column_domain_or_non_array_type : symbol_column_name domain_or_non_array_type",
"default_par_opt :",
"default_par_opt : DEFAULT default_value",
"default_par_opt : '=' default_value",
"function_clause : psql_function_clause",
"function_clause : external_function_clause",
"psql_function_clause : function_clause_start sql_security_clause_opt AS local_declarations_opt full_proc_block",
"external_function_clause : function_clause_start external_clause external_body_clause_opt",
"$$79 :",
"function_clause_start : symbol_UDF_name $$79 $$19 input_parameters RETURNS domain_or_non_array_type collate_clause deterministic_opt",
"deterministic_opt :",
"deterministic_opt : NOT DETERMINISTIC",
"deterministic_opt : DETERMINISTIC",
"external_clause : EXTERNAL NAME utf_string ENGINE valid_symbol_name",
"external_clause : EXTERNAL ENGINE valid_symbol_name",
"external_body_clause_opt :",
"external_body_clause_opt : AS utf_string",
"alter_function_clause : function_clause",
"replace_function_clause : function_clause",
"package_clause : symbol_package_name sql_security_clause_opt AS BEGIN package_items_opt END",
"package_items_opt : package_items",
"package_items_opt :",
"package_items : package_item",
"package_items : package_items package_item",
"package_item : FUNCTION function_clause_start ';'",
"package_item : PROCEDURE procedure_clause_start ';'",
"alter_package_clause : package_clause",
"replace_package_clause : package_clause",
"package_body_clause : symbol_package_name AS BEGIN package_items package_body_items_opt END",
"package_body_clause : symbol_package_name AS BEGIN package_body_items_opt END",
"package_body_items_opt :",
"package_body_items_opt : package_body_items",
"package_body_items : package_body_item",
"package_body_items : package_body_items package_body_item",
"package_body_item : FUNCTION psql_function_clause",
"package_body_item : FUNCTION external_function_clause ';'",
"package_body_item : PROCEDURE psql_procedure_clause",
"package_body_item : PROCEDURE external_procedure_clause ';'",
"local_declarations_opt : local_forward_declarations_opt local_nonforward_declarations_opt",
"local_forward_declarations_opt :",
"local_forward_declarations_opt : local_forward_declarations",
"local_forward_declarations : local_forward_declaration",
"local_forward_declarations : local_forward_declarations local_forward_declaration",
"local_forward_declaration : local_declaration_subproc_start ';'",
"local_forward_declaration : local_declaration_subfunc_start ';'",
"local_nonforward_declarations_opt :",
"local_nonforward_declarations_opt : local_nonforward_declarations",
"local_nonforward_declarations : local_nonforward_declaration",
"local_nonforward_declarations : local_nonforward_declarations local_nonforward_declaration",
"local_nonforward_declaration : DECLARE var_decl_opt local_declaration_item ';'",
"local_nonforward_declaration : local_declaration_subproc_start AS local_declarations_opt full_proc_block",
"local_nonforward_declaration : local_declaration_subfunc_start AS local_declarations_opt full_proc_block",
"$$80 :",
"$$81 :",
"$$82 :",
"local_declaration_subproc_start : DECLARE PROCEDURE symbol_procedure_name $$80 $$81 input_parameters $$82 output_parameters",
"$$83 :",
"$$84 :",
"local_declaration_subfunc_start : DECLARE FUNCTION symbol_UDF_name $$83 $$84 input_parameters RETURNS domain_or_non_array_type collate_clause deterministic_opt",
"local_declaration_item : var_declaration_item",
"local_declaration_item : cursor_declaration_item",
"var_declaration_item : column_domain_or_non_array_type collate_clause default_par_opt",
"var_decl_opt :",
"var_decl_opt : VARIABLE",
"cursor_declaration_item : symbol_cursor_name scroll_opt CURSOR FOR '(' select ')'",
"scroll_opt :",
"scroll_opt : NO SCROLL",
"scroll_opt : SCROLL",
"proc_block : proc_statement",
"proc_block : full_proc_block",
"full_proc_block : BEGIN full_proc_block_body END",
"full_proc_block_body :",
"full_proc_block_body : proc_statements",
"full_proc_block_body : proc_statements excp_hndl_statements",
"proc_statements : proc_block",
"proc_statements : proc_statements proc_block",
"proc_statement : simple_proc_statement ';'",
"proc_statement : complex_proc_statement",
"simple_proc_statement : assignment_statement",
"simple_proc_statement : insert",
"simple_proc_statement : merge",
"simple_proc_statement : update",
"simple_proc_statement : update_or_insert",
"simple_proc_statement : delete",
"simple_proc_statement : singleton_select",
"simple_proc_statement : exec_procedure",
"simple_proc_statement : exec_sql",
"simple_proc_statement : exec_into",
"simple_proc_statement : exec_function",
"simple_proc_statement : excp_statement",
"simple_proc_statement : raise_statement",
"simple_proc_statement : post_event",
"simple_proc_statement : cursor_statement",
"simple_proc_statement : breakleave",
"simple_proc_statement : continue",
"simple_proc_statement : SUSPEND",
"simple_proc_statement : EXIT",
"simple_proc_statement : RETURN value",
"simple_proc_statement : mng_statement",
"assignment_statement : assignment",
"assignment_statement : ':' assignment",
"complex_proc_statement : in_autonomous_transaction",
"complex_proc_statement : if_then_else",
"complex_proc_statement : while",
"complex_proc_statement : for_select",
"complex_proc_statement : for_exec_into",
"in_autonomous_transaction : IN AUTONOMOUS TRANSACTION DO proc_block",
"excp_statement : EXCEPTION symbol_exception_name",
"excp_statement : EXCEPTION symbol_exception_name value",
"excp_statement : EXCEPTION symbol_exception_name USING '(' value_list ')'",
"raise_statement : EXCEPTION",
"$$85 :",
"$$86 :",
"for_select : label_def_opt FOR select $$85 $$86 for_select_into_cursor DO proc_block",
"for_select_into_cursor : into_variable_list cursor_def_opt",
"for_select_into_cursor : into_variable_list_opt cursor_def",
"into_variable_list_opt :",
"into_variable_list_opt : into_variable_list",
"into_variable_list : INTO variable_list",
"$$87 :",
"$$88 :",
"$$89 :",
"exec_sql : EXECUTE STATEMENT $$87 $$88 exec_stmt_inputs $$89 exec_stmt_options",
"exec_into : exec_sql INTO variable_list",
"for_exec_into : label_def_opt FOR exec_into DO proc_block",
"exec_stmt_inputs : value",
"$$90 :",
"exec_stmt_inputs : '(' value ')' '(' $$90 named_params_list ')'",
"exec_stmt_inputs : '(' value ')' '(' $$90 not_named_params_list ')'",
"named_params_list : $$88 named_param",
"named_params_list : named_params_list ',' $$89 named_param",
"named_param : symbol_variable_name BIND_PARAM value",
"named_param : EXCESS symbol_variable_name BIND_PARAM value",
"not_named_params_list : $$88 not_named_param",
"not_named_params_list : not_named_params_list ',' $$89 not_named_param",
"not_named_param : value",
"exec_stmt_options :",
"exec_stmt_options : $$88 exec_stmt_options_list",
"$$91 :",
"exec_stmt_options_list : exec_stmt_options_list $$91 exec_stmt_option",
"exec_stmt_options_list : $$88 exec_stmt_option",
"exec_stmt_option : ON EXTERNAL DATA SOURCE value",
"exec_stmt_option : ON EXTERNAL value",
"exec_stmt_option : AS USER value",
"exec_stmt_option : PASSWORD value",
"exec_stmt_option : ROLE value",
"exec_stmt_option : WITH AUTONOMOUS TRANSACTION",
"exec_stmt_option : WITH COMMON TRANSACTION",
"exec_stmt_option : WITH CALLER PRIVILEGES",
"if_then_else : IF '(' search_condition ')' THEN proc_block ELSE proc_block",
"if_then_else : IF '(' search_condition ')' THEN proc_block",
"post_event : POST_EVENT value event_argument_opt",
"event_argument_opt :",
"singleton_select : select INTO variable_list",
"variable : ':' symbol_variable_name",
"variable_list : variable",
"variable_list : column_name",
"variable_list : variable_list ',' column_name",
"variable_list : variable_list ',' variable",
"while : label_def_opt WHILE '(' search_condition ')' DO proc_block",
"label_def_opt :",
"label_def_opt : symbol_label_name ':'",
"breakleave : BREAK",
"breakleave : LEAVE label_use_opt",
"continue : CONTINUE label_use_opt",
"label_use_opt :",
"label_use_opt : symbol_label_name",
"cursor_def_opt :",
"cursor_def_opt : cursor_def",
"cursor_def : AS CURSOR symbol_cursor_name",
"excp_hndl_statements : excp_hndl_statement",
"excp_hndl_statements : excp_hndl_statements excp_hndl_statement",
"$$92 :",
"$$93 :",
"excp_hndl_statement : WHEN $$92 $$93 errors DO proc_block",
"$$94 :",
"errors : $$94 err",
"$$95 :",
"errors : errors ',' $$95 err",
"err : SQLCODE signed_short_integer",
"err : SQLSTATE STRING",
"err : GDSCODE symbol_gdscode_name",
"err : EXCEPTION symbol_exception_name",
"err : ANY",
"cursor_statement : open_cursor",
"cursor_statement : fetch_cursor",
"cursor_statement : close_cursor",
"open_cursor : OPEN symbol_cursor_name",
"close_cursor : CLOSE symbol_cursor_name",
"$$96 :",
"$$97 :",
"fetch_cursor : FETCH $$96 $$97 fetch_scroll FROM symbol_cursor_name into_variable_list_opt",
"fetch_cursor : FETCH symbol_cursor_name into_variable_list_opt",
"fetch_scroll : FIRST",
"fetch_scroll : LAST",
"fetch_scroll : PRIOR",
"fetch_scroll : NEXT",
"fetch_scroll : ABSOLUTE value",
"fetch_scroll : RELATIVE value",
"exec_procedure : EXECUTE PROCEDURE symbol_procedure_name proc_inputs proc_outputs_opt",
"exec_procedure : EXECUTE PROCEDURE symbol_package_name '.' symbol_procedure_name proc_inputs proc_outputs_opt",
"proc_inputs :",
"proc_inputs : value_list",
"proc_inputs : '(' value_list ')'",
"proc_outputs_opt :",
"proc_outputs_opt : RETURNING_VALUES variable_list",
"proc_outputs_opt : RETURNING_VALUES '(' variable_list ')'",
"$$98 :",
"$$99 :",
"$$100 :",
"exec_block : EXECUTE BLOCK $$98 $$99 block_input_params $$100 output_parameters AS local_declarations_opt full_proc_block",
"block_input_params :",
"block_input_params : '(' $$22 block_parameters ')'",
"block_parameters : $$21 block_parameter",
"block_parameters : block_parameters ',' $$23 block_parameter",
"block_parameter : column_domain_or_non_array_type collate_clause '=' parameter",
"view_clause : simple_table_name column_parens_opt AS select_expr check_opt",
"replace_view_clause : view_clause",
"alter_view_clause : view_clause",
"check_opt :",
"check_opt : WITH CHECK OPTION",
"trigger_clause : create_trigger_start trg_sql_security_clause AS local_declarations_opt full_proc_block",
"trigger_clause : create_trigger_start external_clause external_body_clause_opt",
"$$101 :",
"$$102 :",
"create_trigger_start : symbol_trigger_name $$101 $$102 create_trigger_common",
"$$103 :",
"create_trigger_common : trigger_active $$103 trigger_type trigger_position",
"create_trigger_common : FOR symbol_table_name trigger_active table_trigger_type trigger_position",
"replace_trigger_clause : trigger_clause",
"trigger_active : ACTIVE",
"trigger_active : INACTIVE",
"trigger_active :",
"trigger_type : table_trigger_type trigger_position ON symbol_table_name",
"trigger_type : ON trigger_db_type",
"trigger_type : trigger_type_prefix trigger_ddl_type",
"table_trigger_type : trigger_type_prefix trigger_type_suffix",
"trigger_db_type : CONNECT",
"trigger_db_type : DISCONNECT",
"trigger_db_type : TRANSACTION START",
"trigger_db_type : TRANSACTION COMMIT",
"trigger_db_type : TRANSACTION ROLLBACK",
"trigger_ddl_type : trigger_ddl_type_items",
"trigger_ddl_type : ANY DDL STATEMENT",
"trigger_ddl_type_items : CREATE TABLE",
"trigger_ddl_type_items : ALTER TABLE",
"trigger_ddl_type_items : DROP TABLE",
"trigger_ddl_type_items : CREATE PROCEDURE",
"trigger_ddl_type_items : ALTER PROCEDURE",
"trigger_ddl_type_items : DROP PROCEDURE",
"trigger_ddl_type_items : CREATE FUNCTION",
"trigger_ddl_type_items : ALTER FUNCTION",
"trigger_ddl_type_items : DROP FUNCTION",
"trigger_ddl_type_items : CREATE TRIGGER",
"trigger_ddl_type_items : ALTER TRIGGER",
"trigger_ddl_type_items : DROP TRIGGER",
"trigger_ddl_type_items : CREATE EXCEPTION",
"trigger_ddl_type_items : ALTER EXCEPTION",
"trigger_ddl_type_items : DROP EXCEPTION",
"trigger_ddl_type_items : CREATE VIEW",
"trigger_ddl_type_items : ALTER VIEW",
"trigger_ddl_type_items : DROP VIEW",
"trigger_ddl_type_items : CREATE DOMAIN",
"trigger_ddl_type_items : ALTER DOMAIN",
"trigger_ddl_type_items : DROP DOMAIN",
"trigger_ddl_type_items : CREATE ROLE",
"trigger_ddl_type_items : ALTER ROLE",
"trigger_ddl_type_items : DROP ROLE",
"trigger_ddl_type_items : CREATE SEQUENCE",
"trigger_ddl_type_items : ALTER SEQUENCE",
"trigger_ddl_type_items : DROP SEQUENCE",
"trigger_ddl_type_items : CREATE USER",
"trigger_ddl_type_items : ALTER USER",
"trigger_ddl_type_items : DROP USER",
"trigger_ddl_type_items : CREATE INDEX",
"trigger_ddl_type_items : ALTER INDEX",
"trigger_ddl_type_items : DROP INDEX",
"trigger_ddl_type_items : CREATE COLLATION",
"trigger_ddl_type_items : DROP COLLATION",
"trigger_ddl_type_items : ALTER CHARACTER SET",
"trigger_ddl_type_items : CREATE PACKAGE",
"trigger_ddl_type_items : ALTER PACKAGE",
"trigger_ddl_type_items : DROP PACKAGE",
"trigger_ddl_type_items : CREATE PACKAGE BODY",
"trigger_ddl_type_items : DROP PACKAGE BODY",
"trigger_ddl_type_items : CREATE MAPPING",
"trigger_ddl_type_items : ALTER MAPPING",
"trigger_ddl_type_items : DROP MAPPING",
"trigger_ddl_type_items : trigger_ddl_type OR trigger_ddl_type",
"trigger_type_prefix : BEFORE",
"trigger_type_prefix : AFTER",
"trigger_type_suffix : INSERT",
"trigger_type_suffix : UPDATE",
"trigger_type_suffix : DELETE",
"trigger_type_suffix : INSERT OR UPDATE",
"trigger_type_suffix : INSERT OR DELETE",
"trigger_type_suffix : UPDATE OR INSERT",
"trigger_type_suffix : UPDATE OR DELETE",
"trigger_type_suffix : DELETE OR INSERT",
"trigger_type_suffix : DELETE OR UPDATE",
"trigger_type_suffix : INSERT OR UPDATE OR DELETE",
"trigger_type_suffix : INSERT OR DELETE OR UPDATE",
"trigger_type_suffix : UPDATE OR INSERT OR DELETE",
"trigger_type_suffix : UPDATE OR DELETE OR INSERT",
"trigger_type_suffix : DELETE OR INSERT OR UPDATE",
"trigger_type_suffix : DELETE OR UPDATE OR INSERT",
"trigger_position :",
"trigger_position : POSITION nonneg_short_integer",
"alter : ALTER alter_clause",
"alter : set_generator_clause",
"alter_clause : EXCEPTION alter_exception_clause",
"$$104 :",
"alter_clause : TABLE simple_table_name $$104 $$60 alter_ops",
"alter_clause : VIEW alter_view_clause",
"alter_clause : TRIGGER alter_trigger_clause",
"alter_clause : PROCEDURE alter_procedure_clause",
"alter_clause : PACKAGE alter_package_clause",
"$$105 :",
"alter_clause : DATABASE $$105 $$51 alter_db",
"alter_clause : DOMAIN alter_domain",
"alter_clause : INDEX alter_index_clause",
"alter_clause : EXTERNAL FUNCTION alter_udf_clause",
"alter_clause : FUNCTION alter_function_clause",
"alter_clause : ROLE alter_role_clause",
"alter_clause : USER alter_user_clause",
"alter_clause : CURRENT USER alter_cur_user_clause",
"alter_clause : CHARACTER SET alter_charset_clause",
"alter_clause : GENERATOR alter_sequence_clause",
"alter_clause : SEQUENCE alter_sequence_clause",
"alter_clause : MAPPING $$28 alter_map_clause",
"alter_clause : GLOBAL MAPPING $$29 alter_map_clause",
"alter_clause : EXTERNAL CONNECTIONS POOL alter_eds_conn_pool_clause",
"$$106 :",
"$$107 :",
"alter_domain : keyword_or_column $$106 $$107 alter_domain_ops",
"alter_domain_ops : $$107 alter_domain_op",
"$$108 :",
"alter_domain_ops : alter_domain_ops $$108 alter_domain_op",
"alter_domain_op : SET domain_default",
"alter_domain_op : ADD CONSTRAINT check_constraint",
"alter_domain_op : ADD check_constraint",
"alter_domain_op : DROP DEFAULT",
"alter_domain_op : DROP CONSTRAINT",
"alter_domain_op : DROP NOT NULL",
"alter_domain_op : SET NOT NULL",
"alter_domain_op : TO symbol_column_name",
"alter_domain_op : TYPE non_array_type",
"alter_ops : $$60 alter_op",
"alter_ops : alter_ops ',' $$61 alter_op",
"alter_op : DROP symbol_column_name drop_behaviour",
"alter_op : DROP CONSTRAINT symbol_constraint_name",
"alter_op : ADD $$75 column_def",
"alter_op : ADD $$75 table_constraint_definition",
"alter_op : col_opt alter_column_name POSITION pos_short_integer",
"alter_op : col_opt alter_column_name TO symbol_column_name",
"alter_op : col_opt alter_column_name DROP NOT NULL",
"alter_op : col_opt alter_column_name SET NOT NULL",
"alter_op : col_opt symbol_column_name TYPE alter_data_type_or_domain",
"alter_op : col_opt symbol_column_name TYPE non_array_type def_computed",
"alter_op : col_opt symbol_column_name def_computed",
"alter_op : col_opt symbol_column_name SET domain_default",
"alter_op : col_opt symbol_column_name DROP DEFAULT",
"$$109 :",
"alter_op : col_opt symbol_column_name $$109 $$71 alter_identity_clause_spec",
"alter_op : col_opt symbol_column_name DROP IDENTITY",
"alter_op : ALTER SQL SECURITY DEFINER",
"alter_op : ALTER SQL SECURITY INVOKER",
"alter_op : DROP SQL SECURITY",
"alter_op : ENABLE PUBLICATION",
"alter_op : DISABLE PUBLICATION",
"alter_column_name : keyword_or_column",
"keyword_or_column : valid_symbol_name",
"keyword_or_column : ADMIN",
"keyword_or_column : COLUMN",
"keyword_or_column : EXTRACT",
"keyword_or_column : YEAR",
"keyword_or_column : MONTH",
"keyword_or_column : DAY",
"keyword_or_column : HOUR",
"keyword_or_column : MINUTE",
"keyword_or_column : SECOND",
"keyword_or_column : TIME",
"keyword_or_column : TIMESTAMP",
"keyword_or_column : CURRENT_DATE",
"keyword_or_column : CURRENT_TIME",
"keyword_or_column : CURRENT_TIMESTAMP",
"keyword_or_column : CURRENT_USER",
"keyword_or_column : CURRENT_ROLE",
"keyword_or_column : RECREATE",
"keyword_or_column : CURRENT_CONNECTION",
"keyword_or_column : CURRENT_TRANSACTION",
"keyword_or_column : BIGINT",
"keyword_or_column : CASE",
"keyword_or_column : RELEASE",
"keyword_or_column : ROW_COUNT",
"keyword_or_column : SAVEPOINT",
"keyword_or_column : OPEN",
"keyword_or_column : CLOSE",
"keyword_or_column : FETCH",
"keyword_or_column : ROWS",
"keyword_or_column : USING",
"keyword_or_column : CROSS",
"keyword_or_column : BIT_LENGTH",
"keyword_or_column : BOTH",
"keyword_or_column : CHAR_LENGTH",
"keyword_or_column : CHARACTER_LENGTH",
"keyword_or_column : COMMENT",
"keyword_or_column : LEADING",
"keyword_or_column : LOWER",
"keyword_or_column : OCTET_LENGTH",
"keyword_or_column : TRAILING",
"keyword_or_column : TRIM",
"keyword_or_column : CONNECT",
"keyword_or_column : DISCONNECT",
"keyword_or_column : GLOBAL",
"keyword_or_column : INSENSITIVE",
"keyword_or_column : RECURSIVE",
"keyword_or_column : SENSITIVE",
"keyword_or_column : START",
"keyword_or_column : SIMILAR",
"keyword_or_column : BOOLEAN",
"keyword_or_column : CORR",
"keyword_or_column : COVAR_POP",
"keyword_or_column : COVAR_SAMP",
"keyword_or_column : DELETING",
"keyword_or_column : DETERMINISTIC",
"keyword_or_column : FALSE",
"keyword_or_column : INSERTING",
"keyword_or_column : OFFSET",
"keyword_or_column : OVER",
"keyword_or_column : REGR_AVGX",
"keyword_or_column : REGR_AVGY",
"keyword_or_column : REGR_COUNT",
"keyword_or_column : REGR_INTERCEPT",
"keyword_or_column : REGR_R2",
"keyword_or_column : REGR_SLOPE",
"keyword_or_column : REGR_SXX",
"keyword_or_column : REGR_SXY",
"keyword_or_column : REGR_SYY",
"keyword_or_column : RETURN",
"keyword_or_column : ROW",
"keyword_or_column : SCROLL",
"keyword_or_column : SQLSTATE",
"keyword_or_column : STDDEV_SAMP",
"keyword_or_column : STDDEV_POP",
"keyword_or_column : TRUE",
"keyword_or_column : UNKNOWN",
"keyword_or_column : UPDATING",
"keyword_or_column : VAR_SAMP",
"keyword_or_column : VAR_POP",
"keyword_or_column : BINARY",
"keyword_or_column : DECFLOAT",
"keyword_or_column : INT128",
"keyword_or_column : LATERAL",
"keyword_or_column : LOCAL",
"keyword_or_column : LOCALTIME",
"keyword_or_column : LOCALTIMESTAMP",
"keyword_or_column : PUBLICATION",
"keyword_or_column : RESETTING",
"keyword_or_column : TIMEZONE_HOUR",
"keyword_or_column : TIMEZONE_MINUTE",
"keyword_or_column : UNBOUNDED",
"keyword_or_column : VARBINARY",
"keyword_or_column : WINDOW",
"keyword_or_column : WITHOUT",
"col_opt : ALTER",
"col_opt : ALTER COLUMN",
"alter_data_type_or_domain : non_array_type",
"alter_data_type_or_domain : symbol_column_name",
"$$110 :",
"alter_identity_clause_spec : $$71 alter_identity_clause_generation $$110 alter_identity_clause_options_opt",
"alter_identity_clause_spec : $$71 alter_identity_clause_options",
"alter_identity_clause_generation : SET GENERATED ALWAYS",
"alter_identity_clause_generation : SET GENERATED BY DEFAULT",
"alter_identity_clause_options_opt :",
"alter_identity_clause_options_opt : $$71 alter_identity_clause_options",
"alter_identity_clause_options : alter_identity_clause_options $$72 alter_identity_clause_option",
"alter_identity_clause_options : $$71 alter_identity_clause_option",
"alter_identity_clause_option : RESTART with_opt",
"alter_identity_clause_option : SET INCREMENT by_noise signed_long_integer",
"drop_behaviour :",
"drop_behaviour : RESTRICT",
"drop_behaviour : CASCADE",
"alter_index_clause : symbol_index_name ACTIVE",
"alter_index_clause : symbol_index_name INACTIVE",
"alter_udf_clause : symbol_UDF_name entry_op module_op",
"entry_op :",
"entry_op : ENTRY_POINT utf_string",
"module_op :",
"module_op : MODULE_NAME utf_string",
"alter_role_2X_compatibility : symbol_role_name alter_role_enable AUTO ADMIN MAPPING",
"alter_role_clause : role_clause",
"alter_role_clause : alter_role_2X_compatibility",
"alter_role_enable : SET",
"alter_role_enable : DROP",
"alter_db : $$51 db_alter_clause",
"alter_db : alter_db $$53 db_alter_clause",
"$$111 :",
"db_alter_clause : ADD $$111 db_file_list",
"db_alter_clause : ADD DIFFERENCE FILE utf_string",
"db_alter_clause : DROP DIFFERENCE FILE",
"db_alter_clause : BEGIN BACKUP",
"db_alter_clause : END BACKUP",
"db_alter_clause : SET DEFAULT CHARACTER SET symbol_character_set_name",
"$$112 :",
"db_alter_clause : ENCRYPT WITH valid_symbol_name $$112 crypt_key_clause",
"db_alter_clause : DECRYPT",
"db_alter_clause : SET LINGER TO long_integer",
"db_alter_clause : DROP LINGER",
"db_alter_clause : SET DEFAULT sql_security_clause",
"db_alter_clause : ENABLE PUBLICATION",
"db_alter_clause : DISABLE PUBLICATION",
"db_alter_clause : INCLUDE $$53 pub_table_filter TO PUBLICATION",
"db_alter_clause : EXCLUDE $$53 pub_table_filter FROM PUBLICATION",
"crypt_key_clause :",
"crypt_key_clause : KEY valid_symbol_name",
"pub_table_filter : ALL",
"pub_table_filter : TABLE $$53 pub_table_list",
"pub_table_list : $$51 pub_table_clause",
"pub_table_list : pub_table_list ',' $$52 pub_table_clause",
"pub_table_clause : symbol_table_name",
"alter_trigger_clause : symbol_trigger_name trigger_active trigger_type_opt trigger_position trg_sql_security_clause AS local_declarations_opt full_proc_block",
"alter_trigger_clause : symbol_trigger_name trigger_active trigger_type_opt trigger_position external_clause external_body_clause_opt",
"alter_trigger_clause : symbol_trigger_name trigger_active trigger_type_opt trigger_position trg_sql_security_clause",
"trigger_type_opt : trigger_type_prefix trigger_type_suffix",
"trigger_type_opt :",
"trg_sql_security_clause :",
"trg_sql_security_clause : SQL SECURITY DEFINER",
"trg_sql_security_clause : SQL SECURITY INVOKER",
"trg_sql_security_clause : DROP SQL SECURITY",
"drop : DROP drop_clause",
"drop_clause : EXCEPTION symbol_exception_name",
"drop_clause : INDEX symbol_index_name",
"drop_clause : PROCEDURE symbol_procedure_name",
"drop_clause : TABLE symbol_table_name",
"drop_clause : TRIGGER symbol_trigger_name",
"drop_clause : VIEW symbol_view_name",
"drop_clause : FILTER symbol_filter_name",
"drop_clause : DOMAIN symbol_domain_name",
"drop_clause : EXTERNAL FUNCTION symbol_UDF_name",
"drop_clause : FUNCTION symbol_UDF_name",
"drop_clause : SHADOW pos_short_integer opt_no_file_delete",
"drop_clause : ROLE symbol_role_name",
"drop_clause : GENERATOR symbol_generator_name",
"drop_clause : SEQUENCE symbol_generator_name",
"drop_clause : COLLATION symbol_collation_name",
"drop_clause : USER symbol_user_name USING PLUGIN valid_symbol_name",
"drop_clause : USER symbol_user_name",
"drop_clause : PACKAGE symbol_package_name",
"drop_clause : PACKAGE BODY symbol_package_name",
"drop_clause : MAPPING $$28 drop_map_clause",
"drop_clause : GLOBAL MAPPING $$29 drop_map_clause",
"opt_no_file_delete :",
"opt_no_file_delete : PRESERVE FILE",
"opt_no_file_delete : DELETE FILE",
"data_type : non_array_type",
"data_type : array_type",
"domain_or_non_array_type : domain_or_non_array_type_name",
"domain_or_non_array_type : domain_or_non_array_type_name NOT NULL",
"domain_or_non_array_type_name : non_array_type",
"domain_or_non_array_type_name : domain_type",
"domain_type : TYPE OF symbol_column_name",
"domain_type : TYPE OF COLUMN symbol_column_name '.' symbol_column_name",
"domain_type : symbol_column_name",
"non_array_type : simple_type",
"non_array_type : blob_type",
"array_type : non_charset_simple_type '[' array_spec ']'",
"array_type : character_type '[' array_spec ']' charset_clause",
"array_spec : array_range",
"array_spec : array_spec ',' array_range",
"array_range : signed_long_integer",
"array_range : signed_long_integer ':' signed_long_integer",
"simple_type : non_charset_simple_type",
"simple_type : character_type charset_clause",
"non_charset_simple_type : national_character_type",
"non_charset_simple_type : binary_character_type",
"non_charset_simple_type : numeric_type",
"non_charset_simple_type : float_type",
"non_charset_simple_type : decfloat_type",
"non_charset_simple_type : BIGINT",
"non_charset_simple_type : INT128",
"non_charset_simple_type : integer_keyword",
"non_charset_simple_type : SMALLINT",
"non_charset_simple_type : DATE",
"non_charset_simple_type : TIME without_time_zone_opt",
"non_charset_simple_type : TIME WITH TIME ZONE",
"non_charset_simple_type : TIMESTAMP without_time_zone_opt",
"non_charset_simple_type : TIMESTAMP WITH TIME ZONE",
"non_charset_simple_type : BOOLEAN",
"integer_keyword : INTEGER",
"integer_keyword : INT",
"without_time_zone_opt :",
"without_time_zone_opt : WITHOUT TIME ZONE",
"$$113 :",
"$$114 :",
"blob_type : BLOB $$113 $$114 blob_subtype blob_segsize charset_clause",
"blob_type : BLOB '(' unsigned_short_integer ')'",
"blob_type : BLOB '(' unsigned_short_integer ',' signed_short_integer ')'",
"blob_type : BLOB '(' ',' signed_short_integer ')'",
"blob_segsize :",
"blob_segsize : SEGMENT SIZE unsigned_short_integer",
"blob_subtype :",
"blob_subtype : SUB_TYPE signed_short_integer",
"blob_subtype : SUB_TYPE symbol_blob_subtype_name",
"charset_clause :",
"charset_clause : CHARACTER SET symbol_character_set_name",
"national_character_type : national_character_keyword '(' pos_short_integer ')'",
"national_character_type : national_character_keyword",
"national_character_type : national_character_keyword VARYING '(' pos_short_integer ')'",
"binary_character_type : binary_character_keyword '(' pos_short_integer ')'",
"binary_character_type : binary_character_keyword",
"binary_character_type : varbinary_character_keyword '(' pos_short_integer ')'",
"character_type : character_keyword '(' pos_short_integer ')'",
"character_type : character_keyword",
"character_type : varying_keyword '(' pos_short_integer ')'",
"varying_keyword : VARCHAR",
"varying_keyword : CHARACTER VARYING",
"varying_keyword : CHAR VARYING",
"character_keyword : CHARACTER",
"character_keyword : CHAR",
"national_character_keyword : NCHAR",
"national_character_keyword : NATIONAL CHARACTER",
"national_character_keyword : NATIONAL CHAR",
"binary_character_keyword : BINARY",
"varbinary_character_keyword : VARBINARY",
"varbinary_character_keyword : BINARY VARYING",
"decfloat_type : DECFLOAT precision_opt_nz",
"numeric_type : NUMERIC prec_scale",
"numeric_type : decimal_keyword prec_scale",
"prec_scale :",
"prec_scale : '(' signed_long_integer ')'",
"prec_scale : '(' signed_long_integer ',' signed_long_integer ')'",
"decimal_keyword : DECIMAL",
"decimal_keyword : DEC",
"float_type : FLOAT precision_opt_nz",
"float_type : LONG FLOAT precision_opt_nz",
"float_type : REAL",
"float_type : DOUBLE PRECISION",
"precision_opt_nz :",
"precision_opt_nz : '(' pos_short_integer ')'",
"savepoint : set_savepoint",
"savepoint : release_savepoint",
"savepoint : undo_savepoint",
"set_savepoint : SAVEPOINT symbol_savepoint_name",
"release_savepoint : RELEASE SAVEPOINT symbol_savepoint_name release_only_opt",
"release_only_opt :",
"release_only_opt : ONLY",
"undo_savepoint : ROLLBACK optional_work TO optional_savepoint symbol_savepoint_name",
"optional_savepoint :",
"optional_savepoint : SAVEPOINT",
"commit : COMMIT optional_work optional_retain",
"rollback : ROLLBACK optional_work optional_retain",
"optional_work :",
"optional_work : WORK",
"optional_retain :",
"optional_retain : RETAIN opt_snapshot",
"opt_snapshot :",
"opt_snapshot : SNAPSHOT",
"$$115 :",
"$$116 :",
"set_transaction : SET TRANSACTION $$115 $$116 tran_option_list_opt",
"session_reset : ALTER SESSION RESET",
"set_role : SET ROLE valid_symbol_name",
"set_role : SET TRUSTED ROLE",
"set_debug_option : SET DEBUG OPTION valid_symbol_name '=' constant",
"set_decfloat_round : SET DECFLOAT ROUND valid_symbol_name",
"$$117 :",
"$$118 :",
"set_decfloat_traps : SET DECFLOAT TRAPS TO $$117 $$118 decfloat_traps_list_opt",
"set_bind : SET BIND OF set_bind_from TO set_bind_to",
"set_bind_from : bind_type",
"set_bind_from : TIME ZONE",
"bind_type : non_array_type",
"bind_type : varying_keyword",
"set_bind_to : bind_type",
"set_bind_to : LEGACY",
"set_bind_to : NATIVE",
"set_bind_to : EXTENDED",
"set_bind_to : EXTENDED TIME WITH TIME ZONE",
"set_bind_to : EXTENDED TIMESTAMP WITH TIME ZONE",
"decfloat_traps_list_opt :",
"decfloat_traps_list_opt : $$118 decfloat_traps_list",
"decfloat_traps_list : $$118 decfloat_trap",
"$$119 :",
"decfloat_traps_list : decfloat_traps_list ',' $$119 decfloat_trap",
"decfloat_trap : valid_symbol_name",
"session_statement : SET SESSION IDLE TIMEOUT long_integer timepart_sesion_idle_tout",
"session_statement : SET STATEMENT TIMEOUT long_integer timepart_ses_stmt_tout",
"timepart_sesion_idle_tout :",
"timepart_sesion_idle_tout : HOUR",
"timepart_sesion_idle_tout : MINUTE",
"timepart_sesion_idle_tout : SECOND",
"timepart_ses_stmt_tout :",
"timepart_ses_stmt_tout : HOUR",
"timepart_ses_stmt_tout : MINUTE",
"timepart_ses_stmt_tout : SECOND",
"timepart_ses_stmt_tout : MILLISECOND",
"set_time_zone : SET TIME ZONE set_time_zone_option",
"set_time_zone_option : sql_string",
"set_time_zone_option : LOCAL",
"tran_option_list_opt :",
"tran_option_list_opt : $$116 tran_option_list",
"tran_option_list : $$116 tran_option",
"$$120 :",
"tran_option_list : tran_option_list $$120 tran_option",
"tran_option : READ ONLY",
"tran_option : READ WRITE",
"tran_option : WAIT",
"tran_option : NO WAIT",
"tran_option : $$116 isolation_mode",
"tran_option : NO AUTO UNDO",
"tran_option : IGNORE LIMBO",
"tran_option : RESTART REQUESTS",
"tran_option : AUTO COMMIT",
"tran_option : LOCK TIMEOUT nonneg_short_integer",
"$$121 :",
"$$122 :",
"tran_option : RESERVING $$121 $$122 restr_list",
"isolation_mode : ISOLATION LEVEL $$122 iso_mode",
"isolation_mode : iso_mode",
"iso_mode : $$116 snap_shot",
"iso_mode : READ UNCOMMITTED version_mode",
"iso_mode : READ COMMITTED version_mode",
"snap_shot : SNAPSHOT",
"snap_shot : SNAPSHOT AT NUMBER snapshot_number",
"snap_shot : SNAPSHOT TABLE",
"snap_shot : SNAPSHOT TABLE STABILITY",
"snapshot_number : NUMBER32BIT",
"snapshot_number : NUMBER64BIT",
"version_mode :",
"version_mode : VERSION",
"version_mode : NO VERSION",
"version_mode : READ CONSISTENCY",
"lock_type :",
"lock_type : SHARED",
"lock_type : PROTECTED",
"lock_mode : READ",
"lock_mode : WRITE",
"restr_list : restr_option",
"restr_list : restr_list ',' restr_option",
"restr_option : table_list table_lock",
"table_lock :",
"table_lock : FOR lock_type lock_mode",
"table_list : symbol_table_name",
"table_list : table_list ',' symbol_table_name",
"set_statistics : SET STATISTICS INDEX symbol_index_name",
"comment : COMMENT ON ddl_type0 IS ddl_desc",
"comment : COMMENT ON ddl_type1 symbol_ddl_name IS ddl_desc",
"comment : COMMENT ON ddl_type2 symbol_ddl_name ddl_subname IS ddl_desc",
"comment : COMMENT ON ddl_type3 ddl_qualified_name ddl_subname IS ddl_desc",
"comment : COMMENT ON ddl_type4 ddl_qualified_name IS ddl_desc",
"comment : comment_on_user",
"$$123 :",
"$$124 :",
"comment_on_user : COMMENT ON USER symbol_user_name $$123 $$124 opt_use_plugin IS ddl_desc",
"opt_use_plugin :",
"opt_use_plugin : $$124 use_plugin",
"ddl_type0 : DATABASE",
"ddl_type1 : DOMAIN",
"ddl_type1 : TABLE",
"ddl_type1 : VIEW",
"ddl_type1 : TRIGGER",
"ddl_type1 : FILTER",
"ddl_type1 : EXCEPTION",
"ddl_type1 : GENERATOR",
"ddl_type1 : SEQUENCE",
"ddl_type1 : INDEX",
"ddl_type1 : ROLE",
"ddl_type1 : CHARACTER SET",
"ddl_type1 : COLLATION",
"ddl_type1 : PACKAGE",
"ddl_type2 : COLUMN",
"ddl_type3 : PARAMETER",
"ddl_type3 : PROCEDURE PARAMETER",
"ddl_type3 : FUNCTION PARAMETER",
"ddl_type4 : PROCEDURE",
"ddl_type4 : EXTERNAL FUNCTION",
"ddl_type4 : FUNCTION",
"ddl_subname : '.' symbol_ddl_name",
"ddl_qualified_name : symbol_ddl_name",
"ddl_qualified_name : symbol_ddl_name '.' symbol_ddl_name",
"ddl_desc : utf_string",
"ddl_desc : NULL",
"select : select_expr for_update_clause lock_clause",
"for_update_clause :",
"for_update_clause : FOR UPDATE for_update_list",
"for_update_list :",
"for_update_list : OF column_list",
"lock_clause :",
"lock_clause : WITH LOCK",
"select_expr : with_clause select_expr_body order_clause_opt rows_clause",
"select_expr : with_clause select_expr_body order_clause_opt result_offset_clause fetch_first_clause",
"with_clause :",
"with_clause : WITH RECURSIVE with_list",
"with_clause : WITH with_list",
"with_list : with_item",
"with_list : with_list ',' with_item",
"with_item : symbol_table_alias_name derived_column_list AS '(' select_expr ')'",
"column_select : select_expr",
"column_singleton : column_select",
"select_expr_body : query_term",
"select_expr_body : select_expr_body UNION distinct_noise query_term",
"select_expr_body : select_expr_body UNION ALL query_term",
"query_term : query_spec",
"query_spec : SELECT limit_clause distinct_clause select_list from_clause where_clause group_clause having_clause named_windows_clause plan_clause",
"limit_clause :",
"limit_clause : first_clause skip_clause",
"limit_clause : first_clause",
"limit_clause : skip_clause",
"first_clause : FIRST long_integer",
"first_clause : FIRST '(' value ')'",
"first_clause : FIRST parameter",
"skip_clause : SKIP long_integer",
"skip_clause : SKIP '(' value ')'",
"skip_clause : SKIP parameter",
"distinct_clause : DISTINCT",
"distinct_clause : all_noise",
"select_list : select_items",
"select_list : '*'",
"select_items : select_item",
"select_items : select_items ',' select_item",
"select_item : value_opt_alias",
"select_item : symbol_table_alias_name '.' '*'",
"value_opt_alias : value",
"value_opt_alias : value as_noise symbol_item_alias_name",
"as_noise :",
"as_noise : AS",
"from_clause : FROM from_list",
"from_list : table_reference",
"from_list : from_list ',' table_reference",
"table_reference : joined_table",
"table_reference : table_primary",
"table_primary : table_proc",
"table_primary : derived_table",
"table_primary : lateral_derived_table",
"table_primary : '(' joined_table ')'",
"derived_table : '(' select_expr ')' as_noise correlation_name derived_column_list",
"lateral_derived_table : LATERAL derived_table",
"correlation_name :",
"correlation_name : symbol_table_alias_name",
"derived_column_list :",
"derived_column_list : '(' alias_list ')'",
"alias_list : symbol_item_alias_name",
"alias_list : alias_list ',' symbol_item_alias_name",
"joined_table : cross_join",
"joined_table : natural_join",
"joined_table : qualified_join",
"cross_join : table_reference CROSS JOIN table_primary",
"natural_join : table_reference NATURAL join_type JOIN table_primary",
"qualified_join : table_reference join_type JOIN table_reference join_condition",
"qualified_join : table_reference join_type JOIN table_reference named_columns_join",
"join_condition : ON search_condition",
"named_columns_join : USING '(' column_list ')'",
"table_proc : symbol_procedure_name table_proc_inputs as_noise symbol_table_alias_name",
"table_proc : symbol_procedure_name table_proc_inputs",
"table_proc : symbol_package_name '.' symbol_procedure_name table_proc_inputs as_noise symbol_table_alias_name",
"table_proc : symbol_package_name '.' symbol_procedure_name table_proc_inputs",
"table_proc_inputs :",
"table_proc_inputs : '(' value_list ')'",
"table_name : simple_table_name",
"table_name : symbol_table_name as_noise symbol_table_alias_name",
"simple_table_name : symbol_table_name",
"join_type :",
"join_type : INNER",
"join_type : LEFT outer_noise",
"join_type : RIGHT outer_noise",
"join_type : FULL outer_noise",
"outer_noise :",
"outer_noise : OUTER",
"group_clause :",
"group_clause : GROUP BY group_by_list",
"group_by_list : group_by_item",
"group_by_list : group_by_list ',' group_by_item",
"group_by_item : value",
"having_clause :",
"having_clause : HAVING search_condition",
"where_clause :",
"where_clause : WHERE search_condition",
"named_windows_clause :",
"named_windows_clause : WINDOW window_definition_list",
"window_definition_list : window_definition",
"window_definition_list : window_definition_list ',' window_definition",
"window_definition : symbol_window_name AS '(' window_clause ')'",
"symbol_window_name_opt :",
"symbol_window_name_opt : symbol_window_name",
"plan_clause :",
"plan_clause : PLAN plan_expression",
"$$125 :",
"$$126 :",
"plan_expression : plan_type $$125 '(' $$126 plan_item_list ')'",
"plan_type :",
"plan_type : JOIN",
"plan_type : SORT MERGE",
"plan_type : MERGE",
"plan_type : HASH",
"plan_type : SORT",
"plan_item_list : plan_item",
"plan_item_list : plan_item_list ',' plan_item",
"plan_item : table_or_alias_list access_type",
"plan_item : plan_expression",
"table_or_alias_list : symbol_table_name",
"table_or_alias_list : table_or_alias_list symbol_table_name",
"access_type : NATURAL",
"$$127 :",
"$$128 :",
"access_type : INDEX $$127 '(' $$128 index_list ')'",
"$$129 :",
"access_type : ORDER $$129 symbol_index_name $$128 extra_indices_opt",
"index_list : symbol_index_name",
"index_list : index_list ',' symbol_index_name",
"extra_indices_opt :",
"$$130 :",
"extra_indices_opt : INDEX '(' $$130 index_list ')'",
"order_clause_opt :",
"order_clause_opt : order_clause",
"order_clause : ORDER BY order_list",
"order_list : order_item",
"order_list : order_list ',' order_item",
"order_item : value order_direction nulls_clause",
"order_direction :",
"order_direction : ASC",
"order_direction : DESC",
"nulls_clause :",
"nulls_clause : NULLS nulls_placement",
"nulls_placement : FIRST",
"nulls_placement : LAST",
"rows_clause : ROWS value",
"rows_clause : ROWS value TO value",
"rows_clause_optional :",
"rows_clause_optional : rows_clause",
"row_noise : ROW",
"row_noise : ROWS",
"result_offset_clause :",
"result_offset_clause : OFFSET simple_value_spec row_noise",
"first_next_noise : FIRST",
"first_next_noise : NEXT",
"fetch_first_clause :",
"fetch_first_clause : FETCH first_next_noise simple_value_spec row_noise ONLY",
"fetch_first_clause : FETCH first_next_noise row_noise ONLY",
"$$131 :",
"insert : insert_start $$131 ins_column_parens_opt override_opt VALUES '(' value_or_default_list ')' returning_clause",
"insert : insert_start $$131 ins_column_parens_opt override_opt select_expr returning_clause",
"insert : insert_start DEFAULT VALUES returning_clause",
"insert_start : INSERT INTO simple_table_name",
"override_opt :",
"override_opt : OVERRIDING USER VALUE",
"override_opt : OVERRIDING SYSTEM VALUE",
"value_or_default_list : value_or_default",
"value_or_default_list : value_or_default_list ',' value_or_default",
"value_or_default : value",
"value_or_default : DEFAULT",
"$$132 :",
"$$133 :",
"merge : MERGE INTO table_name USING table_reference ON search_condition $$132 $$133 merge_when_clause returning_clause",
"merge_when_clause : $$133 merge_when_matched_clause",
"merge_when_clause : $$133 merge_when_not_matched_clause",
"$$134 :",
"merge_when_clause : merge_when_clause $$134 merge_when_matched_clause",
"merge_when_clause : merge_when_clause $$134 merge_when_not_matched_clause",
"$$135 :",
"$$136 :",
"$$137 :",
"merge_when_matched_clause : WHEN MATCHED $$135 $$136 $$137 merge_update_specification",
"$$138 :",
"$$139 :",
"merge_when_not_matched_clause : WHEN NOT MATCHED $$138 $$139 merge_insert_specification",
"$$140 :",
"merge_update_specification : THEN UPDATE SET $$140 update_assignments",
"$$141 :",
"merge_update_specification : AND search_condition THEN UPDATE SET $$141 update_assignments",
"merge_update_specification : THEN DELETE",
"merge_update_specification : AND search_condition THEN DELETE",
"$$142 :",
"merge_insert_specification : THEN INSERT $$142 ins_column_parens_opt override_opt VALUES '(' value_or_default_list ')'",
"$$143 :",
"merge_insert_specification : AND search_condition THEN INSERT $$143 ins_column_parens_opt override_opt VALUES '(' value_or_default_list ')'",
"delete : delete_searched",
"delete : delete_positioned",
"delete_searched : DELETE FROM table_name where_clause plan_clause order_clause_opt rows_clause_optional returning_clause",
"delete_positioned : DELETE FROM table_name cursor_clause returning_clause",
"update : update_searched",
"update : update_positioned",
"$$144 :",
"update_searched : UPDATE table_name SET $$144 update_assignments where_clause plan_clause order_clause_opt rows_clause_optional returning_clause",
"update_positioned : UPDATE table_name SET $$144 update_assignments cursor_clause returning_clause",
"$$145 :",
"$$146 :",
"$$147 :",
"update_or_insert : UPDATE OR INSERT INTO simple_table_name $$145 $$146 ins_column_parens_opt override_opt VALUES '(' value_or_default_list ')' $$147 update_or_insert_matching_opt returning_clause",
"update_or_insert_matching_opt :",
"$$148 :",
"update_or_insert_matching_opt : MATCHING $$148 ins_column_parens",
"returning_clause :",
"returning_clause : RETURNING select_list",
"returning_clause : RETURNING select_list INTO variable_list",
"cursor_clause : WHERE CURRENT OF symbol_cursor_name",
"assignment : update_column_name '=' value",
"$$149 :",
"update_assignments : $$149 update_assignment",
"$$150 :",
"update_assignments : update_assignments ',' $$150 update_assignment",
"update_assignment : update_column_name '=' value",
"update_assignment : update_column_name '=' DEFAULT",
"exec_function : udf",
"exec_function : non_aggregate_function",
"column_parens_opt :",
"column_parens_opt : column_parens",
"column_parens : '(' column_list ')'",
"column_list : simple_column_name",
"column_list : column_list ',' simple_column_name",
"ins_column_parens_opt :",
"$$151 :",
"ins_column_parens_opt : $$151 ins_column_parens",
"ins_column_parens : '(' $$148 ins_column_list ')'",
"ins_column_list : update_column_name",
"ins_column_list : ins_column_list ',' update_column_name",
"column_name : simple_column_name",
"column_name : symbol_table_alias_name '.' symbol_column_name",
"column_name : ':' symbol_table_alias_name '.' symbol_column_name",
"simple_column_name : symbol_column_name",
"update_column_name : simple_column_name",
"update_column_name : symbol_table_alias_name '.' symbol_column_name",
"search_condition : value",
"boolean_value_expression : predicate",
"boolean_value_expression : value OR value",
"boolean_value_expression : value AND value",
"boolean_value_expression : NOT value",
"boolean_value_expression : '(' boolean_value_expression ')'",
"boolean_value_expression : value IS boolean_literal",
"boolean_value_expression : value IS NOT boolean_literal",
"predicate : comparison_predicate",
"predicate : distinct_predicate",
"predicate : between_predicate",
"predicate : binary_pattern_predicate",
"predicate : ternary_pattern_predicate",
"predicate : in_predicate",
"predicate : null_predicate",
"predicate : quantified_predicate",
"predicate : exists_predicate",
"predicate : singular_predicate",
"predicate : trigger_action_predicate",
"predicate : session_reset_predicate",
"comparison_predicate : value comparison_operator value",
"comparison_operator : '='",
"comparison_operator : '<'",
"comparison_operator : '>'",
"comparison_operator : GEQ",
"comparison_operator : LEQ",
"comparison_operator : NOT_GTR",
"comparison_operator : NOT_LSS",
"comparison_operator : NEQ",
"quantified_predicate : value comparison_operator quantified_flag '(' column_select ')'",
"quantified_flag : ALL",
"quantified_flag : SOME",
"quantified_flag : ANY",
"distinct_predicate : value IS DISTINCT FROM value",
"distinct_predicate : value IS NOT DISTINCT FROM value",
"between_predicate : value BETWEEN value_special AND value_special",
"between_predicate : value NOT BETWEEN value_special AND value_special",
"binary_pattern_predicate : value binary_pattern_operator value",
"binary_pattern_predicate : value NOT binary_pattern_operator value",
"binary_pattern_operator : CONTAINING",
"binary_pattern_operator : STARTING",
"binary_pattern_operator : STARTING WITH",
"ternary_pattern_predicate : value LIKE value",
"ternary_pattern_predicate : value LIKE value ESCAPE value",
"ternary_pattern_predicate : value NOT LIKE value",
"ternary_pattern_predicate : value NOT LIKE value ESCAPE value",
"ternary_pattern_predicate : value SIMILAR TO value",
"ternary_pattern_predicate : value SIMILAR TO value ESCAPE value",
"ternary_pattern_predicate : value NOT SIMILAR TO value",
"ternary_pattern_predicate : value NOT SIMILAR TO value ESCAPE value",
"in_predicate : value IN in_predicate_value",
"in_predicate : value NOT IN in_predicate_value",
"exists_predicate : EXISTS '(' select_expr ')'",
"singular_predicate : SINGULAR '(' select_expr ')'",
"trigger_action_predicate : INSERTING",
"trigger_action_predicate : UPDATING",
"trigger_action_predicate : DELETING",
"session_reset_predicate : RESETTING",
"null_predicate : value IS NULL",
"null_predicate : value IS UNKNOWN",
"null_predicate : value IS NOT NULL",
"null_predicate : value IS NOT UNKNOWN",
"in_predicate_value : table_subquery",
"in_predicate_value : '(' value_list ')'",
"table_subquery : '(' column_select ')'",
"$$152 :",
"create_user_clause : symbol_user_name $$152 $$124 user_fixed_list_opt",
"$$153 :",
"alter_user_clause : symbol_user_name set_noise $$153 $$124 user_fixed_list_opt",
"$$154 :",
"alter_cur_user_clause : set_noise $$154 $$124 user_fixed_list_opt",
"$$155 :",
"replace_user_clause : symbol_user_name set_noise $$155 $$124 user_fixed_list_opt",
"set_noise :",
"set_noise : SET",
"user_fixed_list_opt :",
"user_fixed_list_opt : $$124 user_fixed_list",
"user_fixed_list : $$124 user_fixed_option",
"$$156 :",
"user_fixed_list : user_fixed_list $$156 user_fixed_option",
"user_fixed_option : FIRSTNAME utf_string",
"user_fixed_option : MIDDLENAME utf_string",
"user_fixed_option : LASTNAME utf_string",
"user_fixed_option : PASSWORD utf_string",
"user_fixed_option : GRANT ADMIN ROLE",
"user_fixed_option : REVOKE ADMIN ROLE",
"user_fixed_option : ACTIVE",
"user_fixed_option : INACTIVE",
"user_fixed_option : $$124 use_plugin",
"$$157 :",
"user_fixed_option : TAGS '(' $$157 user_var_list ')'",
"use_plugin : USING PLUGIN valid_symbol_name",
"user_var_list : $$124 user_var_option",
"user_var_list : user_var_list ',' $$157 user_var_option",
"user_var_option : valid_symbol_name '=' utf_string",
"user_var_option : DROP valid_symbol_name",
"$$158 :",
"$$159 :",
"$$160 :",
"create_map_clause : $$158 map_clause $$159 $$160 map_to",
"$$161 :",
"$$162 :",
"alter_map_clause : $$161 map_clause $$162 $$160 map_to",
"$$163 :",
"$$164 :",
"replace_map_clause : $$163 map_clause $$164 $$160 map_to",
"drop_map_clause : map_name",
"$$165 :",
"$$166 :",
"$$167 :",
"map_clause : map_name $$165 USING $$166 map_using FROM $$167 map_from",
"map_name : valid_symbol_name",
"map_from : map_from_symbol_name map_logoninfo",
"map_from : ANY map_from_symbol_name",
"map_from_symbol_name : valid_symbol_name",
"map_from_symbol_name : USER",
"map_from_symbol_name : GROUP",
"map_logoninfo : sql_string",
"map_logoninfo : valid_symbol_name",
"map_using : PLUGIN valid_symbol_name map_in",
"map_using : ANY PLUGIN map_in",
"map_using : ANY PLUGIN SERVERWIDE",
"map_using : MAPPING map_in",
"map_using : '*' map_in",
"map_in :",
"map_in : IN valid_symbol_name",
"map_to : TO map_role valid_symbol_name",
"map_to : TO map_role",
"map_role : ROLE",
"map_role : USER",
"value : value_primary",
"value : boolean_value_expression",
"value_special : value_primary",
"value_special : '(' boolean_value_expression ')'",
"value_primary : nonparenthesized_value",
"value_primary : '(' value_primary ')'",
"simple_value_spec : constant",
"simple_value_spec : variable",
"simple_value_spec : parameter",
"nonparenthesized_value : column_name",
"nonparenthesized_value : array_element",
"nonparenthesized_value : function",
"nonparenthesized_value : u_constant",
"nonparenthesized_value : boolean_literal",
"nonparenthesized_value : parameter",
"nonparenthesized_value : variable",
"nonparenthesized_value : cast_specification",
"nonparenthesized_value : case_expression",
"nonparenthesized_value : next_value_expression",
"nonparenthesized_value : udf",
"nonparenthesized_value : '-' value_special",
"nonparenthesized_value : '+' value_special",
"nonparenthesized_value : value_special '+' value_special",
"nonparenthesized_value : value_special CONCATENATE value_special",
"nonparenthesized_value : value_special COLLATE symbol_collation_name",
"nonparenthesized_value : value_special AT LOCAL",
"nonparenthesized_value : value_special AT TIME ZONE value_special",
"nonparenthesized_value : value_special '-' value_special",
"nonparenthesized_value : value_special '*' value_special",
"nonparenthesized_value : value_special '/' value_special",
"nonparenthesized_value : '(' column_singleton ')'",
"nonparenthesized_value : current_user",
"nonparenthesized_value : current_role",
"nonparenthesized_value : internal_info",
"nonparenthesized_value : recordKeyType",
"nonparenthesized_value : symbol_table_alias_name '.' recordKeyType",
"nonparenthesized_value : VALUE",
"nonparenthesized_value : datetime_value_expression",
"nonparenthesized_value : null_value",
"recordKeyType : DB_KEY",
"recordKeyType : RDB_RECORD_VERSION",
"datetime_value_expression : CURRENT_DATE",
"datetime_value_expression : LOCALTIME time_precision_opt",
"datetime_value_expression : CURRENT_TIME time_precision_opt",
"datetime_value_expression : LOCALTIMESTAMP timestamp_precision_opt",
"datetime_value_expression : CURRENT_TIMESTAMP timestamp_precision_opt",
"time_precision_opt :",
"time_precision_opt : '(' nonneg_short_integer ')'",
"timestamp_precision_opt :",
"timestamp_precision_opt : '(' nonneg_short_integer ')'",
"array_element : column_name '[' value_list ']'",
"value_list_opt :",
"value_list_opt : value_list",
"value_list : value",
"value_list : value_list ',' value",
"constant : u_constant",
"constant : '-' ul_numeric_constant",
"constant : '-' LIMIT64_INT",
"constant : '-' LIMIT64_NUMBER",
"constant : '-' u_constant_128",
"constant : boolean_literal",
"u_numeric_constant : ul_numeric_constant",
"u_numeric_constant : LIMIT64_NUMBER",
"u_numeric_constant : LIMIT64_INT",
"u_numeric_constant : u_constant_128",
"u_constant_128 : NUM128",
"ul_numeric_constant : NUMBER32BIT",
"ul_numeric_constant : FLOAT_NUMBER",
"ul_numeric_constant : DECIMAL_NUMBER",
"ul_numeric_constant : NUMBER64BIT",
"ul_numeric_constant : SCALEDINT",
"u_constant : u_numeric_constant",
"u_constant : sql_string",
"u_constant : DATE STRING",
"u_constant : TIME STRING",
"u_constant : TIMESTAMP STRING",
"boolean_literal : FALSE",
"boolean_literal : TRUE",
"parameter : '?'",
"current_user : USER",
"current_user : CURRENT_USER",
"current_role : CURRENT_ROLE",
"internal_info : CURRENT_CONNECTION",
"internal_info : CURRENT_TRANSACTION",
"internal_info : GDSCODE",
"internal_info : SQLCODE",
"internal_info : SQLSTATE",
"internal_info : ROW_COUNT",
"internal_info : RDB_ERROR '(' error_context ')'",
"error_context : GDSCODE",
"error_context : SQLCODE",
"error_context : SQLSTATE",
"error_context : EXCEPTION",
"error_context : MESSAGE",
"sql_string : STRING",
"sql_string : INTRODUCER STRING",
"utf_string : sql_string",
"signed_short_integer : nonneg_short_integer",
"signed_short_integer : '-' neg_short_integer",
"nonneg_short_integer : NUMBER32BIT",
"neg_short_integer : NUMBER32BIT",
"pos_short_integer : nonneg_short_integer",
"unsigned_short_integer : NUMBER32BIT",
"signed_long_integer : long_integer",
"signed_long_integer : '-' long_integer",
"long_integer : NUMBER32BIT",
"function : aggregate_function",
"function : non_aggregate_function",
"function : over_clause",
"non_aggregate_function : numeric_value_function",
"non_aggregate_function : string_value_function",
"non_aggregate_function : system_function_expression",
"aggregate_function : aggregate_function_prefix",
"aggregate_function : aggregate_function_prefix FILTER '(' WHERE search_condition ')'",
"aggregate_function_prefix : COUNT '(' '*' ')'",
"aggregate_function_prefix : COUNT '(' all_noise value ')'",
"aggregate_function_prefix : COUNT '(' DISTINCT value ')'",
"aggregate_function_prefix : SUM '(' all_noise value ')'",
"aggregate_function_prefix : SUM '(' DISTINCT value ')'",
"aggregate_function_prefix : AVG '(' all_noise value ')'",
"aggregate_function_prefix : AVG '(' DISTINCT value ')'",
"aggregate_function_prefix : MINIMUM '(' all_noise value ')'",
"aggregate_function_prefix : MINIMUM '(' DISTINCT value ')'",
"aggregate_function_prefix : MAXIMUM '(' all_noise value ')'",
"aggregate_function_prefix : MAXIMUM '(' DISTINCT value ')'",
"aggregate_function_prefix : LIST '(' all_noise value delimiter_opt ')'",
"aggregate_function_prefix : LIST '(' DISTINCT value delimiter_opt ')'",
"aggregate_function_prefix : STDDEV_SAMP '(' value ')'",
"aggregate_function_prefix : STDDEV_POP '(' value ')'",
"aggregate_function_prefix : VAR_SAMP '(' value ')'",
"aggregate_function_prefix : VAR_POP '(' value ')'",
"aggregate_function_prefix : COVAR_SAMP '(' value ',' value ')'",
"aggregate_function_prefix : COVAR_POP '(' value ',' value ')'",
"aggregate_function_prefix : CORR '(' value ',' value ')'",
"aggregate_function_prefix : REGR_AVGX '(' value ',' value ')'",
"aggregate_function_prefix : REGR_AVGY '(' value ',' value ')'",
"aggregate_function_prefix : REGR_COUNT '(' value ',' value ')'",
"aggregate_function_prefix : REGR_INTERCEPT '(' value ',' value ')'",
"aggregate_function_prefix : REGR_R2 '(' value ',' value ')'",
"aggregate_function_prefix : REGR_SLOPE '(' value ',' value ')'",
"aggregate_function_prefix : REGR_SXX '(' value ',' value ')'",
"aggregate_function_prefix : REGR_SXY '(' value ',' value ')'",
"aggregate_function_prefix : REGR_SYY '(' value ',' value ')'",
"window_function : DENSE_RANK '(' ')'",
"window_function : RANK '(' ')'",
"window_function : PERCENT_RANK '(' ')'",
"window_function : CUME_DIST '(' ')'",
"window_function : ROW_NUMBER '(' ')'",
"window_function : FIRST_VALUE '(' value ')'",
"window_function : LAST_VALUE '(' value ')'",
"window_function : NTH_VALUE '(' value ',' value ')' nth_from",
"window_function : LAG '(' value ',' value ',' value ')'",
"window_function : LAG '(' value ',' value ')'",
"window_function : LAG '(' value ')'",
"window_function : LEAD '(' value ',' value ',' value ')'",
"window_function : LEAD '(' value ',' value ')'",
"window_function : LEAD '(' value ')'",
"window_function : NTILE '(' ntile_arg ')'",
"nth_from :",
"nth_from : FROM FIRST",
"nth_from : FROM LAST",
"ntile_arg : u_numeric_constant",
"ntile_arg : variable",
"ntile_arg : parameter",
"aggregate_window_function : aggregate_function",
"aggregate_window_function : window_function",
"over_clause : aggregate_window_function OVER symbol_window_name",
"over_clause : aggregate_window_function OVER '(' window_clause ')'",
"window_clause : symbol_window_name_opt window_partition_opt order_clause_opt window_frame_extent window_frame_exclusion_opt",
"window_partition_opt :",
"window_partition_opt : PARTITION BY value_list",
"window_frame_extent :",
"$$168 :",
"$$169 :",
"window_frame_extent : RANGE $$168 $$169 window_frame",
"$$170 :",
"window_frame_extent : ROWS $$170 $$169 window_frame",
"window_frame : window_frame_start",
"window_frame : BETWEEN window_frame_between_bound1 AND window_frame_between_bound2",
"window_frame_start : UNBOUNDED PRECEDING",
"window_frame_start : CURRENT ROW",
"window_frame_start : value PRECEDING",
"window_frame_between_bound1 : UNBOUNDED PRECEDING",
"window_frame_between_bound1 : CURRENT ROW",
"window_frame_between_bound1 : value PRECEDING",
"window_frame_between_bound1 : value FOLLOWING",
"window_frame_between_bound2 : UNBOUNDED FOLLOWING",
"window_frame_between_bound2 : CURRENT ROW",
"window_frame_between_bound2 : value PRECEDING",
"window_frame_between_bound2 : value FOLLOWING",
"window_frame_exclusion_opt :",
"window_frame_exclusion_opt : EXCLUDE NO OTHERS",
"window_frame_exclusion_opt : EXCLUDE CURRENT ROW",
"window_frame_exclusion_opt : EXCLUDE GROUP",
"window_frame_exclusion_opt : EXCLUDE TIES",
"delimiter_opt :",
"delimiter_opt : ',' value",
"numeric_value_function : extract_expression",
"numeric_value_function : length_expression",
"extract_expression : EXTRACT '(' timestamp_part FROM value ')'",
"length_expression : bit_length_expression",
"length_expression : char_length_expression",
"length_expression : octet_length_expression",
"bit_length_expression : BIT_LENGTH '(' value ')'",
"char_length_expression : CHAR_LENGTH '(' value ')'",
"char_length_expression : CHARACTER_LENGTH '(' value ')'",
"octet_length_expression : OCTET_LENGTH '(' value ')'",
"system_function_expression : system_function_std_syntax '(' value_list_opt ')'",
"system_function_expression : system_function_special_syntax",
"system_function_std_syntax : ABS",
"system_function_std_syntax : ACOS",
"system_function_std_syntax : ACOSH",
"system_function_std_syntax : ASCII_CHAR",
"system_function_std_syntax : ASCII_VAL",
"system_function_std_syntax : ASIN",
"system_function_std_syntax : ASINH",
"system_function_std_syntax : ATAN",
"system_function_std_syntax : ATAN2",
"system_function_std_syntax : ATANH",
"system_function_std_syntax : BASE64_DECODE",
"system_function_std_syntax : BASE64_ENCODE",
"system_function_std_syntax : BIN_AND",
"system_function_std_syntax : BIN_NOT",
"system_function_std_syntax : BIN_OR",
"system_function_std_syntax : BIN_SHL",
"system_function_std_syntax : BIN_SHR",
"system_function_std_syntax : BIN_XOR",
"system_function_std_syntax : BLOB_APPEND",
"system_function_std_syntax : CEIL",
"system_function_std_syntax : CHAR_TO_UUID",
"system_function_std_syntax : COS",
"system_function_std_syntax : COSH",
"system_function_std_syntax : COT",
"system_function_std_syntax : EXP",
"system_function_std_syntax : FLOOR",
"system_function_std_syntax : GEN_UUID",
"system_function_std_syntax : HEX_DECODE",
"system_function_std_syntax : HEX_ENCODE",
"system_function_std_syntax : LEFT",
"system_function_std_syntax : LN",
"system_function_std_syntax : LOG",
"system_function_std_syntax : LOG10",
"system_function_std_syntax : LPAD",
"system_function_std_syntax : MAKE_DBKEY",
"system_function_std_syntax : MAXVALUE",
"system_function_std_syntax : MINVALUE",
"system_function_std_syntax : MOD",
"system_function_std_syntax : PI",
"system_function_std_syntax : POWER",
"system_function_std_syntax : RAND",
"system_function_std_syntax : RDB_GET_CONTEXT",
"system_function_std_syntax : RDB_GET_TRANSACTION_CN",
"system_function_std_syntax : RDB_ROLE_IN_USE",
"system_function_std_syntax : RDB_SET_CONTEXT",
"system_function_std_syntax : REPLACE",
"system_function_std_syntax : REVERSE",
"system_function_std_syntax : RIGHT",
"system_function_std_syntax : ROUND",
"system_function_std_syntax : RPAD",
"system_function_std_syntax : RSA_PRIVATE",
"system_function_std_syntax : RSA_PUBLIC",
"system_function_std_syntax : SIGN",
"system_function_std_syntax : SIN",
"system_function_std_syntax : SINH",
"system_function_std_syntax : SQRT",
"system_function_std_syntax : TAN",
"system_function_std_syntax : TANH",
"system_function_std_syntax : TRUNC",
"system_function_std_syntax : UUID_TO_CHAR",
"system_function_std_syntax : QUANTIZE",
"system_function_std_syntax : TOTALORDER",
"system_function_std_syntax : NORMALIZE_DECFLOAT",
"system_function_std_syntax : COMPARE_DECFLOAT",
"system_function_special_syntax : DATEADD '(' value timestamp_part TO value ')'",
"system_function_special_syntax : DATEADD '(' timestamp_part ',' value ',' value ')'",
"system_function_special_syntax : DATEDIFF '(' timestamp_part FROM value TO value ')'",
"system_function_special_syntax : DATEDIFF '(' timestamp_part ',' value ',' value ')'",
"system_function_special_syntax : encrypt_decrypt '(' value USING valid_symbol_name crypt_opt_mode KEY value crypt_opt_iv crypt_opt_counter_type crypt_opt_counter ')'",
"system_function_special_syntax : FIRST_DAY '(' of_first_last_day_part FROM value ')'",
"system_function_special_syntax : HASH '(' value ')'",
"system_function_special_syntax : hash_func '(' value USING valid_symbol_name ')'",
"system_function_special_syntax : LAST_DAY '(' of_first_last_day_part FROM value ')'",
"system_function_special_syntax : OVERLAY '(' value PLACING value FROM value FOR value ')'",
"system_function_special_syntax : OVERLAY '(' value PLACING value FROM value ')'",
"system_function_special_syntax : POSITION '(' value IN value ')'",
"system_function_special_syntax : POSITION '(' value_list_opt ')'",
"system_function_special_syntax : rsa_encrypt_decrypt '(' value KEY value crypt_opt_lparam crypt_opt_hash crypt_opt_pkcs ')'",
"system_function_special_syntax : RSA_SIGN_HASH '(' value KEY value crypt_opt_hash crypt_opt_saltlen crypt_opt_pkcs ')'",
"system_function_special_syntax : RSA_VERIFY_HASH '(' value SIGNATURE value KEY value crypt_opt_hash crypt_opt_saltlen crypt_opt_pkcs ')'",
"system_function_special_syntax : RDB_SYSTEM_PRIVILEGE '(' valid_symbol_name ')'",
"hash_func : HASH",
"hash_func : CRYPT_HASH",
"rsa_encrypt_decrypt : RSA_DECRYPT",
"rsa_encrypt_decrypt : RSA_ENCRYPT",
"crypt_opt_lparam :",
"crypt_opt_lparam : LPARAM value",
"crypt_opt_pkcs :",
"crypt_opt_pkcs : PKCS_1_5",
"crypt_opt_hash :",
"crypt_opt_hash : HASH valid_symbol_name",
"crypt_opt_saltlen :",
"crypt_opt_saltlen : SALT_LENGTH value",
"crypt_opt_mode :",
"crypt_opt_mode : MODE valid_symbol_name",
"crypt_opt_iv :",
"crypt_opt_iv : IV value",
"crypt_opt_counter_type :",
"crypt_opt_counter_type : crypt_counter_type",
"crypt_counter_type : CTR_BIG_ENDIAN",
"crypt_counter_type : CTR_LITTLE_ENDIAN",
"crypt_opt_counter :",
"crypt_opt_counter : crypt_counter_name value",
"crypt_counter_name : COUNTER",
"crypt_counter_name : CTR_LENGTH",
"encrypt_decrypt : ENCRYPT",
"encrypt_decrypt : DECRYPT",
"of_first_last_day_part : OF YEAR",
"of_first_last_day_part : OF MONTH",
"of_first_last_day_part : OF WEEK",
"string_value_function : substring_function",
"string_value_function : trim_function",
"string_value_function : UPPER '(' value ')'",
"string_value_function : LOWER '(' value ')'",
"substring_function : SUBSTRING '(' value FROM value string_length_opt ')'",
"substring_function : SUBSTRING '(' value SIMILAR value ESCAPE value ')'",
"string_length_opt :",
"string_length_opt : FOR value",
"trim_function : TRIM '(' trim_specification value FROM value ')'",
"trim_function : TRIM '(' value FROM value ')'",
"trim_function : TRIM '(' trim_specification FROM value ')'",
"trim_function : TRIM '(' value ')'",
"trim_specification : BOTH",
"trim_specification : TRAILING",
"trim_specification : LEADING",
"udf : symbol_UDF_call_name '(' value_list ')'",
"udf : symbol_UDF_call_name '(' ')'",
"udf : symbol_package_name '.' symbol_UDF_name '(' value_list ')'",
"udf : symbol_package_name '.' symbol_UDF_name '(' ')'",
"cast_specification : CAST '(' value AS data_type_descriptor ')'",
"case_expression : case_abbreviation",
"case_expression : case_specification",
"case_abbreviation : NULLIF '(' value ',' value ')'",
"case_abbreviation : IIF '(' search_condition ',' value ',' value ')'",
"case_abbreviation : COALESCE '(' value ',' value_list ')'",
"case_abbreviation : DECODE '(' value ',' decode_pairs ')'",
"case_abbreviation : DECODE '(' value ',' decode_pairs ',' value ')'",
"case_specification : simple_case",
"case_specification : searched_case",
"$$171 :",
"$$172 :",
"$$173 :",
"simple_case : CASE case_operand $$171 $$172 $$173 simple_when_clause else_case_result_opt END",
"simple_when_clause : WHEN when_operand THEN case_result",
"simple_when_clause : simple_when_clause WHEN when_operand THEN case_result",
"else_case_result_opt :",
"else_case_result_opt : ELSE case_result",
"searched_case : CASE searched_when_clause END",
"searched_case : CASE searched_when_clause ELSE case_result END",
"searched_when_clause : WHEN search_condition THEN case_result",
"searched_when_clause : searched_when_clause WHEN search_condition THEN case_result",
"when_operand : value",
"case_operand : value",
"case_result : value",
"decode_pairs : value ',' value",
"decode_pairs : decode_pairs ',' value ',' value",
"next_value_expression : NEXT VALUE FOR symbol_generator_name",
"next_value_expression : GEN_ID '(' symbol_generator_name ',' value ')'",
"timestamp_part : YEAR",
"timestamp_part : MONTH",
"timestamp_part : DAY",
"timestamp_part : HOUR",
"timestamp_part : MINUTE",
"timestamp_part : SECOND",
"timestamp_part : MILLISECOND",
"timestamp_part : TIMEZONE_HOUR",
"timestamp_part : TIMEZONE_MINUTE",
"timestamp_part : WEEK",
"timestamp_part : WEEKDAY",
"timestamp_part : YEARDAY",
"all_noise :",
"all_noise : ALL",
"distinct_noise :",
"distinct_noise : DISTINCT",
"null_value : NULL",
"null_value : UNKNOWN",
"symbol_UDF_call_name : SYMBOL",
"symbol_UDF_name : valid_symbol_name",
"symbol_blob_subtype_name : valid_symbol_name",
"symbol_blob_subtype_name : BINARY",
"symbol_character_set_name : valid_symbol_name",
"symbol_character_set_name : BINARY",
"symbol_collation_name : valid_symbol_name",
"symbol_column_name : valid_symbol_name",
"symbol_constraint_name : valid_symbol_name",
"symbol_cursor_name : valid_symbol_name",
"symbol_domain_name : valid_symbol_name",
"symbol_exception_name : valid_symbol_name",
"symbol_filter_name : valid_symbol_name",
"symbol_gdscode_name : valid_symbol_name",
"symbol_generator_name : valid_symbol_name",
"symbol_index_name : valid_symbol_name",
"symbol_item_alias_name : valid_symbol_name",
"symbol_label_name : valid_symbol_name",
"symbol_ddl_name : valid_symbol_name",
"symbol_procedure_name : valid_symbol_name",
"symbol_role_name : valid_symbol_name",
"symbol_table_alias_name : valid_symbol_name",
"symbol_table_name : valid_symbol_name",
"symbol_trigger_name : valid_symbol_name",
"symbol_user_name : valid_symbol_name",
"symbol_variable_name : valid_symbol_name",
"symbol_view_name : valid_symbol_name",
"symbol_savepoint_name : valid_symbol_name",
"symbol_package_name : valid_symbol_name",
"symbol_window_name : valid_symbol_name",
"valid_symbol_name : SYMBOL",
"valid_symbol_name : non_reserved_word",
"non_reserved_word : ACTION",
"non_reserved_word : CASCADE",
"non_reserved_word : FREE_IT",
"non_reserved_word : RESTRICT",
"non_reserved_word : ROLE",
"non_reserved_word : TYPE",
"non_reserved_word : BREAK",
"non_reserved_word : DESCRIPTOR",
"non_reserved_word : SUBSTRING",
"non_reserved_word : COALESCE",
"non_reserved_word : LAST",
"non_reserved_word : LEAVE",
"non_reserved_word : LOCK",
"non_reserved_word : NULLIF",
"non_reserved_word : NULLS",
"non_reserved_word : STATEMENT",
"non_reserved_word : FIRST",
"non_reserved_word : SKIP",
"non_reserved_word : BLOCK",
"non_reserved_word : BACKUP",
"non_reserved_word : DIFFERENCE",
"non_reserved_word : IIF",
"non_reserved_word : SCALAR_ARRAY",
"non_reserved_word : WEEKDAY",
"non_reserved_word : YEARDAY",
"non_reserved_word : SEQUENCE",
"non_reserved_word : NEXT",
"non_reserved_word : RESTART",
"non_reserved_word : COLLATION",
"non_reserved_word : RETURNING",
"non_reserved_word : IGNORE",
"non_reserved_word : LIMBO",
"non_reserved_word : UNDO",
"non_reserved_word : REQUESTS",
"non_reserved_word : TIMEOUT",
"non_reserved_word : ABS",
"non_reserved_word : ACCENT",
"non_reserved_word : ACOS",
"non_reserved_word : ALWAYS",
"non_reserved_word : ASCII_CHAR",
"non_reserved_word : ASCII_VAL",
"non_reserved_word : ASIN",
"non_reserved_word : ATAN",
"non_reserved_word : ATAN2",
"non_reserved_word : BIN_AND",
"non_reserved_word : BIN_OR",
"non_reserved_word : BIN_SHL",
"non_reserved_word : BIN_SHR",
"non_reserved_word : BIN_XOR",
"non_reserved_word : CEIL",
"non_reserved_word : COS",
"non_reserved_word : COSH",
"non_reserved_word : COT",
"non_reserved_word : DATEADD",
"non_reserved_word : DATEDIFF",
"non_reserved_word : DECODE",
"non_reserved_word : EXP",
"non_reserved_word : FLOOR",
"non_reserved_word : GEN_UUID",
"non_reserved_word : GENERATED",
"non_reserved_word : HASH",
"non_reserved_word : LIST",
"non_reserved_word : LN",
"non_reserved_word : LOG",
"non_reserved_word : LOG10",
"non_reserved_word : LPAD",
"non_reserved_word : MATCHED",
"non_reserved_word : MATCHING",
"non_reserved_word : MAXVALUE",
"non_reserved_word : MILLISECOND",
"non_reserved_word : MINVALUE",
"non_reserved_word : MOD",
"non_reserved_word : OVERLAY",
"non_reserved_word : PAD",
"non_reserved_word : PI",
"non_reserved_word : PLACING",
"non_reserved_word : POWER",
"non_reserved_word : PRESERVE",
"non_reserved_word : RAND",
"non_reserved_word : REPLACE",
"non_reserved_word : REVERSE",
"non_reserved_word : ROUND",
"non_reserved_word : RPAD",
"non_reserved_word : SIGN",
"non_reserved_word : SIN",
"non_reserved_word : SINH",
"non_reserved_word : SPACE",
"non_reserved_word : SQRT",
"non_reserved_word : TAN",
"non_reserved_word : TANH",
"non_reserved_word : TEMPORARY",
"non_reserved_word : TRUNC",
"non_reserved_word : AUTONOMOUS",
"non_reserved_word : CHAR_TO_UUID",
"non_reserved_word : FIRSTNAME",
"non_reserved_word : MIDDLENAME",
"non_reserved_word : LASTNAME",
"non_reserved_word : MAPPING",
"non_reserved_word : OS_NAME",
"non_reserved_word : UUID_TO_CHAR",
"non_reserved_word : GRANTED",
"non_reserved_word : CALLER",
"non_reserved_word : COMMON",
"non_reserved_word : DATA",
"non_reserved_word : SOURCE",
"non_reserved_word : TWO_PHASE",
"non_reserved_word : BIN_NOT",
"non_reserved_word : ACTIVE",
"non_reserved_word : AFTER",
"non_reserved_word : ASC",
"non_reserved_word : AUTO",
"non_reserved_word : BEFORE",
"non_reserved_word : COMMITTED",
"non_reserved_word : COMPUTED",
"non_reserved_word : CONDITIONAL",
"non_reserved_word : CONTAINING",
"non_reserved_word : CSTRING",
"non_reserved_word : DATABASE",
"non_reserved_word : DESC",
"non_reserved_word : DO",
"non_reserved_word : DOMAIN",
"non_reserved_word : ENTRY_POINT",
"non_reserved_word : EXCEPTION",
"non_reserved_word : EXIT",
"non_reserved_word : FILE",
"non_reserved_word : GENERATOR",
"non_reserved_word : GEN_ID",
"non_reserved_word : IF",
"non_reserved_word : INACTIVE",
"non_reserved_word : INPUT_TYPE",
"non_reserved_word : ISOLATION",
"non_reserved_word : KEY",
"non_reserved_word : LENGTH",
"non_reserved_word : LEVEL",
"non_reserved_word : MANUAL",
"non_reserved_word : MODULE_NAME",
"non_reserved_word : NAMES",
"non_reserved_word : OPTION",
"non_reserved_word : OUTPUT_TYPE",
"non_reserved_word : OVERFLOW",
"non_reserved_word : PAGE",
"non_reserved_word : PAGES",
"non_reserved_word : PAGE_SIZE",
"non_reserved_word : PASSWORD",
"non_reserved_word : PRIVILEGES",
"non_reserved_word : PROTECTED",
"non_reserved_word : READ",
"non_reserved_word : RESERVING",
"non_reserved_word : RETAIN",
"non_reserved_word : SEGMENT",
"non_reserved_word : SHADOW",
"non_reserved_word : SHARED",
"non_reserved_word : SINGULAR",
"non_reserved_word : SIZE",
"non_reserved_word : SNAPSHOT",
"non_reserved_word : SORT",
"non_reserved_word : STABILITY",
"non_reserved_word : STARTING",
"non_reserved_word : STATISTICS",
"non_reserved_word : SUB_TYPE",
"non_reserved_word : SUSPEND",
"non_reserved_word : TRANSACTION",
"non_reserved_word : UNCOMMITTED",
"non_reserved_word : WAIT",
"non_reserved_word : WEEK",
"non_reserved_word : WORK",
"non_reserved_word : WRITE",
"non_reserved_word : ABSOLUTE",
"non_reserved_word : ACOSH",
"non_reserved_word : ASINH",
"non_reserved_word : ATANH",
"non_reserved_word : BODY",
"non_reserved_word : CONTINUE",
"non_reserved_word : DDL",
"non_reserved_word : DECRYPT",
"non_reserved_word : ENCRYPT",
"non_reserved_word : ENGINE",
"non_reserved_word : IDENTITY",
"non_reserved_word : NAME",
"non_reserved_word : PACKAGE",
"non_reserved_word : PARTITION",
"non_reserved_word : PRIOR",
"non_reserved_word : RELATIVE",
"non_reserved_word : DENSE_RANK",
"non_reserved_word : FIRST_VALUE",
"non_reserved_word : NTH_VALUE",
"non_reserved_word : LAST_VALUE",
"non_reserved_word : LAG",
"non_reserved_word : LEAD",
"non_reserved_word : RANK",
"non_reserved_word : ROW_NUMBER",
"non_reserved_word : USAGE",
"non_reserved_word : LINGER",
"non_reserved_word : TAGS",
"non_reserved_word : PLUGIN",
"non_reserved_word : SERVERWIDE",
"non_reserved_word : INCREMENT",
"non_reserved_word : TRUSTED",
"non_reserved_word : BASE64_DECODE",
"non_reserved_word : BASE64_ENCODE",
"non_reserved_word : BIND",
"non_reserved_word : CLEAR",
"non_reserved_word : COUNTER",
"non_reserved_word : COMPARE_DECFLOAT",
"non_reserved_word : CONNECTIONS",
"non_reserved_word : CONSISTENCY",
"non_reserved_word : CRYPT_HASH",
"non_reserved_word : CTR_BIG_ENDIAN",
"non_reserved_word : CTR_LENGTH",
"non_reserved_word : CTR_LITTLE_ENDIAN",
"non_reserved_word : CUME_DIST",
"non_reserved_word : DEFINER",
"non_reserved_word : DISABLE",
"non_reserved_word : ENABLE",
"non_reserved_word : EXCESS",
"non_reserved_word : EXCLUDE",
"non_reserved_word : EXTENDED",
"non_reserved_word : FIRST_DAY",
"non_reserved_word : FOLLOWING",
"non_reserved_word : HEX_DECODE",
"non_reserved_word : HEX_ENCODE",
"non_reserved_word : IDLE",
"non_reserved_word : INCLUDE",
"non_reserved_word : INVOKER",
"non_reserved_word : IV",
"non_reserved_word : LAST_DAY",
"non_reserved_word : LEGACY",
"non_reserved_word : LIFETIME",
"non_reserved_word : LPARAM",
"non_reserved_word : MAKE_DBKEY",
"non_reserved_word : MESSAGE",
"non_reserved_word : MODE",
"non_reserved_word : NATIVE",
"non_reserved_word : NORMALIZE_DECFLOAT",
"non_reserved_word : NTILE",
"non_reserved_word : NUMBER",
"non_reserved_word : OLDEST",
"non_reserved_word : OTHERS",
"non_reserved_word : OVERRIDING",
"non_reserved_word : PERCENT_RANK",
"non_reserved_word : POOL",
"non_reserved_word : PRECEDING",
"non_reserved_word : PRIVILEGE",
"non_reserved_word : QUANTIZE",
"non_reserved_word : RANGE",
"non_reserved_word : RESET",
"non_reserved_word : RSA_DECRYPT",
"non_reserved_word : RSA_ENCRYPT",
"non_reserved_word : RSA_PRIVATE",
"non_reserved_word : RSA_PUBLIC",
"non_reserved_word : RSA_SIGN_HASH",
"non_reserved_word : RSA_VERIFY_HASH",
"non_reserved_word : SALT_LENGTH",
"non_reserved_word : SECURITY",
"non_reserved_word : SESSION",
"non_reserved_word : SIGNATURE",
"non_reserved_word : SQL",
"non_reserved_word : SYSTEM",
"non_reserved_word : TIES",
"non_reserved_word : TOTALORDER",
"non_reserved_word : TRAPS",
"non_reserved_word : ZONE",
"non_reserved_word : DEBUG",
"non_reserved_word : PKCS_1_5",
"non_reserved_word : BLOB_APPEND",
};
#endif

#ifdef YYREDUCEPOSNFUNC
#define YYCALLREDUCEPOSN(e)   \
	if (reduce_posn) {     \
	  YYREDUCEPOSNFUNC(yyps->pos, &(yyps->psp)[1 - yym], &(yyps->vsp)[1 - yym], \
			   yym, yyps->psp - yyps->ps, yychar, yyposn, e);       \
	  reduce_posn = 0;    \
	}

#ifndef YYCALLREDUCEPOSNARG
#define YYCALLREDUCEPOSNARG yyps->val
#endif


#define YYPOSNARG(n) ((yyps->psp)[1 - yym + (n) - 1])
#define YYPOSNOUT    (yyps->pos)
#endif

// If delete function is not defined by the user, do not deletions.
#ifndef YYDELETEVAL
#define YYDELETEVAL(v, n)
#endif

// If delete function is not defined by the user, do not deletions.
#ifndef YYDELETEPOSN
#define YYDELETEPOSN(v, n)
#endif

#define yyclearin (yychar = (-1))

#define yyerrok (yyps->errflag = 0)

#ifndef YYSTACKGROWTH
#define YYSTACKGROWTH 128
#endif

#ifndef YYDEFSTACKSIZE
#define YYDEFSTACKSIZE 12
#endif

#ifdef YYDEBUG
int yydebug;
#endif


#define YYABORT  goto yyabort
#define YYACCEPT goto yyaccept
#define YYVALID         do { if (yyps->save)          goto yyvalid; } while(0)
#define YYVALID_NESTED  do { if (yyps->save && \
                                 yyps->save->save == 0) goto yyvalid; } while(0)
//
// For use in generated program
//
#define yytrial (yyps->save)
#define yyvsp   (yyps->vsp)
#define yyval   (yyps->val)
#define yydepth (yyps->ssp - yyps->ss)




void Parser::yySCopy(YYSTYPE* to, YYSTYPE* from, int size)
{
  int i;
  for (i = size - 1; i >= 0; i--) {
    to[i] = from[i];
  }
}


void Parser::yyPCopy(YYPOSN* to, YYPOSN* from, int size)
{
  int i;
  for (i = size - 1; i >= 0; i--) {
    to[i] = from[i];
  }
}


void Parser::yyMoreStack(yyparsestate* yyps)
{
  int p = yyps->ssp - yyps->ss;
  Yshort  *tss = yyps->ss;
  YYSTYPE *tvs = yyps->vs;
  YYPOSN  *tps = yyps->ps;
  yyps->ss = FB_NEW_POOL(getPool()) Yshort [yyps->stacksize + YYSTACKGROWTH];
  yyps->vs = FB_NEW_POOL(getPool()) YYSTYPE[yyps->stacksize + YYSTACKGROWTH];
  yyps->ps = FB_NEW_POOL(getPool()) YYPOSN [yyps->stacksize + YYSTACKGROWTH];
  memcpy(yyps->ss, tss, yyps->stacksize * sizeof(Yshort));
  yySCopy(yyps->vs, tvs, yyps->stacksize);
  yyPCopy(yyps->ps, tps, yyps->stacksize);
  yyps->stacksize += YYSTACKGROWTH;
  delete[] tss;
  delete[] tvs;
  delete[] tps;
  yyps->ssp = yyps->ss + p;
  yyps->vsp = yyps->vs + p;
  yyps->psp = yyps->ps + p;
}


Parser::yyparsestate* Parser::yyNewState(int size)
{
  yyparsestate *p = FB_NEW_POOL(getPool()) yyparsestate;
  p->stacksize = size + 4;
  p->ss = FB_NEW_POOL(getPool()) Yshort [size + 4];
  p->vs = FB_NEW_POOL(getPool()) YYSTYPE[size + 4];
  p->ps = FB_NEW_POOL(getPool()) YYPOSN [size + 4];
  memset(&p->vs[0], 0, (size + 4) * sizeof(YYSTYPE));
  memset(&p->ps[0], 0, (size + 4) * sizeof(YYPOSN));
  return p;
}


void Parser::yyFreeState(Parser::yyparsestate* p)
{
  delete[] p->ss;
  delete[] p->vs;
  delete[] p->ps;
  delete p;
}


void Parser::setNodeLineColumn(Node* node)
{
	// Check if we are not accessing the position stack below its base.
	if (&YYPOSNARG(1) >= yyps->ps)
	{
		node->line = YYPOSNARG(1).firstLine;
		node->column = YYPOSNARG(1).firstColumn;
	}
}


int Parser::parseAux()
{
  // ASF: yym moved to Parser.h
  int /*yym, */yyn, yystate, yychar, yynewerrflag;
  yyparsestate *yyerrctx = NULL;
  int reduce_posn;

#if YYDEBUG
  const char *yys;

  if ((yys = getenv("YYDEBUG"))) {
    yyn = *yys;
    if (yyn >= '0' && yyn <= '9')
      yydebug = yyn - '0';
  }
#endif

  yyps = yyNewState(YYDEFSTACKSIZE);
  yyps->save = 0;
  yynerrs = 0;
  yyps->errflag = 0;
  yychar = (-1);

  yyps->ssp = yyps->ss;
  yyps->vsp = yyps->vs;
  yyps->psp = yyps->ps;
  *(yyps->ssp) = yystate = 0;


  //
  // Main parsing loop
  //
 yyloop:
  if ((yyn = yydefred[yystate])) {
    goto yyreduce;
  }

  //
  // Read one token
  //
  if (yychar < 0) {
    if ((yychar = yylex1()) < 0) yychar = 0;
#if YYDEBUG
    if (yydebug) {
      yys = 0;
      if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
      if (!yys) yys = "illegal-symbol";
      printf("yydebug[%d,%p]: state %d, reading %d (%s)",
	     int(yydepth), yytrial, yystate, yychar, yys);
#ifdef YYDBPR
      printf("<");
      YYDBPR(yylval);
      printf(">");
#endif
      printf("\n");
    }
#endif
  }

  //
  // Do we have a conflict?
  //
  if ((yyn = yycindex[yystate]) &&
      (yyn += yychar) >= 0 &&
      yyn <= YYTABLESIZE &&
      yycheck[yyn] == yychar) {
    int ctry;

    if (yypath) {
#if YYDEBUG
      if (yydebug) {
        printf("yydebug[%d,%p]: CONFLICT in state %d: following successful trial parse\n",
	       int(yydepth), yytrial, yystate);
      }
#endif
      // Switch to the next conflict context
      yyparsestate *save = yypath;
      yypath = save->save;
      ctry = save->ctry;
      if (save->state != yystate)
        goto yyabort;
      yyFreeState(save);

    } else {

#if YYDEBUG
      if (yydebug) {
        printf("yydebug[%d,%p]: CONFLICT in state %d. ",
	       int(yydepth), yytrial, yystate);
        if (yyps->save) {
          printf("ALREADY in conflict. Continue trial parse.");
        } else {
          printf("Start trial parse.");
        }
        printf("\n");
      }
#endif
      yyparsestate *save = yyNewState(yyps->ssp - yyps->ss);
      save->save    = yyps->save;
      save->state   = yystate;
      save->errflag = yyps->errflag;
      save->ssp     = save->ss + (yyps->ssp - yyps->ss);
      save->vsp     = save->vs + (yyps->vsp - yyps->vs);
      save->psp     = save->ps + (yyps->psp - yyps->ps);
      memcpy (save->ss, yyps->ss, (yyps->ssp - yyps->ss + 1) * sizeof(Yshort));
      yySCopy(save->vs, yyps->vs, (yyps->ssp - yyps->ss + 1));
      yyPCopy(save->ps, yyps->ps, (yyps->ssp - yyps->ss + 1));
      ctry = yytable[yyn];
      if (yyctable[ctry] == -1) {
#if YYDEBUG
        if (yydebug && yychar >= 0)
          printf("yydebug[%p]: backtracking 1 token\n", yytrial);
#endif
        ctry++;
      }
      save->ctry = ctry;
      if (!yyps->save) {
        // If this is a first conflict in the stack, start saving lexemes
        if (!yylexemes) {
          yylexemes = FB_NEW_POOL(getPool()) Yshort[YYSTACKGROWTH];
          yylvals = FB_NEW_POOL(getPool()) YYSTYPE[YYSTACKGROWTH];
          yylvlim = yylvals + YYSTACKGROWTH;
          yylpsns = FB_NEW_POOL(getPool()) YYPOSN[YYSTACKGROWTH];
          yylplim = yylpsns + YYSTACKGROWTH;
        }
        if (yylvp == yylve) {
          yylvp = yylve = yylvals;
	  yylpp = yylpe = yylpsns;
          yylexp = yylexemes;
          if (yychar >= 0) {
            *yylve++ = yylval;
            *yylpe++ = yyposn;
            *yylexp = yychar;
            yychar = -1;
          }
        }
      }
      if (yychar >= 0) {
        yylvp--, yylpp--, yylexp--;
        yychar = -1;
      }
      save->lexeme = yylvp - yylvals;
      yyps->save = save;
    }
    if (yytable[yyn] == ctry) {
#if YYDEBUG
      if (yydebug)
        printf("yydebug[%d,%p]: state %d, shifting to state %d\n",
               int(yydepth), yytrial, yystate, yyctable[ctry]);
#endif
      if (yychar < 0)
        yylvp++, yylpp++, yylexp++;
      yychar = -1;
      if (yyps->errflag > 0) --yyps->errflag;
      yystate = yyctable[ctry];
      goto yyshift;
    } else {
      yyn = yyctable[ctry];
      goto yyreduce;
    }
  }

  //
  // Is action a shift?
  //
  if ((yyn = yysindex[yystate]) &&
      (yyn += yychar) >= 0 &&
      yyn <= YYTABLESIZE &&
      yycheck[yyn] == yychar) {
#if YYDEBUG
    if (yydebug)
      printf("yydebug[%d,%p]: state %d, shifting to state %d\n",
             int(yydepth), yytrial, yystate, yytable[yyn]);
#endif
    yychar = (-1);
    if (yyps->errflag > 0)  --yyps->errflag;
    yystate = yytable[yyn];
  yyshift:
    if (yyps->ssp >= yyps->ss + yyps->stacksize - 1) {
      yyMoreStack(yyps);
    }
    *++(yyps->ssp) = yystate;
    *++(yyps->vsp) = yylval;
    *++(yyps->psp) = yyposn;
    goto yyloop;
  }
  if ((yyn = yyrindex[yystate]) &&
      (yyn += yychar) >= 0 &&
      yyn <= YYTABLESIZE &&
      yycheck[yyn] == yychar) {
    yyn = yytable[yyn];
    goto yyreduce;
  }

  //
  // Action: error
  //
  if (yyps->errflag) goto yyinrecovery;
  while (yyps->save) {
    int ctry;
    yyparsestate *save = yyps->save;
#if YYDEBUG
    if (yydebug)
      printf("yydebug[%d,%p]: ERROR in state %d, CONFLICT BACKTRACKING to state %d, %d tokens\n",
             int(yydepth), yytrial, yystate, yyps->save->state, int(yylvp - yylvals - yyps->save->lexeme));
#endif
    // Memorize most forward-looking error state in case
    // it's really an error.
    if (yyerrctx == NULL || yyerrctx->lexeme < yylvp-yylvals) {
      // Free old saved error context state
      if (yyerrctx) yyFreeState(yyerrctx);
      // Create and fill out new saved error context state
      yyerrctx = yyNewState(yyps->ssp - yyps->ss);
      yyerrctx->save = yyps->save;
      yyerrctx->state = yystate;
      yyerrctx->errflag = yyps->errflag;
      yyerrctx->ssp = yyerrctx->ss + (yyps->ssp - yyps->ss);
      yyerrctx->vsp = yyerrctx->vs + (yyps->vsp - yyps->vs);
      yyerrctx->psp = yyerrctx->ps + (yyps->psp - yyps->ps);
      memcpy (yyerrctx->ss, yyps->ss, (yyps->ssp - yyps->ss + 1) * sizeof(Yshort));
      yySCopy(yyerrctx->vs, yyps->vs, (yyps->ssp - yyps->ss + 1));
      yyPCopy(yyerrctx->ps, yyps->ps, (yyps->ssp - yyps->ss + 1));
      yyerrctx->lexeme = yylvp - yylvals;
    }
    yylvp  = yylvals   + save->lexeme;
    yylpp  = yylpsns   + save->lexeme;
    yylexp = yylexemes + save->lexeme;
    yychar = -1;
    yyps->ssp = yyps->ss + (save->ssp - save->ss);
    yyps->vsp = yyps->vs + (save->vsp - save->vs);
    yyps->psp = yyps->ps + (save->psp - save->ps);
    memcpy (yyps->ss, save->ss, (yyps->ssp - yyps->ss + 1) * sizeof(Yshort));
    yySCopy(yyps->vs, save->vs,  yyps->vsp - yyps->vs + 1);
    yyPCopy(yyps->ps, save->ps,  yyps->psp - yyps->ps + 1);
    ctry = ++save->ctry;
    yystate = save->state;
    // We tried shift, try reduce now
    if ((yyn = yyctable[ctry]) >= 0) {
      goto yyreduce;
    }
    yyps->save = save->save;
    yyFreeState(save);
    //
    // Nothing left on the stack -- error
    //
    if (!yyps->save) {
#if YYDEBUG
      if (yydebug) {
        printf("yydebug[%p]: trial parse FAILED, entering ERROR mode\n",
	       yytrial);
      }
#endif
      // Restore state as it was in the most forward-advanced error
      yylvp  = yylvals   + yyerrctx->lexeme;
      yylpp  = yylpsns   + yyerrctx->lexeme;
      yylexp = yylexemes + yyerrctx->lexeme;
      yychar = yylexp[-1];
      yylval = yylvp[-1];
      yyposn = yylpp[-1];
      yyps->ssp = yyps->ss + (yyerrctx->ssp - yyerrctx->ss);
      yyps->vsp = yyps->vs + (yyerrctx->vsp - yyerrctx->vs);
      yyps->psp = yyps->ps + (yyerrctx->psp - yyerrctx->ps);
      memcpy (yyps->ss, yyerrctx->ss, (yyps->ssp - yyps->ss + 1) * sizeof(Yshort));
      yySCopy(yyps->vs, yyerrctx->vs,  yyps->vsp - yyps->vs + 1);
      yyPCopy(yyps->ps, yyerrctx->ps,  yyps->psp - yyps->ps + 1);
      yystate = yyerrctx->state;
      yyFreeState(yyerrctx);
      yyerrctx = NULL;
    }
  }
  yyerror_detailed("syntax error", yychar, yylval, yyposn);
  ++yynerrs;

 yyinrecovery:
  if (yyps->errflag < 3) {
    yyps->errflag = 3;
    for (;;) {
      if ((yyn = yysindex[*(yyps->ssp)]) &&
	  (yyn += YYERRCODE) >= 0 &&
          yyn <= YYTABLESIZE &&
	  yycheck[yyn] == YYERRCODE) {
#if YYDEBUG
        if (yydebug)
          printf("yydebug[%d,%p]: state %d, ERROR recovery shifts to state %d\n",
                 int(yydepth), yytrial, *(yyps->ssp), yytable[yyn]);
#endif
        yystate = yytable[yyn];
        goto yyshift;
      } else {
#if YYDEBUG
        if (yydebug)
          printf("yydebug[%d,%p]: ERROR recovery discards state %d\n",
                 int(yydepth), yytrial, *(yyps->ssp));
#endif
        if (yyps->ssp <= yyps->ss) {
	  goto yyabort;
	}
	if (!yytrial) {
	  YYDELETEVAL(yyps->vsp[0], 1);
	  YYDELETEPOSN(yyps->psp[0], 1);
	}
        --(yyps->ssp);
        --(yyps->vsp);
        --(yyps->psp);
      }
    }
  } else {
    if (yychar == 0) goto yyabort;
#if YYDEBUG
    if (yydebug) {
      yys = 0;
      if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
      if (!yys) yys = "illegal-symbol";
      printf("yydebug[%d,%p]: state %d, ERROR recovery discards token %d (%s)\n",
             int(yydepth), yytrial, yystate, yychar, yys);
    }
#endif
    if (!yytrial) {
      YYDELETEVAL(yylval, 0);
      YYDELETEPOSN(yyposn, 0);
    }
    yychar = (-1);
    goto yyloop;
  }

  //
  // Reduce the rule
  //
yyreduce:
  yym = yylen[yyn];
#if YYDEBUG
  if (yydebug) {
    printf("yydebug[%d,%p]: state %d, reducing by rule %d (%s)",
           int(yydepth), yytrial, yystate, yyn, yyrule[yyn]);
#ifdef YYDBPR
    if (yym) {
      int i;
      printf("<");
      for (i = yym; i > 0; i--) {
        if (i != yym) printf(", ");
        YYDBPR((yyps->vsp)[1 - i]);
      }
      printf(">");
    }
#endif
    printf("\n");
  }
#endif
  if (yyps->ssp + 1 - yym >= yyps->ss + yyps->stacksize) {
    yyMoreStack(yyps);
  }

  /* default action - assign last argument as in standard yacc */
  yyps->val = yyvsp[1 - yym];

  /* default reduced position is NULL -- no position at all.
     no position will be assigned at trial time and if no position handling is present */
  memset(&yyps->pos, 0, sizeof(yyps->pos));

  reduce_posn = TRUE;

  switch (yyn) {

case 1:
  if (!yytrial)
{ DSQL_parse = yyvsp[0].dsqlReq; }
break;
case 2:
  if (!yytrial)
{ DSQL_parse = yyvsp[-1].dsqlReq; }
break;
case 3:
  if (!yytrial)
{ yyval.dsqlReq = FB_NEW_POOL(getStatementPool()) DsqlDmlRequest(getStatementPool(), yyvsp[0].stmtNode); }
break;
case 4:
  if (!yytrial)
{ yyval.dsqlReq = FB_NEW_POOL(getStatementPool()) DsqlDdlRequest(getStatementPool(), yyvsp[0].ddlNode); }
break;
case 5:
  if (!yytrial)
{ yyval.dsqlReq = FB_NEW_POOL(getStatementPool()) DsqlTransactionRequest(getStatementPool(), yyvsp[0].traNode); }
break;
case 6:
  if (!yytrial)
{ yyval.dsqlReq = FB_NEW_POOL(getStatementPool()) DsqlSessionManagementRequest(getStatementPool(), yyvsp[0].mngNode); }
break;
case 7:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].stmtNode; }
break;
case 8:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].storeNode; }
break;
case 9:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].mergeNode; }
break;
case 10:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].stmtNode; }
break;
case 11:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].execBlockNode; }
break;
case 12:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].stmtNode; }
break;
case 13:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].selectNode; }
break;
case 14:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].stmtNode; }
break;
case 15:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].updInsNode; }
break;
case 16:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 17:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 18:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 19:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 20:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 21:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 22:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].grantRevokeNode; }
break;
case 23:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 24:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].grantRevokeNode; }
break;
case 25:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 26:
  if (!yytrial)
{ yyval.traNode = yyvsp[0].setTransactionNode; }
break;
case 27:
  if (!yytrial)
{ yyval.traNode = yyvsp[0].traNode; }
break;
case 28:
  if (!yytrial)
{ yyval.traNode = yyvsp[0].traNode; }
break;
case 29:
  if (!yytrial)
{ yyval.mngNode = yyvsp[0].mngNode; }
break;
case 30:
  if (!yytrial)
{ yyval.mngNode = yyvsp[0].setDecFloatRoundNode; }
break;
case 31:
  if (!yytrial)
{ yyval.mngNode = yyvsp[0].setDecFloatTrapsNode; }
break;
case 32:
  if (!yytrial)
{ yyval.mngNode = yyvsp[0].setSessionNode; }
break;
case 33:
  if (!yytrial)
{ yyval.mngNode = yyvsp[0].setRoleNode; }
break;
case 34:
  if (!yytrial)
{ yyval.mngNode = yyvsp[0].sessionResetNode; }
break;
case 35:
  if (!yytrial)
{ yyval.mngNode = yyvsp[0].mngNode; }
break;
case 36:
  if (!yytrial)
{ yyval.mngNode = yyvsp[0].setBindNode; }
break;
case 37:
  if (!yytrial)
{ yyval.grantRevokeNode = newNode<GrantRevokeNode>(true); }
break;
case 38:
yyval.grantRevokeNode = yyvsp[0].grantRevokeNode;
break;
case 39:
  if (!yytrial)
{ yyval.grantRevokeNode = yyvsp[-2].grantRevokeNode; }
break;
case 40:
yyval.privilegeArray = NOTRIAL(&yyvsp[0].grantRevokeNode->privileges);
break;
case 41:
yyval.granteeArray = NOTRIAL(&yyvsp[-6].grantRevokeNode->users);
break;
case 42:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_relation, *yyvsp[-5].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-1].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 43:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_procedure, *yyvsp[-5].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-1].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 44:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_udf, *yyvsp[-5].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-1].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 45:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_package_header, *yyvsp[-5].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-1].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 46:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_exception, *yyvsp[-5].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-1].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 47:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_generator, *yyvsp[-5].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-1].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 48:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_generator, *yyvsp[-5].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-1].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 49:
yyval.granteeArray = NOTRIAL(&yyvsp[-4].grantRevokeNode->users);
break;
case 50:
  if (!yytrial)
{
			yyvsp[-8].grantRevokeNode->object = yyvsp[-5].granteeClause;
			yyvsp[-8].grantRevokeNode->grantAdminOption = yyvsp[-1].boolVal;
			yyvsp[-8].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
			yyvsp[-8].grantRevokeNode->isDdl = true;
		}
break;
case 51:
  if (!yytrial)
{
			yyvsp[-8].grantRevokeNode->object = newNode<GranteeClause>(obj_database, get_object_name(obj_database));
			yyvsp[-8].grantRevokeNode->grantAdminOption = yyvsp[-1].boolVal;
			yyvsp[-8].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
			yyvsp[-8].grantRevokeNode->isDdl = true;
		}
break;
case 52:
yyval.grantRevokeNode = NOTRIAL(yyvsp[0].grantRevokeNode);
break;
case 53:
yyval.granteeArray = NOTRIAL(&yyvsp[-3].grantRevokeNode->users);
break;
case 54:
  if (!yytrial)
{
			yyvsp[-7].grantRevokeNode->grantAdminOption = yyvsp[-1].boolVal;
			yyvsp[-7].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 55:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_relations, get_object_name(obj_relations)); }
break;
case 56:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_views, get_object_name(obj_views)); }
break;
case 57:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_procedures, get_object_name(obj_procedures)); }
break;
case 58:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_functions, get_object_name(obj_functions)); }
break;
case 59:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_packages, get_object_name(obj_packages)); }
break;
case 60:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_generators, get_object_name(obj_generators)); }
break;
case 61:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_generators, get_object_name(obj_generators)); }
break;
case 62:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_domains, get_object_name(obj_domains)); }
break;
case 63:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_exceptions, get_object_name(obj_exceptions)); }
break;
case 64:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_roles, get_object_name(obj_roles)); }
break;
case 65:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_charsets, get_object_name(obj_charsets)); }
break;
case 66:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_collations, get_object_name(obj_collations)); }
break;
case 67:
  if (!yytrial)
{ yyval.granteeClause = newNode<GranteeClause>(obj_filters, get_object_name(obj_filters)); }
break;
case 70:
  if (!yytrial)
{ yyvsp[-1].privilegeArray->add(PrivilegeClause('A', NULL)); }
break;
case 71:
  if (!yytrial)
{ yyvsp[-2].privilegeArray->add(PrivilegeClause('A', NULL)); }
break;
case 72:
yyval.privilegeArray = yyvsp[0].privilegeArray;
break;
case 75:
yyval.privilegeArray = yyvsp[-2].privilegeArray;
break;
case 77:
  if (!yytrial)
{ yyvsp[-1].privilegeArray->add(PrivilegeClause('X', NULL)); }
break;
case 78:
  if (!yytrial)
{ yyvsp[-1].privilegeArray->add(PrivilegeClause('G', NULL)); }
break;
case 79:
  if (!yytrial)
{ yyvsp[-1].privilegeArray->add(PrivilegeClause('S', NULL)); }
break;
case 80:
  if (!yytrial)
{ yyvsp[-1].privilegeArray->add(PrivilegeClause('I', NULL)); }
break;
case 81:
  if (!yytrial)
{ yyvsp[-1].privilegeArray->add(PrivilegeClause('D', NULL)); }
break;
case 82:
  if (!yytrial)
{ yyvsp[-2].privilegeArray->add(PrivilegeClause('U', yyvsp[0].valueListNode)); }
break;
case 83:
  if (!yytrial)
{ yyvsp[-2].privilegeArray->add(PrivilegeClause('R', yyvsp[0].valueListNode)); }
break;
case 84:
  if (!yytrial)
{
			yyvsp[-2].privilegeArray->add(PrivilegeClause('C', NULL));
			yyvsp[-2].privilegeArray->add(PrivilegeClause('L', NULL));
			yyvsp[-2].privilegeArray->add(PrivilegeClause('O', NULL));
		}
break;
case 90:
  if (!yytrial)
{ yyvsp[-1].privilegeArray->add(PrivilegeClause('C', NULL)); }
break;
case 91:
  if (!yytrial)
{ yyvsp[-2].privilegeArray->add(PrivilegeClause('L', NULL)); }
break;
case 92:
  if (!yytrial)
{ yyvsp[-2].privilegeArray->add(PrivilegeClause('O', NULL)); }
break;
case 93:
  if (!yytrial)
{
			yyvsp[-2].privilegeArray->add(PrivilegeClause('L', NULL));
			yyvsp[-2].privilegeArray->add(PrivilegeClause('O', NULL));
		}
break;
case 97:
  if (!yytrial)
{ yyvsp[-1].privilegeArray->add(PrivilegeClause('C', NULL)); }
break;
case 98:
  if (!yytrial)
{ yyvsp[-1].privilegeArray->add(PrivilegeClause('L', NULL)); }
break;
case 99:
  if (!yytrial)
{ yyvsp[-1].privilegeArray->add(PrivilegeClause('O', NULL)); }
break;
case 100:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 101:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 102:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 103:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 104:
  if (!yytrial)
{ yyval.metaNamePtr = NULL; }
break;
case 105:
  if (!yytrial)
{ yyval.metaNamePtr = yyvsp[0].metaNamePtr; }
break;
case 109:
  if (!yytrial)
{ yyval.metaNamePtr = yyvsp[0].metaNamePtr; }
break;
case 110:
  if (!yytrial)
{ yyval.grantRevokeNode = newNode<GrantRevokeNode>(false); }
break;
case 111:
  if (!yytrial)
{ yyval.grantRevokeNode = yyvsp[-2].grantRevokeNode; }
break;
case 112:
yyval.privilegeArray = NOTRIAL(&yyvsp[-1].grantRevokeNode->privileges);
break;
case 113:
yyval.granteeArray = NOTRIAL(&yyvsp[-7].grantRevokeNode->users);
break;
case 114:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_relation, *yyvsp[-4].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-9].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 115:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_procedure, *yyvsp[-4].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-9].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 116:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_udf, *yyvsp[-4].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-9].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 117:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_package_header, *yyvsp[-4].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-9].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 118:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_exception, *yyvsp[-4].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-9].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 119:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_generator, *yyvsp[-4].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-9].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 120:
  if (!yytrial)
{
			yyvsp[-10].grantRevokeNode->object = newNode<GranteeClause>(obj_generator, *yyvsp[-4].metaNamePtr);
			yyvsp[-10].grantRevokeNode->grantAdminOption = yyvsp[-9].boolVal;
			yyvsp[-10].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 121:
yyval.granteeArray = NOTRIAL(&yyvsp[-5].grantRevokeNode->users);
break;
case 122:
  if (!yytrial)
{
			yyvsp[-8].grantRevokeNode->object = yyvsp[-4].granteeClause;
			yyvsp[-8].grantRevokeNode->grantAdminOption = yyvsp[-7].boolVal;
			yyvsp[-8].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
			yyvsp[-8].grantRevokeNode->isDdl = true;
		}
break;
case 123:
  if (!yytrial)
{
			yyvsp[-8].grantRevokeNode->object = newNode<GranteeClause>(obj_database, get_object_name(obj_database));
			yyvsp[-8].grantRevokeNode->grantAdminOption = yyvsp[-7].boolVal;
			yyvsp[-8].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
			yyvsp[-8].grantRevokeNode->isDdl = true;
		}
break;
case 124:
yyval.grantRevokeNode = NOTRIAL(yyvsp[-1].grantRevokeNode);
break;
case 125:
  if (!yytrial)
{
			yyvsp[-7].grantRevokeNode->grantAdminOption = yyvsp[-6].boolVal;
			yyvsp[-7].grantRevokeNode->grantor = yyvsp[0].metaNamePtr;
		}
break;
case 127:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 128:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 129:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 130:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 131:
yyval.granteeArray = yyvsp[0].granteeArray;
break;
case 134:
yyval.granteeArray = yyvsp[-2].granteeArray;
break;
case 137:
  if (!yytrial)
{ yyvsp[-2].granteeArray->add(GranteeClause(obj_procedure, *yyvsp[0].metaNamePtr)); }
break;
case 138:
  if (!yytrial)
{ yyvsp[-2].granteeArray->add(GranteeClause(obj_udf, *yyvsp[0].metaNamePtr)); }
break;
case 139:
  if (!yytrial)
{ yyvsp[-2].granteeArray->add(GranteeClause(obj_package_header, *yyvsp[0].metaNamePtr)); }
break;
case 140:
  if (!yytrial)
{ yyvsp[-2].granteeArray->add(GranteeClause(obj_trigger, *yyvsp[0].metaNamePtr)); }
break;
case 141:
  if (!yytrial)
{ yyvsp[-2].granteeArray->add(GranteeClause(obj_view, *yyvsp[0].metaNamePtr)); }
break;
case 142:
  if (!yytrial)
{ yyvsp[-2].granteeArray->add(GranteeClause(obj_sql_role, *yyvsp[0].metaNamePtr)); }
break;
case 143:
  if (!yytrial)
{ yyvsp[-3].granteeArray->add(GranteeClause(obj_privilege, *yyvsp[0].metaNamePtr)); }
break;
case 144:
  if (!yytrial)
{ yyvsp[-1].granteeArray->add(GranteeClause(obj_user_or_role, *yyvsp[0].metaNamePtr)); }
break;
case 145:
  if (!yytrial)
{ yyvsp[-2].granteeArray->add(GranteeClause(obj_user, *yyvsp[0].metaNamePtr)); }
break;
case 146:
  if (!yytrial)
{ yyvsp[-2].granteeArray->add(GranteeClause(obj_user_group, *yyvsp[0].metaNamePtr)); }
break;
case 148:
yyval.grantRevokeNode = yyvsp[-2].grantRevokeNode;
break;
case 150:
  if (!yytrial)
{
			yyvsp[-1].grantRevokeNode->roles.add(GranteeClause(obj_sql_role, *yyvsp[0].metaNamePtr));
			yyvsp[-1].grantRevokeNode->defaultRoles.add(false);
		}
break;
case 151:
  if (!yytrial)
{
			yyvsp[-2].grantRevokeNode->roles.add(GranteeClause(obj_sql_role, *yyvsp[0].metaNamePtr));
			yyvsp[-2].grantRevokeNode->defaultRoles.add(true);
		}
break;
case 154:
  if (!yytrial)
{ yyvsp[-1].granteeArray->add(GranteeClause(obj_user_or_role, *yyvsp[0].metaNamePtr)); }
break;
case 155:
  if (!yytrial)
{ yyvsp[-2].granteeArray->add(GranteeClause(obj_user, *yyvsp[0].metaNamePtr)); }
break;
case 156:
  if (!yytrial)
{ yyvsp[-2].granteeArray->add(GranteeClause(obj_sql_role, *yyvsp[0].metaNamePtr)); }
break;
case 157:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode;}
break;
case 158:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 159:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterFunctionNode; }
break;
case 160:
  if (!yytrial)
{ yyval.createAlterFunctionNode = newNode<CreateAlterFunctionNode>(*yyvsp[0].metaNamePtr); }
break;
case 161:
yyval.parametersClause = NOTRIAL(&yyvsp[0].createAlterFunctionNode->parameters);
break;
case 162:
yyval.createAlterFunctionNode = yyvsp[-3].createAlterFunctionNode;
break;
case 163:
  if (!yytrial)
{
				yyval.createAlterFunctionNode = yyvsp[-9].createAlterFunctionNode;
				yyval.createAlterFunctionNode->external = newNode<ExternalClause>();
				yyval.createAlterFunctionNode->external->name = *yyvsp[-2].stringPtr;
				yyval.createAlterFunctionNode->external->udfModule = *yyvsp[0].stringPtr;
			}
break;
case 165:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_blob;
			yyval.legacyField->length = sizeof(bid);
		}
break;
case 166:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_cstring;
			yyval.legacyField->charLength = (USHORT) yyvsp[-2].int32Val;
			if (yyvsp[0].metaNamePtr)
				yyval.legacyField->charSet = *yyvsp[0].metaNamePtr;
		}
break;
case 168:
yyval.parametersClause = yyvsp[0].parametersClause;
break;
case 170:
yyval.parametersClause = yyvsp[-1].parametersClause;
break;
case 173:
yyval.parametersClause = yyvsp[-2].parametersClause;
break;
case 175:
  if (!yytrial)
{
			yyvsp[-2].parametersClause->add(newNode<ParameterClause>(yyvsp[-1].legacyField, MetaName()));
			yyvsp[-2].parametersClause->back()->udfMechanism = yyvsp[0].nullableIntVal;
		}
break;
case 176:
  if (!yytrial)
{ yyval.nullableIntVal = Nullable<int>::empty(); }
break;
case 177:
  if (!yytrial)
{ yyval.nullableIntVal = Nullable<int>::val(FUN_descriptor); }
break;
case 178:
  if (!yytrial)
{ yyval.nullableIntVal = Nullable<int>::val(FUN_scalar_array); }
break;
case 179:
  if (!yytrial)
{ yyval.nullableIntVal = Nullable<int>::val(FUN_ref_with_null); }
break;
case 180:
yyval.createAlterFunctionNode = yyvsp[0].createAlterFunctionNode;
break;
case 182:
yyval.createAlterFunctionNode = yyvsp[-1].createAlterFunctionNode;
break;
case 184:
  if (!yytrial)
{
			yyvsp[-2].createAlterFunctionNode->returnType = newNode<ParameterClause>(yyvsp[-1].legacyField, MetaName());
			yyvsp[-2].createAlterFunctionNode->returnType->udfMechanism = yyvsp[0].int32Val;
		}
break;
case 185:
  if (!yytrial)
{ yyvsp[-2].createAlterFunctionNode->udfReturnPos = yyvsp[0].int32Val; }
break;
case 186:
  if (!yytrial)
{ yyval.int32Val = FUN_reference; }
break;
case 187:
  if (!yytrial)
{ yyval.int32Val = FUN_value; }
break;
case 188:
  if (!yytrial)
{ yyval.int32Val = FUN_descriptor; }
break;
case 189:
  if (!yytrial)
{ yyval.int32Val = -1 * FUN_reference; }
break;
case 190:
  if (!yytrial)
{ yyval.int32Val = -1 * FUN_descriptor; }
break;
case 191:
  if (!yytrial)
{
				CreateFilterNode* node = newNode<CreateFilterNode>(*yyvsp[-8].metaNamePtr);
				node->inputFilter = yyvsp[-6].filterNameNumber;
				node->outputFilter = yyvsp[-4].filterNameNumber;
				node->entryPoint = *yyvsp[-2].stringPtr;
				node->moduleName = *yyvsp[0].stringPtr;
				yyval.ddlNode = node;
			}
break;
case 192:
  if (!yytrial)
{ yyval.filterNameNumber = newNode<CreateFilterNode::NameNumber>(*yyvsp[0].metaNamePtr); }
break;
case 193:
  if (!yytrial)
{ yyval.filterNameNumber = newNode<CreateFilterNode::NameNumber>(yyvsp[0].int32Val); }
break;
case 194:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 195:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterExceptionNode; }
break;
case 196:
  if (!yytrial)
{
				CreateIndexNode* node = newNode<CreateIndexNode>(*yyvsp[-2].metaNamePtr);
				node->unique = yyvsp[-5].boolVal;
				node->descending = yyvsp[-4].boolVal;
				node->relation = yyvsp[0].relSourceNode;
				yyval.ddlNode = node;
			}
break;
case 197:
yyval.createIndexNode = static_cast<CreateIndexNode*>(yyvsp[0].ddlNode);
break;
case 198:
  if (!yytrial)
{
				yyval.ddlNode = yyvsp[-2].ddlNode;
			}
break;
case 199:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterFunctionNode; }
break;
case 200:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterProcedureNode; }
break;
case 201:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createRelationNode; }
break;
case 202:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createRelationNode; }
break;
case 203:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterTriggerNode; }
break;
case 204:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterViewNode; }
break;
case 205:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterSequenceNode; }
break;
case 206:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterSequenceNode; }
break;
case 207:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].alterDatabaseNode; }
break;
case 208:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createDomainNode; }
break;
case 209:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createShadowNode; }
break;
case 210:
  if (!yytrial)
{ yyvsp[0].createAlterRoleNode->createFlag = true; yyval.ddlNode = yyvsp[0].createAlterRoleNode; }
break;
case 211:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createCollationNode; }
break;
case 212:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterUserNode; }
break;
case 213:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterPackageNode; }
break;
case 214:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createPackageBodyNode; }
break;
case 215:
yyval.boolVal = false;
break;
case 216:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].mappingNode; }
break;
case 217:
yyval.boolVal = true;
break;
case 218:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].mappingNode; }
break;
case 219:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 220:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreateProcedureNode>(yyvsp[0].createAlterProcedureNode); }
break;
case 221:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreateFunctionNode>(yyvsp[0].createAlterFunctionNode); }
break;
case 222:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreateTableNode>(yyvsp[0].createRelationNode); }
break;
case 223:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreateTableNode>(yyvsp[0].createRelationNode); }
break;
case 224:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreateViewNode>(yyvsp[0].createAlterViewNode); }
break;
case 225:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreateTriggerNode>(yyvsp[0].createAlterTriggerNode); }
break;
case 226:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreatePackageNode>(yyvsp[0].createAlterPackageNode); }
break;
case 227:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreatePackageBodyNode>(yyvsp[0].createPackageBodyNode); }
break;
case 228:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreateExceptionNode>(yyvsp[0].createAlterExceptionNode); }
break;
case 229:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreateSequenceNode>(yyvsp[0].createAlterSequenceNode); }
break;
case 230:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreateSequenceNode>(yyvsp[0].createAlterSequenceNode); }
break;
case 231:
  if (!yytrial)
{ yyval.ddlNode = newNode<RecreateUserNode>(yyvsp[0].createAlterUserNode); }
break;
case 232:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 233:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterProcedureNode; }
break;
case 234:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterFunctionNode; }
break;
case 235:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterTriggerNode; }
break;
case 236:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterPackageNode; }
break;
case 237:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 238:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterExceptionNode; }
break;
case 239:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterSequenceNode; }
break;
case 240:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterSequenceNode; }
break;
case 241:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterUserNode; }
break;
case 242:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].mappingNode; }
break;
case 243:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].mappingNode; }
break;
case 244:
  if (!yytrial)
{ yyval.createAlterExceptionNode = newNode<CreateAlterExceptionNode>(*yyvsp[-1].metaNamePtr, yyvsp[0].intlStringPtr->getString()); }
break;
case 245:
  if (!yytrial)
{
			CreateAlterExceptionNode* node = newNode<CreateAlterExceptionNode>(*yyvsp[-1].metaNamePtr, yyvsp[0].intlStringPtr->getString());
			node->alter = true;
			yyval.createAlterExceptionNode = node;
		}
break;
case 246:
  if (!yytrial)
{
			CreateAlterExceptionNode* node = newNode<CreateAlterExceptionNode>(*yyvsp[-1].metaNamePtr, yyvsp[0].intlStringPtr->getString());
			node->create = false;
			node->alter = true;
			yyval.createAlterExceptionNode = node;
		}
break;
case 247:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 248:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 249:
  if (!yytrial)
{ yyvsp[-1].createIndexNode->columns = yyvsp[0].valueListNode; }
break;
case 250:
  if (!yytrial)
{ yyvsp[-1].createIndexNode->columns = yyvsp[0].valueListNode; }
break;
case 251:
  if (!yytrial)
{
 			yyvsp[-4].createIndexNode->computed = newNode<ValueSourceClause>();
			yyvsp[-4].createIndexNode->computed->value = yyvsp[-1].valueExprNode;
			yyvsp[-4].createIndexNode->computed->source = makeParseStr(YYPOSNARG(2), YYPOSNARG(4));
		}
break;
case 252:
  if (!yytrial)
{
	 			yyval.createShadowNode = newNode<CreateShadowNode>(yyvsp[-4].int32Val);
		 		yyval.createShadowNode->manual = yyvsp[-3].boolVal;
		 		yyval.createShadowNode->conditional = yyvsp[-2].boolVal;
		 		yyval.createShadowNode->files.add(newNode<DbFileClause>(*yyvsp[-1].stringPtr));
		 		yyval.createShadowNode->files.front()->length = yyvsp[0].int32Val;
	 		}
break;
case 253:
yyval.dbFilesClause = NOTRIAL(&yyvsp[0].createShadowNode->files);
break;
case 254:
  if (!yytrial)
{ yyval.createShadowNode = yyvsp[-2].createShadowNode; }
break;
case 255:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 256:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 257:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 258:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 259:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 260:
  if (!yytrial)
{ yyval.int32Val = 0; }
break;
case 261:
  if (!yytrial)
{ yyval.int32Val = yyvsp[-1].int32Val; }
break;
case 263:
yyval.dbFilesClause = yyvsp[0].dbFilesClause;
break;
case 265:
  if (!yytrial)
{ yyvsp[-1].dbFilesClause->add(yyvsp[0].dbFileClause); }
break;
case 266:
  if (!yytrial)
{ yyvsp[-2].dbFilesClause->add(yyvsp[0].dbFileClause); }
break;
case 267:
  if (!yytrial)
{
				yyvsp[-1].legacyField->fld_name = *yyvsp[-3].metaNamePtr;
				yyval.createDomainNode = newNode<CreateDomainNode>(
					newNode<ParameterClause>(yyvsp[-1].legacyField, MetaName(), yyvsp[0].valueSourceClause));
			}
break;
case 268:
yyval.createDomainNode = yyvsp[0].createDomainNode;
break;
case 269:
  if (!yytrial)
{
				yyval.createDomainNode = yyvsp[-3].createDomainNode;
				if (yyvsp[0].metaNamePtr)
					yyval.createDomainNode->nameType->type->collate = *yyvsp[0].metaNamePtr;
			}
break;
case 273:
yyval.createDomainNode = yyvsp[-1].createDomainNode;
break;
case 275:
  if (!yytrial)
{ setClause(yyvsp[-1].createDomainNode->notNull, "NOT NULL"); }
break;
case 276:
  if (!yytrial)
{ setClause(yyvsp[-1].createDomainNode->check, "DOMAIN CHECK CONSTRAINT", yyvsp[0].boolSourceClause); }
break;
case 279:
  if (!yytrial)
{
			ValueSourceClause* clause = newNode<ValueSourceClause>();
			clause->value = yyvsp[0].valueExprNode;
			clause->source = makeParseStr(YYPOSNARG(1), YYPOSNARG(2));
			yyval.valueSourceClause = clause;
		}
break;
case 280:
  if (!yytrial)
{ yyval.valueSourceClause = NULL; }
break;
case 283:
  if (!yytrial)
{
			BoolSourceClause* clause = newNode<BoolSourceClause>();
			clause->value = yyvsp[-1].boolExprNode;
			clause->source = makeParseStr(YYPOSNARG(1), YYPOSNARG(4));
			yyval.boolSourceClause = clause;
		}
break;
case 284:
  if (!yytrial)
{ yyval.createAlterSequenceNode = newNode<CreateAlterSequenceNode>(*yyvsp[0].metaNamePtr); }
break;
case 285:
yyval.createAlterSequenceNode = yyvsp[0].createAlterSequenceNode;
break;
case 286:
  if (!yytrial)
{ yyval.createAlterSequenceNode = yyvsp[-2].createAlterSequenceNode; }
break;
case 288:
yyval.createAlterSequenceNode = yyvsp[-2].createAlterSequenceNode;
break;
case 292:
  if (!yytrial)
{
			setClause(yyvsp[-3].createAlterSequenceNode->value, "START WITH", yyvsp[0].int64Val);
			setClause(yyvsp[-3].createAlterSequenceNode->restartSpecified, "RESTART", true);
		}
break;
case 293:
  if (!yytrial)
{ setClause(yyvsp[-3].createAlterSequenceNode->step, "INCREMENT BY", yyvsp[0].int32Val); }
break;
case 296:
  if (!yytrial)
{
			CreateAlterSequenceNode* node = newNode<CreateAlterSequenceNode>(*yyvsp[0].metaNamePtr);
			node->alter = true;
			yyval.createAlterSequenceNode = node;
		}
break;
case 297:
  if (!yytrial)
{
			/* Remove this to implement CORE-5137*/
			if (!yyvsp[-2].createAlterSequenceNode->restartSpecified && !yyvsp[-2].createAlterSequenceNode->step.specified)
				yyerrorIncompleteCmd(YYPOSNARG(3));
			yyval.createAlterSequenceNode = yyvsp[-2].createAlterSequenceNode;
		}
break;
case 300:
  if (!yytrial)
{
			setClause(yyvsp[-1].createAlterSequenceNode->restartSpecified, "RESTART", true);
		}
break;
case 303:
  if (!yytrial)
{
			CreateAlterSequenceNode* node = newNode<CreateAlterSequenceNode>(*yyvsp[0].metaNamePtr);
			node->create = false;
			node->alter = true;
			yyval.createAlterSequenceNode = node;
		}
break;
case 304:
  if (!yytrial)
{
			if (!yyvsp[-2].createAlterSequenceNode->restartSpecified && !yyvsp[-2].createAlterSequenceNode->value.specified && !yyvsp[-2].createAlterSequenceNode->step.specified)
				yyerrorIncompleteCmd(YYPOSNARG(3));
			yyval.createAlterSequenceNode = yyvsp[-2].createAlterSequenceNode;
		}
break;
case 309:
  if (!yytrial)
{
			setClause(yyvsp[-2].createAlterSequenceNode->restartSpecified, "RESTART", true);
			setClause(yyvsp[-2].createAlterSequenceNode->value, "RESTART WITH", yyvsp[0].nullableInt64Val);
		}
break;
case 310:
  if (!yytrial)
{ yyval.nullableInt64Val = BaseNullable<SINT64>::empty(); }
break;
case 311:
  if (!yytrial)
{ yyval.nullableInt64Val = BaseNullable<SINT64>::val(yyvsp[0].int64Val); }
break;
case 312:
  if (!yytrial)
{
			CreateAlterSequenceNode* node = newNode<CreateAlterSequenceNode>(*yyvsp[-2].metaNamePtr);
			node->create = false;
			node->alter = true;
			node->legacy = true;
			node->restartSpecified = true;
			node->value = BaseNullable<SINT64>::val(yyvsp[0].int64Val);
			yyval.createAlterSequenceNode = node;
		}
break;
case 313:
  if (!yytrial)
{ yyval.int64Val = yyvsp[0].int32Val; }
break;
case 314:
  if (!yytrial)
{
			SINT64 signedNumber = (SINT64) yyvsp[0].scaledNumber.number;

			if (!yyvsp[0].scaledNumber.hex && yyvsp[0].scaledNumber.number > MAX_SINT64)
			{
				ERRD_post(
					Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
					Arg::Gds(isc_arith_except) <<
					Arg::Gds(isc_numeric_out_of_range));
			}

			yyval.int64Val = signedNumber;
		}
break;
case 315:
  if (!yytrial)
{
			SINT64 signedNumber = (SINT64) yyvsp[0].scaledNumber.number;

			if (yyvsp[0].scaledNumber.hex && signedNumber == MIN_SINT64)
				ERRD_post(Arg::Gds(isc_exception_integer_overflow));

			yyval.int64Val = -signedNumber;
		}
break;
case 316:
  if (!yytrial)
{
			yyval.int64Val = MIN_SINT64;
		}
break;
case 317:
  if (!yytrial)
{ yyval.createAlterRoleNode = newNode<CreateAlterRoleNode>(*yyvsp[0].metaNamePtr); }
break;
case 318:
yyval.createAlterRoleNode = yyvsp[0].createAlterRoleNode;
break;
case 319:
  if (!yytrial)
{ yyval.createAlterRoleNode = yyvsp[-2].createAlterRoleNode; }
break;
case 323:
yyval.createAlterRoleNode = yyvsp[-4].createAlterRoleNode;
break;
case 325:
  if (!yytrial)
{ yyvsp[-3].createAlterRoleNode->sysPrivDrop = true; }
break;
case 327:
yyval.createAlterRoleNode = yyvsp[-2].createAlterRoleNode;
break;
case 329:
  if (!yytrial)
{ yyvsp[-1].createAlterRoleNode->addPrivilege(yyvsp[0].metaNamePtr); }
break;
case 330:
  if (!yytrial)
{ yyval.createCollationNode = newNode<CreateCollationNode>(*yyvsp[-2].metaNamePtr, *yyvsp[0].metaNamePtr); }
break;
case 331:
yyval.createCollationNode = yyvsp[0].createCollationNode;
break;
case 332:
yyval.createCollationNode = yyvsp[-2].createCollationNode;
break;
case 333:
yyval.createCollationNode = yyvsp[-4].createCollationNode;
break;
case 334:
  if (!yytrial)
{ yyval.createCollationNode = yyvsp[-6].createCollationNode; }
break;
case 336:
  if (!yytrial)
{ yyvsp[-2].createCollationNode->fromName = *yyvsp[0].metaNamePtr; }
break;
case 337:
  if (!yytrial)
{ yyvsp[-5].createCollationNode->fromExternal = *yyvsp[-1].stringPtr; }
break;
case 341:
yyval.createCollationNode = yyvsp[-1].createCollationNode;
break;
case 346:
  if (!yytrial)
{ yyvsp[-2].createCollationNode->unsetAttribute(TEXTTYPE_ATTR_PAD_SPACE); }
break;
case 347:
  if (!yytrial)
{ yyvsp[-2].createCollationNode->setAttribute(TEXTTYPE_ATTR_PAD_SPACE); }
break;
case 348:
  if (!yytrial)
{ yyvsp[-2].createCollationNode->unsetAttribute(TEXTTYPE_ATTR_CASE_INSENSITIVE); }
break;
case 349:
  if (!yytrial)
{ yyvsp[-2].createCollationNode->setAttribute(TEXTTYPE_ATTR_CASE_INSENSITIVE); }
break;
case 350:
  if (!yytrial)
{ yyvsp[-2].createCollationNode->unsetAttribute(TEXTTYPE_ATTR_ACCENT_INSENSITIVE); }
break;
case 351:
  if (!yytrial)
{ yyvsp[-2].createCollationNode->setAttribute(TEXTTYPE_ATTR_ACCENT_INSENSITIVE); }
break;
case 353:
  if (!yytrial)
{
			const string& s = *yyvsp[0].stringPtr;
			yyvsp[-1].createCollationNode->specificAttributes.clear();
			yyvsp[-1].createCollationNode->specificAttributes.add((const UCHAR*) s.begin(), s.length());
		}
break;
case 354:
  if (!yytrial)
{ yyval.ddlNode = newNode<AlterCharSetNode>(*yyvsp[-4].metaNamePtr, *yyvsp[0].metaNamePtr); }
break;
case 355:
  if (!yytrial)
{ yyval.ddlNode = newNode<AlterEDSPoolSetNode>(AlterEDSPoolSetNode::POOL_SIZE, yyvsp[0].int32Val); }
break;
case 356:
  if (!yytrial)
{ yyval.ddlNode = newNode<AlterEDSPoolSetNode>(AlterEDSPoolSetNode::POOL_LIFETIME, yyvsp[-1].int32Val * yyvsp[0].intVal); }
break;
case 357:
  if (!yytrial)
{ yyval.ddlNode = newNode<AlterEDSPoolClearNode>(AlterEDSPoolClearNode::POOL_DB, yyvsp[0].intlStringPtr->getString()); }
break;
case 358:
  if (!yytrial)
{ yyval.ddlNode = newNode<AlterEDSPoolClearNode>(AlterEDSPoolClearNode::POOL_ALL); }
break;
case 359:
  if (!yytrial)
{ yyval.ddlNode = newNode<AlterEDSPoolClearNode>(AlterEDSPoolClearNode::POOL_OLDEST); }
break;
case 360:
  if (!yytrial)
{ yyval.intVal = 3600; }
break;
case 361:
  if (!yytrial)
{ yyval.intVal = 60; }
break;
case 362:
  if (!yytrial)
{ yyval.intVal = 1; }
break;
case 363:
  if (!yytrial)
{
				yyval.alterDatabaseNode = newNode<AlterDatabaseNode>();
				yyval.alterDatabaseNode->create = true;
			}
break;
case 364:
yyval.alterDatabaseNode = yyvsp[0].alterDatabaseNode;
break;
case 365:
yyval.alterDatabaseNode = yyvsp[-2].alterDatabaseNode;
break;
case 366:
  if (!yytrial)
{ yyval.alterDatabaseNode = yyvsp[-4].alterDatabaseNode; }
break;
case 373:
yyval.alterDatabaseNode = yyvsp[-1].alterDatabaseNode;
break;
case 382:
  if (!yytrial)
{ yyvsp[-4].alterDatabaseNode->createLength = yyvsp[-1].int32Val; }
break;
case 387:
  if (!yytrial)
{ yyvsp[-1].alterDatabaseNode->files.add(yyvsp[0].dbFileClause); }
break;
case 388:
  if (!yytrial)
{ yyvsp[-4].alterDatabaseNode->setDefaultCharSet = *yyvsp[0].metaNamePtr; }
break;
case 389:
  if (!yytrial)
{
			yyvsp[-6].alterDatabaseNode->setDefaultCharSet = *yyvsp[-2].metaNamePtr;
			yyvsp[-6].alterDatabaseNode->setDefaultCollation = *yyvsp[0].metaNamePtr;
		}
break;
case 390:
  if (!yytrial)
{ yyvsp[-3].alterDatabaseNode->differenceFile = *yyvsp[0].stringPtr; }
break;
case 391:
  if (!yytrial)
{
				DbFileClause* clause = newNode<DbFileClause>(*yyvsp[0].stringPtr);
				yyval.dbFileClause = clause;
			}
break;
case 392:
yyval.dbFileClause = yyvsp[0].dbFileClause;
break;
case 393:
  if (!yytrial)
{ yyval.dbFileClause = yyvsp[-2].dbFileClause; }
break;
case 397:
yyval.dbFileClause = yyvsp[-1].dbFileClause;
break;
case 399:
  if (!yytrial)
{ yyvsp[-3].dbFileClause->start = yyvsp[0].int32Val; }
break;
case 400:
  if (!yytrial)
{ yyvsp[-4].dbFileClause->length = yyvsp[-1].int32Val; }
break;
case 407:
  if (!yytrial)
{
				yyval.createRelationNode = newNode<CreateRelationNode>(yyvsp[-1].relSourceNode, yyvsp[0].stringPtr);
			}
break;
case 408:
yyval.createRelationNode = yyvsp[-1].createRelationNode;
break;
case 409:
yyval.relationNode = yyvsp[-4].createRelationNode;
break;
case 410:
  if (!yytrial)
{
				yyval.createRelationNode = yyvsp[-6].createRelationNode;
			}
break;
case 412:
yyval.relationNode = yyvsp[0].relationNode;
break;
case 413:
yyval.relationNode = yyvsp[-2].relationNode;
break;
case 415:
  if (!yytrial)
{ setClause(yyvsp[-1].relationNode->ssDefiner, "SQL SECURITY", yyvsp[0].boolVal); }
break;
case 416:
  if (!yytrial)
{ setClause(yyvsp[-1].relationNode->replicationState, "PUBLICATION", yyvsp[0].boolVal); }
break;
case 417:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 418:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 419:
  if (!yytrial)
{ yyval.nullableBoolVal = Nullable<bool>::empty(); }
break;
case 420:
  if (!yytrial)
{ yyval.nullableBoolVal = Nullable<bool>::val(yyvsp[0].boolVal); }
break;
case 421:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 422:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 423:
  if (!yytrial)
{
				yyval.createRelationNode = newNode<CreateRelationNode>(yyvsp[0].relSourceNode);
				yyval.createRelationNode->relationType = Nullable<rel_t>::empty();
			}
break;
case 424:
yyval.createRelationNode = yyvsp[-4].createRelationNode;
break;
case 425:
  if (!yytrial)
{
				yyval.createRelationNode = yyvsp[-6].createRelationNode;
				if (!yyval.createRelationNode->relationType.specified)
					yyval.createRelationNode->relationType = rel_global_temp_delete;
			}
break;
case 426:
yyval.createRelationNode = yyvsp[0].createRelationNode;
break;
case 428:
yyval.createRelationNode = yyvsp[-2].createRelationNode;
break;
case 431:
  if (!yytrial)
{ setClause(yyvsp[-1].createRelationNode->ssDefiner, "SQL SECURITY", yyvsp[0].nullableBoolVal); }
break;
case 432:
  if (!yytrial)
{ setClause(yyvsp[-4].createRelationNode->relationType, "ON COMMIT DELETE ROWS", rel_global_temp_delete); }
break;
case 433:
  if (!yytrial)
{ setClause(yyvsp[-4].createRelationNode->relationType, "ON COMMIT PRESERVE ROWS", rel_global_temp_preserve); }
break;
case 434:
  if (!yytrial)
{ yyval.stringPtr = NULL; }
break;
case 435:
  if (!yytrial)
{ yyval.stringPtr = yyvsp[0].stringPtr; }
break;
case 436:
  if (!yytrial)
{ yyval.stringPtr = yyvsp[0].stringPtr; }
break;
case 439:
yyval.relationNode = yyvsp[0].createRelationNode;
break;
case 442:
  if (!yytrial)
{
				RelationNode::AddColumnClause* clause = yyval.addColumnClause =
					newNode<RelationNode::AddColumnClause>();
				clause->field = yyvsp[-1].legacyField;
				clause->field->fld_name = *yyvsp[-2].metaNamePtr;
				clause->defaultValue = yyvsp[0].valueSourceClause;
				yyvsp[-3].relationNode->clauses.add(clause);
			}
break;
case 443:
yyval.addColumnClause = NOTRIAL(yyvsp[0].addColumnClause);
break;
case 444:
  if (!yytrial)
{
				if (yyvsp[0].metaNamePtr)
					yyvsp[-3].addColumnClause->collate = *yyvsp[0].metaNamePtr;
			}
break;
case 445:
  if (!yytrial)
{
				RelationNode::AddColumnClause* clause = yyval.addColumnClause =
					newNode<RelationNode::AddColumnClause>();
				clause->field = yyvsp[-1].legacyField;
				clause->field->fld_name = *yyvsp[-2].metaNamePtr;
				clause->identityOptions = yyvsp[0].identityOptions;
				yyvsp[-3].relationNode->clauses.add(clause);
			}
break;
case 446:
  if (!yytrial)
{
				if (yyvsp[0].metaNamePtr)
					yyvsp[-3].addColumnClause->collate = *yyvsp[0].metaNamePtr;
			}
break;
case 447:
  if (!yytrial)
{
			RelationNode::AddColumnClause* clause = newNode<RelationNode::AddColumnClause>();
			clause->field = yyvsp[-1].legacyField;
			clause->field->fld_name = *yyvsp[-2].metaNamePtr;
			clause->computed = yyvsp[0].valueSourceClause;
			yyvsp[-3].relationNode->clauses.add(clause);
			clause->field->flags |= FLD_computed;
		}
break;
case 448:
  if (!yytrial)
{
			RelationNode::AddColumnClause* clause = newNode<RelationNode::AddColumnClause>();
			clause->field = newNode<dsql_fld>();
			clause->field->fld_name = *yyvsp[-1].metaNamePtr;
			clause->computed = yyvsp[0].valueSourceClause;
			yyvsp[-2].relationNode->clauses.add(clause);
			clause->field->flags |= FLD_computed;
		}
break;
case 449:
  if (!yytrial)
{ yyval.identityOptions = newNode<RelationNode::IdentityOptions>(yyvsp[-2].identityType); }
break;
case 450:
yyval.identityOptions = yyvsp[0].identityOptions;
break;
case 451:
  if (!yytrial)
{ yyval.identityOptions = yyvsp[-2].identityOptions; }
break;
case 452:
  if (!yytrial)
{ yyval.identityType = IDENT_TYPE_BY_DEFAULT; }
break;
case 453:
  if (!yytrial)
{ yyval.identityType = IDENT_TYPE_ALWAYS; }
break;
case 455:
yyval.identityOptions = yyvsp[-1].identityOptions;
break;
case 459:
  if (!yytrial)
{ setClause(yyvsp[-3].identityOptions->startValue, "START WITH", yyvsp[0].int64Val); }
break;
case 460:
  if (!yytrial)
{ setClause(yyvsp[-3].identityOptions->increment, "INCREMENT BY", yyvsp[0].int32Val); }
break;
case 461:
  if (!yytrial)
{
			ValueSourceClause* clause = newNode<ValueSourceClause>();
			clause->value = yyvsp[-1].valueExprNode;
			clause->source = makeParseStr(YYPOSNARG(2), YYPOSNARG(4));
			yyval.valueSourceClause = clause;
		}
break;
case 468:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->typeOfName = *yyvsp[0].metaNamePtr;
		}
break;
case 469:
  if (!yytrial)
{ yyval.metaNamePtr = NULL; }
break;
case 470:
  if (!yytrial)
{ yyval.metaNamePtr = yyvsp[0].metaNamePtr; }
break;
case 472:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->typeOfName = *yyvsp[0].metaNamePtr;
		}
break;
case 473:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->typeOfTable = *yyvsp[-2].metaNamePtr;
			yyval.legacyField->typeOfName = *yyvsp[0].metaNamePtr;
		}
break;
case 474:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->typeOfName = *yyvsp[0].metaNamePtr;
			yyval.legacyField->fullDomain = true;
		}
break;
case 475:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 476:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 477:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 478:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 479:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 480:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 482:
yyval.addColumnClause = yyvsp[0].addColumnClause;
break;
case 485:
yyval.addColumnClause = yyvsp[-1].addColumnClause;
break;
case 487:
  if (!yytrial)
{
			if (yyvsp[-2].metaNamePtr)
				yyvsp[-3].addColumnClause->constraints.back()->name = *yyvsp[-2].metaNamePtr;
		}
break;
case 488:
  if (!yytrial)
{
			setClause(yyvsp[-1].addColumnClause->notNullSpecified, "NOT NULL");
			RelationNode::AddConstraintClause& constraint = yyvsp[-1].addColumnClause->constraints.add();
			constraint.constraintType = RelationNode::AddConstraintClause::CTYPE_NOT_NULL;
		}
break;
case 489:
  if (!yytrial)
{
			RelationNode::AddConstraintClause& constraint = yyvsp[-1].addColumnClause->constraints.add();
			constraint.constraintType = RelationNode::AddConstraintClause::CTYPE_CHECK;
			constraint.check = yyvsp[0].boolSourceClause;
		}
break;
case 490:
  if (!yytrial)
{
			RelationNode::AddConstraintClause& constraint = yyvsp[-5].addColumnClause->constraints.add();
			constraint.constraintType = RelationNode::AddConstraintClause::CTYPE_FK;

			constraint.columns.add(yyvsp[-5].addColumnClause->field->fld_name);
			constraint.refRelation = *yyvsp[-3].metaNamePtr;
			constraint.refAction = yyvsp[-1].refActionClause;

			const ValueListNode* refColumns = yyvsp[-2].valueListNode;
			if (refColumns)
			{
				const NestConst<ValueExprNode>* ptr = refColumns->items.begin();

				for (const NestConst<ValueExprNode>* const end = refColumns->items.end(); ptr != end; ++ptr)
					constraint.refColumns.add(nodeAs<FieldNode>(*ptr)->dsqlName);
			}

			constraint.index = yyvsp[0].indexConstraintClause;
		}
break;
case 491:
  if (!yytrial)
{
			RelationNode::AddConstraintClause& constraint = yyvsp[-2].addColumnClause->constraints.add();
			constraint.constraintType = RelationNode::AddConstraintClause::CTYPE_UNIQUE;
			constraint.index = yyvsp[0].indexConstraintClause;
		}
break;
case 492:
  if (!yytrial)
{
			RelationNode::AddConstraintClause& constraint = yyvsp[-3].addColumnClause->constraints.add();
			constraint.constraintType = RelationNode::AddConstraintClause::CTYPE_PK;
			constraint.index = yyvsp[0].indexConstraintClause;
		}
break;
case 493:
yyval.relationNode = yyvsp[-1].relationNode;
break;
case 494:
  if (!yytrial)
{
			if (yyvsp[-2].metaNamePtr)
			{
				static_cast<RelationNode::AddConstraintClause*>(
					yyvsp[-3].relationNode->clauses.back().getObject())->name = *yyvsp[-2].metaNamePtr;
			}
		}
break;
case 495:
  if (!yytrial)
{ yyval.metaNamePtr = NULL; }
break;
case 496:
  if (!yytrial)
{ yyval.metaNamePtr = yyvsp[0].metaNamePtr; }
break;
case 497:
  if (!yytrial)
{
			RelationNode::AddConstraintClause& constraint = *newNode<RelationNode::AddConstraintClause>();
			constraint.constraintType = RelationNode::AddConstraintClause::CTYPE_UNIQUE;

			const ValueListNode* columns = yyvsp[-1].valueListNode;
			const NestConst<ValueExprNode>* ptr = columns->items.begin();

			for (const NestConst<ValueExprNode>* const end = columns->items.end(); ptr != end; ++ptr)
				constraint.columns.add(nodeAs<FieldNode>(*ptr)->dsqlName);

			constraint.index = yyvsp[0].indexConstraintClause;

			yyvsp[-3].relationNode->clauses.add(&constraint);
		}
break;
case 498:
  if (!yytrial)
{
			RelationNode::AddConstraintClause& constraint = *newNode<RelationNode::AddConstraintClause>();
			constraint.constraintType = RelationNode::AddConstraintClause::CTYPE_PK;

			const ValueListNode* columns = yyvsp[-1].valueListNode;
			const NestConst<ValueExprNode>* ptr = columns->items.begin();

			for (const NestConst<ValueExprNode>* const end = columns->items.end(); ptr != end; ++ptr)
				constraint.columns.add(nodeAs<FieldNode>(*ptr)->dsqlName);

			constraint.index = yyvsp[0].indexConstraintClause;

			yyvsp[-4].relationNode->clauses.add(&constraint);
		}
break;
case 499:
  if (!yytrial)
{
			RelationNode::AddConstraintClause& constraint = *newNode<RelationNode::AddConstraintClause>();
			constraint.constraintType = RelationNode::AddConstraintClause::CTYPE_FK;

			const ValueListNode* columns = yyvsp[-5].valueListNode;
			const NestConst<ValueExprNode>* ptr = columns->items.begin();

			for (const NestConst<ValueExprNode>* const end = columns->items.end(); ptr != end; ++ptr)
				constraint.columns.add(nodeAs<FieldNode>(*ptr)->dsqlName);

			constraint.refRelation = *yyvsp[-3].metaNamePtr;
			constraint.refAction = yyvsp[-1].refActionClause;

			const ValueListNode* refColumns = yyvsp[-2].valueListNode;
			if (refColumns)
			{
				const NestConst<ValueExprNode>* ptr = refColumns->items.begin();

				for (const NestConst<ValueExprNode>* const end = refColumns->items.end(); ptr != end; ++ptr)
					constraint.refColumns.add(nodeAs<FieldNode>(*ptr)->dsqlName);
			}

			constraint.index = yyvsp[0].indexConstraintClause;

			yyvsp[-8].relationNode->clauses.add(&constraint);
		}
break;
case 500:
  if (!yytrial)
{
			RelationNode::AddConstraintClause* constraint = newNode<RelationNode::AddConstraintClause>();
			constraint->constraintType = RelationNode::AddConstraintClause::CTYPE_CHECK;
			constraint->check = yyvsp[0].boolSourceClause;
			yyvsp[-1].relationNode->clauses.add(constraint);
		}
break;
case 501:
  if (!yytrial)
{ yyval.indexConstraintClause = newNode<RelationNode::IndexConstraintClause>(); }
break;
case 502:
  if (!yytrial)
{
			RelationNode::IndexConstraintClause* clause = yyval.indexConstraintClause =
				newNode<RelationNode::IndexConstraintClause>();
			clause->descending = yyvsp[-2].boolVal;
			clause->name = *yyvsp[0].metaNamePtr;
		}
break;
case 503:
  if (!yytrial)
{ yyval.refActionClause = NULL; }
break;
case 504:
  if (!yytrial)
{ yyval.refActionClause = newNode<RelationNode::RefActionClause>(yyvsp[0].uintVal, 0); }
break;
case 505:
  if (!yytrial)
{ yyval.refActionClause = newNode<RelationNode::RefActionClause>(0, yyvsp[0].uintVal); }
break;
case 506:
  if (!yytrial)
{ yyval.refActionClause = newNode<RelationNode::RefActionClause>(yyvsp[0].uintVal, yyvsp[-1].uintVal); }
break;
case 507:
  if (!yytrial)
{ yyval.refActionClause = newNode<RelationNode::RefActionClause>(yyvsp[-1].uintVal, yyvsp[0].uintVal); }
break;
case 508:
  if (!yytrial)
{ yyval.uintVal = yyvsp[0].uintVal;}
break;
case 509:
  if (!yytrial)
{ yyval.uintVal = yyvsp[0].uintVal;}
break;
case 510:
  if (!yytrial)
{ yyval.uintVal = RelationNode::RefActionClause::ACTION_CASCADE; }
break;
case 511:
  if (!yytrial)
{ yyval.uintVal = RelationNode::RefActionClause::ACTION_SET_DEFAULT; }
break;
case 512:
  if (!yytrial)
{ yyval.uintVal = RelationNode::RefActionClause::ACTION_SET_NULL; }
break;
case 513:
  if (!yytrial)
{ yyval.uintVal = RelationNode::RefActionClause::ACTION_NONE; }
break;
case 516:
  if (!yytrial)
{
			yyval.createAlterProcedureNode = yyvsp[-4].createAlterProcedureNode;
			yyval.createAlterProcedureNode->ssDefiner = yyvsp[-3].nullableBoolVal;
			yyval.createAlterProcedureNode->source = makeParseStr(YYPOSNARG(4), YYPOSNARG(5));
			yyval.createAlterProcedureNode->localDeclList = yyvsp[-1].compoundStmtNode;
			yyval.createAlterProcedureNode->body = yyvsp[0].stmtNode;
		}
break;
case 517:
  if (!yytrial)
{
			yyval.createAlterProcedureNode = yyvsp[-2].createAlterProcedureNode;
			yyval.createAlterProcedureNode->external = yyvsp[-1].externalClause;
			if (yyvsp[0].stringPtr)
				yyval.createAlterProcedureNode->source = *yyvsp[0].stringPtr;
		}
break;
case 518:
  if (!yytrial)
{ yyval.createAlterProcedureNode = newNode<CreateAlterProcedureNode>(*yyvsp[0].metaNamePtr); }
break;
case 519:
yyval.parametersClause = NOTRIAL(&yyvsp[0].createAlterProcedureNode->parameters);
break;
case 520:
yyval.parametersClause = NOTRIAL(&yyvsp[-2].createAlterProcedureNode->returns);
break;
case 521:
  if (!yytrial)
{ yyval.createAlterProcedureNode = yyvsp[-4].createAlterProcedureNode; }
break;
case 522:
  if (!yytrial)
{
			yyval.createAlterProcedureNode = yyvsp[0].createAlterProcedureNode;
			yyval.createAlterProcedureNode->alter = true;
			yyval.createAlterProcedureNode->create = false;
		}
break;
case 523:
  if (!yytrial)
{
			yyval.createAlterProcedureNode = yyvsp[0].createAlterProcedureNode;
			yyval.createAlterProcedureNode->alter = true;
		}
break;
case 531:
  if (!yytrial)
{ yyvsp[-3].parametersClause->add(newNode<ParameterClause>(yyvsp[-2].legacyField, optName(yyvsp[-1].metaNamePtr), yyvsp[0].valueSourceClause)); }
break;
case 534:
  if (!yytrial)
{ yyvsp[-2].parametersClause->add(newNode<ParameterClause>(yyvsp[-1].legacyField, optName(yyvsp[0].metaNamePtr))); }
break;
case 535:
  if (!yytrial)
{
			yyval.legacyField = yyvsp[0].legacyField;
			yyval.legacyField->fld_name = *yyvsp[-1].metaNamePtr;
		}
break;
case 536:
  if (!yytrial)
{ yyval.valueSourceClause = NULL; }
break;
case 537:
  if (!yytrial)
{
			ValueSourceClause* clause = newNode<ValueSourceClause>();
			clause->value = yyvsp[0].valueExprNode;
			clause->source = makeParseStr(YYPOSNARG(1), YYPOSNARG(2));
			yyval.valueSourceClause = clause;
		}
break;
case 538:
  if (!yytrial)
{
			ValueSourceClause* clause = newNode<ValueSourceClause>();
			clause->value = yyvsp[0].valueExprNode;
			clause->source = makeParseStr(YYPOSNARG(1), YYPOSNARG(2));
			yyval.valueSourceClause = clause;
		}
break;
case 541:
  if (!yytrial)
{
			yyval.createAlterFunctionNode = yyvsp[-4].createAlterFunctionNode;
			yyval.createAlterFunctionNode->ssDefiner = yyvsp[-3].nullableBoolVal;
			yyval.createAlterFunctionNode->source = makeParseStr(YYPOSNARG(4), YYPOSNARG(5));
			yyval.createAlterFunctionNode->localDeclList = yyvsp[-1].compoundStmtNode;
			yyval.createAlterFunctionNode->body = yyvsp[0].stmtNode;
		}
break;
case 542:
  if (!yytrial)
{
			yyval.createAlterFunctionNode = yyvsp[-2].createAlterFunctionNode;
			yyval.createAlterFunctionNode->external = yyvsp[-1].externalClause;
			if (yyvsp[0].stringPtr)
				yyval.createAlterFunctionNode->source = *yyvsp[0].stringPtr;
		}
break;
case 543:
  if (!yytrial)
{ yyval.createAlterFunctionNode = newNode<CreateAlterFunctionNode>(*yyvsp[0].metaNamePtr); }
break;
case 544:
  if (!yytrial)
{
				yyval.createAlterFunctionNode = yyvsp[-6].createAlterFunctionNode;
				yyval.createAlterFunctionNode->returnType = newNode<ParameterClause>(yyvsp[-2].legacyField, optName(yyvsp[-1].metaNamePtr));
				yyval.createAlterFunctionNode->deterministic = yyvsp[0].boolVal;
			}
break;
case 545:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 546:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 547:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 548:
  if (!yytrial)
{
			yyval.externalClause = newNode<ExternalClause>();
			yyval.externalClause->name = *yyvsp[-2].stringPtr;
			yyval.externalClause->engine = *yyvsp[0].metaNamePtr;
		}
break;
case 549:
  if (!yytrial)
{
			yyval.externalClause = newNode<ExternalClause>();
			yyval.externalClause->engine = *yyvsp[0].metaNamePtr;
		}
break;
case 550:
  if (!yytrial)
{ yyval.stringPtr = NULL; }
break;
case 551:
  if (!yytrial)
{ yyval.stringPtr = yyvsp[0].stringPtr; }
break;
case 552:
  if (!yytrial)
{
			yyval.createAlterFunctionNode = yyvsp[0].createAlterFunctionNode;
			yyval.createAlterFunctionNode->alter = true;
			yyval.createAlterFunctionNode->create = false;
		}
break;
case 553:
  if (!yytrial)
{
			yyval.createAlterFunctionNode = yyvsp[0].createAlterFunctionNode;
			yyval.createAlterFunctionNode->alter = true;
		}
break;
case 554:
  if (!yytrial)
{
			CreateAlterPackageNode* node = newNode<CreateAlterPackageNode>(*yyvsp[-5].metaNamePtr);
			node->ssDefiner = yyvsp[-4].nullableBoolVal;
			node->source = makeParseStr(YYPOSNARG(4), YYPOSNARG(6));
			node->items = yyvsp[-1].packageItems;
			yyval.createAlterPackageNode = node;
		}
break;
case 556:
  if (!yytrial)
{ yyval.packageItems = newNode<Array<CreateAlterPackageNode::Item> >(); }
break;
case 557:
  if (!yytrial)
{
			yyval.packageItems = newNode<Array<CreateAlterPackageNode::Item> >();
			yyval.packageItems->add(yyvsp[0].packageItem);
		}
break;
case 558:
  if (!yytrial)
{
			yyval.packageItems = yyvsp[-1].packageItems;
			yyval.packageItems->add(yyvsp[0].packageItem);
		}
break;
case 559:
  if (!yytrial)
{ yyval.packageItem = CreateAlterPackageNode::Item::create(yyvsp[-1].createAlterFunctionNode); }
break;
case 560:
  if (!yytrial)
{ yyval.packageItem = CreateAlterPackageNode::Item::create(yyvsp[-1].createAlterProcedureNode); }
break;
case 561:
  if (!yytrial)
{
			yyval.createAlterPackageNode = yyvsp[0].createAlterPackageNode;
			yyval.createAlterPackageNode->alter = true;
			yyval.createAlterPackageNode->create = false;
		}
break;
case 562:
  if (!yytrial)
{
			yyval.createAlterPackageNode = yyvsp[0].createAlterPackageNode;
			yyval.createAlterPackageNode->alter = true;
		}
break;
case 563:
  if (!yytrial)
{
			CreatePackageBodyNode* node = newNode<CreatePackageBodyNode>(*yyvsp[-5].metaNamePtr);
			node->source = makeParseStr(YYPOSNARG(3), YYPOSNARG(6));
			node->declaredItems = yyvsp[-2].packageItems;
			node->items = yyvsp[-1].packageItems;
			yyval.createPackageBodyNode = node;
		}
break;
case 564:
  if (!yytrial)
{
			CreatePackageBodyNode* node = newNode<CreatePackageBodyNode>(*yyvsp[-4].metaNamePtr);
			node->source = makeParseStr(YYPOSNARG(3), YYPOSNARG(5));
			node->items = yyvsp[-1].packageItems;
			yyval.createPackageBodyNode = node;
		}
break;
case 565:
  if (!yytrial)
{ yyval.packageItems = newNode<Array<CreateAlterPackageNode::Item> >(); }
break;
case 567:
  if (!yytrial)
{
			yyval.packageItems = newNode<Array<CreateAlterPackageNode::Item> >();
			yyval.packageItems->add(yyvsp[0].packageItem);
		}
break;
case 568:
  if (!yytrial)
{
			yyval.packageItems = yyvsp[-1].packageItems;
			yyval.packageItems->add(yyvsp[0].packageItem);
		}
break;
case 569:
  if (!yytrial)
{ yyval.packageItem = CreateAlterPackageNode::Item::create(yyvsp[0].createAlterFunctionNode); }
break;
case 570:
  if (!yytrial)
{ yyval.packageItem = CreateAlterPackageNode::Item::create(yyvsp[-1].createAlterFunctionNode); }
break;
case 571:
  if (!yytrial)
{ yyval.packageItem = CreateAlterPackageNode::Item::create(yyvsp[0].createAlterProcedureNode); }
break;
case 572:
  if (!yytrial)
{ yyval.packageItem = CreateAlterPackageNode::Item::create(yyvsp[-1].createAlterProcedureNode); }
break;
case 573:
  if (!yytrial)
{
			CompoundStmtNode* forward = yyvsp[-1].compoundStmtNode;
			CompoundStmtNode* nonForward = yyvsp[0].compoundStmtNode;

			if (!forward)
				yyval.compoundStmtNode = nonForward;
			else
			{
				if (nonForward)
					forward->statements.add(nonForward->statements.begin(), nonForward->statements.getCount());

				yyval.compoundStmtNode = forward;
			}
		}
break;
case 574:
  if (!yytrial)
{ yyval.compoundStmtNode = NULL; }
break;
case 576:
  if (!yytrial)
{
			yyval.compoundStmtNode = newNode<CompoundStmtNode>();
			yyval.compoundStmtNode->statements.add(yyvsp[0].stmtNode);
		}
break;
case 577:
  if (!yytrial)
{
			yyvsp[-1].compoundStmtNode->statements.add(yyvsp[0].stmtNode);
			yyval.compoundStmtNode = yyvsp[-1].compoundStmtNode;
		}
break;
case 578:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[-1].declareSubProcNode; }
break;
case 579:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[-1].declareSubFuncNode; }
break;
case 580:
  if (!yytrial)
{ yyval.compoundStmtNode = NULL; }
break;
case 582:
  if (!yytrial)
{
			yyval.compoundStmtNode = newNode<CompoundStmtNode>();
			yyval.compoundStmtNode->statements.add(yyvsp[0].stmtNode);
		}
break;
case 583:
  if (!yytrial)
{
			yyvsp[-1].compoundStmtNode->statements.add(yyvsp[0].stmtNode);
			yyval.compoundStmtNode = yyvsp[-1].compoundStmtNode;
		}
break;
case 584:
  if (!yytrial)
{
			yyval.stmtNode = yyvsp[-1].stmtNode;
			yyval.stmtNode->line = YYPOSNARG(1).firstLine;
			yyval.stmtNode->column = YYPOSNARG(1).firstColumn;
		}
break;
case 585:
  if (!yytrial)
{
			DeclareSubProcNode* node = yyvsp[-3].declareSubProcNode;
			node->dsqlBlock = newNode<ExecBlockNode>();
			node->dsqlBlock->parameters = node->dsqlParameters;
			node->dsqlBlock->returns = node->dsqlReturns;
			node->dsqlBlock->localDeclList = yyvsp[-1].compoundStmtNode;
			node->dsqlBlock->body = yyvsp[0].stmtNode;

			for (FB_SIZE_T i = 0; i < node->dsqlBlock->parameters.getCount(); ++i)
				node->dsqlBlock->parameters[i]->parameterExpr = make_parameter();

			yyval.stmtNode = node;
		}
break;
case 586:
  if (!yytrial)
{
			DeclareSubFuncNode* node = yyvsp[-3].declareSubFuncNode;
			node->dsqlBlock = newNode<ExecBlockNode>();
			node->dsqlBlock->parameters = node->dsqlParameters;
			node->dsqlBlock->returns = node->dsqlReturns;
			node->dsqlBlock->localDeclList = yyvsp[-1].compoundStmtNode;
			node->dsqlBlock->body = yyvsp[0].stmtNode;

			for (FB_SIZE_T i = 0; i < node->dsqlBlock->parameters.getCount(); ++i)
				node->dsqlBlock->parameters[i]->parameterExpr = make_parameter();

			yyval.stmtNode = node;
		}
break;
case 587:
  if (!yytrial)
{ yyval.declareSubProcNode = newNode<DeclareSubProcNode>(NOTRIAL(*yyvsp[0].metaNamePtr)); }
break;
case 588:
yyval.parametersClause = NOTRIAL(&yyvsp[0].declareSubProcNode->dsqlParameters);
break;
case 589:
yyval.parametersClause = NOTRIAL(&yyvsp[-2].declareSubProcNode->dsqlReturns);
break;
case 590:
  if (!yytrial)
{ yyval.declareSubProcNode = yyvsp[-4].declareSubProcNode; }
break;
case 591:
  if (!yytrial)
{ yyval.declareSubFuncNode = newNode<DeclareSubFuncNode>(NOTRIAL(*yyvsp[0].metaNamePtr)); }
break;
case 592:
yyval.parametersClause = NOTRIAL(&yyvsp[0].declareSubFuncNode->dsqlParameters);
break;
case 593:
  if (!yytrial)
{
				yyval.declareSubFuncNode = yyvsp[-6].declareSubFuncNode;
				yyval.declareSubFuncNode->dsqlReturns.add(newNode<ParameterClause>(yyvsp[-2].legacyField, optName(yyvsp[-1].metaNamePtr)));
				yyval.declareSubFuncNode->dsqlDeterministic = yyvsp[0].boolVal;
			}
break;
case 596:
  if (!yytrial)
{
			DeclareVariableNode* node = newNode<DeclareVariableNode>();
			node->dsqlDef = newNode<ParameterClause>(yyvsp[-2].legacyField, optName(yyvsp[-1].metaNamePtr), yyvsp[0].valueSourceClause);
			yyval.stmtNode = node;
		}
break;
case 599:
  if (!yytrial)
{
			DeclareCursorNode* node = newNode<DeclareCursorNode>(*yyvsp[-6].metaNamePtr,
				DeclareCursorNode::CUR_TYPE_EXPLICIT);
			node->dsqlScroll = yyvsp[-5].boolVal;
			node->dsqlSelect = yyvsp[-1].selectNode;
			yyval.stmtNode = node;
		}
break;
case 600:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 601:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 602:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 605:
  if (!yytrial)
{ yyval.stmtNode = newNode<LineColumnNode>(YYPOSNARG(1).firstLine, YYPOSNARG(1).firstColumn, yyvsp[-1].stmtNode); }
break;
case 606:
  if (!yytrial)
{ yyval.stmtNode = newNode<CompoundStmtNode>(); }
break;
case 607:
  if (!yytrial)
{
			BlockNode* node = newNode<BlockNode>();
			node->action = yyvsp[0].compoundStmtNode;
			yyval.stmtNode = node;
		}
break;
case 608:
  if (!yytrial)
{
			BlockNode* node = newNode<BlockNode>();
			node->action = yyvsp[-1].compoundStmtNode;
			node->handlers = yyvsp[0].compoundStmtNode;
			yyval.stmtNode = node;
		}
break;
case 609:
  if (!yytrial)
{
			yyval.compoundStmtNode = newNode<CompoundStmtNode>();
			yyval.compoundStmtNode->statements.add(yyvsp[0].stmtNode);
		}
break;
case 610:
  if (!yytrial)
{
			yyvsp[-1].compoundStmtNode->statements.add(yyvsp[0].stmtNode);
			yyval.compoundStmtNode = yyvsp[-1].compoundStmtNode;
		}
break;
case 611:
{YYVALID;}
  if (!yytrial)
{ yyval.stmtNode = newNode<LineColumnNode>(YYPOSNARG(1).firstLine, YYPOSNARG(1).firstColumn, yyvsp[-1].stmtNode); }
break;
case 612:
{YYVALID;}
  if (!yytrial)
{ yyval.stmtNode = newNode<LineColumnNode>(YYPOSNARG(1).firstLine, YYPOSNARG(1).firstColumn, yyvsp[0].stmtNode); }
break;
case 614:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].storeNode; }
break;
case 615:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].mergeNode; }
break;
case 617:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].updInsNode; }
break;
case 621:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].execStatementNode; }
break;
case 622:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].execStatementNode; }
break;
case 624:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].stmtNode; }
break;
case 630:
  if (!yytrial)
{ yyval.stmtNode = newNode<SuspendNode>(); }
break;
case 631:
  if (!yytrial)
{ yyval.stmtNode = newNode<ExitNode>(); }
break;
case 632:
  if (!yytrial)
{ yyval.stmtNode = newNode<ReturnNode>(yyvsp[0].valueExprNode); }
break;
case 633:
  if (!yytrial)
{ yyval.stmtNode = newNode<SessionManagementWrapperNode>(yyvsp[0].mngNode, makeParseStr(YYPOSNARG(1), YYPOSNARG(1))); }
break;
case 635:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].stmtNode; }
break;
case 639:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].forNode; }
break;
case 640:
  if (!yytrial)
{ yyval.stmtNode = yyvsp[0].execStatementNode; }
break;
case 641:
  if (!yytrial)
{
			InAutonomousTransactionNode* node = newNode<InAutonomousTransactionNode>();
			node->action = yyvsp[0].stmtNode;
			yyval.stmtNode = node;
		}
break;
case 642:
  if (!yytrial)
{ yyval.stmtNode = newNode<ExceptionNode>(*yyvsp[0].metaNamePtr); }
break;
case 643:
  if (!yytrial)
{ yyval.stmtNode = newNode<ExceptionNode>(*yyvsp[-1].metaNamePtr, yyvsp[0].valueExprNode); }
break;
case 644:
  if (!yytrial)
{ yyval.stmtNode = newNode<ExceptionNode>(*yyvsp[-4].metaNamePtr, (ValueExprNode*) NULL, yyvsp[-1].valueListNode); }
break;
case 645:
  if (!yytrial)
{ yyval.stmtNode = newNode<ExceptionNode>(); }
break;
case 646:
  if (!yytrial)
{
				ForNode* node = newNode<ForNode>();
				node->dsqlLabelName = yyvsp[-2].metaNamePtr;
				node->dsqlSelect = yyvsp[0].selectNode;
				yyval.forNode = node;
			}
break;
case 647:
yyval.forNode = yyvsp[0].forNode;
break;
case 648:
  if (!yytrial)
{
				ForNode* node = yyvsp[-4].forNode;
				node->statement = yyvsp[0].stmtNode;
				yyval.forNode = node;
			}
break;
case 649:
  if (!yytrial)
{
			yyvsp[-2].forNode->dsqlInto = yyvsp[-1].valueListNode;
			yyvsp[-2].forNode->dsqlCursor = yyvsp[0].declCursorNode;
		}
break;
case 650:
  if (!yytrial)
{
			yyvsp[-2].forNode->dsqlInto = yyvsp[-1].valueListNode;
			yyvsp[-2].forNode->dsqlCursor = yyvsp[0].declCursorNode;
		}
break;
case 651:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 653:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[0].valueListNode; }
break;
case 654:
  if (!yytrial)
{ yyval.execStatementNode = newNode<ExecStatementNode>(); }
break;
case 655:
yyval.execStatementNode = yyvsp[0].execStatementNode;
break;
case 656:
yyval.execStatementNode = yyvsp[-2].execStatementNode;
break;
case 657:
  if (!yytrial)
{
			yyval.execStatementNode = yyvsp[-4].execStatementNode;
		}
break;
case 658:
  if (!yytrial)
{
			yyval.execStatementNode = yyvsp[-2].execStatementNode;
			yyval.execStatementNode->outputs = yyvsp[0].valueListNode;
		}
break;
case 659:
  if (!yytrial)
{
			yyval.execStatementNode = yyvsp[-2].execStatementNode;
			yyval.execStatementNode->dsqlLabelName = yyvsp[-4].metaNamePtr;
			yyval.execStatementNode->innerStmt = yyvsp[0].stmtNode;
		}
break;
case 660:
  if (!yytrial)
{ yyvsp[-1].execStatementNode->sql = yyvsp[0].valueExprNode; }
break;
case 661:
yyval.execStatementNode = yyvsp[-4].execStatementNode;
break;
case 662:
  if (!yytrial)
{ yyvsp[-7].execStatementNode->sql = yyvsp[-5].valueExprNode; }
break;
case 663:
  if (!yytrial)
{ yyvsp[-7].execStatementNode->sql = yyvsp[-5].valueExprNode; }
break;
case 666:
  if (!yytrial)
{
			if (!yyvsp[-3].execStatementNode->inputNames)
				yyvsp[-3].execStatementNode->inputNames = FB_NEW_POOL(getPool()) EDS::ParamNames(getPool());

			yyvsp[-3].execStatementNode->inputNames->add(yyvsp[-2].metaNamePtr);

			if (!yyvsp[-3].execStatementNode->inputs)
				yyvsp[-3].execStatementNode->inputs = newNode<ValueListNode>(yyvsp[0].valueExprNode);
			else
				yyvsp[-3].execStatementNode->inputs->add(yyvsp[0].valueExprNode);
		}
break;
case 667:
  if (!yytrial)
{
			if (!yyvsp[-4].execStatementNode->inputNames)
				yyvsp[-4].execStatementNode->inputNames = FB_NEW_POOL(getPool()) EDS::ParamNames(getPool());

			if (!yyvsp[-4].execStatementNode->excessInputs)
				yyvsp[-4].execStatementNode->excessInputs = FB_NEW_POOL(getPool()) EDS::ParamNumbers(getPool());

			yyvsp[-4].execStatementNode->excessInputs->add(yyvsp[-4].execStatementNode->inputNames->getCount());

			yyvsp[-4].execStatementNode->inputNames->add(yyvsp[-2].metaNamePtr);

			if (!yyvsp[-4].execStatementNode->inputs)
				yyvsp[-4].execStatementNode->inputs = newNode<ValueListNode>(yyvsp[0].valueExprNode);
			else
				yyvsp[-4].execStatementNode->inputs->add(yyvsp[0].valueExprNode);
		}
break;
case 670:
  if (!yytrial)
{
			if (!yyvsp[-1].execStatementNode->inputs)
				yyvsp[-1].execStatementNode->inputs = newNode<ValueListNode>(yyvsp[0].valueExprNode);
			else
				yyvsp[-1].execStatementNode->inputs->add(yyvsp[0].valueExprNode);
		}
break;
case 673:
yyval.execStatementNode = yyvsp[-1].execStatementNode;
break;
case 676:
  if (!yytrial)
{ setClause(yyvsp[-5].execStatementNode->dataSource, "EXTERNAL DATA SOURCE", yyvsp[0].valueExprNode); }
break;
case 677:
  if (!yytrial)
{ setClause(yyvsp[-3].execStatementNode->dataSource, "EXTERNAL DATA SOURCE", yyvsp[0].valueExprNode); }
break;
case 678:
  if (!yytrial)
{ setClause(yyvsp[-3].execStatementNode->userName, "USER", yyvsp[0].valueExprNode); }
break;
case 679:
  if (!yytrial)
{ setClause(yyvsp[-2].execStatementNode->password, "PASSWORD", yyvsp[0].valueExprNode); }
break;
case 680:
  if (!yytrial)
{ setClause(yyvsp[-2].execStatementNode->role, "ROLE", yyvsp[0].valueExprNode); }
break;
case 681:
  if (!yytrial)
{ setClause(yyvsp[-3].execStatementNode->traScope, "TRANSACTION", EDS::traAutonomous); }
break;
case 682:
  if (!yytrial)
{ setClause(yyvsp[-3].execStatementNode->traScope, "TRANSACTION", EDS::traCommon); }
break;
case 683:
  if (!yytrial)
{ setClause(yyvsp[-3].execStatementNode->useCallerPrivs, "CALLER PRIVILEGES"); }
break;
case 684:
  if (!yytrial)
{
			IfNode* node = newNode<IfNode>();
			node->condition = yyvsp[-5].boolExprNode;
			node->trueAction = yyvsp[-2].stmtNode;
			node->falseAction = yyvsp[0].stmtNode;
			yyval.stmtNode = node;
		}
break;
case 685:
  if (!yytrial)
{
			IfNode* node = newNode<IfNode>();
			node->condition = yyvsp[-3].boolExprNode;
			node->trueAction = yyvsp[0].stmtNode;
			yyval.stmtNode = node;
		}
break;
case 686:
  if (!yytrial)
{
			PostEventNode* node = newNode<PostEventNode>();
			node->event = yyvsp[-1].valueExprNode;
			node->argument = yyvsp[0].valueExprNode;
			yyval.stmtNode = node;
		}
break;
case 687:
  if (!yytrial)
{ yyval.valueExprNode = NULL; }
break;
case 688:
  if (!yytrial)
{
			ForNode* node = newNode<ForNode>();
			node->dsqlSelect = yyvsp[-2].selectNode;
			node->dsqlInto = yyvsp[0].valueListNode;
			yyval.stmtNode = node;
		}
break;
case 689:
  if (!yytrial)
{
			VariableNode* node = newNode<VariableNode>();
			node->dsqlName = *yyvsp[0].metaNamePtr;
			yyval.valueExprNode = node;
		}
break;
case 690:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(yyvsp[0].valueExprNode); }
break;
case 691:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(yyvsp[0].fieldNode); }
break;
case 692:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-2].valueListNode->add(yyvsp[0].fieldNode); }
break;
case 693:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-2].valueListNode->add(yyvsp[0].valueExprNode); }
break;
case 694:
  if (!yytrial)
{
			LoopNode* node = newNode<LoopNode>();
			node->dsqlLabelName = yyvsp[-6].metaNamePtr;
			node->dsqlExpr = yyvsp[-3].boolExprNode;
			node->statement = yyvsp[0].stmtNode;
			yyval.stmtNode = node;
		}
break;
case 695:
  if (!yytrial)
{ yyval.metaNamePtr = NULL; }
break;
case 696:
  if (!yytrial)
{ yyval.metaNamePtr = yyvsp[-1].metaNamePtr; }
break;
case 697:
  if (!yytrial)
{ yyval.stmtNode = newNode<ContinueLeaveNode>(blr_leave); }
break;
case 698:
  if (!yytrial)
{
			ContinueLeaveNode* node = newNode<ContinueLeaveNode>(blr_leave);
			node->dsqlLabelName = yyvsp[0].metaNamePtr;
			yyval.stmtNode = node;
		}
break;
case 699:
  if (!yytrial)
{
			ContinueLeaveNode* node = newNode<ContinueLeaveNode>(blr_continue_loop);
			node->dsqlLabelName = yyvsp[0].metaNamePtr;
			yyval.stmtNode = node;
		}
break;
case 700:
  if (!yytrial)
{ yyval.metaNamePtr = NULL; }
break;
case 702:
  if (!yytrial)
{ yyval.declCursorNode = NULL; }
break;
case 704:
  if (!yytrial)
{ yyval.declCursorNode = newNode<DeclareCursorNode>(*yyvsp[0].metaNamePtr, DeclareCursorNode::CUR_TYPE_FOR); }
break;
case 705:
  if (!yytrial)
{
			yyval.compoundStmtNode = newNode<CompoundStmtNode>();
			yyval.compoundStmtNode->statements.add(yyvsp[0].stmtNode);
		}
break;
case 706:
  if (!yytrial)
{
			yyvsp[-1].compoundStmtNode->statements.add(yyvsp[0].stmtNode);
			yyval.compoundStmtNode = yyvsp[-1].compoundStmtNode;
		}
break;
case 707:
  if (!yytrial)
{ yyval.errorHandlerNode = newNode<ErrorHandlerNode>(); }
break;
case 708:
yyval.exceptionArray = NOTRIAL(&yyvsp[0].errorHandlerNode->conditions);
break;
case 709:
  if (!yytrial)
{
				ErrorHandlerNode* node = yyvsp[-4].errorHandlerNode;
				node->action = yyvsp[0].stmtNode;
				yyval.stmtNode = node;
			}
break;
case 710:
yyval.exceptionArray = yyvsp[0].exceptionArray;
break;
case 712:
yyval.exceptionArray = yyvsp[-2].exceptionArray;
break;
case 714:
  if (!yytrial)
{
			ExceptionItem& item = yyvsp[-2].exceptionArray->add();
			item.type = ExceptionItem::SQL_CODE;
			item.code = yyvsp[0].int32Val;
		}
break;
case 715:
  if (!yytrial)
{
			ExceptionItem& item = yyvsp[-2].exceptionArray->add();
			item.type = ExceptionItem::SQL_STATE;
			item.name = yyvsp[0].intlStringPtr->getString();
		}
break;
case 716:
  if (!yytrial)
{
			ExceptionItem& item = yyvsp[-2].exceptionArray->add();
			item.type = ExceptionItem::GDS_CODE;
			item.name = yyvsp[0].metaNamePtr->c_str();
		}
break;
case 717:
  if (!yytrial)
{
			ExceptionItem& item = yyvsp[-2].exceptionArray->add();
			item.type = ExceptionItem::XCP_CODE;
			item.name = yyvsp[0].metaNamePtr->c_str();
		}
break;
case 718:
  if (!yytrial)
{
			ExceptionItem& item = yyvsp[-1].exceptionArray->add();
			item.type = ExceptionItem::XCP_DEFAULT;
		}
break;
case 722:
  if (!yytrial)
{ yyval.stmtNode = newNode<CursorStmtNode>(blr_cursor_open, *yyvsp[0].metaNamePtr); }
break;
case 723:
  if (!yytrial)
{ yyval.stmtNode = newNode<CursorStmtNode>(blr_cursor_close, *yyvsp[0].metaNamePtr); }
break;
case 724:
  if (!yytrial)
{ yyval.cursorStmtNode = newNode<CursorStmtNode>(blr_cursor_fetch_scroll); }
break;
case 725:
yyval.cursorStmtNode = yyvsp[0].cursorStmtNode;
break;
case 726:
  if (!yytrial)
{
			CursorStmtNode* cursorStmt = yyvsp[-5].cursorStmtNode;
			cursorStmt->dsqlName = *yyvsp[-1].metaNamePtr;
			cursorStmt->dsqlIntoStmt = yyvsp[0].valueListNode;
			yyval.stmtNode = cursorStmt;
		}
break;
case 727:
  if (!yytrial)
{ yyval.stmtNode = newNode<CursorStmtNode>(blr_cursor_fetch, *yyvsp[-1].metaNamePtr, yyvsp[0].valueListNode); }
break;
case 728:
  if (!yytrial)
{ yyvsp[-1].cursorStmtNode->scrollOp = blr_scroll_bof; }
break;
case 729:
  if (!yytrial)
{ yyvsp[-1].cursorStmtNode->scrollOp = blr_scroll_eof; }
break;
case 730:
  if (!yytrial)
{ yyvsp[-1].cursorStmtNode->scrollOp = blr_scroll_backward; }
break;
case 731:
  if (!yytrial)
{ yyvsp[-1].cursorStmtNode->scrollOp = blr_scroll_forward; }
break;
case 732:
  if (!yytrial)
{
			yyvsp[-2].cursorStmtNode->scrollOp = blr_scroll_absolute;
			yyvsp[-2].cursorStmtNode->scrollExpr = yyvsp[0].valueExprNode;
		}
break;
case 733:
  if (!yytrial)
{
			yyvsp[-2].cursorStmtNode->scrollOp = blr_scroll_relative;
			yyvsp[-2].cursorStmtNode->scrollExpr = yyvsp[0].valueExprNode;
		}
break;
case 734:
  if (!yytrial)
{ yyval.stmtNode = newNode<ExecProcedureNode>(QualifiedName(*yyvsp[-2].metaNamePtr), yyvsp[-1].valueListNode, yyvsp[0].valueListNode); }
break;
case 735:
  if (!yytrial)
{ yyval.stmtNode = newNode<ExecProcedureNode>(QualifiedName(*yyvsp[-2].metaNamePtr, *yyvsp[-4].metaNamePtr), yyvsp[-1].valueListNode, yyvsp[0].valueListNode); }
break;
case 736:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 737:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[0].valueListNode; }
break;
case 738:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-1].valueListNode; }
break;
case 739:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 740:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[0].valueListNode; }
break;
case 741:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-1].valueListNode; }
break;
case 742:
  if (!yytrial)
{ yyval.execBlockNode = newNode<ExecBlockNode>(); }
break;
case 743:
yyval.parametersClause = NOTRIAL(&yyvsp[0].execBlockNode->parameters);
break;
case 744:
yyval.parametersClause = NOTRIAL(&yyvsp[-2].execBlockNode->returns);
break;
case 745:
  if (!yytrial)
{
			ExecBlockNode* node = yyvsp[-7].execBlockNode;
			node->localDeclList = yyvsp[-1].compoundStmtNode;
			node->body = yyvsp[0].stmtNode;
			yyval.execBlockNode = node;
		}
break;
case 750:
  if (!yytrial)
{ yyvsp[-4].parametersClause->add(newNode<ParameterClause>(yyvsp[-3].legacyField, optName(yyvsp[-2].metaNamePtr), (ValueSourceClause*) NULL, yyvsp[0].valueExprNode)); }
break;
case 751:
  if (!yytrial)
{
			CreateAlterViewNode* node = newNode<CreateAlterViewNode>(yyvsp[-4].relSourceNode, yyvsp[-3].valueListNode, yyvsp[-1].selectExprNode);
			node->source = makeParseStr(YYPOSNARG(4), YYPOSNARG(5));
			node->withCheckOption = yyvsp[0].boolVal;
			yyval.createAlterViewNode = node;
		}
break;
case 752:
  if (!yytrial)
{
			yyvsp[0].createAlterViewNode->alter = true;
			yyval.ddlNode = yyvsp[0].createAlterViewNode;
		}
break;
case 753:
  if (!yytrial)
{
			yyvsp[0].createAlterViewNode->alter = true;
			yyvsp[0].createAlterViewNode->create = false;
			yyval.ddlNode = yyvsp[0].createAlterViewNode;
		}
break;
case 754:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 755:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 756:
  if (!yytrial)
{
			yyval.createAlterTriggerNode = yyvsp[-4].createAlterTriggerNode;
			yyval.createAlterTriggerNode->ssDefiner = yyvsp[-3].nullableSqlSecurityVal;
			yyval.createAlterTriggerNode->source = makeParseStr(YYPOSNARG(3), YYPOSNARG(5));
			yyval.createAlterTriggerNode->localDeclList = yyvsp[-1].compoundStmtNode;
			yyval.createAlterTriggerNode->body = yyvsp[0].stmtNode;
		}
break;
case 757:
  if (!yytrial)
{
			yyval.createAlterTriggerNode = yyvsp[-2].createAlterTriggerNode;
			yyval.createAlterTriggerNode->external = yyvsp[-1].externalClause;
			if (yyvsp[0].stringPtr)
				yyval.createAlterTriggerNode->source = *yyvsp[0].stringPtr;
		}
break;
case 758:
  if (!yytrial)
{ yyval.createAlterTriggerNode = newNode<CreateAlterTriggerNode>(*yyvsp[0].metaNamePtr); }
break;
case 759:
yyval.createAlterTriggerNode = NOTRIAL(yyvsp[0].createAlterTriggerNode);
break;
case 760:
  if (!yytrial)
{ yyval.createAlterTriggerNode = yyvsp[-2].createAlterTriggerNode; }
break;
case 761:
yyval.createAlterTriggerNode = NOTRIAL(yyvsp[-1].createAlterTriggerNode);
break;
case 762:
  if (!yytrial)
{
			yyvsp[-4].createAlterTriggerNode->active = yyvsp[-3].nullableBoolVal;
			yyvsp[-4].createAlterTriggerNode->type = yyvsp[-1].uint64Val;
			setClause(yyvsp[-4].createAlterTriggerNode->position, "POSITION", yyvsp[0].nullableIntVal);
		}
break;
case 763:
  if (!yytrial)
{
			yyvsp[-5].createAlterTriggerNode->relationName = *yyvsp[-3].metaNamePtr;
			yyvsp[-5].createAlterTriggerNode->active = yyvsp[-2].nullableBoolVal;
			yyvsp[-5].createAlterTriggerNode->type = yyvsp[-1].uint64Val;
			setClause(yyvsp[-5].createAlterTriggerNode->position, "POSITION", yyvsp[0].nullableIntVal);
		}
break;
case 764:
  if (!yytrial)
{
			yyval.createAlterTriggerNode = yyvsp[0].createAlterTriggerNode;
			yyval.createAlterTriggerNode->alter = true;
		}
break;
case 765:
  if (!yytrial)
{ yyval.nullableBoolVal = Nullable<bool>::val(true); }
break;
case 766:
  if (!yytrial)
{ yyval.nullableBoolVal = Nullable<bool>::val(false); }
break;
case 767:
  if (!yytrial)
{ yyval.nullableBoolVal = Nullable<bool>::empty(); }
break;
case 768:
  if (!yytrial)
{
			yyval.uint64Val = yyvsp[-3].uint64Val;
			setClause(yyvsp[-4].createAlterTriggerNode->position, "POSITION", yyvsp[-2].nullableIntVal);
			yyvsp[-4].createAlterTriggerNode->relationName = *yyvsp[0].metaNamePtr;
		}
break;
case 769:
  if (!yytrial)
{ yyval.uint64Val = yyvsp[0].uint64Val; }
break;
case 770:
  if (!yytrial)
{ yyval.uint64Val = yyvsp[-1].uint64Val + yyvsp[0].uint64Val; }
break;
case 771:
  if (!yytrial)
{ yyval.uint64Val = yyvsp[-1].uint64Val + yyvsp[0].uint64Val - 1; }
break;
case 772:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DB | DB_TRIGGER_CONNECT; }
break;
case 773:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DB | DB_TRIGGER_DISCONNECT; }
break;
case 774:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DB | DB_TRIGGER_TRANS_START; }
break;
case 775:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DB | DB_TRIGGER_TRANS_COMMIT; }
break;
case 776:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DB | DB_TRIGGER_TRANS_ROLLBACK; }
break;
case 778:
  if (!yytrial)
{
			yyval.uint64Val = TRIGGER_TYPE_DDL | DDL_TRIGGER_ANY;
		}
break;
case 779:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_TABLE); }
break;
case 780:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_TABLE); }
break;
case 781:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_TABLE); }
break;
case 782:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_PROCEDURE); }
break;
case 783:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_PROCEDURE); }
break;
case 784:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_PROCEDURE); }
break;
case 785:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_FUNCTION); }
break;
case 786:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_FUNCTION); }
break;
case 787:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_FUNCTION); }
break;
case 788:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_TRIGGER); }
break;
case 789:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_TRIGGER); }
break;
case 790:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_TRIGGER); }
break;
case 791:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_EXCEPTION); }
break;
case 792:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_EXCEPTION); }
break;
case 793:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_EXCEPTION); }
break;
case 794:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_VIEW); }
break;
case 795:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_VIEW); }
break;
case 796:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_VIEW); }
break;
case 797:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_DOMAIN); }
break;
case 798:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_DOMAIN); }
break;
case 799:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_DOMAIN); }
break;
case 800:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_ROLE); }
break;
case 801:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_ROLE); }
break;
case 802:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_ROLE); }
break;
case 803:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_SEQUENCE); }
break;
case 804:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_SEQUENCE); }
break;
case 805:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_SEQUENCE); }
break;
case 806:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_USER); }
break;
case 807:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_USER); }
break;
case 808:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_USER); }
break;
case 809:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_INDEX); }
break;
case 810:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_INDEX); }
break;
case 811:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_INDEX); }
break;
case 812:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_COLLATION); }
break;
case 813:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_COLLATION); }
break;
case 814:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_CHARACTER_SET); }
break;
case 815:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_PACKAGE); }
break;
case 816:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_PACKAGE); }
break;
case 817:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_PACKAGE); }
break;
case 818:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_PACKAGE_BODY); }
break;
case 819:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_PACKAGE_BODY); }
break;
case 820:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_CREATE_MAPPING); }
break;
case 821:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_ALTER_MAPPING); }
break;
case 822:
  if (!yytrial)
{ yyval.uint64Val = TRIGGER_TYPE_DDL | (1LL << DDL_TRIGGER_DROP_MAPPING); }
break;
case 823:
  if (!yytrial)
{ yyval.uint64Val = yyvsp[-2].uint64Val | yyvsp[0].uint64Val; }
break;
case 824:
  if (!yytrial)
{ yyval.uint64Val = 0; }
break;
case 825:
  if (!yytrial)
{ yyval.uint64Val = 1; }
break;
case 826:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(1, 0, 0); }
break;
case 827:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(2, 0, 0); }
break;
case 828:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(3, 0, 0); }
break;
case 829:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(1, 2, 0); }
break;
case 830:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(1, 3, 0); }
break;
case 831:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(2, 1, 0); }
break;
case 832:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(2, 3, 0); }
break;
case 833:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(3, 1, 0); }
break;
case 834:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(3, 2, 0); }
break;
case 835:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(1, 2, 3); }
break;
case 836:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(1, 3, 2); }
break;
case 837:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(2, 1, 3); }
break;
case 838:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(2, 3, 1); }
break;
case 839:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(3, 1, 2); }
break;
case 840:
  if (!yytrial)
{ yyval.uint64Val = trigger_type_suffix(3, 2, 1); }
break;
case 841:
  if (!yytrial)
{ yyval.nullableIntVal = Nullable<int>::empty(); }
break;
case 842:
  if (!yytrial)
{ yyval.nullableIntVal = Nullable<int>::val(yyvsp[0].int32Val); }
break;
case 843:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 844:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterSequenceNode; }
break;
case 845:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterExceptionNode; }
break;
case 846:
  if (!yytrial)
{ yyval.ddlNode = newNode<AlterRelationNode>(yyvsp[0].relSourceNode); }
break;
case 847:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[-2].relationNode; }
break;
case 848:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 849:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterTriggerNode; }
break;
case 850:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterProcedureNode; }
break;
case 851:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterPackageNode; }
break;
case 852:
  if (!yytrial)
{ yyval.alterDatabaseNode = newNode<AlterDatabaseNode>(); }
break;
case 853:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[-2].alterDatabaseNode; }
break;
case 854:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].alterDomainNode; }
break;
case 855:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 856:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 857:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterFunctionNode; }
break;
case 858:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 859:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterUserNode; }
break;
case 860:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterUserNode; }
break;
case 861:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 862:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterSequenceNode; }
break;
case 863:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterSequenceNode; }
break;
case 864:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].mappingNode; }
break;
case 865:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].mappingNode; }
break;
case 866:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 867:
  if (!yytrial)
{ yyval.alterDomainNode = newNode<AlterDomainNode>(*yyvsp[0].metaNamePtr); }
break;
case 868:
yyval.alterDomainNode = yyvsp[0].alterDomainNode;
break;
case 869:
  if (!yytrial)
{ yyval.alterDomainNode = yyvsp[-2].alterDomainNode; }
break;
case 871:
yyval.alterDomainNode = yyvsp[-1].alterDomainNode;
break;
case 873:
  if (!yytrial)
{ setClause(yyvsp[-2].alterDomainNode->setDefault, "DOMAIN DEFAULT", yyvsp[0].valueSourceClause); }
break;
case 874:
  if (!yytrial)
{ setClause(yyvsp[-3].alterDomainNode->setConstraint, "DOMAIN CONSTRAINT", yyvsp[0].boolSourceClause); }
break;
case 875:
  if (!yytrial)
{ setClause(yyvsp[-2].alterDomainNode->setConstraint, "DOMAIN CONSTRAINT", yyvsp[0].boolSourceClause); }
break;
case 876:
  if (!yytrial)
{ setClause(yyvsp[-2].alterDomainNode->dropDefault, "DOMAIN DROP DEFAULT"); }
break;
case 877:
  if (!yytrial)
{ setClause(yyvsp[-2].alterDomainNode->dropConstraint, "DOMAIN DROP CONSTRAINT"); }
break;
case 878:
  if (!yytrial)
{ setClause(yyvsp[-3].alterDomainNode->notNullFlag, "{SET | DROP} NOT NULL", false); }
break;
case 879:
  if (!yytrial)
{ setClause(yyvsp[-3].alterDomainNode->notNullFlag, "{SET | DROP} NOT NULL", true); }
break;
case 880:
  if (!yytrial)
{ setClause(yyvsp[-2].alterDomainNode->renameTo, "DOMAIN NAME", *yyvsp[0].metaNamePtr); }
break;
case 881:
  if (!yytrial)
{
			/*// FIXME: ALTER DOMAIN doesn't support collations, and altered domain's*/
			/*// collation is always lost.*/
			dsql_fld* type = yyvsp[0].legacyField;
			type->collate = "";
			setClause(yyvsp[-2].alterDomainNode->type, "DOMAIN TYPE", type);
		}
break;
case 884:
  if (!yytrial)
{
			RelationNode::DropColumnClause* clause = newNode<RelationNode::DropColumnClause>();
			clause->name = *yyvsp[-1].metaNamePtr;
			clause->cascade = yyvsp[0].boolVal;
			yyvsp[-3].relationNode->clauses.add(clause);
		}
break;
case 885:
  if (!yytrial)
{
			RelationNode::DropConstraintClause* clause = newNode<RelationNode::DropConstraintClause>();
			clause->name = *yyvsp[0].metaNamePtr;
			yyvsp[-3].relationNode->clauses.add(clause);
		}
break;
case 888:
  if (!yytrial)
{
			RelationNode::AlterColPosClause* clause = newNode<RelationNode::AlterColPosClause>();
			clause->name = *yyvsp[-2].metaNamePtr;
			clause->newPos = yyvsp[0].int32Val;
			yyvsp[-4].relationNode->clauses.add(clause);
		}
break;
case 889:
  if (!yytrial)
{
			RelationNode::AlterColNameClause* clause = newNode<RelationNode::AlterColNameClause>();
			clause->fromName = *yyvsp[-2].metaNamePtr;
			clause->toName = *yyvsp[0].metaNamePtr;
			yyvsp[-4].relationNode->clauses.add(clause);
		}
break;
case 890:
  if (!yytrial)
{
			RelationNode::AlterColNullClause* clause = newNode<RelationNode::AlterColNullClause>();
			clause->name = *yyvsp[-3].metaNamePtr;
			clause->notNullFlag = false;
			yyvsp[-5].relationNode->clauses.add(clause);
		}
break;
case 891:
  if (!yytrial)
{
			RelationNode::AlterColNullClause* clause = newNode<RelationNode::AlterColNullClause>();
			clause->name = *yyvsp[-3].metaNamePtr;
			clause->notNullFlag = true;
			yyvsp[-5].relationNode->clauses.add(clause);
		}
break;
case 892:
  if (!yytrial)
{
			RelationNode::AlterColTypeClause* clause = newNode<RelationNode::AlterColTypeClause>();
			clause->field = yyvsp[0].legacyField;
			clause->field->fld_name = *yyvsp[-2].metaNamePtr;
			yyvsp[-4].relationNode->clauses.add(clause);
		}
break;
case 893:
  if (!yytrial)
{
			RelationNode::AlterColTypeClause* clause = newNode<RelationNode::AlterColTypeClause>();
			clause->field = yyvsp[-1].legacyField;
			clause->field->fld_name = *yyvsp[-3].metaNamePtr;
			clause->computed = yyvsp[0].valueSourceClause;
			yyvsp[-5].relationNode->clauses.add(clause);
			clause->field->flags |= FLD_computed;
		}
break;
case 894:
  if (!yytrial)
{
			RelationNode::AlterColTypeClause* clause = newNode<RelationNode::AlterColTypeClause>();
			clause->field = newNode<dsql_fld>();
			clause->field->fld_name = *yyvsp[-1].metaNamePtr;
			clause->computed = yyvsp[0].valueSourceClause;
			yyvsp[-3].relationNode->clauses.add(clause);
			clause->field->flags |= FLD_computed;
		}
break;
case 895:
  if (!yytrial)
{
			RelationNode::AlterColTypeClause* clause = newNode<RelationNode::AlterColTypeClause>();
			clause->field = newNode<dsql_fld>();
			clause->field->fld_name = *yyvsp[-2].metaNamePtr;
			clause->defaultValue = yyvsp[0].valueSourceClause;
			yyvsp[-4].relationNode->clauses.add(clause);
		}
break;
case 896:
  if (!yytrial)
{
			RelationNode::AlterColTypeClause* clause = newNode<RelationNode::AlterColTypeClause>();
			clause->field = newNode<dsql_fld>();
			clause->field->fld_name = *yyvsp[-2].metaNamePtr;
			clause->dropDefault = true;
			yyvsp[-4].relationNode->clauses.add(clause);
		}
break;
case 897:
  if (!yytrial)
{ yyval.identityOptions = newNode<RelationNode::IdentityOptions>(); }
break;
case 898:
  if (!yytrial)
{
				RelationNode::AlterColTypeClause* clause = newNode<RelationNode::AlterColTypeClause>();
				clause->field = newNode<dsql_fld>();
				clause->field->fld_name = *yyvsp[-3].metaNamePtr;
				clause->identityOptions = yyvsp[-2].identityOptions;
				yyvsp[-5].relationNode->clauses.add(clause);
			}
break;
case 899:
  if (!yytrial)
{
			RelationNode::AlterColTypeClause* clause = newNode<RelationNode::AlterColTypeClause>();
			clause->field = newNode<dsql_fld>();
			clause->field->fld_name = *yyvsp[-2].metaNamePtr;
			clause->dropIdentity = true;
			yyvsp[-4].relationNode->clauses.add(clause);
		}
break;
case 900:
  if (!yytrial)
{
			setClause(yyvsp[-4].relationNode->ssDefiner, "SQL SECURITY", true);
			RelationNode::Clause* clause =
				newNode<RelationNode::Clause>(RelationNode::Clause::TYPE_ALTER_SQL_SECURITY);
			yyvsp[-4].relationNode->clauses.add(clause);
		}
break;
case 901:
  if (!yytrial)
{
			setClause(yyvsp[-4].relationNode->ssDefiner, "SQL SECURITY", false);
			RelationNode::Clause* clause =
				newNode<RelationNode::Clause>(RelationNode::Clause::TYPE_ALTER_SQL_SECURITY);
			yyvsp[-4].relationNode->clauses.add(clause);
		}
break;
case 902:
  if (!yytrial)
{
			setClause(yyvsp[-3].relationNode->ssDefiner, "SQL SECURITY", Nullable<bool>::empty());
			RelationNode::Clause* clause =
				newNode<RelationNode::Clause>(RelationNode::Clause::TYPE_ALTER_SQL_SECURITY);
			yyvsp[-3].relationNode->clauses.add(clause);
		}
break;
case 903:
  if (!yytrial)
{
			setClause(yyvsp[-2].relationNode->replicationState, "PUBLICATION", true);
			RelationNode::Clause* clause =
				newNode<RelationNode::Clause>(RelationNode::Clause::TYPE_ALTER_PUBLICATION);
			yyvsp[-2].relationNode->clauses.add(clause);
		}
break;
case 904:
  if (!yytrial)
{
			setClause(yyvsp[-2].relationNode->replicationState, "PUBLICATION", false);
			RelationNode::Clause* clause =
				newNode<RelationNode::Clause>(RelationNode::Clause::TYPE_ALTER_PUBLICATION);
			yyvsp[-2].relationNode->clauses.add(clause);
		}
break;
case 1003:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->typeOfName = *yyvsp[0].metaNamePtr;
		}
break;
case 1004:
yyval.identityOptions = yyvsp[-2].identityOptions;
break;
case 1007:
  if (!yytrial)
{ yyvsp[-3].identityOptions->type = IDENT_TYPE_ALWAYS; }
break;
case 1008:
  if (!yytrial)
{ yyvsp[-4].identityOptions->type = IDENT_TYPE_BY_DEFAULT; }
break;
case 1013:
  if (!yytrial)
{
			setClause(yyvsp[-2].identityOptions->restart, "RESTART");
			yyvsp[-2].identityOptions->startValue = yyvsp[0].nullableInt64Val;
		}
break;
case 1014:
  if (!yytrial)
{ setClause(yyvsp[-4].identityOptions->increment, "SET INCREMENT BY", yyvsp[0].int32Val); }
break;
case 1015:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 1016:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 1017:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 1018:
  if (!yytrial)
{ yyval.ddlNode = newNode<AlterIndexNode>(*yyvsp[-1].metaNamePtr, true); }
break;
case 1019:
  if (!yytrial)
{ yyval.ddlNode = newNode<AlterIndexNode>(*yyvsp[-1].metaNamePtr, false); }
break;
case 1020:
  if (!yytrial)
{
			AlterExternalFunctionNode* node = newNode<AlterExternalFunctionNode>(*yyvsp[-2].metaNamePtr);
			if (yyvsp[-1].stringPtr)
				node->clauses.name = *yyvsp[-1].stringPtr;
			if (yyvsp[0].stringPtr)
				node->clauses.udfModule = *yyvsp[0].stringPtr;
			yyval.ddlNode = node;
		}
break;
case 1021:
  if (!yytrial)
{ yyval.stringPtr = NULL; }
break;
case 1022:
  if (!yytrial)
{ yyval.stringPtr = yyvsp[0].stringPtr; }
break;
case 1023:
  if (!yytrial)
{ yyval.stringPtr = NULL; }
break;
case 1024:
  if (!yytrial)
{ yyval.stringPtr = yyvsp[0].stringPtr; }
break;
case 1025:
  if (!yytrial)
{
			MappingNode* mn = newNode<MappingNode>(MappingNode::MAP_RPL, "AutoAdminImplementationMapping");
			mn->op = yyvsp[-3].boolVal ? MappingNode::MAP_RPL : MappingNode::MAP_DROP;
			mn->from = newNode<IntlString>(FB_DOMAIN_ANY_RID_ADMINS);
			mn->fromType = newNode<MetaName>(FB_PREDEFINED_GROUP);
			mn->mode = 'P';
			mn->plugin = newNode<MetaName>("Win_Sspi");
			mn->role = true;
			mn->to = yyvsp[-4].metaNamePtr;
			mn->validateAdmin();
			yyval.ddlNode = mn;
		}
break;
case 1026:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterRoleNode; }
break;
case 1027:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 1028:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 1029:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 1032:
yyval.dbFilesClause = NOTRIAL(&yyvsp[-1].alterDatabaseNode->files);
break;
case 1034:
  if (!yytrial)
{ yyvsp[-4].alterDatabaseNode->differenceFile = *yyvsp[0].stringPtr; }
break;
case 1035:
  if (!yytrial)
{ yyvsp[-3].alterDatabaseNode->clauses |= AlterDatabaseNode::CLAUSE_DROP_DIFFERENCE; }
break;
case 1036:
  if (!yytrial)
{ yyvsp[-2].alterDatabaseNode->clauses |= AlterDatabaseNode::CLAUSE_BEGIN_BACKUP; }
break;
case 1037:
  if (!yytrial)
{ yyvsp[-2].alterDatabaseNode->clauses |= AlterDatabaseNode::CLAUSE_END_BACKUP; }
break;
case 1038:
  if (!yytrial)
{ yyvsp[-5].alterDatabaseNode->setDefaultCharSet = *yyvsp[0].metaNamePtr; }
break;
case 1039:
yyval.alterDatabaseNode = yyvsp[-3].alterDatabaseNode;
break;
case 1040:
  if (!yytrial)
{
			setClauseFlag(yyvsp[-5].alterDatabaseNode->clauses, AlterDatabaseNode::CLAUSE_CRYPT, "CRYPT");
			yyvsp[-5].alterDatabaseNode->cryptPlugin = *yyvsp[-2].metaNamePtr;
		}
break;
case 1041:
  if (!yytrial)
{ setClauseFlag(yyvsp[-1].alterDatabaseNode->clauses, AlterDatabaseNode::CLAUSE_CRYPT, "CRYPT"); }
break;
case 1042:
  if (!yytrial)
{ yyvsp[-4].alterDatabaseNode->linger = yyvsp[0].int32Val; }
break;
case 1043:
  if (!yytrial)
{ yyvsp[-2].alterDatabaseNode->linger = 0; }
break;
case 1044:
  if (!yytrial)
{ yyvsp[-3].alterDatabaseNode->ssDefiner = yyvsp[0].boolVal; }
break;
case 1045:
  if (!yytrial)
{ yyvsp[-2].alterDatabaseNode->clauses |= AlterDatabaseNode::CLAUSE_ENABLE_PUB; }
break;
case 1046:
  if (!yytrial)
{ yyvsp[-2].alterDatabaseNode->clauses |= AlterDatabaseNode::CLAUSE_DISABLE_PUB; }
break;
case 1047:
  if (!yytrial)
{ yyvsp[-5].alterDatabaseNode->clauses |= AlterDatabaseNode::CLAUSE_PUB_INCL_TABLE; }
break;
case 1048:
  if (!yytrial)
{ yyvsp[-5].alterDatabaseNode->clauses |= AlterDatabaseNode::CLAUSE_PUB_EXCL_TABLE; }
break;
case 1050:
  if (!yytrial)
{ yyvsp[-2].alterDatabaseNode->keyName = *yyvsp[0].metaNamePtr; }
break;
case 1055:
  if (!yytrial)
{ yyvsp[-1].alterDatabaseNode->pubTables.add(*yyvsp[0].metaNamePtr); }
break;
case 1056:
  if (!yytrial)
{
			yyval.createAlterTriggerNode = newNode<CreateAlterTriggerNode>(*yyvsp[-7].metaNamePtr);
			yyval.createAlterTriggerNode->alter = true;
			yyval.createAlterTriggerNode->create = false;
			yyval.createAlterTriggerNode->active = yyvsp[-6].nullableBoolVal;
			yyval.createAlterTriggerNode->type = yyvsp[-5].nullableUint64Val;
			yyval.createAlterTriggerNode->position = yyvsp[-4].nullableIntVal;
			yyval.createAlterTriggerNode->ssDefiner = yyvsp[-3].nullableSqlSecurityVal;
			yyval.createAlterTriggerNode->source = makeParseStr(YYPOSNARG(6), YYPOSNARG(8));
			yyval.createAlterTriggerNode->localDeclList = yyvsp[-1].compoundStmtNode;
			yyval.createAlterTriggerNode->body = yyvsp[0].stmtNode;
		}
break;
case 1057:
  if (!yytrial)
{
			yyval.createAlterTriggerNode = newNode<CreateAlterTriggerNode>(*yyvsp[-5].metaNamePtr);
			yyval.createAlterTriggerNode->alter = true;
			yyval.createAlterTriggerNode->create = false;
			yyval.createAlterTriggerNode->active = yyvsp[-4].nullableBoolVal;
			yyval.createAlterTriggerNode->type = yyvsp[-3].nullableUint64Val;
			yyval.createAlterTriggerNode->position = yyvsp[-2].nullableIntVal;
			yyval.createAlterTriggerNode->external = yyvsp[-1].externalClause;
			if (yyvsp[0].stringPtr)
				yyval.createAlterTriggerNode->source = *yyvsp[0].stringPtr;
		}
break;
case 1058:
  if (!yytrial)
{
			yyval.createAlterTriggerNode = newNode<CreateAlterTriggerNode>(*yyvsp[-4].metaNamePtr);
			yyval.createAlterTriggerNode->alter = true;
			yyval.createAlterTriggerNode->create = false;
			yyval.createAlterTriggerNode->active = yyvsp[-3].nullableBoolVal;
			yyval.createAlterTriggerNode->type = yyvsp[-2].nullableUint64Val;
			yyval.createAlterTriggerNode->position = yyvsp[-1].nullableIntVal;
			yyval.createAlterTriggerNode->ssDefiner = yyvsp[0].nullableSqlSecurityVal;
		}
break;
case 1059:
  if (!yytrial)
{ yyval.nullableUint64Val = Nullable<FB_UINT64>::val(yyvsp[-1].uint64Val + yyvsp[0].uint64Val - 1); }
break;
case 1060:
  if (!yytrial)
{ yyval.nullableUint64Val = Nullable<FB_UINT64>::empty(); }
break;
case 1061:
  if (!yytrial)
{ yyval.nullableSqlSecurityVal = Nullable<TriggerDefinition::SqlSecurity>::empty(); }
break;
case 1062:
  if (!yytrial)
{ yyval.nullableSqlSecurityVal = Nullable<TriggerDefinition::SqlSecurity>::val(TriggerDefinition::SS_DEFINER); }
break;
case 1063:
  if (!yytrial)
{ yyval.nullableSqlSecurityVal = Nullable<TriggerDefinition::SqlSecurity>::val(TriggerDefinition::SS_INVOKER); }
break;
case 1064:
  if (!yytrial)
{ yyval.nullableSqlSecurityVal = Nullable<TriggerDefinition::SqlSecurity>::val(TriggerDefinition::SS_DROP); }
break;
case 1065:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].ddlNode; }
break;
case 1066:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropExceptionNode>(*yyvsp[0].metaNamePtr); }
break;
case 1067:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropIndexNode>(*yyvsp[0].metaNamePtr); }
break;
case 1068:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropProcedureNode>(*yyvsp[0].metaNamePtr); }
break;
case 1069:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropRelationNode>(*yyvsp[0].metaNamePtr, false); }
break;
case 1070:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropTriggerNode>(*yyvsp[0].metaNamePtr); }
break;
case 1071:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropRelationNode>(*yyvsp[0].metaNamePtr, true); }
break;
case 1072:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropFilterNode>(*yyvsp[0].metaNamePtr); }
break;
case 1073:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropDomainNode>(*yyvsp[0].metaNamePtr); }
break;
case 1074:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropFunctionNode>(*yyvsp[0].metaNamePtr); }
break;
case 1075:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropFunctionNode>(*yyvsp[0].metaNamePtr); }
break;
case 1076:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropShadowNode>(yyvsp[-1].int32Val, yyvsp[0].boolVal); }
break;
case 1077:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropRoleNode>(*yyvsp[0].metaNamePtr); }
break;
case 1078:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropSequenceNode>(*yyvsp[0].metaNamePtr); }
break;
case 1079:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropSequenceNode>(*yyvsp[0].metaNamePtr); }
break;
case 1080:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropCollationNode>(*yyvsp[0].metaNamePtr); }
break;
case 1081:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropUserNode>(*yyvsp[-3].metaNamePtr, yyvsp[0].metaNamePtr); }
break;
case 1082:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropUserNode>(*yyvsp[0].metaNamePtr); }
break;
case 1083:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropPackageNode>(*yyvsp[0].metaNamePtr); }
break;
case 1084:
  if (!yytrial)
{ yyval.ddlNode = newNode<DropPackageBodyNode>(*yyvsp[0].metaNamePtr); }
break;
case 1085:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].mappingNode; }
break;
case 1086:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].mappingNode; }
break;
case 1087:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 1088:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 1089:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 1093:
  if (!yytrial)
{
			yyval.legacyField = yyvsp[-2].legacyField;
			yyval.legacyField->notNull = true;
		}
break;
case 1096:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->typeOfName = *yyvsp[0].metaNamePtr;
		}
break;
case 1097:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->typeOfName = *yyvsp[0].metaNamePtr;
			yyval.legacyField->typeOfTable = *yyvsp[-2].metaNamePtr;
		}
break;
case 1098:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->typeOfName = *yyvsp[0].metaNamePtr;
			yyval.legacyField->fullDomain = true;
		}
break;
case 1101:
  if (!yytrial)
{
			yyvsp[-3].legacyField->ranges = yyvsp[-1].valueListNode;
			yyvsp[-3].legacyField->dimensions = yyvsp[-3].legacyField->ranges->items.getCount() / 2;
			yyvsp[-3].legacyField->elementDtype = yyvsp[-3].legacyField->dtype;
			yyval.legacyField = yyvsp[-3].legacyField;
		}
break;
case 1102:
  if (!yytrial)
{
			yyvsp[-4].legacyField->ranges = yyvsp[-2].valueListNode;
			yyvsp[-4].legacyField->dimensions = yyvsp[-4].legacyField->ranges->items.getCount() / 2;
			yyvsp[-4].legacyField->elementDtype = yyvsp[-4].legacyField->dtype;
			if (yyvsp[0].metaNamePtr)
				yyvsp[-4].legacyField->charSet = *yyvsp[0].metaNamePtr;
			yyval.legacyField = yyvsp[-4].legacyField;
		}
break;
case 1104:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-2].valueListNode->add(yyvsp[0].valueListNode->items[0])->add(yyvsp[0].valueListNode->items[1]); }
break;
case 1105:
  if (!yytrial)
{
			if (yyvsp[0].int32Val < 1)
		 		yyval.valueListNode = newNode<ValueListNode>(MAKE_const_slong(yyvsp[0].int32Val))->add(MAKE_const_slong(1));
			else
		 		yyval.valueListNode = newNode<ValueListNode>(MAKE_const_slong(1))->add(MAKE_const_slong(yyvsp[0].int32Val));
		}
break;
case 1106:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(MAKE_const_slong(yyvsp[-2].int32Val))->add(MAKE_const_slong(yyvsp[0].int32Val)); }
break;
case 1108:
  if (!yytrial)
{
			yyval.legacyField = yyvsp[-1].legacyField;
			if (yyvsp[0].metaNamePtr)
			{
				yyval.legacyField->charSet = *yyvsp[0].metaNamePtr;
				yyval.legacyField->flags |= FLD_has_chset;
			}
		}
break;
case 1114:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();

			if (client_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post (Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
					Arg::Gds(isc_sql_dialect_datatype_unsupport) << Arg::Num(client_dialect) <<
																	Arg::Str("BIGINT"));
			}

			if (db_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post (Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
					Arg::Gds(isc_sql_db_dialect_dtype_unsupport) << Arg::Num(db_dialect) <<
																Arg::Str("BIGINT"));
			}

			yyval.legacyField->dtype = dtype_int64;
			yyval.legacyField->length = sizeof(SINT64);
			yyval.legacyField->flags |= FLD_has_prec;
		}
break;
case 1115:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_int128;
			yyval.legacyField->length = sizeof(Int128);
			yyval.legacyField->flags |= FLD_has_prec;
		}
break;
case 1116:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_long;
			yyval.legacyField->length = sizeof(SLONG);
			yyval.legacyField->flags |= FLD_has_prec;
		}
break;
case 1117:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_short;
			yyval.legacyField->length = sizeof(SSHORT);
			yyval.legacyField->flags |= FLD_has_prec;
		}
break;
case 1118:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			stmt_ambiguous = true;

			if (client_dialect <= SQL_DIALECT_V5)
			{
				/* Post warning saying that DATE is equivalent to TIMESTAMP*/
				ERRD_post_warning(Arg::Warning(isc_sqlwarn) << Arg::Num(301) <<
								  Arg::Warning(isc_dtype_renamed));
				yyval.legacyField->dtype = dtype_timestamp;
				yyval.legacyField->length = sizeof(GDS_TIMESTAMP);
			}
			else if (client_dialect == SQL_DIALECT_V6_TRANSITION)
				yyabandon(YYPOSNARG(1), -104, isc_transitional_date);
			else
			{
				yyval.legacyField->dtype = dtype_sql_date;
				yyval.legacyField->length = sizeof(ULONG);
			}
			yyval.legacyField->flags |= FLD_has_prec;
		}
break;
case 1119:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();

			checkTimeDialect();
			yyval.legacyField->dtype = dtype_sql_time;
			yyval.legacyField->length = sizeof(SLONG);
			yyval.legacyField->flags |= FLD_has_prec;
		}
break;
case 1120:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();

			checkTimeDialect();
			yyval.legacyField->dtype = dtype_sql_time_tz;
			yyval.legacyField->length = sizeof(ISC_TIME_TZ);
			yyval.legacyField->flags |= FLD_has_prec;
		}
break;
case 1121:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_timestamp;
			yyval.legacyField->length = sizeof(GDS_TIMESTAMP);
			yyval.legacyField->flags |= FLD_has_prec;
		}
break;
case 1122:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_timestamp_tz;
			yyval.legacyField->length = sizeof(ISC_TIMESTAMP_TZ);
			yyval.legacyField->flags |= FLD_has_prec;
		}
break;
case 1123:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_boolean;
			yyval.legacyField->length = sizeof(UCHAR);
		}
break;
case 1128:
  if (!yytrial)
{ yyval.legacyField = newNode<dsql_fld>(); }
break;
case 1129:
yyval.legacyField = NOTRIAL(yyvsp[0].legacyField);
break;
case 1130:
  if (!yytrial)
{
			yyval.legacyField = yyvsp[-4].legacyField;
			yyval.legacyField->dtype = dtype_blob;
			yyval.legacyField->length = sizeof(ISC_QUAD);
			yyval.legacyField->segLength = yyvsp[-1].uintVal;
			if (yyvsp[0].metaNamePtr)
			{
				yyval.legacyField->charSet = *yyvsp[0].metaNamePtr;
				yyval.legacyField->flags |= FLD_has_chset;
			}
		}
break;
case 1131:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_blob;
			yyval.legacyField->length = sizeof(ISC_QUAD);
			yyval.legacyField->segLength = (USHORT) yyvsp[-1].int32Val;
			yyval.legacyField->subType = 0;
		}
break;
case 1132:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_blob;
			yyval.legacyField->length = sizeof(ISC_QUAD);
			yyval.legacyField->segLength = (USHORT) yyvsp[-3].int32Val;
			yyval.legacyField->subType = (USHORT) yyvsp[-1].int32Val;
			yyval.legacyField->flags |= FLD_has_sub;
		}
break;
case 1133:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_blob;
			yyval.legacyField->length = sizeof(ISC_QUAD);
			yyval.legacyField->segLength = 80;
			yyval.legacyField->subType = (USHORT) yyvsp[-1].int32Val;
			yyval.legacyField->flags |= FLD_has_sub;
		}
break;
case 1134:
  if (!yytrial)
{ yyval.uintVal = (USHORT) 80; }
break;
case 1135:
  if (!yytrial)
{ yyval.uintVal = (USHORT) yyvsp[0].int32Val; }
break;
case 1136:
  if (!yytrial)
{ yyvsp[0].legacyField->subType = (USHORT) 0; }
break;
case 1137:
  if (!yytrial)
{ yyvsp[-2].legacyField->subType = (USHORT) yyvsp[0].int32Val; yyvsp[-2].legacyField->flags |= FLD_has_sub; }
break;
case 1138:
  if (!yytrial)
{ yyvsp[-2].legacyField->subTypeName = *yyvsp[0].metaNamePtr; yyvsp[-2].legacyField->flags |= FLD_has_sub; }
break;
case 1139:
  if (!yytrial)
{ yyval.metaNamePtr = NULL; }
break;
case 1140:
  if (!yytrial)
{ yyval.metaNamePtr = yyvsp[0].metaNamePtr; }
break;
case 1141:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_text;
			yyval.legacyField->charLength = (USHORT) yyvsp[-1].int32Val;
			yyval.legacyField->flags |= (FLD_national | FLD_has_len);
		}
break;
case 1142:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_text;
			yyval.legacyField->charLength = 1;
			yyval.legacyField->flags |= FLD_national;
		}
break;
case 1143:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_varying;
			yyval.legacyField->charLength = (USHORT) yyvsp[-1].int32Val;
			yyval.legacyField->flags |= (FLD_national | FLD_has_len);
		}
break;
case 1144:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_text;
			yyval.legacyField->charLength = (USHORT) yyvsp[-1].int32Val;
			yyval.legacyField->length = (USHORT) yyvsp[-1].int32Val;
			yyval.legacyField->textType = ttype_binary;
			yyval.legacyField->charSetId = CS_BINARY;
			yyval.legacyField->subType = fb_text_subtype_binary;
			yyval.legacyField->flags |= (FLD_has_len | FLD_has_chset);
		}
break;
case 1145:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_text;
			yyval.legacyField->charLength = 1;
			yyval.legacyField->length = 1;
			yyval.legacyField->textType = ttype_binary;
			yyval.legacyField->charSetId = CS_BINARY;
			yyval.legacyField->subType = fb_text_subtype_binary;
			yyval.legacyField->flags |= FLD_has_chset;
		}
break;
case 1146:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_varying;
			yyval.legacyField->charLength = (USHORT) yyvsp[-1].int32Val;
			yyval.legacyField->length = (USHORT) yyvsp[-1].int32Val + sizeof(USHORT);
			yyval.legacyField->textType = ttype_binary;
			yyval.legacyField->charSetId = CS_BINARY;
			yyval.legacyField->subType = fb_text_subtype_binary;
			yyval.legacyField->flags |= (FLD_has_len | FLD_has_chset);
		}
break;
case 1147:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_text;
			yyval.legacyField->charLength = (USHORT) yyvsp[-1].int32Val;
			yyval.legacyField->flags |= FLD_has_len;
		}
break;
case 1148:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_text;
			yyval.legacyField->charLength = 1;
		}
break;
case 1149:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_varying;
			yyval.legacyField->charLength = (USHORT) yyvsp[-1].int32Val;
			yyval.legacyField->flags |= FLD_has_len;
		}
break;
case 1161:
  if (!yytrial)
{
			SLONG precision = yyvsp[0].int32Val;

			if (precision != 0 && precision != 16 && precision != 34)
				yyabandon(YYPOSNARG(2), -842, isc_decprecision_err);	/* DecFloat precision must be 16 or 34.*/

			yyval.legacyField = newNode<dsql_fld>();
			if (precision)
				yyval.legacyField->flags |= FLD_has_prec;
			yyval.legacyField->precision = precision == 0 ? 34 : (USHORT) precision;
			yyval.legacyField->dtype = precision == 16 ? dtype_dec64 : dtype_dec128;
			yyval.legacyField->length = precision == 16 ? sizeof(Decimal64) : sizeof(Decimal128);
		}
break;
case 1162:
  if (!yytrial)
{
			yyval.legacyField = yyvsp[0].legacyField;
			yyval.legacyField->subType = dsc_num_type_numeric;
			yyval.legacyField->flags |= FLD_has_sub;
		}
break;
case 1163:
  if (!yytrial)
{
			yyval.legacyField = yyvsp[0].legacyField;
			yyval.legacyField->subType = dsc_num_type_decimal;
			yyval.legacyField->flags |= FLD_has_sub;

			if (yyval.legacyField->dtype == dtype_short)
			{
				yyval.legacyField->dtype = dtype_long;
				yyval.legacyField->length = sizeof(SLONG);
			}
		}
break;
case 1164:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_long;
			yyval.legacyField->length = sizeof(SLONG);
			yyval.legacyField->precision = 9;
		}
break;
case 1165:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->flags |= FLD_has_prec;

			if (yyvsp[-1].int32Val < 1 || yyvsp[-1].int32Val > 38)
				yyabandon(YYPOSNARG(2), -842, Arg::Gds(isc_precision_err2) << Arg::Num(1) << Arg::Num(38));
																/* Precision must be between 1 and 38*/

			if (yyvsp[-1].int32Val > 18)
			{
				yyval.legacyField->dtype = dtype_int128;
				yyval.legacyField->length = sizeof(Int128);
			}
			else if (yyvsp[-1].int32Val > 9)
			{
				if ( ( (client_dialect <= SQL_DIALECT_V5) && (db_dialect > SQL_DIALECT_V5) ) ||
					( (client_dialect > SQL_DIALECT_V5) && (db_dialect <= SQL_DIALECT_V5) ) )
				{
					ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-817) <<
							  Arg::Gds(isc_ddl_not_allowed_by_db_sql_dial) << Arg::Num(db_dialect));
				}

				if (client_dialect <= SQL_DIALECT_V5)
				{
					yyval.legacyField->dtype = dtype_double;
					yyval.legacyField->length = sizeof(double);
				}
				else
				{
					if (client_dialect == SQL_DIALECT_V6_TRANSITION)
					{
						ERRD_post_warning(Arg::Warning(isc_dsql_warn_precision_ambiguous));
						ERRD_post_warning(Arg::Warning(isc_dsql_warn_precision_ambiguous1));
						ERRD_post_warning(Arg::Warning(isc_dsql_warn_precision_ambiguous2));
					}

					yyval.legacyField->dtype = dtype_int64;
					yyval.legacyField->length = sizeof(SINT64);
				}
			}
			else
			{
				if (yyvsp[-1].int32Val < 5)
				{
					yyval.legacyField->dtype = dtype_short;
					yyval.legacyField->length = sizeof(SSHORT);
				}
				else
				{
					yyval.legacyField->dtype = dtype_long;
					yyval.legacyField->length = sizeof(SLONG);
				}
			}

			yyval.legacyField->precision = (USHORT) yyvsp[-1].int32Val;
		}
break;
case 1166:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->flags |= (FLD_has_prec | FLD_has_scale);

			if (yyvsp[-3].int32Val < 1 || yyvsp[-3].int32Val > 38)
				yyabandon(YYPOSNARG(2), -842, Arg::Gds(isc_precision_err2) << Arg::Num(1) << Arg::Num(38));
																/* Precision must be between 1 and 38*/

			if (yyvsp[-1].int32Val > yyvsp[-3].int32Val || yyvsp[-1].int32Val < 0)
				yyabandon(YYPOSNARG(4), -842, isc_scale_nogt);	/* Scale must be between 0 and precision*/

			if (yyvsp[-3].int32Val > 18)
			{
				yyval.legacyField->dtype = dtype_int128;
				yyval.legacyField->length = sizeof(Int128);
			}
			else if (yyvsp[-3].int32Val > 9)
			{
				if ( ( (client_dialect <= SQL_DIALECT_V5) && (db_dialect > SQL_DIALECT_V5) ) ||
					( (client_dialect > SQL_DIALECT_V5) && (db_dialect <= SQL_DIALECT_V5) ) )
				{
					ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-817) <<
							  Arg::Gds(isc_ddl_not_allowed_by_db_sql_dial) << Arg::Num(db_dialect));
				}

				if (client_dialect <= SQL_DIALECT_V5)
				{
					yyval.legacyField->dtype = dtype_double;
					yyval.legacyField->length = sizeof(double);
				}
				else
				{
					if (client_dialect == SQL_DIALECT_V6_TRANSITION)
					{
						ERRD_post_warning(Arg::Warning(isc_dsql_warn_precision_ambiguous));
						ERRD_post_warning(Arg::Warning(isc_dsql_warn_precision_ambiguous1));
						ERRD_post_warning(Arg::Warning(isc_dsql_warn_precision_ambiguous2));
					}
					/* client_dialect >= SQL_DIALECT_V6*/
					yyval.legacyField->dtype = dtype_int64;
					yyval.legacyField->length = sizeof(SINT64);
				}
			}
			else
			{
				if (yyvsp[-3].int32Val < 5)
				{
					yyval.legacyField->dtype = dtype_short;
					yyval.legacyField->length = sizeof(SSHORT);
				}
				else
				{
					yyval.legacyField->dtype = dtype_long;
					yyval.legacyField->length = sizeof(SLONG);
				}
			}

			yyval.legacyField->precision = (USHORT) yyvsp[-3].int32Val;
			yyval.legacyField->scale = - (SSHORT) yyvsp[-1].int32Val;
		}
break;
case 1169:
  if (!yytrial)
{
		    /* Precision is binary digits of the significand: 1-24 for 32 bit single precision, 25-53 for 64 bit double precision*/
			/* Precision 0 is the 'no precision specified' case, which defaults to 32 bit single precision*/
			SLONG precision = yyvsp[0].int32Val;

			if (precision != 0 && (precision < 1 || precision > 53))
				yyabandon(YYPOSNARG(2), -842, Arg::Gds(isc_precision_err2) << Arg::Num(1) << Arg::Num(53));
																/* Precision must be between 1 and 53*/

			yyval.legacyField = newNode<dsql_fld>();

			if (precision > 24)
			{
				yyval.legacyField->dtype = dtype_double;
				yyval.legacyField->length = sizeof(double);
			}
			else
			{
				yyval.legacyField->dtype = dtype_real;
				yyval.legacyField->length = sizeof(float);
			}
		}
break;
case 1170:
  if (!yytrial)
{
			/* Precision is binary digits of the significand: 1-53 for 64 bit double precision*/
			/* Precision 0 is the 'no precision specified case', which defaults to 64 bit double precision*/
			SLONG precision = yyvsp[0].int32Val;

			if (precision != 0 && (precision < 1 || precision > 53))
				yyabandon(YYPOSNARG(3), -842, Arg::Gds(isc_precision_err2) << Arg::Num(1) << Arg::Num(53));
																/* Precision must be between 1 and 53*/

			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_double;
			yyval.legacyField->length = sizeof(double);
		}
break;
case 1171:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_real;
			yyval.legacyField->length = sizeof(float);
		}
break;
case 1172:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_double;
			yyval.legacyField->length = sizeof(double);
		}
break;
case 1173:
  if (!yytrial)
{ yyval.int32Val = 0; }
break;
case 1174:
  if (!yytrial)
{ yyval.int32Val = yyvsp[-1].int32Val; }
break;
case 1178:
  if (!yytrial)
{
			UserSavepointNode* node = newNode<UserSavepointNode>();
			node->command = UserSavepointNode::CMD_SET;
			node->name = *yyvsp[0].metaNamePtr;
			yyval.stmtNode = node;
		}
break;
case 1179:
  if (!yytrial)
{
			UserSavepointNode* node = newNode<UserSavepointNode>();
			node->command = (yyvsp[0].boolVal ? UserSavepointNode::CMD_RELEASE_ONLY : UserSavepointNode::CMD_RELEASE);
			node->name = *yyvsp[-1].metaNamePtr;
			yyval.stmtNode = node;
		}
break;
case 1180:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 1181:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 1182:
  if (!yytrial)
{
			UserSavepointNode* node = newNode<UserSavepointNode>();
			node->command = UserSavepointNode::CMD_ROLLBACK;
			node->name = *yyvsp[0].metaNamePtr;
			yyval.stmtNode = node;
		}
break;
case 1185:
  if (!yytrial)
{ yyval.traNode = newNode<CommitRollbackNode>(CommitRollbackNode::CMD_COMMIT, yyvsp[0].boolVal); }
break;
case 1186:
  if (!yytrial)
{ yyval.traNode = newNode<CommitRollbackNode>(CommitRollbackNode::CMD_ROLLBACK, yyvsp[0].boolVal); }
break;
case 1189:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 1190:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 1193:
  if (!yytrial)
{ yyval.setTransactionNode = newNode<SetTransactionNode>(); }
break;
case 1194:
yyval.setTransactionNode = yyvsp[0].setTransactionNode;
break;
case 1195:
  if (!yytrial)
{ yyval.setTransactionNode = yyvsp[-2].setTransactionNode; }
break;
case 1196:
  if (!yytrial)
{ yyval.sessionResetNode = newNode<SessionResetNode>(); }
break;
case 1197:
  if (!yytrial)
{ yyval.setRoleNode = newNode<SetRoleNode>(yyvsp[0].metaNamePtr); }
break;
case 1198:
  if (!yytrial)
{ yyval.setRoleNode = newNode<SetRoleNode>(); }
break;
case 1199:
  if (!yytrial)
{ yyval.mngNode = newNode<SetDebugOptionNode>(yyvsp[-2].metaNamePtr, yyvsp[0].valueExprNode); }
break;
case 1200:
  if (!yytrial)
{ yyval.setDecFloatRoundNode = newNode<SetDecFloatRoundNode>(yyvsp[0].metaNamePtr); }
break;
case 1201:
  if (!yytrial)
{ yyval.setDecFloatTrapsNode = newNode<SetDecFloatTrapsNode>(); }
break;
case 1202:
yyval.setDecFloatTrapsNode = yyvsp[0].setDecFloatTrapsNode;
break;
case 1203:
  if (!yytrial)
{ yyval.setDecFloatTrapsNode = yyvsp[-2].setDecFloatTrapsNode; }
break;
case 1204:
  if (!yytrial)
{ yyval.setBindNode = newNode<SetBindNode>(); yyval.setBindNode->from = yyvsp[-2].legacyField; yyval.setBindNode->to = yyvsp[0].legacyField; }
break;
case 1206:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_timestamp_tz;
			yyval.legacyField->length = 0;
		}
break;
case 1208:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_varying;
			yyval.legacyField->charLength = 0;
		}
break;
case 1209:
  if (!yytrial)
{
			yyval.legacyField = yyvsp[0].legacyField;
		}
break;
case 1210:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->flags = FLD_legacy;
		}
break;
case 1211:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->flags = FLD_native;
		}
break;
case 1212:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->flags = FLD_extended;
		}
break;
case 1213:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			checkTimeDialect();
			yyval.legacyField->dtype = dtype_ex_time_tz;
			yyval.legacyField->length = sizeof(ISC_TIME_TZ_EX);
			yyval.legacyField->flags |= FLD_has_prec;
		}
break;
case 1214:
  if (!yytrial)
{
			yyval.legacyField = newNode<dsql_fld>();
			yyval.legacyField->dtype = dtype_ex_timestamp_tz;
			yyval.legacyField->length = sizeof(ISC_TIMESTAMP_TZ_EX);
			yyval.legacyField->flags |= FLD_has_prec;
		}
break;
case 1218:
yyval.setDecFloatTrapsNode = yyvsp[-2].setDecFloatTrapsNode;
break;
case 1220:
  if (!yytrial)
{ yyvsp[-1].setDecFloatTrapsNode->trap(yyvsp[0].metaNamePtr); }
break;
case 1221:
  if (!yytrial)
{ yyval.setSessionNode = newNode<SetSessionNode>(SetSessionNode::TYPE_IDLE_TIMEOUT, yyvsp[-1].int32Val, yyvsp[0].blrOp); }
break;
case 1222:
  if (!yytrial)
{ yyval.setSessionNode = newNode<SetSessionNode>(SetSessionNode::TYPE_STMT_TIMEOUT, yyvsp[-1].int32Val, yyvsp[0].blrOp); }
break;
case 1223:
  if (!yytrial)
{ yyval.blrOp = blr_extract_minute; }
break;
case 1224:
  if (!yytrial)
{ yyval.blrOp = blr_extract_hour; }
break;
case 1225:
  if (!yytrial)
{ yyval.blrOp = blr_extract_minute; }
break;
case 1226:
  if (!yytrial)
{ yyval.blrOp = blr_extract_second; }
break;
case 1227:
  if (!yytrial)
{ yyval.blrOp = blr_extract_second; }
break;
case 1228:
  if (!yytrial)
{ yyval.blrOp = blr_extract_hour; }
break;
case 1229:
  if (!yytrial)
{ yyval.blrOp = blr_extract_minute; }
break;
case 1230:
  if (!yytrial)
{ yyval.blrOp = blr_extract_second; }
break;
case 1231:
  if (!yytrial)
{ yyval.blrOp = blr_extract_millisecond; }
break;
case 1232:
  if (!yytrial)
{ yyval.mngNode = yyvsp[0].mngNode; }
break;
case 1233:
  if (!yytrial)
{ yyval.mngNode = newNode<SetTimeZoneNode>(yyvsp[0].intlStringPtr->getString()); }
break;
case 1234:
  if (!yytrial)
{ yyval.mngNode = newNode<SetTimeZoneNode>(); }
break;
case 1238:
yyval.setTransactionNode = yyvsp[-1].setTransactionNode;
break;
case 1240:
  if (!yytrial)
{ setClause(yyvsp[-2].setTransactionNode->readOnly, "READ {ONLY | WRITE}", true); }
break;
case 1241:
  if (!yytrial)
{ setClause(yyvsp[-2].setTransactionNode->readOnly, "READ {ONLY | WRITE}", false); }
break;
case 1242:
  if (!yytrial)
{ setClause(yyvsp[-1].setTransactionNode->wait, "[NO] WAIT", true); }
break;
case 1243:
  if (!yytrial)
{ setClause(yyvsp[-2].setTransactionNode->wait, "[NO] WAIT", false); }
break;
case 1244:
  if (!yytrial)
{ setClause(yyvsp[-2].setTransactionNode->isoLevel, "ISOLATION LEVEL", yyvsp[0].uintVal); }
break;
case 1245:
  if (!yytrial)
{ setClause(yyvsp[-3].setTransactionNode->noAutoUndo, "NO AUTO UNDO", true); }
break;
case 1246:
  if (!yytrial)
{ setClause(yyvsp[-2].setTransactionNode->ignoreLimbo, "IGNORE LIMBO", true); }
break;
case 1247:
  if (!yytrial)
{ setClause(yyvsp[-2].setTransactionNode->restartRequests, "RESTART REQUESTS", true); }
break;
case 1248:
  if (!yytrial)
{ setClause(yyvsp[-2].setTransactionNode->autoCommit, "AUTO COMMIT", true); }
break;
case 1249:
  if (!yytrial)
{ setClause(yyvsp[-3].setTransactionNode->lockTimeout, "LOCK TIMEOUT", (USHORT) yyvsp[0].int32Val); }
break;
case 1250:
  if (!yytrial)
{ checkDuplicateClause(yyvsp[-1].setTransactionNode->reserveList, "RESERVING"); }
break;
case 1251:
yyval.setTransactionNode = yyvsp[-2].setTransactionNode;
break;
case 1253:
  if (!yytrial)
{ yyval.uintVal = yyvsp[0].uintVal;}
break;
case 1255:
  if (!yytrial)
{ yyval.uintVal = yyvsp[0].uintVal; }
break;
case 1256:
  if (!yytrial)
{ yyval.uintVal = yyvsp[0].uintVal; }
break;
case 1257:
  if (!yytrial)
{ yyval.uintVal = yyvsp[0].uintVal; }
break;
case 1258:
  if (!yytrial)
{ yyval.uintVal = SetTransactionNode::ISO_LEVEL_CONCURRENCY; }
break;
case 1259:
  if (!yytrial)
{
			setClause(yyvsp[-4].setTransactionNode->atSnapshotNumber, "SNAPSHOT AT NUMBER", (CommitNumber) yyvsp[0].int64Val);
			yyval.uintVal = SetTransactionNode::ISO_LEVEL_CONCURRENCY;
		}
break;
case 1260:
  if (!yytrial)
{ yyval.uintVal = SetTransactionNode::ISO_LEVEL_CONSISTENCY; }
break;
case 1261:
  if (!yytrial)
{ yyval.uintVal = SetTransactionNode::ISO_LEVEL_CONSISTENCY; }
break;
case 1262:
  if (!yytrial)
{ yyval.int64Val = yyvsp[0].int32Val; }
break;
case 1263:
  if (!yytrial)
{ yyval.int64Val = yyvsp[0].scaledNumber.number; }
break;
case 1264:
  if (!yytrial)
{ yyval.uintVal = SetTransactionNode::ISO_LEVEL_READ_COMMITTED_NO_REC_VERSION; }
break;
case 1265:
  if (!yytrial)
{ yyval.uintVal = SetTransactionNode::ISO_LEVEL_READ_COMMITTED_REC_VERSION; }
break;
case 1266:
  if (!yytrial)
{ yyval.uintVal = SetTransactionNode::ISO_LEVEL_READ_COMMITTED_NO_REC_VERSION; }
break;
case 1267:
  if (!yytrial)
{ yyval.uintVal = SetTransactionNode::ISO_LEVEL_READ_COMMITTED_READ_CONSISTENCY; }
break;
case 1268:
  if (!yytrial)
{ yyval.uintVal = 0; }
break;
case 1269:
  if (!yytrial)
{ yyval.uintVal = SetTransactionNode::LOCK_MODE_SHARED; }
break;
case 1270:
  if (!yytrial)
{ yyval.uintVal = SetTransactionNode::LOCK_MODE_PROTECTED; }
break;
case 1271:
  if (!yytrial)
{ yyval.uintVal = SetTransactionNode::LOCK_MODE_READ; }
break;
case 1272:
  if (!yytrial)
{ yyval.uintVal = SetTransactionNode::LOCK_MODE_WRITE; }
break;
case 1273:
  if (!yytrial)
{ yyvsp[-1].setTransactionNode->reserveList.add(yyvsp[0].setTransactionRestrictionClause); }
break;
case 1274:
  if (!yytrial)
{ yyvsp[-3].setTransactionNode->reserveList.add(yyvsp[0].setTransactionRestrictionClause); }
break;
case 1275:
  if (!yytrial)
{ yyval.setTransactionRestrictionClause = newNode<SetTransactionNode::RestrictionOption>(yyvsp[-1].metaNameArray, yyvsp[0].uintVal); }
break;
case 1276:
  if (!yytrial)
{ yyval.uintVal = 0; }
break;
case 1277:
  if (!yytrial)
{ yyval.uintVal = yyvsp[-1].uintVal | yyvsp[0].uintVal; }
break;
case 1278:
  if (!yytrial)
{
			ObjectsArray<MetaName>* node = newNode<ObjectsArray<MetaName> >();
			node->add(*yyvsp[0].metaNamePtr);
			yyval.metaNameArray = node;
		}
break;
case 1279:
  if (!yytrial)
{
			ObjectsArray<MetaName>* node = yyvsp[-2].metaNameArray;
			node->add(*yyvsp[0].metaNamePtr);
			yyval.metaNameArray = node;
		}
break;
case 1280:
  if (!yytrial)
{ yyval.ddlNode = newNode<SetStatisticsNode>(*yyvsp[0].metaNamePtr); }
break;
case 1281:
  if (!yytrial)
{ yyval.ddlNode = newNode<CommentOnNode>(yyvsp[-2].intVal, QualifiedName(""), "", *yyvsp[0].stringPtr); }
break;
case 1282:
  if (!yytrial)
{ yyval.ddlNode = newNode<CommentOnNode>(yyvsp[-3].intVal, QualifiedName(*yyvsp[-2].metaNamePtr), "", *yyvsp[0].stringPtr); }
break;
case 1283:
  if (!yytrial)
{ yyval.ddlNode = newNode<CommentOnNode>(yyvsp[-4].intVal, QualifiedName(*yyvsp[-3].metaNamePtr), *yyvsp[-2].metaNamePtr, *yyvsp[0].stringPtr); }
break;
case 1284:
  if (!yytrial)
{ yyval.ddlNode = newNode<CommentOnNode>(yyvsp[-4].intVal, *yyvsp[-3].qualifiedNamePtr, *yyvsp[-2].metaNamePtr, *yyvsp[0].stringPtr); }
break;
case 1285:
  if (!yytrial)
{ yyval.ddlNode = newNode<CommentOnNode>(yyvsp[-3].intVal, *yyvsp[-2].qualifiedNamePtr, "", *yyvsp[0].stringPtr); }
break;
case 1286:
  if (!yytrial)
{ yyval.ddlNode = yyvsp[0].createAlterUserNode; }
break;
case 1287:
  if (!yytrial)
{
				yyval.createAlterUserNode = newNode<CreateAlterUserNode>(CreateAlterUserNode::USER_MOD, *yyvsp[0].metaNamePtr);
			}
break;
case 1288:
yyval.createAlterUserNode = yyvsp[0].createAlterUserNode;
break;
case 1289:
  if (!yytrial)
{
				CreateAlterUserNode* node = yyval.createAlterUserNode = yyvsp[-4].createAlterUserNode;
				node->comment = yyvsp[0].stringPtr;
			}
break;
case 1292:
  if (!yytrial)
{ yyval.intVal = obj_database; }
break;
case 1293:
  if (!yytrial)
{ yyval.intVal = obj_field; }
break;
case 1294:
  if (!yytrial)
{ yyval.intVal = obj_relation; }
break;
case 1295:
  if (!yytrial)
{ yyval.intVal = obj_view; }
break;
case 1296:
  if (!yytrial)
{ yyval.intVal = obj_trigger; }
break;
case 1297:
  if (!yytrial)
{ yyval.intVal = obj_blob_filter; }
break;
case 1298:
  if (!yytrial)
{ yyval.intVal = obj_exception; }
break;
case 1299:
  if (!yytrial)
{ yyval.intVal = obj_generator; }
break;
case 1300:
  if (!yytrial)
{ yyval.intVal = obj_generator; }
break;
case 1301:
  if (!yytrial)
{ yyval.intVal = obj_index; }
break;
case 1302:
  if (!yytrial)
{ yyval.intVal = obj_sql_role; }
break;
case 1303:
  if (!yytrial)
{ yyval.intVal = obj_charset; }
break;
case 1304:
  if (!yytrial)
{ yyval.intVal = obj_collation; }
break;
case 1305:
  if (!yytrial)
{ yyval.intVal = obj_package_header; }
break;
case 1306:
  if (!yytrial)
{ yyval.intVal = obj_relation; }
break;
case 1307:
  if (!yytrial)
{ yyval.intVal = obj_parameter; }
break;
case 1308:
  if (!yytrial)
{ yyval.intVal = obj_procedure; }
break;
case 1309:
  if (!yytrial)
{ yyval.intVal = obj_udf; }
break;
case 1310:
  if (!yytrial)
{ yyval.intVal = obj_procedure; }
break;
case 1311:
  if (!yytrial)
{ yyval.intVal = obj_udf; }
break;
case 1312:
  if (!yytrial)
{ yyval.intVal = obj_udf; }
break;
case 1313:
  if (!yytrial)
{ yyval.metaNamePtr = yyvsp[0].metaNamePtr; }
break;
case 1314:
  if (!yytrial)
{ yyval.qualifiedNamePtr = newNode<QualifiedName>(*yyvsp[0].metaNamePtr); }
break;
case 1315:
  if (!yytrial)
{ yyval.qualifiedNamePtr = newNode<QualifiedName>(*yyvsp[0].metaNamePtr, *yyvsp[-2].metaNamePtr); }
break;
case 1316:
  if (!yytrial)
{ yyval.stringPtr = yyvsp[0].stringPtr; }
break;
case 1317:
  if (!yytrial)
{ yyval.stringPtr = newString(""); }
break;
case 1318:
  if (!yytrial)
{
			SelectNode* node = newNode<SelectNode>();
			node->dsqlExpr = yyvsp[-2].selectExprNode;
			node->dsqlForUpdate = yyvsp[-1].boolVal;
			node->dsqlWithLock = yyvsp[0].boolVal;
			yyval.selectNode = node;
		}
break;
case 1319:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 1320:
  if (!yytrial)
{ yyval.boolVal = true; /* for_update_list is ignored */ }
break;
case 1321:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 1322:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[0].valueListNode; }
break;
case 1323:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 1324:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 1325:
  if (!yytrial)
{
			SelectExprNode* node = yyval.selectExprNode = newNode<SelectExprNode>();
			node->querySpec = yyvsp[-2].recSourceNode;
			node->orderClause = yyvsp[-1].valueListNode;
			node->rowsClause = yyvsp[0].rowsClause;
			node->withClause = yyvsp[-3].withClause;
		}
break;
case 1326:
  if (!yytrial)
{
			SelectExprNode* node = yyval.selectExprNode = newNode<SelectExprNode>();
			node->querySpec = yyvsp[-3].recSourceNode;
			node->orderClause = yyvsp[-2].valueListNode;

			if (yyvsp[-1].valueExprNode || yyvsp[0].valueExprNode)
			{
				RowsClause* rowsNode = newNode<RowsClause>();
				rowsNode->skip = yyvsp[-1].valueExprNode;
				rowsNode->length = yyvsp[0].valueExprNode;
				node->rowsClause = rowsNode;
			}

			node->withClause = yyvsp[-4].withClause;
		}
break;
case 1327:
  if (!yytrial)
{ yyval.withClause = NULL; }
break;
case 1328:
  if (!yytrial)
{
			yyval.withClause = yyvsp[0].withClause;
			yyval.withClause->recursive = true;
		}
break;
case 1329:
  if (!yytrial)
{ yyval.withClause = yyvsp[0].withClause; }
break;
case 1330:
  if (!yytrial)
{
			yyval.withClause = newNode<WithClause>();
			yyval.withClause->add(yyvsp[0].selectExprNode);
		}
break;
case 1331:
  if (!yytrial)
{
			yyval.withClause = yyvsp[-2].withClause;
			yyval.withClause->add(yyvsp[0].selectExprNode);
		}
break;
case 1332:
  if (!yytrial)
{
			yyval.selectExprNode = yyvsp[-1].selectExprNode;
			yyval.selectExprNode->dsqlFlags |= RecordSourceNode::DFLAG_DERIVED;
			yyval.selectExprNode->alias = yyvsp[-5].metaNamePtr->c_str();
			yyval.selectExprNode->columns = yyvsp[-4].metaNameArray;
		}
break;
case 1333:
  if (!yytrial)
{
			yyval.selectExprNode = yyvsp[0].selectExprNode;
			yyval.selectExprNode->dsqlFlags |= RecordSourceNode::DFLAG_VALUE;
		}
break;
case 1334:
  if (!yytrial)
{
			yyvsp[0].selectExprNode->dsqlFlags |= RecordSourceNode::DFLAG_SINGLETON;
			yyval.valueExprNode = newNode<SubQueryNode>(blr_via, yyvsp[0].selectExprNode);
		}
break;
case 1335:
  if (!yytrial)
{ yyval.recSourceNode = yyvsp[0].rseNode; }
break;
case 1336:
  if (!yytrial)
{
			UnionSourceNode* node = nodeAs<UnionSourceNode>(yyvsp[-3].recSourceNode);
			if (node && !node->dsqlAll)
				node->dsqlClauses->add(yyvsp[0].rseNode);
			else
			{
				node = newNode<UnionSourceNode>();
				node->dsqlClauses = newNode<RecSourceListNode>(yyvsp[-3].recSourceNode)->add(yyvsp[0].rseNode);
			}
			yyval.recSourceNode = node;
		}
break;
case 1337:
  if (!yytrial)
{
			UnionSourceNode* node = nodeAs<UnionSourceNode>(yyvsp[-3].recSourceNode);
			if (node && node->dsqlAll)
				node->dsqlClauses->add(yyvsp[0].rseNode);
			else
			{
				node = newNode<UnionSourceNode>();
				node->dsqlAll = true;
				node->dsqlClauses = newNode<RecSourceListNode>(yyvsp[-3].recSourceNode)->add(yyvsp[0].rseNode);
			}
			yyval.recSourceNode = node;
		}
break;
case 1339:
  if (!yytrial)
{
			RseNode* rse = newNode<RseNode>();
			rse->dsqlFirst = yyvsp[-8].valueListNode ? yyvsp[-8].valueListNode->items[1] : NULL;
			rse->dsqlSkip = yyvsp[-8].valueListNode ? yyvsp[-8].valueListNode->items[0] : NULL;
			rse->dsqlDistinct = yyvsp[-7].valueListNode;
			rse->dsqlSelectList = yyvsp[-6].valueListNode;
			rse->dsqlFrom = yyvsp[-5].recSourceListNode;
			rse->dsqlWhere = yyvsp[-4].boolExprNode;
			rse->dsqlGroup = yyvsp[-3].valueListNode;
			rse->dsqlHaving = yyvsp[-2].boolExprNode;
			rse->dsqlNamedWindows = yyvsp[-1].namedWindowsClause;
			rse->rse_plan = yyvsp[0].planNode;
			yyval.rseNode = rse;
		}
break;
case 1340:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 1341:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(yyvsp[0].valueExprNode)->add(yyvsp[-1].valueExprNode); }
break;
case 1342:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(1u)->add(yyvsp[0].valueExprNode); }
break;
case 1343:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(yyvsp[0].valueExprNode)->add(NULL); }
break;
case 1344:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_const_slong(yyvsp[0].int32Val); }
break;
case 1345:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[-1].valueExprNode; }
break;
case 1346:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1347:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_const_slong(yyvsp[0].int32Val); }
break;
case 1348:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[-1].valueExprNode; }
break;
case 1349:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1350:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(0); }
break;
case 1351:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 1352:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[0].valueListNode; }
break;
case 1353:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 1354:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(yyvsp[0].valueExprNode); }
break;
case 1355:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-2].valueListNode->add(yyvsp[0].valueExprNode); }
break;
case 1357:
  if (!yytrial)
{
			FieldNode* fieldNode = newNode<FieldNode>();
			fieldNode->dsqlQualifier = *yyvsp[-2].metaNamePtr;
			yyval.valueExprNode = fieldNode;
		}
break;
case 1359:
  if (!yytrial)
{ yyval.valueExprNode = newNode<DsqlAliasNode>(*yyvsp[0].metaNamePtr, yyvsp[-2].valueExprNode); }
break;
case 1362:
  if (!yytrial)
{ yyval.recSourceListNode = yyvsp[0].recSourceListNode; }
break;
case 1363:
  if (!yytrial)
{ yyval.recSourceListNode = newNode<RecSourceListNode>(yyvsp[0].recSourceNode); }
break;
case 1364:
  if (!yytrial)
{ yyval.recSourceListNode = yyvsp[-2].recSourceListNode->add(yyvsp[0].recSourceNode); }
break;
case 1368:
  if (!yytrial)
{ yyval.recSourceNode = yyvsp[0].selectExprNode; }
break;
case 1369:
  if (!yytrial)
{ yyval.recSourceNode = yyvsp[0].selectExprNode; }
break;
case 1370:
  if (!yytrial)
{ yyval.recSourceNode = yyvsp[-1].recSourceNode; }
break;
case 1371:
  if (!yytrial)
{
			yyval.selectExprNode = yyvsp[-4].selectExprNode;
			yyval.selectExprNode->dsqlFlags |= RecordSourceNode::DFLAG_DERIVED;
			if (yyvsp[-1].metaNamePtr)
				yyval.selectExprNode->alias = yyvsp[-1].metaNamePtr->c_str();
			yyval.selectExprNode->columns = yyvsp[0].metaNameArray;
		}
break;
case 1372:
  if (!yytrial)
{
			yyval.selectExprNode = yyvsp[0].selectExprNode;
			yyval.selectExprNode->dsqlFlags |= RecordSourceNode::DFLAG_LATERAL;
		}
break;
case 1373:
  if (!yytrial)
{ yyval.metaNamePtr = NULL; }
break;
case 1375:
  if (!yytrial)
{ yyval.metaNameArray = NULL; }
break;
case 1376:
  if (!yytrial)
{ yyval.metaNameArray = yyvsp[-1].metaNameArray; }
break;
case 1377:
  if (!yytrial)
{
			ObjectsArray<MetaName>* node = newNode<ObjectsArray<MetaName> >();
			node->add(*yyvsp[0].metaNamePtr);
			yyval.metaNameArray = node;
		}
break;
case 1378:
  if (!yytrial)
{
			ObjectsArray<MetaName>* node = yyvsp[-2].metaNameArray;
			node->add(*yyvsp[0].metaNamePtr);
			yyval.metaNameArray = node;
		}
break;
case 1382:
  if (!yytrial)
{
			RseNode* rse = newNode<RseNode>();
			rse->dsqlExplicitJoin = true;
			rse->rse_jointype = blr_inner;
			rse->dsqlFrom = newNode<RecSourceListNode>(yyvsp[-3].recSourceNode)->add(yyvsp[0].recSourceNode);
			yyval.recSourceNode = rse;
		}
break;
case 1383:
  if (!yytrial)
{
			RseNode* rse = newNode<RseNode>();
			rse->dsqlExplicitJoin = true;
			rse->rse_jointype = yyvsp[-2].blrOp;
			rse->dsqlFrom = newNode<RecSourceListNode>(yyvsp[-4].recSourceNode)->add(yyvsp[0].recSourceNode);
			rse->dsqlJoinUsing = newNode<ValueListNode>(0u);	/* using list with size 0 -> natural*/
			yyval.recSourceNode = rse;
		}
break;
case 1384:
  if (!yytrial)
{
			RseNode* rse = newNode<RseNode>();
			rse->dsqlExplicitJoin = true;
			rse->rse_jointype = yyvsp[-3].blrOp;
			rse->dsqlFrom = newNode<RecSourceListNode>(yyvsp[-4].recSourceNode);
			rse->dsqlFrom->add(yyvsp[-1].recSourceNode);
			rse->dsqlWhere = yyvsp[0].boolExprNode;
			yyval.recSourceNode = rse;
		}
break;
case 1385:
  if (!yytrial)
{
			RseNode* rse = newNode<RseNode>();
			rse->dsqlExplicitJoin = true;
			rse->rse_jointype = yyvsp[-3].blrOp;
			rse->dsqlFrom = newNode<RecSourceListNode>(yyvsp[-4].recSourceNode);
			rse->dsqlFrom->add(yyvsp[-1].recSourceNode);
			rse->dsqlJoinUsing = yyvsp[0].valueListNode;
			yyval.recSourceNode = rse;
		}
break;
case 1386:
  if (!yytrial)
{ yyval.boolExprNode = yyvsp[0].boolExprNode; }
break;
case 1387:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-1].valueListNode; }
break;
case 1388:
  if (!yytrial)
{
			ProcedureSourceNode* node = newNode<ProcedureSourceNode>(QualifiedName(*yyvsp[-3].metaNamePtr));
			node->sourceList = yyvsp[-2].valueListNode;
			node->alias = yyvsp[0].metaNamePtr->c_str();
			yyval.recSourceNode = node;
		}
break;
case 1389:
  if (!yytrial)
{
			ProcedureSourceNode* node = newNode<ProcedureSourceNode>(QualifiedName(*yyvsp[-1].metaNamePtr));
			node->sourceList = yyvsp[0].valueListNode;
			yyval.recSourceNode = node;
		}
break;
case 1390:
  if (!yytrial)
{
			ProcedureSourceNode* node = newNode<ProcedureSourceNode>(
				QualifiedName(*yyvsp[-3].metaNamePtr, *yyvsp[-5].metaNamePtr));
			node->sourceList = yyvsp[-2].valueListNode;
			node->alias = yyvsp[0].metaNamePtr->c_str();
			yyval.recSourceNode = node;
		}
break;
case 1391:
  if (!yytrial)
{
			ProcedureSourceNode* node = newNode<ProcedureSourceNode>(
				QualifiedName(*yyvsp[-1].metaNamePtr, *yyvsp[-3].metaNamePtr));
			node->sourceList = yyvsp[0].valueListNode;
			yyval.recSourceNode = node;
		}
break;
case 1392:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 1393:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-1].valueListNode; }
break;
case 1395:
  if (!yytrial)
{
			RelationSourceNode* node = newNode<RelationSourceNode>(*yyvsp[-2].metaNamePtr);
			node->alias = yyvsp[0].metaNamePtr->c_str();
			yyval.relSourceNode = node;
		}
break;
case 1396:
  if (!yytrial)
{ yyval.relSourceNode = newNode<RelationSourceNode>(*yyvsp[0].metaNamePtr); }
break;
case 1397:
  if (!yytrial)
{ yyval.blrOp = blr_inner; }
break;
case 1398:
  if (!yytrial)
{ yyval.blrOp = blr_inner; }
break;
case 1399:
  if (!yytrial)
{ yyval.blrOp = blr_left; }
break;
case 1400:
  if (!yytrial)
{ yyval.blrOp = blr_right; }
break;
case 1401:
  if (!yytrial)
{ yyval.blrOp = blr_full; }
break;
case 1404:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 1405:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[0].valueListNode; }
break;
case 1406:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(yyvsp[0].valueExprNode); }
break;
case 1407:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-2].valueListNode->add(yyvsp[0].valueExprNode); }
break;
case 1409:
  if (!yytrial)
{ yyval.boolExprNode = NULL; }
break;
case 1410:
  if (!yytrial)
{ yyval.boolExprNode = yyvsp[0].boolExprNode; }
break;
case 1411:
  if (!yytrial)
{ yyval.boolExprNode = NULL; }
break;
case 1412:
  if (!yytrial)
{ yyval.boolExprNode = yyvsp[0].boolExprNode; }
break;
case 1413:
  if (!yytrial)
{ yyval.namedWindowsClause = NULL; }
break;
case 1414:
  if (!yytrial)
{ yyval.namedWindowsClause = yyvsp[0].namedWindowsClause; }
break;
case 1415:
  if (!yytrial)
{
			NamedWindowsClause* node = newNode<NamedWindowsClause>();
			node->add(*yyvsp[0].namedWindowClause);
			yyval.namedWindowsClause = node;
		}
break;
case 1416:
  if (!yytrial)
{
			NamedWindowsClause* node = yyvsp[-2].namedWindowsClause;
			node->add(*yyvsp[0].namedWindowClause);
			yyval.namedWindowsClause = node;
		}
break;
case 1417:
  if (!yytrial)
{
			yyval.namedWindowClause = newNode<NamedWindowClause>(*yyvsp[-4].metaNamePtr, yyvsp[-1].windowClause);
		}
break;
case 1418:
  if (!yytrial)
{ yyval.metaNamePtr = NULL; }
break;
case 1420:
  if (!yytrial)
{ yyval.planNode = NULL; }
break;
case 1421:
  if (!yytrial)
{ yyval.planNode = yyvsp[0].planNode; }
break;
case 1422:
  if (!yytrial)
{ yyval.planNode = newNode<PlanNode>(PlanNode::TYPE_RETRIEVE); }
break;
case 1423:
yyval.planNode = yyvsp[-1].planNode;
break;
case 1424:
  if (!yytrial)
{ yyval.planNode = yyvsp[-4].planNode; }
break;
case 1431:
  if (!yytrial)
{ yyvsp[-1].planNode->subNodes.add(yyvsp[0].planNode); }
break;
case 1432:
  if (!yytrial)
{ yyvsp[-3].planNode->subNodes.add(yyvsp[0].planNode); }
break;
case 1433:
  if (!yytrial)
{
			yyval.planNode = newNode<PlanNode>(PlanNode::TYPE_RETRIEVE);
			yyval.planNode->dsqlNames = yyvsp[-1].metaNameArray;
			yyval.planNode->accessType = yyvsp[0].accessType;
		}
break;
case 1435:
  if (!yytrial)
{
			ObjectsArray<MetaName>* node = newNode<ObjectsArray<MetaName> >();
			node->add(*yyvsp[0].metaNamePtr);
			yyval.metaNameArray = node;
		}
break;
case 1436:
  if (!yytrial)
{
			ObjectsArray<MetaName>* node = yyvsp[-1].metaNameArray;
			node->add(*yyvsp[0].metaNamePtr);
			yyval.metaNameArray = node;
		}
break;
case 1437:
  if (!yytrial)
{ yyval.accessType = newNode<PlanNode::AccessType>(PlanNode::AccessType::TYPE_SEQUENTIAL); }
break;
case 1438:
  if (!yytrial)
{ yyval.accessType = newNode<PlanNode::AccessType>(PlanNode::AccessType::TYPE_INDICES); }
break;
case 1439:
yyval.accessType = yyvsp[-1].accessType;
break;
case 1440:
  if (!yytrial)
{ yyval.accessType = yyvsp[-4].accessType; }
break;
case 1441:
  if (!yytrial)
{ yyval.accessType = newNode<PlanNode::AccessType>(PlanNode::AccessType::TYPE_NAVIGATIONAL); }
break;
case 1442:
  if (!yytrial)
{
			yyval.accessType = yyvsp[-3].accessType;
			yyval.accessType->items.insert(0).indexName = *yyvsp[-2].metaNamePtr;
		}
break;
case 1443:
  if (!yytrial)
{
			PlanNode::AccessItem& item = yyvsp[-1].accessType->items.add();
			item.indexName = *yyvsp[0].metaNamePtr;
		}
break;
case 1444:
  if (!yytrial)
{
			PlanNode::AccessItem& item = yyvsp[-3].accessType->items.add();
			item.indexName = *yyvsp[0].metaNamePtr;
		}
break;
case 1446:
yyval.accessType = yyvsp[-2].accessType;
break;
case 1448:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 1450:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[0].valueListNode; }
break;
case 1451:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(yyvsp[0].valueExprNode); }
break;
case 1452:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-2].valueListNode->add(yyvsp[0].valueExprNode); }
break;
case 1453:
  if (!yytrial)
{
			OrderNode* node = newNode<OrderNode>(yyvsp[-2].valueExprNode);
			node->descending = yyvsp[-1].boolVal;
			node->nullsPlacement = yyvsp[0].nullsPlacement;
			yyval.valueExprNode = node;
		}
break;
case 1454:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 1455:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 1456:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 1457:
  if (!yytrial)
{ yyval.nullsPlacement = OrderNode::NULLS_DEFAULT; }
break;
case 1458:
  if (!yytrial)
{ yyval.nullsPlacement = yyvsp[0].nullsPlacement; }
break;
case 1459:
  if (!yytrial)
{ yyval.nullsPlacement = OrderNode::NULLS_FIRST; }
break;
case 1460:
  if (!yytrial)
{ yyval.nullsPlacement = OrderNode::NULLS_LAST; }
break;
case 1461:
  if (!yytrial)
{
			yyval.rowsClause = newNode<RowsClause>();
			yyval.rowsClause->length = yyvsp[0].valueExprNode;
		}
break;
case 1462:
  if (!yytrial)
{
			yyval.rowsClause = newNode<RowsClause>();
			yyval.rowsClause->skip = newNode<ArithmeticNode>(blr_subtract, true, yyvsp[-2].valueExprNode, MAKE_const_slong(1));
			yyval.rowsClause->length = newNode<ArithmeticNode>(blr_add, true,
				newNode<ArithmeticNode>(blr_subtract, true, yyvsp[0].valueExprNode, yyvsp[-2].valueExprNode), MAKE_const_slong(1));
		}
break;
case 1463:
  if (!yytrial)
{ yyval.rowsClause = NULL; }
break;
case 1467:
  if (!yytrial)
{ yyval.valueExprNode = NULL; }
break;
case 1468:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[-1].valueExprNode; }
break;
case 1471:
  if (!yytrial)
{ yyval.valueExprNode = NULL; }
break;
case 1472:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[-2].valueExprNode; }
break;
case 1473:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_const_slong(1); }
break;
case 1474:
yyval.nestFieldArray = NOTRIAL(&yyvsp[0].storeNode->dsqlFields);
break;
case 1475:
  if (!yytrial)
{
			StoreNode* node = yyval.storeNode = yyvsp[-8].storeNode;
			node->overrideClause = yyvsp[-5].nullableOverrideClause;
			node->dsqlValues = yyvsp[-2].valueListNode;
			node->dsqlReturning = yyvsp[0].returningClause;
		}
break;
case 1476:
  if (!yytrial)
{
			StoreNode* node = yyval.storeNode = yyvsp[-5].storeNode;
			node->overrideClause = yyvsp[-2].nullableOverrideClause;
			node->dsqlRse = yyvsp[-1].selectExprNode;
			node->dsqlReturning = yyvsp[0].returningClause;
			yyval.storeNode = node;
		}
break;
case 1477:
  if (!yytrial)
{
			StoreNode* node = yyval.storeNode = yyvsp[-3].storeNode;
			node->dsqlReturning = yyvsp[0].returningClause;
			yyval.storeNode = node;
		}
break;
case 1478:
  if (!yytrial)
{
			StoreNode* node = newNode<StoreNode>();
			node->dsqlRelation = yyvsp[0].relSourceNode;
			yyval.storeNode = node;
		}
break;
case 1479:
  if (!yytrial)
{ yyval.nullableOverrideClause = Nullable<OverrideClause>::empty(); }
break;
case 1480:
  if (!yytrial)
{ yyval.nullableOverrideClause = Nullable<OverrideClause>::val(OverrideClause::USER_VALUE); }
break;
case 1481:
  if (!yytrial)
{ yyval.nullableOverrideClause = Nullable<OverrideClause>::val(OverrideClause::SYSTEM_VALUE); }
break;
case 1482:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(yyvsp[0].valueExprNode); }
break;
case 1483:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-2].valueListNode->add(yyvsp[0].valueExprNode); }
break;
case 1485:
  if (!yytrial)
{ yyval.valueExprNode = NULL; }
break;
case 1486:
  if (!yytrial)
{
				MergeNode* node = yyval.mergeNode = newNode<MergeNode>();
				node->relation = yyvsp[-4].relSourceNode;
				node->usingClause = yyvsp[-2].recSourceNode;
				node->condition = yyvsp[0].boolExprNode;
			}
break;
case 1487:
yyval.mergeNode = yyvsp[0].mergeNode;
break;
case 1488:
  if (!yytrial)
{
				MergeNode* node = yyval.mergeNode = yyvsp[-3].mergeNode;
				node->returning = yyvsp[0].returningClause;
			}
break;
case 1491:
yyval.mergeNode = yyvsp[-1].mergeNode;
break;
case 1494:
  if (!yytrial)
{ yyval.mergeMatchedClause = &yyvsp[-2].mergeNode->whenMatched.add(); }
break;
case 1495:
yyval.mergeMatchedClause = NOTRIAL(yyvsp[0].mergeMatchedClause);
break;
case 1496:
yyval.metaNamePtr =  NOTRIAL(&yyvsp[-4].mergeNode->relation->dsqlName);
break;
case 1498:
  if (!yytrial)
{ yyval.mergeNotMatchedClause = &yyvsp[-3].mergeNode->whenNotMatched.add(); }
break;
case 1499:
yyval.mergeNotMatchedClause = NOTRIAL(yyvsp[0].mergeNotMatchedClause);
break;
case 1501:
yyval.metaNamePtr = NOTRIAL(yyvsp[-3].metaNamePtr);
break;
case 1502:
  if (!yytrial)
{ yyvsp[-6].mergeMatchedClause->assignments = yyvsp[0].compoundStmtNode; }
break;
case 1503:
yyval.metaNamePtr = NOTRIAL(yyvsp[-5].metaNamePtr);
break;
case 1504:
  if (!yytrial)
{
			yyvsp[-8].mergeMatchedClause->condition = yyvsp[-5].boolExprNode;
			yyvsp[-8].mergeMatchedClause->assignments = yyvsp[0].compoundStmtNode;
		}
break;
case 1506:
  if (!yytrial)
{ yyvsp[-5].mergeMatchedClause->condition = yyvsp[-2].boolExprNode; }
break;
case 1507:
yyval.nestFieldArray = NOTRIAL(&yyvsp[-2].mergeNotMatchedClause->fields);
break;
case 1508:
  if (!yytrial)
{
			yyvsp[-9].mergeNotMatchedClause->overrideClause = yyvsp[-4].nullableOverrideClause;
			yyvsp[-9].mergeNotMatchedClause->values = yyvsp[-1].valueListNode;
		}
break;
case 1509:
yyval.nestFieldArray = NOTRIAL(&yyvsp[-4].mergeNotMatchedClause->fields);
break;
case 1510:
  if (!yytrial)
{
			yyvsp[-11].mergeNotMatchedClause->overrideClause = yyvsp[-4].nullableOverrideClause;
			yyvsp[-11].mergeNotMatchedClause->values = yyvsp[-1].valueListNode;
			yyvsp[-11].mergeNotMatchedClause->condition = yyvsp[-9].boolExprNode;
		}
break;
case 1513:
  if (!yytrial)
{
			EraseNode* node = newNode<EraseNode>();
			node->dsqlRelation = yyvsp[-5].relSourceNode;
			node->dsqlBoolean = yyvsp[-4].boolExprNode;
			node->dsqlPlan = yyvsp[-3].planNode;
			node->dsqlOrder = yyvsp[-2].valueListNode;
			node->dsqlRows = yyvsp[-1].rowsClause;
			node->dsqlReturning = yyvsp[0].returningClause;
			yyval.stmtNode = node;
		}
break;
case 1514:
  if (!yytrial)
{
			EraseNode* node = newNode<EraseNode>();
			node->dsqlRelation = yyvsp[-2].relSourceNode;
			node->dsqlCursorName = *yyvsp[-1].metaNamePtr;
			node->dsqlReturning = yyvsp[0].returningClause;
			yyval.stmtNode = node;
		}
break;
case 1517:
yyval.metaNamePtr = NOTRIAL(&yyvsp[-1].relSourceNode->dsqlName);
break;
case 1518:
  if (!yytrial)
{
			ModifyNode* node = newNode<ModifyNode>();
			node->dsqlRelation = yyvsp[-8].relSourceNode;
			node->statement = yyvsp[-5].compoundStmtNode;
			node->dsqlBoolean = yyvsp[-4].boolExprNode;
			node->dsqlPlan = yyvsp[-3].planNode;
			node->dsqlOrder = yyvsp[-2].valueListNode;
			node->dsqlRows = yyvsp[-1].rowsClause;
			node->dsqlReturning = yyvsp[0].returningClause;
			yyval.stmtNode = node;
		}
break;
case 1519:
  if (!yytrial)
{
			ModifyNode* node = newNode<ModifyNode>();
			node->dsqlRelation = yyvsp[-5].relSourceNode;
			node->statement = yyvsp[-2].compoundStmtNode;
			node->dsqlCursorName = *yyvsp[-1].metaNamePtr;
			node->dsqlReturning = yyvsp[0].returningClause;
			yyval.stmtNode = node;
		}
break;
case 1520:
  if (!yytrial)
{
				UpdateOrInsertNode* node = yyval.updInsNode = newNode<UpdateOrInsertNode>();
				node->relation = yyvsp[0].relSourceNode;
			}
break;
case 1521:
yyval.nestFieldArray = NOTRIAL(&yyvsp[0].updInsNode->fields);
break;
case 1522:
yyval.nestFieldArray = NOTRIAL(&yyvsp[-7].updInsNode->matching);
break;
case 1523:
  if (!yytrial)
{
				UpdateOrInsertNode* node = yyval.updInsNode = yyvsp[-10].updInsNode;
				node->overrideClause = yyvsp[-7].nullableOverrideClause;
				node->values = yyvsp[-4].valueListNode;
				node->returning = yyvsp[0].returningClause;
			}
break;
case 1525:
yyval.nestFieldArray = yyvsp[-1].nestFieldArray;
break;
case 1527:
  if (!yytrial)
{ yyval.returningClause = NULL; }
break;
case 1528:
  if (!yytrial)
{
			yyval.returningClause = FB_NEW_POOL(getPool()) ReturningClause(getPool());
			yyval.returningClause->first = yyvsp[0].valueListNode;
		}
break;
case 1529:
  if (!yytrial)
{
			yyval.returningClause = FB_NEW_POOL(getPool()) ReturningClause(getPool());
			yyval.returningClause->first = yyvsp[-2].valueListNode;
			yyval.returningClause->second = yyvsp[0].valueListNode;
		}
break;
case 1530:
  if (!yytrial)
{ yyval.metaNamePtr = newNode<MetaName>(*yyvsp[0].metaNamePtr); }
break;
case 1531:
  if (!yytrial)
{
			AssignmentNode* node = newNode<AssignmentNode>();
			node->asgnTo = yyvsp[-2].fieldNode;
			node->asgnFrom = yyvsp[0].valueExprNode;
			yyval.stmtNode = node;
		}
break;
case 1532:
yyval.metaNamePtr = yyvsp[0].metaNamePtr;
break;
case 1533:
  if (!yytrial)
{
			yyval.compoundStmtNode = newNode<CompoundStmtNode>();
			yyval.compoundStmtNode->statements.add(yyvsp[0].stmtNode);
		}
break;
case 1534:
yyval.metaNamePtr = yyvsp[-2].metaNamePtr;
break;
case 1535:
  if (!yytrial)
{
			yyvsp[-3].compoundStmtNode->statements.add(yyvsp[0].stmtNode);
			yyval.compoundStmtNode = yyvsp[-3].compoundStmtNode;
		}
break;
case 1536:
  if (!yytrial)
{
			AssignmentNode* node = newNode<AssignmentNode>();
			node->asgnTo = yyvsp[-2].fieldNode;
			node->asgnFrom = yyvsp[0].valueExprNode;
			yyval.stmtNode = node;
		}
break;
case 1537:
  if (!yytrial)
{
			AssignmentNode* node = newNode<AssignmentNode>();
			node->asgnTo = yyvsp[-2].fieldNode;
			node->asgnFrom = newNode<DefaultNode>(*yyvsp[-3].metaNamePtr, yyvsp[-2].fieldNode->dsqlName);
			yyval.stmtNode = node;
		}
break;
case 1538:
  if (!yytrial)
{
			AssignmentNode* node = newNode<AssignmentNode>();
			node->asgnTo = NullNode::instance();
			node->asgnFrom = yyvsp[0].valueExprNode;
			yyval.stmtNode = node;
		}
break;
case 1539:
  if (!yytrial)
{
			AssignmentNode* node = newNode<AssignmentNode>();
			node->asgnTo = NullNode::instance();
			node->asgnFrom = yyvsp[0].valueExprNode;
			yyval.stmtNode = node;
		}
break;
case 1540:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 1542:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-1].valueListNode; }
break;
case 1543:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(yyvsp[0].fieldNode); }
break;
case 1544:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-2].valueListNode->add(yyvsp[0].fieldNode); }
break;
case 1546:
yyval.nestFieldArray = yyvsp[0].nestFieldArray;
break;
case 1549:
  if (!yytrial)
{ yyvsp[-1].nestFieldArray->add(yyvsp[0].fieldNode); }
break;
case 1550:
  if (!yytrial)
{ yyvsp[-3].nestFieldArray->add(yyvsp[0].fieldNode); }
break;
case 1552:
  if (!yytrial)
{
			FieldNode* fieldNode = newNode<FieldNode>();
			fieldNode->dsqlQualifier = *yyvsp[-2].metaNamePtr;
			fieldNode->dsqlName = *yyvsp[0].metaNamePtr;
			yyval.fieldNode = fieldNode;
		}
break;
case 1553:
  if (!yytrial)
{
			FieldNode* fieldNode = newNode<FieldNode>();
			fieldNode->dsqlQualifier = *yyvsp[-2].metaNamePtr;
			fieldNode->dsqlName = *yyvsp[0].metaNamePtr;
			fieldNode->dsqlCursorField = true;
			yyval.fieldNode = fieldNode;
		}
break;
case 1554:
  if (!yytrial)
{
			FieldNode* fieldNode = newNode<FieldNode>();
			fieldNode->dsqlName = *yyvsp[0].metaNamePtr;
			yyval.fieldNode = fieldNode;
		}
break;
case 1556:
  if (!yytrial)
{
			FieldNode* fieldNode = newNode<FieldNode>();
			fieldNode->dsqlQualifier = *yyvsp[-2].metaNamePtr;
			fieldNode->dsqlName = *yyvsp[0].metaNamePtr;
			yyval.fieldNode = fieldNode;
		}
break;
case 1557:
  if (!yytrial)
{ yyval.boolExprNode = valueToBool(yyvsp[0].valueExprNode); }
break;
case 1559:
  if (!yytrial)
{ yyval.boolExprNode = newNode<BinaryBoolNode>(blr_or, valueToBool(yyvsp[-2].valueExprNode), valueToBool(yyvsp[0].valueExprNode)); }
break;
case 1560:
  if (!yytrial)
{ yyval.boolExprNode = newNode<BinaryBoolNode>(blr_and, valueToBool(yyvsp[-2].valueExprNode), valueToBool(yyvsp[0].valueExprNode)); }
break;
case 1561:
  if (!yytrial)
{ yyval.boolExprNode = newNode<NotBoolNode>(valueToBool(yyvsp[0].valueExprNode)); }
break;
case 1562:
  if (!yytrial)
{ yyval.boolExprNode = yyvsp[-1].boolExprNode; }
break;
case 1563:
  if (!yytrial)
{
			ComparativeBoolNode* node = newNode<ComparativeBoolNode>(blr_equiv, yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode);
			node->dsqlCheckBoolean = true;
			yyval.boolExprNode = node;
		}
break;
case 1564:
  if (!yytrial)
{
			ComparativeBoolNode* node = newNode<ComparativeBoolNode>(blr_equiv, yyvsp[-3].valueExprNode, yyvsp[0].valueExprNode);
			node->dsqlCheckBoolean = true;
			yyval.boolExprNode = newNode<NotBoolNode>(node);
		}
break;
case 1577:
  if (!yytrial)
{ yyval.boolExprNode = newNode<ComparativeBoolNode>(yyvsp[-1].blrOp, yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1578:
  if (!yytrial)
{ yyval.blrOp = blr_eql; }
break;
case 1579:
  if (!yytrial)
{ yyval.blrOp = blr_lss; }
break;
case 1580:
  if (!yytrial)
{ yyval.blrOp = blr_gtr; }
break;
case 1581:
  if (!yytrial)
{ yyval.blrOp = blr_geq; }
break;
case 1582:
  if (!yytrial)
{ yyval.blrOp = blr_leq; }
break;
case 1583:
  if (!yytrial)
{ yyval.blrOp = blr_leq; }
break;
case 1584:
  if (!yytrial)
{ yyval.blrOp = blr_geq; }
break;
case 1585:
  if (!yytrial)
{ yyval.blrOp = blr_neq; }
break;
case 1586:
  if (!yytrial)
{
			ComparativeBoolNode* node = newNode<ComparativeBoolNode>(yyvsp[-4].blrOp, yyvsp[-5].valueExprNode);
			node->dsqlFlag = yyvsp[-3].cmpBoolFlag;
			node->dsqlSpecialArg = yyvsp[-1].selectExprNode;
			yyval.boolExprNode = node;
		}
break;
case 1587:
  if (!yytrial)
{ yyval.cmpBoolFlag = ComparativeBoolNode::DFLAG_ANSI_ALL; }
break;
case 1588:
  if (!yytrial)
{ yyval.cmpBoolFlag = ComparativeBoolNode::DFLAG_ANSI_ANY; }
break;
case 1589:
  if (!yytrial)
{ yyval.cmpBoolFlag = ComparativeBoolNode::DFLAG_ANSI_ANY; }
break;
case 1590:
  if (!yytrial)
{
			ComparativeBoolNode* node = newNode<ComparativeBoolNode>(blr_equiv, yyvsp[-4].valueExprNode, yyvsp[0].valueExprNode);
			yyval.boolExprNode = newNode<NotBoolNode>(node);
		}
break;
case 1591:
  if (!yytrial)
{ yyval.boolExprNode = newNode<ComparativeBoolNode>(blr_equiv, yyvsp[-5].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1592:
  if (!yytrial)
{
			yyval.boolExprNode = newNode<ComparativeBoolNode>(blr_between, yyvsp[-4].valueExprNode, yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode);
		}
break;
case 1593:
  if (!yytrial)
{
			ComparativeBoolNode* node = newNode<ComparativeBoolNode>(blr_between, yyvsp[-5].valueExprNode, yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode);
			yyval.boolExprNode = newNode<NotBoolNode>(node);
		}
break;
case 1594:
  if (!yytrial)
{ yyval.boolExprNode = newNode<ComparativeBoolNode>(yyvsp[-1].blrOp, yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1595:
  if (!yytrial)
{
			ComparativeBoolNode* cmpNode = newNode<ComparativeBoolNode>(yyvsp[-1].blrOp, yyvsp[-3].valueExprNode, yyvsp[0].valueExprNode);
			yyval.boolExprNode = newNode<NotBoolNode>(cmpNode);
		}
break;
case 1596:
  if (!yytrial)
{ yyval.blrOp = blr_containing; }
break;
case 1597:
  if (!yytrial)
{ yyval.blrOp = blr_starting; }
break;
case 1598:
  if (!yytrial)
{ yyval.blrOp = blr_starting; }
break;
case 1599:
  if (!yytrial)
{ yyval.boolExprNode = newNode<ComparativeBoolNode>(blr_like, yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1600:
  if (!yytrial)
{ yyval.boolExprNode = newNode<ComparativeBoolNode>(blr_like, yyvsp[-4].valueExprNode, yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1601:
  if (!yytrial)
{
			ComparativeBoolNode* node = newNode<ComparativeBoolNode>(blr_like, yyvsp[-3].valueExprNode, yyvsp[0].valueExprNode);
			yyval.boolExprNode = newNode<NotBoolNode>(node);
		}
break;
case 1602:
  if (!yytrial)
{
			ComparativeBoolNode* node = newNode<ComparativeBoolNode>(blr_like, yyvsp[-5].valueExprNode, yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode);
			yyval.boolExprNode = newNode<NotBoolNode>(node);
		}
break;
case 1603:
  if (!yytrial)
{ yyval.boolExprNode = newNode<ComparativeBoolNode>(blr_similar, yyvsp[-3].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1604:
  if (!yytrial)
{ yyval.boolExprNode = newNode<ComparativeBoolNode>(blr_similar, yyvsp[-5].valueExprNode, yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1605:
  if (!yytrial)
{
			ComparativeBoolNode* node = newNode<ComparativeBoolNode>(blr_similar, yyvsp[-4].valueExprNode, yyvsp[0].valueExprNode);
			yyval.boolExprNode = newNode<NotBoolNode>(node);
		}
break;
case 1606:
  if (!yytrial)
{
			ComparativeBoolNode* node = newNode<ComparativeBoolNode>(blr_similar, yyvsp[-6].valueExprNode, yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode);
			yyval.boolExprNode = newNode<NotBoolNode>(node);
		}
break;
case 1607:
  if (!yytrial)
{
			ComparativeBoolNode* node = newNode<ComparativeBoolNode>(blr_eql, yyvsp[-2].valueExprNode);
			node->dsqlFlag = ComparativeBoolNode::DFLAG_ANSI_ANY;
			node->dsqlSpecialArg = yyvsp[0].exprNode;
			yyval.boolExprNode = node;
		}
break;
case 1608:
  if (!yytrial)
{
			ComparativeBoolNode* node = newNode<ComparativeBoolNode>(blr_eql, yyvsp[-3].valueExprNode);
			node->dsqlFlag = ComparativeBoolNode::DFLAG_ANSI_ANY;
			node->dsqlSpecialArg = yyvsp[0].exprNode;
			yyval.boolExprNode = newNode<NotBoolNode>(node);
		}
break;
case 1609:
  if (!yytrial)
{ yyval.boolExprNode = newNode<RseBoolNode>(blr_any, yyvsp[-1].selectExprNode); }
break;
case 1610:
  if (!yytrial)
{ yyval.boolExprNode = newNode<RseBoolNode>(blr_unique, yyvsp[-1].selectExprNode); }
break;
case 1611:
  if (!yytrial)
{
			yyval.boolExprNode = newNode<ComparativeBoolNode>(blr_eql,
					newNode<InternalInfoNode>(MAKE_const_slong(INFO_TYPE_TRIGGER_ACTION)),
					MAKE_const_slong(1));
		}
break;
case 1612:
  if (!yytrial)
{
			yyval.boolExprNode = newNode<ComparativeBoolNode>(blr_eql,
					newNode<InternalInfoNode>(MAKE_const_slong(INFO_TYPE_TRIGGER_ACTION)),
					MAKE_const_slong(2));
		}
break;
case 1613:
  if (!yytrial)
{
			yyval.boolExprNode = newNode<ComparativeBoolNode>(blr_eql,
					newNode<InternalInfoNode>(MAKE_const_slong(INFO_TYPE_TRIGGER_ACTION)),
					MAKE_const_slong(3));
		}
break;
case 1614:
  if (!yytrial)
{
			yyval.boolExprNode = newNode<ComparativeBoolNode>(blr_eql,
					newNode<InternalInfoNode>(MAKE_const_slong(INFO_TYPE_SESSION_RESETTING)),
					MAKE_const_slong(1));
		}
break;
case 1615:
  if (!yytrial)
{ yyval.boolExprNode = newNode<MissingBoolNode>(yyvsp[-2].valueExprNode); }
break;
case 1616:
  if (!yytrial)
{ yyval.boolExprNode = newNode<MissingBoolNode>(yyvsp[-2].valueExprNode, true); }
break;
case 1617:
  if (!yytrial)
{ yyval.boolExprNode = newNode<NotBoolNode>(newNode<MissingBoolNode>(yyvsp[-3].valueExprNode)); }
break;
case 1618:
  if (!yytrial)
{ yyval.boolExprNode = newNode<NotBoolNode>(newNode<MissingBoolNode>(yyvsp[-3].valueExprNode, true)); }
break;
case 1619:
  if (!yytrial)
{ yyval.exprNode = yyvsp[0].selectExprNode; }
break;
case 1620:
  if (!yytrial)
{ yyval.exprNode = yyvsp[-1].valueListNode; }
break;
case 1621:
  if (!yytrial)
{ yyval.selectExprNode = yyvsp[-1].selectExprNode; }
break;
case 1622:
  if (!yytrial)
{
			yyval.createAlterUserNode = newNode<CreateAlterUserNode>(CreateAlterUserNode::USER_ADD, *yyvsp[0].metaNamePtr);
		}
break;
case 1623:
  if (!yytrial)
{
			yyval.createAlterUserNode = yyvsp[-2].createAlterUserNode;
		}
break;
case 1624:
  if (!yytrial)
{
			yyval.createAlterUserNode = newNode<CreateAlterUserNode>(CreateAlterUserNode::USER_MOD, *yyvsp[-1].metaNamePtr);
		}
break;
case 1625:
  if (!yytrial)
{
			yyval.createAlterUserNode = yyvsp[-2].createAlterUserNode;
		}
break;
case 1626:
  if (!yytrial)
{
			yyval.createAlterUserNode = newNode<CreateAlterUserNode>(CreateAlterUserNode::USER_MOD, "");
		}
break;
case 1627:
  if (!yytrial)
{
			yyval.createAlterUserNode = yyvsp[-2].createAlterUserNode;
		}
break;
case 1628:
  if (!yytrial)
{
			yyval.createAlterUserNode = newNode<CreateAlterUserNode>(CreateAlterUserNode::USER_RPL, *yyvsp[-1].metaNamePtr);
		}
break;
case 1629:
  if (!yytrial)
{
			yyval.createAlterUserNode = yyvsp[-2].createAlterUserNode;
		}
break;
case 1635:
yyval.createAlterUserNode = yyvsp[-1].createAlterUserNode;
break;
case 1637:
  if (!yytrial)
{ setClause(yyvsp[-2].createAlterUserNode->firstName, "FIRSTNAME", yyvsp[0].stringPtr); }
break;
case 1638:
  if (!yytrial)
{ setClause(yyvsp[-2].createAlterUserNode->middleName, "MIDDLENAME", yyvsp[0].stringPtr); }
break;
case 1639:
  if (!yytrial)
{ setClause(yyvsp[-2].createAlterUserNode->lastName, "LASTNAME", yyvsp[0].stringPtr); }
break;
case 1640:
  if (!yytrial)
{ setClause(yyvsp[-2].createAlterUserNode->password, "PASSWORD", yyvsp[0].stringPtr); }
break;
case 1641:
  if (!yytrial)
{ setClause(yyvsp[-3].createAlterUserNode->adminRole, "ADMIN ROLE", true); }
break;
case 1642:
  if (!yytrial)
{ setClause(yyvsp[-3].createAlterUserNode->adminRole, "ADMIN ROLE", false); }
break;
case 1643:
  if (!yytrial)
{ setClause(yyvsp[-1].createAlterUserNode->active, "ACTIVE/INACTIVE", true); }
break;
case 1644:
  if (!yytrial)
{ setClause(yyvsp[-1].createAlterUserNode->active, "ACTIVE/INACTIVE", false); }
break;
case 1646:
yyval.createAlterUserNode = yyvsp[-2].createAlterUserNode;
break;
case 1648:
  if (!yytrial)
{ setClause(yyvsp[-3].createAlterUserNode->plugin, "USING PLUGIN", yyvsp[0].metaNamePtr); }
break;
case 1651:
  if (!yytrial)
{
			yyvsp[-3].createAlterUserNode->addProperty(yyvsp[-2].metaNamePtr, yyvsp[0].stringPtr);
		}
break;
case 1652:
  if (!yytrial)
{
			yyvsp[-2].createAlterUserNode->addProperty(yyvsp[0].metaNamePtr);
		}
break;
case 1653:
yyval.mappingOp = MappingNode::MAP_ADD;
break;
case 1654:
  if (!yytrial)
{
				yyval.mappingNode = yyvsp[0].mappingNode;
				yyval.mappingNode->global = yyvsp[-2].boolVal;
			}
break;
case 1655:
yyval.mappingNode = yyvsp[0].mappingNode;
break;
case 1656:
  if (!yytrial)
{
				yyval.mappingNode = yyvsp[-2].mappingNode;
			}
break;
case 1657:
yyval.mappingOp = MappingNode::MAP_MOD;
break;
case 1658:
  if (!yytrial)
{
				yyval.mappingNode = yyvsp[0].mappingNode;
				yyval.mappingNode->global = yyvsp[-2].boolVal;
			}
break;
case 1659:
  if (!yytrial)
{
				yyval.mappingNode = yyvsp[-2].mappingNode;
			}
break;
case 1660:
yyval.mappingOp = MappingNode::MAP_RPL;
break;
case 1661:
  if (!yytrial)
{
				yyval.mappingNode = yyvsp[0].mappingNode;
				yyval.mappingNode->global = yyvsp[-2].boolVal;
			}
break;
case 1662:
  if (!yytrial)
{
				yyval.mappingNode = yyvsp[-2].mappingNode;
			}
break;
case 1663:
  if (!yytrial)
{
 			MappingNode* node = newNode<MappingNode>(MappingNode::MAP_DROP, *yyvsp[0].metaNamePtr);
			node->global = yyvsp[-1].boolVal;
			yyval.mappingNode = node;
		}
break;
case 1664:
  if (!yytrial)
{
				yyval.mappingNode = newNode<MappingNode>(yyvsp[-1].mappingOp, *yyvsp[0].metaNamePtr);
			}
break;
case 1665:
yyval.mappingNode = yyvsp[-1].mappingNode;
break;
case 1666:
yyval.mappingNode = yyvsp[-4].mappingNode;
break;
case 1667:
  if (!yytrial)
{
				yyval.mappingNode = yyvsp[-6].mappingNode;
			}
break;
case 1668:
  if (!yytrial)
{ yyval.metaNamePtr = yyvsp[0].metaNamePtr; }
break;
case 1669:
  if (!yytrial)
{
			yyvsp[-2].mappingNode->fromType = yyvsp[-1].metaNamePtr;
			yyvsp[-2].mappingNode->from = yyvsp[0].intlStringPtr;
		}
break;
case 1670:
  if (!yytrial)
{
			yyvsp[-2].mappingNode->fromType = yyvsp[0].metaNamePtr;
			yyvsp[-2].mappingNode->from = newNode<IntlString>("*");
		}
break;
case 1672:
  if (!yytrial)
{ yyval.metaNamePtr = newNode<MetaName>("USER"); }
break;
case 1673:
  if (!yytrial)
{ yyval.metaNamePtr = newNode<MetaName>("GROUP"); }
break;
case 1675:
  if (!yytrial)
{ yyval.intlStringPtr = newNode<IntlString>(yyvsp[0].metaNamePtr->c_str()); }
break;
case 1676:
  if (!yytrial)
{
			yyvsp[-3].mappingNode->mode = 'P';
			yyvsp[-3].mappingNode->plugin = yyvsp[-1].metaNamePtr;
			yyvsp[-3].mappingNode->db = yyvsp[0].metaNamePtr;
		}
break;
case 1677:
  if (!yytrial)
{
			yyvsp[-3].mappingNode->mode = 'P';
			yyvsp[-3].mappingNode->db = yyvsp[0].metaNamePtr;
		}
break;
case 1678:
  if (!yytrial)
{
			yyvsp[-3].mappingNode->mode = 'S';
		}
break;
case 1679:
  if (!yytrial)
{
			yyvsp[-2].mappingNode->mode = 'M';
			yyvsp[-2].mappingNode->db = yyvsp[0].metaNamePtr;
		}
break;
case 1680:
  if (!yytrial)
{
			yyvsp[-2].mappingNode->mode = '*';
			yyvsp[-2].mappingNode->db = yyvsp[0].metaNamePtr;
		}
break;
case 1681:
  if (!yytrial)
{ yyval.metaNamePtr = NULL; }
break;
case 1682:
  if (!yytrial)
{ yyval.metaNamePtr = yyvsp[0].metaNamePtr; }
break;
case 1683:
  if (!yytrial)
{
			yyvsp[-3].mappingNode->role = yyvsp[-1].boolVal;
			yyvsp[-3].mappingNode->to = yyvsp[0].metaNamePtr;
		}
break;
case 1684:
  if (!yytrial)
{
			yyvsp[-2].mappingNode->role = yyvsp[0].boolVal;
		}
break;
case 1685:
  if (!yytrial)
{ yyval.boolVal = true; }
break;
case 1686:
  if (!yytrial)
{ yyval.boolVal = false; }
break;
case 1688:
  if (!yytrial)
{ yyval.valueExprNode = newNode<BoolAsValueNode>(yyvsp[0].boolExprNode); }
break;
case 1690:
  if (!yytrial)
{ yyval.valueExprNode = newNode<BoolAsValueNode>(yyvsp[-1].boolExprNode); }
break;
case 1692:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[-1].valueExprNode; }
break;
case 1696:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].fieldNode; }
break;
case 1698:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1705:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1706:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1707:
  if (!yytrial)
{ yyval.valueExprNode = newNode<NegateNode>(yyvsp[0].valueExprNode); }
break;
case 1708:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1709:
  if (!yytrial)
{ yyval.valueExprNode = newNode<ArithmeticNode>(blr_add, (client_dialect < SQL_DIALECT_V6_TRANSITION), yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1710:
  if (!yytrial)
{ yyval.valueExprNode = newNode<ConcatenateNode>(yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1711:
  if (!yytrial)
{ yyval.valueExprNode = newNode<CollateNode>(yyvsp[-2].valueExprNode, *yyvsp[0].metaNamePtr); }
break;
case 1712:
  if (!yytrial)
{ yyval.valueExprNode = newNode<AtNode>(yyvsp[-2].valueExprNode, nullptr); }
break;
case 1713:
  if (!yytrial)
{ yyval.valueExprNode = newNode<AtNode>(yyvsp[-4].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1714:
  if (!yytrial)
{ yyval.valueExprNode = newNode<ArithmeticNode>(blr_subtract, (client_dialect < SQL_DIALECT_V6_TRANSITION), yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1715:
  if (!yytrial)
{ yyval.valueExprNode = newNode<ArithmeticNode>(blr_multiply, (client_dialect < SQL_DIALECT_V6_TRANSITION), yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1716:
  if (!yytrial)
{ yyval.valueExprNode = newNode<ArithmeticNode>(blr_divide, (client_dialect < SQL_DIALECT_V6_TRANSITION), yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1717:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[-1].valueExprNode; }
break;
case 1718:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1719:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1720:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1721:
  if (!yytrial)
{ yyval.valueExprNode = newNode<RecordKeyNode>(yyvsp[0].blrOp); }
break;
case 1722:
  if (!yytrial)
{ yyval.valueExprNode = newNode<RecordKeyNode>(yyvsp[0].blrOp, *yyvsp[-2].metaNamePtr); }
break;
case 1723:
  if (!yytrial)
{ yyval.valueExprNode = newNode<DomainValidationNode>(); }
break;
case 1724:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1725:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1726:
  if (!yytrial)
{ yyval.blrOp = blr_dbkey; }
break;
case 1727:
  if (!yytrial)
{ yyval.blrOp = blr_record_version2; }
break;
case 1728:
  if (!yytrial)
{
			if (client_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
						  Arg::Gds(isc_sql_dialect_datatype_unsupport) << Arg::Num(client_dialect) <<
						  												  Arg::Str("DATE"));
			}

			if (db_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
						  Arg::Gds(isc_sql_db_dialect_dtype_unsupport) << Arg::Num(db_dialect) <<
						  												  Arg::Str("DATE"));
			}

			yyval.valueExprNode = newNode<CurrentDateNode>();
		}
break;
case 1729:
  if (!yytrial)
{
			if (client_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
						  Arg::Gds(isc_sql_dialect_datatype_unsupport) << Arg::Num(client_dialect) <<
						  												  Arg::Str("TIME"));
			}

			if (db_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
						  Arg::Gds(isc_sql_db_dialect_dtype_unsupport) << Arg::Num(db_dialect) <<
						  												  Arg::Str("TIME"));
			}

			yyval.valueExprNode = newNode<LocalTimeNode>(yyvsp[0].uintVal);
		}
break;
case 1730:
  if (!yytrial)
{
			if (client_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
						  Arg::Gds(isc_sql_dialect_datatype_unsupport) << Arg::Num(client_dialect) <<
						  												  Arg::Str("TIME"));
			}

			if (db_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
						  Arg::Gds(isc_sql_db_dialect_dtype_unsupport) << Arg::Num(db_dialect) <<
						  												  Arg::Str("TIME"));
			}

			yyval.valueExprNode = newNode<CurrentTimeNode>(yyvsp[0].uintVal);
		}
break;
case 1731:
  if (!yytrial)
{ yyval.valueExprNode = newNode<LocalTimeStampNode>(yyvsp[0].uintVal); }
break;
case 1732:
  if (!yytrial)
{ yyval.valueExprNode = newNode<CurrentTimeStampNode>(yyvsp[0].uintVal); }
break;
case 1733:
  if (!yytrial)
{ yyval.uintVal = DEFAULT_TIME_PRECISION; }
break;
case 1734:
  if (!yytrial)
{ yyval.uintVal = yyvsp[-1].int32Val; }
break;
case 1735:
  if (!yytrial)
{ yyval.uintVal = DEFAULT_TIMESTAMP_PRECISION; }
break;
case 1736:
  if (!yytrial)
{ yyval.uintVal = yyvsp[-1].int32Val; }
break;
case 1737:
  if (!yytrial)
{
			ArrayNode* node = newNode<ArrayNode>(yyvsp[-3].fieldNode);
			node->field->dsqlIndices = yyvsp[-1].valueListNode;
			yyval.valueExprNode = node;
		}
break;
case 1738:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(0); }
break;
case 1739:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[0].valueListNode; }
break;
case 1740:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(yyvsp[0].valueExprNode); }
break;
case 1741:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-2].valueListNode->add(yyvsp[0].valueExprNode); }
break;
case 1743:
  if (!yytrial)
{ yyval.valueExprNode = newNode<NegateNode>(yyvsp[0].valueExprNode); }
break;
case 1744:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_const_sint64(MIN_SINT64, 0); }
break;
case 1745:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_const_sint64(MIN_SINT64, yyvsp[0].lim64ptr->getScale()); }
break;
case 1746:
  if (!yytrial)
{ yyval.valueExprNode = newNode<NegateNode>(yyvsp[0].valueExprNode); }
break;
case 1748:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1749:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_constant(yyvsp[0].lim64ptr->c_str(), CONSTANT_NUM128, yyvsp[0].lim64ptr->getScale()); }
break;
case 1750:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_constant(yyvsp[0].lim64ptr->c_str(), CONSTANT_NUM128); }
break;
case 1752:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_constant(yyvsp[0].lim64ptr->c_str(), CONSTANT_NUM128, yyvsp[0].lim64ptr->getScale()); }
break;
case 1753:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_const_slong(yyvsp[0].int32Val); }
break;
case 1754:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_constant(yyvsp[0].stringPtr->c_str(), CONSTANT_DOUBLE); }
break;
case 1755:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_constant(yyvsp[0].stringPtr->c_str(), CONSTANT_DECIMAL); }
break;
case 1756:
  if (!yytrial)
{
			SINT64 signedNumber = (SINT64) yyvsp[0].scaledNumber.number;

			if (yyvsp[0].scaledNumber.hex && signedNumber < 0)
				yyval.valueExprNode = newNode<NegateNode>(MAKE_const_sint64(-signedNumber, yyvsp[0].scaledNumber.scale));
			else
				yyval.valueExprNode = MAKE_const_sint64(signedNumber, yyvsp[0].scaledNumber.scale);
		}
break;
case 1757:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_const_sint64((SINT64) yyvsp[0].scaledNumber.number, yyvsp[0].scaledNumber.scale); }
break;
case 1759:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_str_constant(yyvsp[0].intlStringPtr, lex.att_charset); }
break;
case 1760:
  if (!yytrial)
{
			if (client_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
						  Arg::Gds(isc_sql_dialect_datatype_unsupport) << Arg::Num(client_dialect) <<
						  												  Arg::Str("DATE"));
			}
			if (db_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
						  Arg::Gds(isc_sql_db_dialect_dtype_unsupport) << Arg::Num(db_dialect) <<
						  												  Arg::Str("DATE"));
			}
			yyval.valueExprNode = MAKE_constant(yyvsp[0].intlStringPtr->getString().c_str(), CONSTANT_DATE);
		}
break;
case 1761:
  if (!yytrial)
{
			if (client_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
						  Arg::Gds(isc_sql_dialect_datatype_unsupport) << Arg::Num(client_dialect) <<
						  												  Arg::Str("TIME"));
			}
			if (db_dialect < SQL_DIALECT_V6_TRANSITION)
			{
				ERRD_post(Arg::Gds(isc_sqlerr) << Arg::Num(-104) <<
						  Arg::Gds(isc_sql_db_dialect_dtype_unsupport) << Arg::Num(db_dialect) <<
						  												  Arg::Str("TIME"));
			}
			yyval.valueExprNode = MAKE_constant(yyvsp[0].intlStringPtr->getString().c_str(), CONSTANT_TIME);
		}
break;
case 1762:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_constant(yyvsp[0].intlStringPtr->getString().c_str(), CONSTANT_TIMESTAMP); }
break;
case 1763:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_constant("", CONSTANT_BOOLEAN); }
break;
case 1764:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_constant("1", CONSTANT_BOOLEAN); }
break;
case 1765:
  if (!yytrial)
{ yyval.valueExprNode = make_parameter(); }
break;
case 1766:
  if (!yytrial)
{ yyval.valueExprNode = newNode<CurrentUserNode>(); }
break;
case 1767:
  if (!yytrial)
{ yyval.valueExprNode = newNode<CurrentUserNode>(); }
break;
case 1768:
  if (!yytrial)
{ yyval.valueExprNode = newNode<CurrentRoleNode>(); }
break;
case 1769:
  if (!yytrial)
{ yyval.valueExprNode = newNode<InternalInfoNode>(MAKE_const_slong(INFO_TYPE_CONNECTION_ID)); }
break;
case 1770:
  if (!yytrial)
{ yyval.valueExprNode = newNode<InternalInfoNode>(MAKE_const_slong(INFO_TYPE_TRANSACTION_ID)); }
break;
case 1771:
  if (!yytrial)
{ yyval.valueExprNode = newNode<InternalInfoNode>(MAKE_const_slong(INFO_TYPE_GDSCODE)); }
break;
case 1772:
  if (!yytrial)
{ yyval.valueExprNode = newNode<InternalInfoNode>(MAKE_const_slong(INFO_TYPE_SQLCODE)); }
break;
case 1773:
  if (!yytrial)
{ yyval.valueExprNode = newNode<InternalInfoNode>(MAKE_const_slong(INFO_TYPE_SQLSTATE)); }
break;
case 1774:
  if (!yytrial)
{ yyval.valueExprNode = newNode<InternalInfoNode>(MAKE_const_slong(INFO_TYPE_ROWS_AFFECTED)); }
break;
case 1775:
  if (!yytrial)
{ yyval.valueExprNode = newNode<InternalInfoNode>(MAKE_const_slong(yyvsp[-1].int32Val)); }
break;
case 1776:
  if (!yytrial)
{ yyval.int32Val = INFO_TYPE_GDSCODE; }
break;
case 1777:
  if (!yytrial)
{ yyval.int32Val = INFO_TYPE_SQLCODE; }
break;
case 1778:
  if (!yytrial)
{ yyval.int32Val = INFO_TYPE_SQLSTATE; }
break;
case 1779:
  if (!yytrial)
{ yyval.int32Val = INFO_TYPE_EXCEPTION; }
break;
case 1780:
  if (!yytrial)
{ yyval.int32Val = INFO_TYPE_ERROR_MSG; }
break;
case 1782:
  if (!yytrial)
{
			yyval.intlStringPtr = yyvsp[0].intlStringPtr;
			yyval.intlStringPtr->setCharSet(*yyvsp[-1].metaNamePtr);

			StrMark* mark = strMarks.get(yyvsp[0].intlStringPtr);

			if (mark)	/* hex string is not in strMarks*/
				mark->introduced = true;
		}
break;
case 1783:
  if (!yytrial)
{ yyval.stringPtr = newString(yyvsp[0].intlStringPtr->toUtf8(scratch)); }
break;
case 1785:
  if (!yytrial)
{ yyval.int32Val = -yyvsp[0].int32Val; }
break;
case 1786:
  if (!yytrial)
{
			if (yyvsp[0].int32Val > SHRT_POS_MAX)
				yyabandon(YYPOSNARG(1), -842, isc_expec_short);	/* Short integer expected*/

			yyval.int32Val = yyvsp[0].int32Val;
		}
break;
case 1787:
  if (!yytrial)
{
			if (yyvsp[0].int32Val > SHRT_NEG_MAX)
				yyabandon(YYPOSNARG(1), -842, isc_expec_short);	/* Short integer expected*/

			yyval.int32Val = yyvsp[0].int32Val;
		}
break;
case 1788:
  if (!yytrial)
{
			if (yyvsp[0].int32Val == 0)
				yyabandon(YYPOSNARG(1), -842, isc_expec_positive);	/* Positive number expected*/

			yyval.int32Val = yyvsp[0].int32Val;
		}
break;
case 1789:
  if (!yytrial)
{
			if (yyvsp[0].int32Val > SHRT_UNSIGNED_MAX)
				yyabandon(YYPOSNARG(1), -842, isc_expec_ushort);	/* Unsigned short integer expected*/

			yyval.int32Val = yyvsp[0].int32Val;
		}
break;
case 1791:
  if (!yytrial)
{ yyval.int32Val = -yyvsp[0].int32Val; }
break;
case 1792:
  if (!yytrial)
{ yyval.int32Val = yyvsp[0].int32Val;}
break;
case 1793:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].aggNode; }
break;
case 1800:
  if (!yytrial)
{
			yyval.aggNode = yyvsp[-5].aggNode;

			if (yyval.aggNode->aggInfo.blr == blr_agg_count2 && !yyval.aggNode->arg)	/* count(*)*/
				yyval.aggNode->arg = newNode<ValueIfNode>(yyvsp[-1].boolExprNode, MAKE_const_slong(1), NullNode::instance());
			else
			{
				fb_assert(yyval.aggNode->arg);
				yyval.aggNode->arg = newNode<ValueIfNode>(yyvsp[-1].boolExprNode, yyval.aggNode->arg, NullNode::instance());
			}
		}
break;
case 1801:
  if (!yytrial)
{ yyval.aggNode = newNode<CountAggNode>(false, (client_dialect < SQL_DIALECT_V6_TRANSITION)); }
break;
case 1802:
  if (!yytrial)
{ yyval.aggNode = newNode<CountAggNode>(false, (client_dialect < SQL_DIALECT_V6_TRANSITION), yyvsp[-1].valueExprNode); }
break;
case 1803:
  if (!yytrial)
{ yyval.aggNode = newNode<CountAggNode>(true, (client_dialect < SQL_DIALECT_V6_TRANSITION), yyvsp[-1].valueExprNode); }
break;
case 1804:
  if (!yytrial)
{
			yyval.aggNode = newNode<SumAggNode>(false,
				(client_dialect < SQL_DIALECT_V6_TRANSITION), yyvsp[-1].valueExprNode);
		}
break;
case 1805:
  if (!yytrial)
{
			yyval.aggNode = newNode<SumAggNode>(true,
				(client_dialect < SQL_DIALECT_V6_TRANSITION), yyvsp[-1].valueExprNode);
		}
break;
case 1806:
  if (!yytrial)
{
			yyval.aggNode = newNode<AvgAggNode>(false,
				(client_dialect < SQL_DIALECT_V6_TRANSITION), yyvsp[-1].valueExprNode);
		}
break;
case 1807:
  if (!yytrial)
{
			yyval.aggNode = newNode<AvgAggNode>(true,
				(client_dialect < SQL_DIALECT_V6_TRANSITION), yyvsp[-1].valueExprNode);
		}
break;
case 1808:
  if (!yytrial)
{ yyval.aggNode = newNode<MaxMinAggNode>(MaxMinAggNode::TYPE_MIN, yyvsp[-1].valueExprNode); }
break;
case 1809:
  if (!yytrial)
{ yyval.aggNode = newNode<MaxMinAggNode>(MaxMinAggNode::TYPE_MIN, yyvsp[-1].valueExprNode); }
break;
case 1810:
  if (!yytrial)
{ yyval.aggNode = newNode<MaxMinAggNode>(MaxMinAggNode::TYPE_MAX, yyvsp[-1].valueExprNode); }
break;
case 1811:
  if (!yytrial)
{ yyval.aggNode = newNode<MaxMinAggNode>(MaxMinAggNode::TYPE_MAX, yyvsp[-1].valueExprNode); }
break;
case 1812:
  if (!yytrial)
{ yyval.aggNode = newNode<ListAggNode>(false, yyvsp[-2].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1813:
  if (!yytrial)
{ yyval.aggNode = newNode<ListAggNode>(true, yyvsp[-2].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1814:
  if (!yytrial)
{ yyval.aggNode = newNode<StdDevAggNode>(StdDevAggNode::TYPE_STDDEV_SAMP, yyvsp[-1].valueExprNode); }
break;
case 1815:
  if (!yytrial)
{ yyval.aggNode = newNode<StdDevAggNode>(StdDevAggNode::TYPE_STDDEV_POP, yyvsp[-1].valueExprNode); }
break;
case 1816:
  if (!yytrial)
{ yyval.aggNode = newNode<StdDevAggNode>(StdDevAggNode::TYPE_VAR_SAMP, yyvsp[-1].valueExprNode); }
break;
case 1817:
  if (!yytrial)
{ yyval.aggNode = newNode<StdDevAggNode>(StdDevAggNode::TYPE_VAR_POP, yyvsp[-1].valueExprNode); }
break;
case 1818:
  if (!yytrial)
{ yyval.aggNode = newNode<CorrAggNode>(CorrAggNode::TYPE_COVAR_SAMP, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1819:
  if (!yytrial)
{ yyval.aggNode = newNode<CorrAggNode>(CorrAggNode::TYPE_COVAR_POP, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1820:
  if (!yytrial)
{ yyval.aggNode = newNode<CorrAggNode>(CorrAggNode::TYPE_CORR, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1821:
  if (!yytrial)
{ yyval.aggNode = newNode<RegrAggNode>(RegrAggNode::TYPE_REGR_AVGX, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1822:
  if (!yytrial)
{ yyval.aggNode = newNode<RegrAggNode>(RegrAggNode::TYPE_REGR_AVGY, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1823:
  if (!yytrial)
{ yyval.aggNode = newNode<RegrCountAggNode>(yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1824:
  if (!yytrial)
{ yyval.aggNode = newNode<RegrAggNode>(RegrAggNode::TYPE_REGR_INTERCEPT, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1825:
  if (!yytrial)
{ yyval.aggNode = newNode<RegrAggNode>(RegrAggNode::TYPE_REGR_R2, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1826:
  if (!yytrial)
{ yyval.aggNode = newNode<RegrAggNode>(RegrAggNode::TYPE_REGR_SLOPE, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1827:
  if (!yytrial)
{ yyval.aggNode = newNode<RegrAggNode>(RegrAggNode::TYPE_REGR_SXX, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1828:
  if (!yytrial)
{ yyval.aggNode = newNode<RegrAggNode>(RegrAggNode::TYPE_REGR_SXY, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1829:
  if (!yytrial)
{ yyval.aggNode = newNode<RegrAggNode>(RegrAggNode::TYPE_REGR_SYY, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1830:
  if (!yytrial)
{ yyval.aggNode = newNode<DenseRankWinNode>(); }
break;
case 1831:
  if (!yytrial)
{ yyval.aggNode = newNode<RankWinNode>(); }
break;
case 1832:
  if (!yytrial)
{ yyval.aggNode = newNode<PercentRankWinNode>(); }
break;
case 1833:
  if (!yytrial)
{ yyval.aggNode = newNode<CumeDistWinNode>(); }
break;
case 1834:
  if (!yytrial)
{ yyval.aggNode = newNode<RowNumberWinNode>(); }
break;
case 1835:
  if (!yytrial)
{ yyval.aggNode = newNode<FirstValueWinNode>(yyvsp[-1].valueExprNode); }
break;
case 1836:
  if (!yytrial)
{ yyval.aggNode = newNode<LastValueWinNode>(yyvsp[-1].valueExprNode); }
break;
case 1837:
  if (!yytrial)
{ yyval.aggNode = newNode<NthValueWinNode>(yyvsp[-4].valueExprNode, yyvsp[-2].valueExprNode, yyvsp[0].valueExprNode); }
break;
case 1838:
  if (!yytrial)
{ yyval.aggNode = newNode<LagWinNode>(yyvsp[-5].valueExprNode, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1839:
  if (!yytrial)
{ yyval.aggNode = newNode<LagWinNode>(yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode, NullNode::instance()); }
break;
case 1840:
  if (!yytrial)
{ yyval.aggNode = newNode<LagWinNode>(yyvsp[-1].valueExprNode, MAKE_const_slong(1), NullNode::instance()); }
break;
case 1841:
  if (!yytrial)
{ yyval.aggNode = newNode<LeadWinNode>(yyvsp[-5].valueExprNode, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 1842:
  if (!yytrial)
{ yyval.aggNode = newNode<LeadWinNode>(yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode, NullNode::instance()); }
break;
case 1843:
  if (!yytrial)
{ yyval.aggNode = newNode<LeadWinNode>(yyvsp[-1].valueExprNode, MAKE_const_slong(1), NullNode::instance()); }
break;
case 1844:
  if (!yytrial)
{ yyval.aggNode = newNode<NTileWinNode>(yyvsp[-1].valueExprNode); }
break;
case 1845:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_const_slong(NthValueWinNode::FROM_FIRST); }
break;
case 1846:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_const_slong(NthValueWinNode::FROM_FIRST); }
break;
case 1847:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_const_slong(NthValueWinNode::FROM_LAST); }
break;
case 1853:
  if (!yytrial)
{ yyval.valueExprNode = newNode<OverNode>(yyvsp[-2].aggNode, yyvsp[0].metaNamePtr); }
break;
case 1854:
  if (!yytrial)
{ yyval.valueExprNode = newNode<OverNode>(yyvsp[-4].aggNode, yyvsp[-1].windowClause); }
break;
case 1855:
  if (!yytrial)
{
			yyval.windowClause = newNode<WindowClause>(yyvsp[-4].metaNamePtr, yyvsp[-3].valueListNode, yyvsp[-2].valueListNode, yyvsp[-1].windowClauseFrameExtent, yyvsp[0].windowClauseExclusion);
		}
break;
case 1856:
  if (!yytrial)
{ yyval.valueListNode = NULL; }
break;
case 1857:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[0].valueListNode; }
break;
case 1858:
  if (!yytrial)
{ yyval.windowClauseFrameExtent = NULL; }
break;
case 1859:
  if (!yytrial)
{ yyval.windowClauseFrameExtent = newNode<WindowClause::FrameExtent>(WindowClause::FrameExtent::Unit::RANGE); }
break;
case 1860:
yyval.windowClauseFrameExtent = yyvsp[0].windowClauseFrameExtent;
break;
case 1861:
  if (!yytrial)
{ yyval.windowClauseFrameExtent = yyvsp[-2].windowClauseFrameExtent; }
break;
case 1862:
  if (!yytrial)
{ yyval.windowClauseFrameExtent = newNode<WindowClause::FrameExtent>(WindowClause::FrameExtent::Unit::ROWS); }
break;
case 1863:
  if (!yytrial)
{ yyval.windowClauseFrameExtent = yyvsp[-2].windowClauseFrameExtent; }
break;
case 1864:
  if (!yytrial)
{
			yyvsp[-1].windowClauseFrameExtent->frame1 = yyvsp[0].windowClauseFrame;
			yyvsp[-1].windowClauseFrameExtent->frame2 =
				newNode<WindowClause::Frame>(WindowClause::Frame::Bound::CURRENT_ROW);
		}
break;
case 1865:
  if (!yytrial)
{
			yyvsp[-4].windowClauseFrameExtent->frame1 = yyvsp[-2].windowClauseFrame;
			yyvsp[-4].windowClauseFrameExtent->frame2 = yyvsp[0].windowClauseFrame;
		}
break;
case 1866:
  if (!yytrial)
{ yyval.windowClauseFrame = newNode<WindowClause::Frame>(WindowClause::Frame::Bound::PRECEDING); }
break;
case 1867:
  if (!yytrial)
{ yyval.windowClauseFrame = newNode<WindowClause::Frame>(WindowClause::Frame::Bound::CURRENT_ROW); }
break;
case 1868:
  if (!yytrial)
{ yyval.windowClauseFrame = newNode<WindowClause::Frame>(WindowClause::Frame::Bound::PRECEDING, yyvsp[-1].valueExprNode); }
break;
case 1869:
  if (!yytrial)
{ yyval.windowClauseFrame = newNode<WindowClause::Frame>(WindowClause::Frame::Bound::PRECEDING); }
break;
case 1870:
  if (!yytrial)
{ yyval.windowClauseFrame = newNode<WindowClause::Frame>(WindowClause::Frame::Bound::CURRENT_ROW); }
break;
case 1871:
  if (!yytrial)
{ yyval.windowClauseFrame = newNode<WindowClause::Frame>(WindowClause::Frame::Bound::PRECEDING, yyvsp[-1].valueExprNode); }
break;
case 1872:
  if (!yytrial)
{ yyval.windowClauseFrame = newNode<WindowClause::Frame>(WindowClause::Frame::Bound::FOLLOWING, yyvsp[-1].valueExprNode); }
break;
case 1873:
  if (!yytrial)
{ yyval.windowClauseFrame = newNode<WindowClause::Frame>(WindowClause::Frame::Bound::FOLLOWING); }
break;
case 1874:
  if (!yytrial)
{ yyval.windowClauseFrame = newNode<WindowClause::Frame>(WindowClause::Frame::Bound::CURRENT_ROW); }
break;
case 1875:
  if (!yytrial)
{ yyval.windowClauseFrame = newNode<WindowClause::Frame>(WindowClause::Frame::Bound::PRECEDING, yyvsp[-1].valueExprNode); }
break;
case 1876:
  if (!yytrial)
{ yyval.windowClauseFrame = newNode<WindowClause::Frame>(WindowClause::Frame::Bound::FOLLOWING, yyvsp[-1].valueExprNode); }
break;
case 1877:
  if (!yytrial)
{ yyval.windowClauseExclusion = WindowClause::Exclusion::NO_OTHERS; }
break;
case 1878:
  if (!yytrial)
{ yyval.windowClauseExclusion = WindowClause::Exclusion::NO_OTHERS; }
break;
case 1879:
  if (!yytrial)
{ yyval.windowClauseExclusion = WindowClause::Exclusion::CURRENT_ROW; }
break;
case 1880:
  if (!yytrial)
{ yyval.windowClauseExclusion = WindowClause::Exclusion::GROUP; }
break;
case 1881:
  if (!yytrial)
{ yyval.windowClauseExclusion = WindowClause::Exclusion::TIES; }
break;
case 1882:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_str_constant(newIntlString(","), lex.att_charset); }
break;
case 1883:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1886:
  if (!yytrial)
{ yyval.valueExprNode = newNode<ExtractNode>(yyvsp[-3].blrOp, yyvsp[-1].valueExprNode); }
break;
case 1890:
  if (!yytrial)
{ yyval.valueExprNode = newNode<StrLenNode>(blr_strlen_bit, yyvsp[-1].valueExprNode); }
break;
case 1891:
  if (!yytrial)
{ yyval.valueExprNode = newNode<StrLenNode>(blr_strlen_char, yyvsp[-1].valueExprNode); }
break;
case 1892:
  if (!yytrial)
{ yyval.valueExprNode = newNode<StrLenNode>(blr_strlen_char, yyvsp[-1].valueExprNode); }
break;
case 1893:
  if (!yytrial)
{ yyval.valueExprNode = newNode<StrLenNode>(blr_strlen_octet, yyvsp[-1].valueExprNode); }
break;
case 1894:
  if (!yytrial)
{ yyval.valueExprNode = newNode<SysFuncCallNode>(*yyvsp[-3].metaNamePtr, yyvsp[-1].valueListNode); }
break;
case 1895:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].sysFuncCallNode; }
break;
case 1960:
  if (!yytrial)
{
			yyval.sysFuncCallNode = newNode<SysFuncCallNode>(*yyvsp[-6].metaNamePtr,
				newNode<ValueListNode>(yyvsp[-4].valueExprNode)->add(MAKE_const_slong(yyvsp[-3].blrOp))->add(yyvsp[-1].valueExprNode));
			yyval.sysFuncCallNode->dsqlSpecialSyntax = true;
		}
break;
case 1961:
  if (!yytrial)
{
			yyval.sysFuncCallNode = newNode<SysFuncCallNode>(*yyvsp[-7].metaNamePtr,
				newNode<ValueListNode>(yyvsp[-3].valueExprNode)->add(MAKE_const_slong(yyvsp[-5].blrOp))->add(yyvsp[-1].valueExprNode));
			yyval.sysFuncCallNode->dsqlSpecialSyntax = true;
		}
break;
case 1962:
  if (!yytrial)
{
			yyval.sysFuncCallNode = newNode<SysFuncCallNode>(*yyvsp[-7].metaNamePtr,
				newNode<ValueListNode>(MAKE_const_slong(yyvsp[-5].blrOp))->add(yyvsp[-3].valueExprNode)->add(yyvsp[-1].valueExprNode));
			yyval.sysFuncCallNode->dsqlSpecialSyntax = true;
		}
break;
case 1963:
  if (!yytrial)
{
			yyval.sysFuncCallNode = newNode<SysFuncCallNode>(*yyvsp[-7].metaNamePtr,
				newNode<ValueListNode>(MAKE_const_slong(yyvsp[-5].blrOp))->add(yyvsp[-3].valueExprNode)->add(yyvsp[-1].valueExprNode));
			yyval.sysFuncCallNode->dsqlSpecialSyntax = true;
		}
break;
case 1964:
  if (!yytrial)
{
			yyval.sysFuncCallNode = newNode<SysFuncCallNode>(*yyvsp[-11].metaNamePtr,
				newNode<ValueListNode>(yyvsp[-9].valueExprNode)->add(MAKE_str_constant(newIntlString(yyvsp[-7].metaNamePtr->c_str()), CS_ASCII))->
					add(MAKE_str_constant(newIntlString(yyvsp[-6].metaNamePtr->c_str()), CS_ASCII))->add(yyvsp[-4].valueExprNode)->add(yyvsp[-3].valueExprNode)->
					add(MAKE_str_constant(newIntlString(yyvsp[-2].metaNamePtr->c_str()), CS_ASCII))->add(yyvsp[-1].valueExprNode));
			yyval.sysFuncCallNode->dsqlSpecialSyntax = true;
		}
break;
case 1965:
  if (!yytrial)
{
			yyval.sysFuncCallNode = newNode<SysFuncCallNode>(*yyvsp[-5].metaNamePtr,
				newNode<ValueListNode>(MAKE_const_slong(yyvsp[-3].blrOp))->add(yyvsp[-1].valueExprNode));
			yyval.sysFuncCallNode->dsqlSpecialSyntax = true;
		}
break;
case 1966:
  if (!yytrial)
{ yyval.sysFuncCallNode = newNode<SysFuncCallNode>(*yyvsp[-3].metaNamePtr, newNode<ValueListNode>(yyvsp[-1].valueExprNode)); }
break;
case 1967:
  if (!yytrial)
{
			yyval.sysFuncCallNode = newNode<SysFuncCallNode>(*yyvsp[-5].metaNamePtr,
				newNode<ValueListNode>(yyvsp[-3].valueExprNode)->add(MAKE_str_constant(newIntlString(yyvsp[-1].metaNamePtr->c_str()), CS_ASCII)));
			yyval.sysFuncCallNode->dsqlSpecialSyntax = true;
		}
break;
case 1968:
  if (!yytrial)
{
			yyval.sysFuncCallNode = newNode<SysFuncCallNode>(*yyvsp[-5].metaNamePtr,
				newNode<ValueListNode>(MAKE_const_slong(yyvsp[-3].blrOp))->add(yyvsp[-1].valueExprNode));
			yyval.sysFuncCallNode->dsqlSpecialSyntax = true;
		}
break;
case 1969:
  if (!yytrial)
{
			yyval.sysFuncCallNode = newNode<SysFuncCallNode>(*yyvsp[-9].metaNamePtr,
				newNode<ValueListNode>(yyvsp[-7].valueExprNode)->add(yyvsp[-5].valueExprNode)->add(yyvsp[-3].valueExprNode)->add(yyvsp[-1].valueExprNode));
			yyval.sysFuncCallNode->dsqlSpecialSyntax = true;
		}
break;
case 1970:
  if (!yytrial)
{
			yyval.sysFuncCallNode = newNode<SysFuncCallNode>(*yyvsp[-7].metaNamePtr,
				newNode<ValueListNode>(yyvsp[-5].valueExprNode)->add(yyvsp[-3].valueExprNode)->add(yyvsp[-1].valueExprNode));
			yyval.sysFuncCallNode->dsqlSpecialSyntax = true;
		}
break;
case 1971:
  if (!yytrial)
{
			yyval.sysFuncCallNode = newNode<SysFuncCallNode>(*yyvsp[-5].metaNamePtr, newNode<ValueListNode>(yyvsp[-3].valueExprNode)->add(yyvsp[-1].valueExprNode));
			yyval.sysFuncCallNode->dsqlSpecialSyntax = true;
		}
break;
case 1972:
  if (!yytrial)
{ yyval.sysFuncCallNode = newNode<SysFuncCallNode>(*yyvsp[-3].metaNamePtr, yyvsp[-1].valueListNode); }
break;
case 1973:
  if (!yytrial)
{
			yyval.sysFuncCallNode = newNode<SysFuncCallNode>(*yyvsp[-8].metaNamePtr,
				newNode<ValueListNode>(yyvsp[-6].valueExprNode)->add(yyvsp[-4].valueExprNode)->add(yyvsp[-3].valueExprNode)->
					add(MAKE_str_constant(newIntlString(yyvsp[-2].metaNamePtr->c_str()), CS_ASCII))->add(yyvsp[-1].valueExprNode));
			yyval.sysFuncCallNode->dsqlSpecialSyntax = true;
		}
break;
case 1974:
  if (!yytrial)
{
			yyval.sysFuncCallNode = newNode<SysFuncCallNode>(*yyvsp[-8].metaNamePtr,
				newNode<ValueListNode>(yyvsp[-6].valueExprNode)->add(yyvsp[-4].valueExprNode)->
					add(MAKE_str_constant(newIntlString(yyvsp[-3].metaNamePtr->c_str()), CS_ASCII))->add(yyvsp[-2].valueExprNode)->add(yyvsp[-1].valueExprNode));
			yyval.sysFuncCallNode->dsqlSpecialSyntax = true;
		}
break;
case 1975:
  if (!yytrial)
{
			yyval.sysFuncCallNode = newNode<SysFuncCallNode>(*yyvsp[-10].metaNamePtr,
				newNode<ValueListNode>(yyvsp[-8].valueExprNode)->add(yyvsp[-6].valueExprNode)->add(yyvsp[-4].valueExprNode)->
					add(MAKE_str_constant(newIntlString(yyvsp[-3].metaNamePtr->c_str()), CS_ASCII))->add(yyvsp[-2].valueExprNode)->add(yyvsp[-1].valueExprNode));
			yyval.sysFuncCallNode->dsqlSpecialSyntax = true;
		}
break;
case 1976:
  if (!yytrial)
{
			ValueExprNode* v = MAKE_system_privilege(yyvsp[-1].metaNamePtr->c_str());
			yyval.sysFuncCallNode = newNode<SysFuncCallNode>(*yyvsp[-3].metaNamePtr, newNode<ValueListNode>(v));
		}
break;
case 1981:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_str_constant(newIntlString(""), CS_ASCII); }
break;
case 1982:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1983:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_const_slong(0); }
break;
case 1984:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_const_slong(1); }
break;
case 1985:
  if (!yytrial)
{ yyval.metaNamePtr = newNode<MetaName>(""); }
break;
case 1986:
  if (!yytrial)
{ yyval.metaNamePtr = yyvsp[0].metaNamePtr; }
break;
case 1987:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_str_constant(newIntlString(""), CS_ASCII); }
break;
case 1988:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1989:
  if (!yytrial)
{ yyval.metaNamePtr = newNode<MetaName>(""); }
break;
case 1990:
  if (!yytrial)
{ yyval.metaNamePtr = yyvsp[0].metaNamePtr; }
break;
case 1991:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_str_constant(newIntlString(""), CS_ASCII); }
break;
case 1992:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 1993:
  if (!yytrial)
{ yyval.metaNamePtr = newNode<MetaName>(""); }
break;
case 1994:
  if (!yytrial)
{ yyval.metaNamePtr = yyvsp[0].metaNamePtr; }
break;
case 1997:
  if (!yytrial)
{ yyval.valueExprNode = MAKE_str_constant(newIntlString(""), CS_ASCII); }
break;
case 1998:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 2003:
  if (!yytrial)
{ yyval.blrOp = blr_extract_year; }
break;
case 2004:
  if (!yytrial)
{ yyval.blrOp = blr_extract_month; }
break;
case 2005:
  if (!yytrial)
{ yyval.blrOp = blr_extract_week; }
break;
case 2008:
  if (!yytrial)
{ yyval.valueExprNode = newNode<StrCaseNode>(blr_upcase, yyvsp[-1].valueExprNode); }
break;
case 2009:
  if (!yytrial)
{ yyval.valueExprNode = newNode<StrCaseNode>(blr_lowcase, yyvsp[-1].valueExprNode); }
break;
case 2010:
  if (!yytrial)
{
			/* SQL spec requires numbering to start with 1,*/
			/* hence we decrement the first parameter to make it*/
			/* compatible with the engine's implementation*/
			ArithmeticNode* subtractNode = newNode<ArithmeticNode>(
				blr_subtract, true, yyvsp[-2].valueExprNode, MAKE_const_slong(1));

			yyval.valueExprNode = newNode<SubstringNode>(yyvsp[-4].valueExprNode, subtractNode, yyvsp[-1].valueExprNode);
		}
break;
case 2011:
  if (!yytrial)
{ yyval.valueExprNode = newNode<SubstringSimilarNode>(yyvsp[-5].valueExprNode, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 2012:
  if (!yytrial)
{ yyval.valueExprNode = NULL; }
break;
case 2013:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 2014:
  if (!yytrial)
{ yyval.valueExprNode = newNode<TrimNode>(yyvsp[-4].blrOp, yyvsp[-1].valueExprNode, yyvsp[-3].valueExprNode); }
break;
case 2015:
  if (!yytrial)
{ yyval.valueExprNode = newNode<TrimNode>(blr_trim_both, yyvsp[-1].valueExprNode, yyvsp[-3].valueExprNode); }
break;
case 2016:
  if (!yytrial)
{ yyval.valueExprNode = newNode<TrimNode>(yyvsp[-3].blrOp, yyvsp[-1].valueExprNode); }
break;
case 2017:
  if (!yytrial)
{ yyval.valueExprNode = newNode<TrimNode>(blr_trim_both, yyvsp[-1].valueExprNode); }
break;
case 2018:
  if (!yytrial)
{ yyval.blrOp = blr_trim_both; }
break;
case 2019:
  if (!yytrial)
{ yyval.blrOp = blr_trim_trailing; }
break;
case 2020:
  if (!yytrial)
{ yyval.blrOp = blr_trim_leading; }
break;
case 2021:
  if (!yytrial)
{ yyval.valueExprNode = newNode<UdfCallNode>(QualifiedName(*yyvsp[-3].metaNamePtr, ""), yyvsp[-1].valueListNode); }
break;
case 2022:
  if (!yytrial)
{ yyval.valueExprNode = newNode<UdfCallNode>(QualifiedName(*yyvsp[-2].metaNamePtr, ""), newNode<ValueListNode>(0)); }
break;
case 2023:
  if (!yytrial)
{ yyval.valueExprNode = newNode<UdfCallNode>(QualifiedName(*yyvsp[-3].metaNamePtr, *yyvsp[-5].metaNamePtr), yyvsp[-1].valueListNode); }
break;
case 2024:
  if (!yytrial)
{ yyval.valueExprNode = newNode<UdfCallNode>(QualifiedName(*yyvsp[-2].metaNamePtr, *yyvsp[-4].metaNamePtr), newNode<ValueListNode>(0)); }
break;
case 2025:
  if (!yytrial)
{ yyval.valueExprNode = newNode<CastNode>(yyvsp[-3].valueExprNode, yyvsp[-1].legacyField); }
break;
case 2028:
  if (!yytrial)
{
			ComparativeBoolNode* condition = newNode<ComparativeBoolNode>(blr_eql, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode);
			yyval.valueExprNode = newNode<ValueIfNode>(condition, NullNode::instance(), yyvsp[-3].valueExprNode);
		}
break;
case 2029:
  if (!yytrial)
{ yyval.valueExprNode = newNode<ValueIfNode>(yyvsp[-5].boolExprNode, yyvsp[-3].valueExprNode, yyvsp[-1].valueExprNode); }
break;
case 2030:
  if (!yytrial)
{ yyval.valueExprNode = newNode<CoalesceNode>(yyvsp[-1].valueListNode->addFront(yyvsp[-3].valueExprNode)); }
break;
case 2031:
  if (!yytrial)
{
			ValueListNode* list = yyvsp[-1].valueListNode;
			ValueListNode* conditions = newNode<ValueListNode>(list->items.getCount() / 2);
			ValueListNode* values = newNode<ValueListNode>(list->items.getCount() / 2);

			for (FB_SIZE_T i = 0; i < list->items.getCount(); i += 2)
			{
				conditions->items[i / 2] = list->items[i];
				values->items[i / 2] = list->items[i + 1];
			}

			yyval.valueExprNode = newNode<DecodeNode>(yyvsp[-3].valueExprNode, conditions, values);
		}
break;
case 2032:
  if (!yytrial)
{
			ValueListNode* list = yyvsp[-3].valueListNode;
			ValueListNode* conditions = newNode<ValueListNode>(list->items.getCount() / 2);
			ValueListNode* values = newNode<ValueListNode>(list->items.getCount() / 2 + 1);

			for (FB_SIZE_T i = 0; i < list->items.getCount(); i += 2)
			{
				conditions->items[i / 2] = list->items[i];
				values->items[i / 2] = list->items[i + 1];
			}

			values->items[list->items.getCount() / 2] = yyvsp[-1].valueExprNode;

			yyval.valueExprNode = newNode<DecodeNode>(yyvsp[-5].valueExprNode, conditions, values);
		}
break;
case 2033:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].decodeNode; }
break;
case 2034:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 2035:
  if (!yytrial)
{ yyval.decodeNode = newNode<DecodeNode>(yyvsp[0].valueExprNode, newNode<ValueListNode>(0u), newNode<ValueListNode>(0u)); }
break;
case 2036:
yyval.valueListNode = NOTRIAL(yyvsp[0].decodeNode->conditions);
break;
case 2037:
yyval.valueListNode =  NOTRIAL(yyvsp[-1].decodeNode->values);
break;
case 2038:
  if (!yytrial)
{
				DecodeNode* node = yyval.decodeNode = yyvsp[-5].decodeNode;
				node->label = "CASE";
				if (yyvsp[-1].valueExprNode)
					node->values->add(yyvsp[-1].valueExprNode);
			}
break;
case 2039:
  if (!yytrial)
{
			yyvsp[-5].valueListNode->add(yyvsp[-2].valueExprNode);
			yyvsp[-4].valueListNode->add(yyvsp[0].valueExprNode);
		}
break;
case 2040:
  if (!yytrial)
{
			yyvsp[-6].valueListNode->add(yyvsp[-2].valueExprNode);
			yyvsp[-5].valueListNode->add(yyvsp[0].valueExprNode);
		}
break;
case 2041:
  if (!yytrial)
{ yyval.valueExprNode = NULL; }
break;
case 2042:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[0].valueExprNode; }
break;
case 2043:
  if (!yytrial)
{ yyval.valueExprNode = yyvsp[-1].valueIfNode; }
break;
case 2044:
  if (!yytrial)
{
			ValueIfNode* last = yyvsp[-3].valueIfNode;
			ValueIfNode* next;

			while ((next = nodeAs<ValueIfNode>(last->falseValue)))
				last = next;

			fb_assert(nodeIs<NullNode>(last->falseValue));

			last->falseValue = yyvsp[-1].valueExprNode;
			yyval.valueExprNode = yyvsp[-3].valueIfNode;
		}
break;
case 2045:
  if (!yytrial)
{ yyval.valueIfNode = newNode<ValueIfNode>(yyvsp[-2].boolExprNode, yyvsp[0].valueExprNode, NullNode::instance()); }
break;
case 2046:
  if (!yytrial)
{
			ValueIfNode* cond = newNode<ValueIfNode>(yyvsp[-2].boolExprNode, yyvsp[0].valueExprNode, NullNode::instance());
			ValueIfNode* last = yyvsp[-4].valueIfNode;
			ValueIfNode* next;

			while ((next = nodeAs<ValueIfNode>(last->falseValue)))
				last = next;

			fb_assert(nodeIs<NullNode>(last->falseValue));

			last->falseValue = cond;
			yyval.valueIfNode = yyvsp[-4].valueIfNode;
		}
break;
case 2050:
  if (!yytrial)
{ yyval.valueListNode = newNode<ValueListNode>(0u)->add(yyvsp[-2].valueExprNode)->add(yyvsp[0].valueExprNode); }
break;
case 2051:
  if (!yytrial)
{ yyval.valueListNode = yyvsp[-4].valueListNode->add(yyvsp[-2].valueExprNode)->add(yyvsp[0].valueExprNode); }
break;
case 2052:
  if (!yytrial)
{
			yyval.valueExprNode = newNode<GenIdNode>((client_dialect < SQL_DIALECT_V6_TRANSITION),
				*yyvsp[0].metaNamePtr, ((Jrd::ValueExprNode*) NULL), true, false);
		}
break;
case 2053:
  if (!yytrial)
{
			yyval.valueExprNode = newNode<GenIdNode>((client_dialect < SQL_DIALECT_V6_TRANSITION),
				*yyvsp[-3].metaNamePtr, yyvsp[-1].valueExprNode, false, false);
		}
break;
case 2054:
  if (!yytrial)
{ yyval.blrOp = blr_extract_year; }
break;
case 2055:
  if (!yytrial)
{ yyval.blrOp = blr_extract_month; }
break;
case 2056:
  if (!yytrial)
{ yyval.blrOp = blr_extract_day; }
break;
case 2057:
  if (!yytrial)
{ yyval.blrOp = blr_extract_hour; }
break;
case 2058:
  if (!yytrial)
{ yyval.blrOp = blr_extract_minute; }
break;
case 2059:
  if (!yytrial)
{ yyval.blrOp = blr_extract_second; }
break;
case 2060:
  if (!yytrial)
{ yyval.blrOp = blr_extract_millisecond; }
break;
case 2061:
  if (!yytrial)
{ yyval.blrOp = blr_extract_timezone_hour; }
break;
case 2062:
  if (!yytrial)
{ yyval.blrOp = blr_extract_timezone_minute; }
break;
case 2063:
  if (!yytrial)
{ yyval.blrOp = blr_extract_week; }
break;
case 2064:
  if (!yytrial)
{ yyval.blrOp = blr_extract_weekday; }
break;
case 2065:
  if (!yytrial)
{ yyval.blrOp = blr_extract_yearday; }
break;
case 2070:
  if (!yytrial)
{ yyval.valueExprNode = NullNode::instance(); }
break;
case 2071:
  if (!yytrial)
{
			dsql_fld* field = newNode<dsql_fld>();
			field->dtype = dtype_boolean;
			field->length = sizeof(UCHAR);

			CastNode* castNode = newNode<CastNode>(NullNode::instance(), field);
			castNode->dsqlAlias = "CONSTANT";
			yyval.valueExprNode = castNode;
		}
break;

  default:
    break;
  }

#if YYDEBUG && defined(YYDBPR)
  if (yydebug) {
    printf("yydebug[%d]: after reduction, result is ", yytrial);
    YYDBPR(yyps->val);
    printf("\n");
  }
#endif

  // Perform user-defined position reduction
#ifdef YYREDUCEPOSNFUNC
  if (!yytrial) {
    YYCALLREDUCEPOSN(YYREDUCEPOSNFUNCARG);
  }
#endif

  yyps->ssp -= yym;
  yystate = *(yyps->ssp);
  yyps->vsp -= yym;
  yyps->psp -= yym;

  yym = yylhs[yyn];
  if (yystate == 0 && yym == 0) {
#if YYDEBUG
    if (yydebug) {
      printf("yydebug[%d,%p]: after reduction, shifting from state 0 to state %d\n",
	     int(yydepth), yytrial, YYFINAL);
    }
#endif
    yystate = YYFINAL;
    *++(yyps->ssp) = YYFINAL;
    *++(yyps->vsp) = yyps->val;
    yyretlval = yyps->val;	// return value of root non-terminal to yylval
    *++(yyps->psp) = yyps->pos;
    yyretposn = yyps->pos;	// return value of root position to yyposn
    if (yychar < 0) {
      if ((yychar = yylex1()) < 0) {
        yychar = 0;
      }
#if YYDEBUG
      if (yydebug) {
        yys = 0;
        if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
        if (!yys) yys = "illegal-symbol";
        printf("yydebug[%d,%p]: state %d, reading %d (%s)\n",
	       int(yydepth), yytrial, YYFINAL, yychar, yys);
      }
#endif
    }
    if (yychar == 0) goto yyaccept;
    goto yyloop;
  }

  if ((yyn = yygindex[yym]) && (yyn += yystate) >= 0 &&
      yyn <= YYTABLESIZE && yycheck[yyn] == yystate) {
    yystate = yytable[yyn];
  } else {
    yystate = yydgoto[yym];
  }
#if YYDEBUG
  if (yydebug)
    printf("yydebug[%d,%p]: after reduction, shifting from state %d to state %d\n",
           int(yydepth), yytrial, *(yyps->ssp), yystate);
#endif
  if (yyps->ssp >= yyps->ss + yyps->stacksize - 1) {
    yyMoreStack(yyps);
  }
  *++(yyps->ssp) = yystate;
  *++(yyps->vsp) = yyps->val;
  *++(yyps->psp) = yyps->pos;
  goto yyloop;


  //
  // Reduction declares that this path is valid.
  // Set yypath and do a full parse
  //
yyvalid:
  if (yypath) {
    goto yyabort;
  }
  while (yyps->save) {
    yyparsestate *save = yyps->save;
    yyps->save = save->save;
    save->save = yypath;
    yypath = save;
  }
#if YYDEBUG
  if (yydebug)
    printf("yydebug[%d,%p]: CONFLICT trial successful, backtracking to state %d, %d tokens\n",
           int(yydepth), yytrial, yypath->state, int(yylvp - yylvals - yypath->lexeme));
#endif
  if (yyerrctx) {
    yyFreeState(yyerrctx);
    yyerrctx = NULL;
  }
  yychar = -1;
  yyps->ssp = yyps->ss + (yypath->ssp - yypath->ss);
  yyps->vsp = yyps->vs + (yypath->vsp - yypath->vs);
  yyps->psp = yyps->ps + (yypath->psp - yypath->ps);
  memcpy (yyps->ss, yypath->ss, (yyps->ssp - yyps->ss + 1) * sizeof(Yshort));
  yySCopy(yyps->vs, yypath->vs,  yyps->vsp - yyps->vs + 1);
  yyPCopy(yyps->ps, yypath->ps,  yyps->psp - yyps->ps + 1);
  yylvp = yylvals + yypath->lexeme;
  yylpp = yylpsns + yypath->lexeme;
  yylexp = yylexemes + yypath->lexeme;
  yystate = yypath->state;
  goto yyloop;


yyabort:
  if (yyerrctx) {
    yyFreeState(yyerrctx);
    yyerrctx = NULL;
  }

  YYSTYPE *pv;
  for(pv = yyps->vs; pv < yyps->vsp; pv++) {
    YYDELETEVAL(*pv, 2);
  }

  YYPOSN *pp;
  for(pp = yyps->ps; pp < yyps->psp; pp++) {
    YYDELETEPOSN(*pp, 2);
  }

  while (yyps) {
    yyparsestate *save = yyps;
    yyps = save->save;
    yyFreeState(save);
  }
  while (yypath) {
    yyparsestate *save = yypath;
    yypath = save->save;
    yyFreeState(save);
  }
  return (1);


yyaccept:
  if (yyps->save) goto yyvalid;
  if (yyerrctx) {
    yyFreeState(yyerrctx);
    yyerrctx = NULL;
  }
  while (yyps) {
    yyparsestate *save = yyps;
    yyps = save->save;
    yyFreeState(save);
  }
  while (yypath) {
    yyparsestate *save = yypath;
    yypath = save->save;
    yyFreeState(save);
  }
  return (0);
}


int Parser::yylex1()
{
  if (yylvp < yylve) {
    yylval = *yylvp++;
    yyposn = *yylpp++;
    return *yylexp++;
  } else {
    if (yyps->save) {
      if (yylvp == yylvlim) {
	yyexpand();
      }
      *yylexp = yylex();
      *yylvp++ = yylval;
      yylve++;
      *yylpp++ = yyposn;
      yylpe++;
      return *yylexp++;
    } else {
      return yylex();
    }
  }
}


int Parser::yyexpand()
{
  int p = yylvp - yylvals;
  int s = yylvlim - yylvals;
  s += YYSTACKGROWTH;
  { Yshort  *tl = yylexemes;
    YYSTYPE *tv = yylvals;
    YYPOSN  *tp = yylpsns;
    yylvals = FB_NEW_POOL(getPool()) YYSTYPE[s];
    yylpsns = FB_NEW_POOL(getPool()) YYPOSN[s];
    yylexemes = FB_NEW_POOL(getPool()) Yshort[s];
    memcpy(yylexemes, tl, (s - YYSTACKGROWTH) * sizeof(Yshort));
    yySCopy(yylvals, tv, s - YYSTACKGROWTH);
    yyPCopy(yylpsns, tp, s - YYSTACKGROWTH);
    delete[] tl;
    delete[] tv;
    delete[] tp;
  }
  yylvp = yylve = yylvals + p;
  yylvlim = yylvals + s;
  yylpp = yylpe = yylpsns + p;
  yylplim = yylpsns + s;
  yylexp = yylexemes + p;
  return 0;
}

